/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 414
#define LARGE_STATE_COUNT 117
#define SYMBOL_COUNT 159
#define ALIAS_COUNT 3
#define TOKEN_COUNT 102
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 17
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define MAX_RESERVED_WORD_SET_SIZE 45
#define PRODUCTION_ID_COUNT 30
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_COMMA = 2,
  anon_sym_SEMI = 3,
  anon_sym_LPAREN = 4,
  anon_sym_RPAREN = 5,
  anon_sym_EQ = 6,
  aux_sym_execute_statement_token1 = 7,
  anon_sym_TILDE = 8,
  anon_sym_COLON = 9,
  anon_sym_DASH = 10,
  anon_sym_PLUS = 11,
  anon_sym_LT_GT = 12,
  anon_sym_GT = 13,
  anon_sym_LT = 14,
  anon_sym_GT_EQ = 15,
  anon_sym_LT_EQ = 16,
  anon_sym_STAR = 17,
  anon_sym_SLASH = 18,
  anon_sym_PERCENT = 19,
  anon_sym_QMARK_LPAREN = 20,
  anon_sym_DOT = 21,
  anon_sym_LBRACK = 22,
  anon_sym_RBRACK = 23,
  sym_IF_KEYWORD = 24,
  sym_THEN_KEYWORD = 25,
  sym_ELSIF_KEYWORD = 26,
  sym_ELSE_KEYWORD = 27,
  sym_ENDIF_KEYWORD = 28,
  sym_FOR_KEYWORD = 29,
  sym_EACH_KEYWORD = 30,
  sym_IN_KEYWORD = 31,
  sym_TO_KEYWORD = 32,
  sym_WHILE_KEYWORD = 33,
  sym_DO_KEYWORD = 34,
  sym_ENDDO_KEYWORD = 35,
  sym_GOTO_KEYWORD = 36,
  sym_RETURN_KEYWORD = 37,
  sym_BREAK_KEYWORD = 38,
  sym_CONTINUE_KEYWORD = 39,
  sym_PROCEDURE_KEYWORD = 40,
  sym_FUNCTION_KEYWORD = 41,
  sym_ENDPROCEDURE_KEYWORD = 42,
  sym_ENDFUNCTION_KEYWORD = 43,
  sym_VAR_KEYWORD = 44,
  sym_EXPORT_KEYWORD = 45,
  sym_VAL_KEYWORD = 46,
  sym_TRUE_KEYWORD = 47,
  sym_FALSE_KEYWORD = 48,
  sym_UNDEFINED_KEYWORD = 49,
  sym_TRY_KEYWORD = 50,
  sym_EXCEPT_KEYWORD = 51,
  sym_RAISE_KEYWORD = 52,
  sym_ENDTRY_KEYWORD = 53,
  sym_ASYNC_KEYWORD = 54,
  sym_AWAIT_KEYWORD = 55,
  sym_NEW_KEYWORD = 56,
  sym_ADDHANDLER_KEYWORD = 57,
  sym_REMOVEHANDLER_KEYWORD = 58,
  sym_AND_KEYWORD = 59,
  sym_OR_KEYWORD = 60,
  sym_NOT_KEYWORD = 61,
  sym_PREPROC_IF_KEYWORD = 62,
  sym_PREPROC_ELSIF_KEYWORD = 63,
  sym_PREPROC_ELSE_KEYWORD = 64,
  sym_PREPROC_ENDIF_KEYWORD = 65,
  sym_PREPROC_REGION_KEYWORD = 66,
  sym_PREPROC_ENDREGION_KEYWORD = 67,
  sym_NULL_KEYWORD = 68,
  aux_sym_preprocessor_token1 = 69,
  aux_sym_preprocessor_token2 = 70,
  aux_sym_preprocessor_token3 = 71,
  aux_sym_preprocessor_token4 = 72,
  aux_sym_preprocessor_token5 = 73,
  aux_sym_preprocessor_token6 = 74,
  aux_sym_preprocessor_token7 = 75,
  aux_sym_preprocessor_token8 = 76,
  aux_sym_preprocessor_token9 = 77,
  aux_sym_preprocessor_token10 = 78,
  aux_sym_preprocessor_token11 = 79,
  aux_sym_preprocessor_token12 = 80,
  aux_sym_preprocessor_token13 = 81,
  aux_sym_preprocessor_token14 = 82,
  aux_sym_preprocessor_token15 = 83,
  aux_sym_preprocessor_token16 = 84,
  aux_sym_preprocessor_token17 = 85,
  aux_sym_preprocessor_token18 = 86,
  aux_sym_preprocessor_token19 = 87,
  aux_sym_preprocessor_token20 = 88,
  aux_sym_preprocessor_token21 = 89,
  aux_sym_preprocessor_token22 = 90,
  aux_sym_preprocessor_token23 = 91,
  aux_sym_preprocessor_token24 = 92,
  aux_sym_preprocessor_token25 = 93,
  aux_sym_preprocessor_token26 = 94,
  sym_number = 95,
  sym_date = 96,
  anon_sym_DQUOTE = 97,
  aux_sym_string_token1 = 98,
  anon_sym_PIPE = 99,
  anon_sym_SLASH_SLASH = 100,
  aux_sym_line_comment_token1 = 101,
  sym_source_file = 102,
  sym__definition = 103,
  sym_procedure_definition = 104,
  sym_function_definition = 105,
  sym_var_definition = 106,
  sym_parameters = 107,
  sym_parameter = 108,
  sym__statement = 109,
  sym_call_statement = 110,
  sym_assignment_statement = 111,
  sym_return_statement = 112,
  sym_try_statement = 113,
  sym_rise_error_statement = 114,
  sym_var_statement = 115,
  sym_if_statement = 116,
  sym_elseif_clause = 117,
  sym_else_clause = 118,
  sym_while_statement = 119,
  sym_for_statement = 120,
  sym_for_each_statement = 121,
  sym_continue_statement = 122,
  sym_break_statement = 123,
  sym_execute_statement = 124,
  sym_goto_statement = 125,
  sym_label_statement = 126,
  sym_add_handler_statement = 127,
  sym_remove_handler_statement = 128,
  sym_await_statement = 129,
  sym_expression = 130,
  sym_unary_expression = 131,
  sym_binary_expression = 132,
  sym_ternary_expression = 133,
  sym_new_expression = 134,
  sym_new_expression_method = 135,
  sym_call_expression = 136,
  sym_await_expression = 137,
  sym__assignment_member = 138,
  sym_property_access = 139,
  sym_access = 140,
  sym__access_call = 141,
  sym__access_index = 142,
  sym__access_property = 143,
  sym_method_call = 144,
  sym_arguments = 145,
  sym_preprocessor = 146,
  sym__const_value = 147,
  sym_boolean = 148,
  sym_string = 149,
  sym_multiline_string = 150,
  sym_line_comment = 151,
  aux_sym_source_file_repeat1 = 152,
  aux_sym_procedure_definition_repeat1 = 153,
  aux_sym_var_definition_repeat1 = 154,
  aux_sym_parameters_repeat1 = 155,
  aux_sym_if_statement_repeat1 = 156,
  aux_sym_arguments_repeat1 = 157,
  aux_sym_multiline_string_repeat1 = 158,
  alias_sym_const_expression = 159,
  alias_sym_index = 160,
  alias_sym_property = 161,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_COMMA] = ",",
  [anon_sym_SEMI] = ";",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_EQ] = "=",
  [aux_sym_execute_statement_token1] = "execute_statement_token1",
  [anon_sym_TILDE] = "~",
  [anon_sym_COLON] = ":",
  [anon_sym_DASH] = "operator",
  [anon_sym_PLUS] = "operator",
  [anon_sym_LT_GT] = "operator",
  [anon_sym_GT] = "operator",
  [anon_sym_LT] = "operator",
  [anon_sym_GT_EQ] = "operator",
  [anon_sym_LT_EQ] = "operator",
  [anon_sym_STAR] = "operator",
  [anon_sym_SLASH] = "operator",
  [anon_sym_PERCENT] = "operator",
  [anon_sym_QMARK_LPAREN] = "\?(",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [sym_IF_KEYWORD] = "IF_KEYWORD",
  [sym_THEN_KEYWORD] = "THEN_KEYWORD",
  [sym_ELSIF_KEYWORD] = "ELSIF_KEYWORD",
  [sym_ELSE_KEYWORD] = "ELSE_KEYWORD",
  [sym_ENDIF_KEYWORD] = "ENDIF_KEYWORD",
  [sym_FOR_KEYWORD] = "FOR_KEYWORD",
  [sym_EACH_KEYWORD] = "EACH_KEYWORD",
  [sym_IN_KEYWORD] = "IN_KEYWORD",
  [sym_TO_KEYWORD] = "TO_KEYWORD",
  [sym_WHILE_KEYWORD] = "WHILE_KEYWORD",
  [sym_DO_KEYWORD] = "DO_KEYWORD",
  [sym_ENDDO_KEYWORD] = "ENDDO_KEYWORD",
  [sym_GOTO_KEYWORD] = "GOTO_KEYWORD",
  [sym_RETURN_KEYWORD] = "RETURN_KEYWORD",
  [sym_BREAK_KEYWORD] = "BREAK_KEYWORD",
  [sym_CONTINUE_KEYWORD] = "CONTINUE_KEYWORD",
  [sym_PROCEDURE_KEYWORD] = "PROCEDURE_KEYWORD",
  [sym_FUNCTION_KEYWORD] = "FUNCTION_KEYWORD",
  [sym_ENDPROCEDURE_KEYWORD] = "ENDPROCEDURE_KEYWORD",
  [sym_ENDFUNCTION_KEYWORD] = "ENDFUNCTION_KEYWORD",
  [sym_VAR_KEYWORD] = "VAR_KEYWORD",
  [sym_EXPORT_KEYWORD] = "EXPORT_KEYWORD",
  [sym_VAL_KEYWORD] = "VAL_KEYWORD",
  [sym_TRUE_KEYWORD] = "TRUE_KEYWORD",
  [sym_FALSE_KEYWORD] = "FALSE_KEYWORD",
  [sym_UNDEFINED_KEYWORD] = "UNDEFINED_KEYWORD",
  [sym_TRY_KEYWORD] = "TRY_KEYWORD",
  [sym_EXCEPT_KEYWORD] = "EXCEPT_KEYWORD",
  [sym_RAISE_KEYWORD] = "RAISE_KEYWORD",
  [sym_ENDTRY_KEYWORD] = "ENDTRY_KEYWORD",
  [sym_ASYNC_KEYWORD] = "ASYNC_KEYWORD",
  [sym_AWAIT_KEYWORD] = "AWAIT_KEYWORD",
  [sym_NEW_KEYWORD] = "NEW_KEYWORD",
  [sym_ADDHANDLER_KEYWORD] = "ADDHANDLER_KEYWORD",
  [sym_REMOVEHANDLER_KEYWORD] = "REMOVEHANDLER_KEYWORD",
  [sym_AND_KEYWORD] = "operator",
  [sym_OR_KEYWORD] = "operator",
  [sym_NOT_KEYWORD] = "operator",
  [sym_PREPROC_IF_KEYWORD] = "PREPROC_IF_KEYWORD",
  [sym_PREPROC_ELSIF_KEYWORD] = "PREPROC_ELSIF_KEYWORD",
  [sym_PREPROC_ELSE_KEYWORD] = "PREPROC_ELSE_KEYWORD",
  [sym_PREPROC_ENDIF_KEYWORD] = "PREPROC_ENDIF_KEYWORD",
  [sym_PREPROC_REGION_KEYWORD] = "PREPROC_REGION_KEYWORD",
  [sym_PREPROC_ENDREGION_KEYWORD] = "PREPROC_ENDREGION_KEYWORD",
  [sym_NULL_KEYWORD] = "NULL_KEYWORD",
  [aux_sym_preprocessor_token1] = "preproc",
  [aux_sym_preprocessor_token2] = "preproc",
  [aux_sym_preprocessor_token3] = "preproc",
  [aux_sym_preprocessor_token4] = "preproc",
  [aux_sym_preprocessor_token5] = "preproc",
  [aux_sym_preprocessor_token6] = "preproc",
  [aux_sym_preprocessor_token7] = "preproc",
  [aux_sym_preprocessor_token8] = "preproc",
  [aux_sym_preprocessor_token9] = "annotation",
  [aux_sym_preprocessor_token10] = "annotation",
  [aux_sym_preprocessor_token11] = "annotation",
  [aux_sym_preprocessor_token12] = "annotation",
  [aux_sym_preprocessor_token13] = "annotation",
  [aux_sym_preprocessor_token14] = "annotation",
  [aux_sym_preprocessor_token15] = "annotation",
  [aux_sym_preprocessor_token16] = "annotation",
  [aux_sym_preprocessor_token17] = "annotation",
  [aux_sym_preprocessor_token18] = "annotation",
  [aux_sym_preprocessor_token19] = "annotation",
  [aux_sym_preprocessor_token20] = "annotation",
  [aux_sym_preprocessor_token21] = "annotation",
  [aux_sym_preprocessor_token22] = "annotation",
  [aux_sym_preprocessor_token23] = "annotation",
  [aux_sym_preprocessor_token24] = "annotation",
  [aux_sym_preprocessor_token25] = "annotation",
  [aux_sym_preprocessor_token26] = "annotation",
  [sym_number] = "number",
  [sym_date] = "date",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_token1] = "string_content",
  [anon_sym_PIPE] = "|",
  [anon_sym_SLASH_SLASH] = "//",
  [aux_sym_line_comment_token1] = "line_comment_token1",
  [sym_source_file] = "source_file",
  [sym__definition] = "_definition",
  [sym_procedure_definition] = "procedure_definition",
  [sym_function_definition] = "function_definition",
  [sym_var_definition] = "var_definition",
  [sym_parameters] = "parameters",
  [sym_parameter] = "parameter",
  [sym__statement] = "_statement",
  [sym_call_statement] = "call_statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym_return_statement] = "return_statement",
  [sym_try_statement] = "try_statement",
  [sym_rise_error_statement] = "rise_error_statement",
  [sym_var_statement] = "var_statement",
  [sym_if_statement] = "if_statement",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_while_statement] = "while_statement",
  [sym_for_statement] = "for_statement",
  [sym_for_each_statement] = "for_each_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_execute_statement] = "execute_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_label_statement] = "label_statement",
  [sym_add_handler_statement] = "add_handler_statement",
  [sym_remove_handler_statement] = "remove_handler_statement",
  [sym_await_statement] = "await_statement",
  [sym_expression] = "expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_new_expression] = "new_expression",
  [sym_new_expression_method] = "new_expression_method",
  [sym_call_expression] = "call_expression",
  [sym_await_expression] = "await_expression",
  [sym__assignment_member] = "_assignment_member",
  [sym_property_access] = "property_access",
  [sym_access] = "access",
  [sym__access_call] = "_access_call",
  [sym__access_index] = "_access_index",
  [sym__access_property] = "_access_property",
  [sym_method_call] = "method_call",
  [sym_arguments] = "arguments",
  [sym_preprocessor] = "preprocessor",
  [sym__const_value] = "_const_value",
  [sym_boolean] = "boolean",
  [sym_string] = "string",
  [sym_multiline_string] = "string",
  [sym_line_comment] = "line_comment",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_procedure_definition_repeat1] = "procedure_definition_repeat1",
  [aux_sym_var_definition_repeat1] = "var_definition_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_multiline_string_repeat1] = "multiline_string_repeat1",
  [alias_sym_const_expression] = "const_expression",
  [alias_sym_index] = "index",
  [alias_sym_property] = "property",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_EQ] = anon_sym_EQ,
  [aux_sym_execute_statement_token1] = aux_sym_execute_statement_token1,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_DASH,
  [anon_sym_LT_GT] = anon_sym_DASH,
  [anon_sym_GT] = anon_sym_DASH,
  [anon_sym_LT] = anon_sym_DASH,
  [anon_sym_GT_EQ] = anon_sym_DASH,
  [anon_sym_LT_EQ] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_DASH,
  [anon_sym_PERCENT] = anon_sym_DASH,
  [anon_sym_QMARK_LPAREN] = anon_sym_QMARK_LPAREN,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [sym_IF_KEYWORD] = sym_IF_KEYWORD,
  [sym_THEN_KEYWORD] = sym_THEN_KEYWORD,
  [sym_ELSIF_KEYWORD] = sym_ELSIF_KEYWORD,
  [sym_ELSE_KEYWORD] = sym_ELSE_KEYWORD,
  [sym_ENDIF_KEYWORD] = sym_ENDIF_KEYWORD,
  [sym_FOR_KEYWORD] = sym_FOR_KEYWORD,
  [sym_EACH_KEYWORD] = sym_EACH_KEYWORD,
  [sym_IN_KEYWORD] = sym_IN_KEYWORD,
  [sym_TO_KEYWORD] = sym_TO_KEYWORD,
  [sym_WHILE_KEYWORD] = sym_WHILE_KEYWORD,
  [sym_DO_KEYWORD] = sym_DO_KEYWORD,
  [sym_ENDDO_KEYWORD] = sym_ENDDO_KEYWORD,
  [sym_GOTO_KEYWORD] = sym_GOTO_KEYWORD,
  [sym_RETURN_KEYWORD] = sym_RETURN_KEYWORD,
  [sym_BREAK_KEYWORD] = sym_BREAK_KEYWORD,
  [sym_CONTINUE_KEYWORD] = sym_CONTINUE_KEYWORD,
  [sym_PROCEDURE_KEYWORD] = sym_PROCEDURE_KEYWORD,
  [sym_FUNCTION_KEYWORD] = sym_FUNCTION_KEYWORD,
  [sym_ENDPROCEDURE_KEYWORD] = sym_ENDPROCEDURE_KEYWORD,
  [sym_ENDFUNCTION_KEYWORD] = sym_ENDFUNCTION_KEYWORD,
  [sym_VAR_KEYWORD] = sym_VAR_KEYWORD,
  [sym_EXPORT_KEYWORD] = sym_EXPORT_KEYWORD,
  [sym_VAL_KEYWORD] = sym_VAL_KEYWORD,
  [sym_TRUE_KEYWORD] = sym_TRUE_KEYWORD,
  [sym_FALSE_KEYWORD] = sym_FALSE_KEYWORD,
  [sym_UNDEFINED_KEYWORD] = sym_UNDEFINED_KEYWORD,
  [sym_TRY_KEYWORD] = sym_TRY_KEYWORD,
  [sym_EXCEPT_KEYWORD] = sym_EXCEPT_KEYWORD,
  [sym_RAISE_KEYWORD] = sym_RAISE_KEYWORD,
  [sym_ENDTRY_KEYWORD] = sym_ENDTRY_KEYWORD,
  [sym_ASYNC_KEYWORD] = sym_ASYNC_KEYWORD,
  [sym_AWAIT_KEYWORD] = sym_AWAIT_KEYWORD,
  [sym_NEW_KEYWORD] = sym_NEW_KEYWORD,
  [sym_ADDHANDLER_KEYWORD] = sym_ADDHANDLER_KEYWORD,
  [sym_REMOVEHANDLER_KEYWORD] = sym_REMOVEHANDLER_KEYWORD,
  [sym_AND_KEYWORD] = anon_sym_DASH,
  [sym_OR_KEYWORD] = anon_sym_DASH,
  [sym_NOT_KEYWORD] = anon_sym_DASH,
  [sym_PREPROC_IF_KEYWORD] = sym_PREPROC_IF_KEYWORD,
  [sym_PREPROC_ELSIF_KEYWORD] = sym_PREPROC_ELSIF_KEYWORD,
  [sym_PREPROC_ELSE_KEYWORD] = sym_PREPROC_ELSE_KEYWORD,
  [sym_PREPROC_ENDIF_KEYWORD] = sym_PREPROC_ENDIF_KEYWORD,
  [sym_PREPROC_REGION_KEYWORD] = sym_PREPROC_REGION_KEYWORD,
  [sym_PREPROC_ENDREGION_KEYWORD] = sym_PREPROC_ENDREGION_KEYWORD,
  [sym_NULL_KEYWORD] = sym_NULL_KEYWORD,
  [aux_sym_preprocessor_token1] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token2] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token3] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token4] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token5] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token6] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token7] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token8] = aux_sym_preprocessor_token1,
  [aux_sym_preprocessor_token9] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token10] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token11] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token12] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token13] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token14] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token15] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token16] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token17] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token18] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token19] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token20] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token21] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token22] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token23] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token24] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token25] = aux_sym_preprocessor_token9,
  [aux_sym_preprocessor_token26] = aux_sym_preprocessor_token9,
  [sym_number] = sym_number,
  [sym_date] = sym_date,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [aux_sym_line_comment_token1] = aux_sym_line_comment_token1,
  [sym_source_file] = sym_source_file,
  [sym__definition] = sym__definition,
  [sym_procedure_definition] = sym_procedure_definition,
  [sym_function_definition] = sym_function_definition,
  [sym_var_definition] = sym_var_definition,
  [sym_parameters] = sym_parameters,
  [sym_parameter] = sym_parameter,
  [sym__statement] = sym__statement,
  [sym_call_statement] = sym_call_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_rise_error_statement] = sym_rise_error_statement,
  [sym_var_statement] = sym_var_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_while_statement] = sym_while_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_for_each_statement] = sym_for_each_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_execute_statement] = sym_execute_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_label_statement] = sym_label_statement,
  [sym_add_handler_statement] = sym_add_handler_statement,
  [sym_remove_handler_statement] = sym_remove_handler_statement,
  [sym_await_statement] = sym_await_statement,
  [sym_expression] = sym_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_new_expression_method] = sym_new_expression_method,
  [sym_call_expression] = sym_call_expression,
  [sym_await_expression] = sym_await_expression,
  [sym__assignment_member] = sym__assignment_member,
  [sym_property_access] = sym_property_access,
  [sym_access] = sym_access,
  [sym__access_call] = sym__access_call,
  [sym__access_index] = sym__access_index,
  [sym__access_property] = sym__access_property,
  [sym_method_call] = sym_method_call,
  [sym_arguments] = sym_arguments,
  [sym_preprocessor] = sym_preprocessor,
  [sym__const_value] = sym__const_value,
  [sym_boolean] = sym_boolean,
  [sym_string] = sym_string,
  [sym_multiline_string] = sym_string,
  [sym_line_comment] = sym_line_comment,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_procedure_definition_repeat1] = aux_sym_procedure_definition_repeat1,
  [aux_sym_var_definition_repeat1] = aux_sym_var_definition_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_multiline_string_repeat1] = aux_sym_multiline_string_repeat1,
  [alias_sym_const_expression] = alias_sym_const_expression,
  [alias_sym_index] = alias_sym_index,
  [alias_sym_property] = alias_sym_property,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_execute_statement_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT_GT] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_QMARK_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [sym_IF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_THEN_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ELSIF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ELSE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ENDIF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_FOR_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_EACH_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_IN_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_TO_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_WHILE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_DO_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ENDDO_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_GOTO_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_RETURN_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_BREAK_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_CONTINUE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PROCEDURE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_FUNCTION_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ENDPROCEDURE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ENDFUNCTION_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_VAR_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_EXPORT_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_VAL_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_TRUE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_FALSE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_UNDEFINED_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_TRY_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_EXCEPT_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_RAISE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ENDTRY_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ASYNC_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_AWAIT_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_NEW_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_ADDHANDLER_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_REMOVEHANDLER_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_AND_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_OR_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_NOT_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_IF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_ELSIF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_ELSE_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_ENDIF_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_REGION_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_PREPROC_ENDREGION_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [sym_NULL_KEYWORD] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token4] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token5] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token6] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token7] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token8] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token9] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token10] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token11] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token12] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token13] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token14] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token15] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token16] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token17] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token18] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token19] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token20] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token21] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token22] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token23] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token24] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token25] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preprocessor_token26] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_date] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_line_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__definition] = {
    .visible = false,
    .named = true,
  },
  [sym_procedure_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_var_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_call_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_rise_error_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_var_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_each_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_execute_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_label_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_add_handler_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_remove_handler_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_await_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression_method] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_member] = {
    .visible = false,
    .named = true,
  },
  [sym_property_access] = {
    .visible = true,
    .named = true,
  },
  [sym_access] = {
    .visible = true,
    .named = true,
  },
  [sym__access_call] = {
    .visible = false,
    .named = true,
  },
  [sym__access_index] = {
    .visible = false,
    .named = true,
  },
  [sym__access_property] = {
    .visible = false,
    .named = true,
  },
  [sym_method_call] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_preprocessor] = {
    .visible = true,
    .named = true,
  },
  [sym__const_value] = {
    .visible = false,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_multiline_string] = {
    .visible = true,
    .named = true,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_procedure_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_var_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multiline_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_const_expression] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_index] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_property] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_condition = 4,
  field_consequence = 5,
  field_def = 6,
  field_export = 7,
  field_left = 8,
  field_name = 9,
  field_operator = 10,
  field_parameter = 11,
  field_parameters = 12,
  field_result = 13,
  field_right = 14,
  field_type = 15,
  field_val = 16,
  field_var_name = 17,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_def] = "def",
  [field_export] = "export",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameter] = "parameter",
  [field_parameters] = "parameters",
  [field_result] = "result",
  [field_right] = "right",
  [field_type] = "type",
  [field_val] = "val",
  [field_var_name] = "var_name",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 2},
  [5] = {.index = 4, .length = 2},
  [6] = {.index = 6, .length = 1},
  [7] = {.index = 7, .length = 2},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 2},
  [11] = {.index = 13, .length = 1},
  [12] = {.index = 14, .length = 2},
  [13] = {.index = 16, .length = 3},
  [14] = {.index = 19, .length = 1},
  [15] = {.index = 20, .length = 2},
  [16] = {.index = 22, .length = 3},
  [17] = {.index = 25, .length = 2},
  [19] = {.index = 27, .length = 2},
  [20] = {.index = 29, .length = 1},
  [21] = {.index = 30, .length = 3},
  [22] = {.index = 33, .length = 2},
  [23] = {.index = 35, .length = 2},
  [24] = {.index = 37, .length = 2},
  [25] = {.index = 39, .length = 2},
  [26] = {.index = 41, .length = 3},
  [27] = {.index = 44, .length = 2},
  [28] = {.index = 46, .length = 3},
  [29] = {.index = 49, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_result, 1},
  [1] =
    {field_var_name, 1},
  [2] =
    {field_arguments, 1},
    {field_name, 0},
  [4] =
    {field_argument, 1},
    {field_operator, 0},
  [6] =
    {field_type, 1},
  [7] =
    {field_export, 2},
    {field_var_name, 1},
  [9] =
    {field_var_name, 1},
    {field_var_name, 2, .inherited = true},
  [11] =
    {field_left, 0},
    {field_right, 2},
  [13] =
    {field_type, 2},
  [14] =
    {field_arguments, 2},
    {field_type, 1},
  [16] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [19] =
    {field_name, 0},
  [20] =
    {field_name, 1},
    {field_parameters, 2},
  [22] =
    {field_export, 3},
    {field_var_name, 1},
    {field_var_name, 2, .inherited = true},
  [25] =
    {field_var_name, 0, .inherited = true},
    {field_var_name, 1, .inherited = true},
  [27] =
    {field_name, 1},
    {field_val, 0},
  [29] =
    {field_parameter, 1},
  [30] =
    {field_export, 3},
    {field_name, 1},
    {field_parameters, 2},
  [33] =
    {field_name, 2},
    {field_parameters, 3},
  [35] =
    {field_def, 2},
    {field_name, 0},
  [37] =
    {field_parameter, 1},
    {field_parameter, 2, .inherited = true},
  [39] =
    {field_parameter, 0, .inherited = true},
    {field_parameter, 1, .inherited = true},
  [41] =
    {field_export, 4},
    {field_name, 2},
    {field_parameters, 3},
  [44] =
    {field_arguments, 4},
    {field_type, 2},
  [46] =
    {field_def, 3},
    {field_name, 1},
    {field_val, 0},
  [49] =
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_const_expression,
  },
  [10] = {
    [2] = alias_sym_property,
  },
  [13] = {
    [1] = anon_sym_DASH,
  },
  [18] = {
    [2] = alias_sym_index,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_expression, 2,
    sym_expression,
    alias_sym_index,
  sym__const_value, 2,
    sym__const_value,
    alias_sym_const_expression,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 2,
  [9] = 7,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 67,
  [74] = 74,
  [75] = 14,
  [76] = 76,
  [77] = 16,
  [78] = 78,
  [79] = 79,
  [80] = 45,
  [81] = 44,
  [82] = 46,
  [83] = 53,
  [84] = 52,
  [85] = 47,
  [86] = 51,
  [87] = 50,
  [88] = 49,
  [89] = 48,
  [90] = 69,
  [91] = 67,
  [92] = 60,
  [93] = 61,
  [94] = 65,
  [95] = 55,
  [96] = 56,
  [97] = 68,
  [98] = 57,
  [99] = 70,
  [100] = 58,
  [101] = 59,
  [102] = 54,
  [103] = 63,
  [104] = 62,
  [105] = 66,
  [106] = 64,
  [107] = 67,
  [108] = 78,
  [109] = 76,
  [110] = 72,
  [111] = 71,
  [112] = 74,
  [113] = 79,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 202,
  [204] = 202,
  [205] = 205,
  [206] = 206,
  [207] = 205,
  [208] = 208,
  [209] = 208,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 211,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 210,
  [224] = 211,
  [225] = 221,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 212,
  [233] = 213,
  [234] = 226,
  [235] = 235,
  [236] = 236,
  [237] = 227,
  [238] = 228,
  [239] = 229,
  [240] = 230,
  [241] = 231,
  [242] = 242,
  [243] = 226,
  [244] = 244,
  [245] = 227,
  [246] = 228,
  [247] = 229,
  [248] = 230,
  [249] = 231,
  [250] = 250,
  [251] = 251,
  [252] = 235,
  [253] = 253,
  [254] = 235,
  [255] = 210,
  [256] = 235,
  [257] = 235,
  [258] = 236,
  [259] = 244,
  [260] = 222,
  [261] = 251,
  [262] = 215,
  [263] = 222,
  [264] = 251,
  [265] = 215,
  [266] = 216,
  [267] = 216,
  [268] = 268,
  [269] = 16,
  [270] = 14,
  [271] = 45,
  [272] = 53,
  [273] = 49,
  [274] = 51,
  [275] = 44,
  [276] = 47,
  [277] = 52,
  [278] = 48,
  [279] = 50,
  [280] = 46,
  [281] = 281,
  [282] = 281,
  [283] = 281,
  [284] = 63,
  [285] = 58,
  [286] = 70,
  [287] = 55,
  [288] = 59,
  [289] = 54,
  [290] = 56,
  [291] = 60,
  [292] = 69,
  [293] = 61,
  [294] = 62,
  [295] = 66,
  [296] = 64,
  [297] = 68,
  [298] = 65,
  [299] = 299,
  [300] = 67,
  [301] = 57,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 302,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 306,
  [316] = 307,
  [317] = 303,
  [318] = 318,
  [319] = 306,
  [320] = 307,
  [321] = 303,
  [322] = 322,
  [323] = 323,
  [324] = 302,
  [325] = 313,
  [326] = 322,
  [327] = 322,
  [328] = 323,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 333,
  [336] = 16,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 338,
  [343] = 343,
  [344] = 341,
  [345] = 345,
  [346] = 346,
  [347] = 339,
  [348] = 341,
  [349] = 343,
  [350] = 339,
  [351] = 343,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 338,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 362,
  [365] = 360,
  [366] = 366,
  [367] = 363,
  [368] = 362,
  [369] = 363,
  [370] = 370,
  [371] = 360,
  [372] = 363,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 362,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 381,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 382,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 381,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(291);
      ADVANCE_MAP(
        '"', 358,
        '#', 22,
        '%', 308,
        '&', 13,
        '\'', 288,
        '(', 294,
        ')', 295,
        '*', 306,
        '+', 300,
        ',', 292,
        '-', 299,
        '.', 310,
        '/', 307,
        ':', 298,
        ';', 293,
        '<', 303,
        '=', 296,
        '>', 302,
        '?', 11,
        '[', 311,
        ']', 312,
        '|', 362,
        '~', 297,
        'F', 363,
        'f', 363,
        'N', 379,
        'n', 379,
        'U', 375,
        'u', 375,
        0x41b, 395,
        0x43b, 395,
        0x41d, 385,
        0x43d, 385,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(354);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '"', 358,
        '\'', 288,
        '/', 12,
        'F', 15,
        'f', 15,
        'N', 125,
        'n', 125,
        'T', 103,
        't', 103,
        'U', 86,
        'u', 86,
        0x418, 262,
        0x438, 262,
        0x41b, 247,
        0x43b, 247,
        0x41d, 164,
        0x43d, 164,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(355);
      END_STATE();
    case 2:
      if (lookahead == '"') ADVANCE(361);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '%', 308,
        '(', 294,
        ')', 295,
        '*', 306,
        '+', 300,
        ',', 292,
        '-', 299,
        '.', 310,
        '/', 307,
        '<', 303,
        '=', 296,
        '>', 302,
        '[', 311,
        ']', 312,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 4:
      if (lookahead == '\'') ADVANCE(357);
      END_STATE();
    case 5:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(4);
      END_STATE();
    case 6:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(5);
      END_STATE();
    case 7:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(6);
      END_STATE();
    case 8:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(7);
      END_STATE();
    case 9:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(8);
      END_STATE();
    case 10:
      if (lookahead == '\'') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(9);
      END_STATE();
    case 11:
      if (lookahead == '(') ADVANCE(309);
      END_STATE();
    case 12:
      if (lookahead == '/') ADVANCE(401);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'A', 58,
        'a', 58,
        'B', 32,
        'b', 32,
        'C', 66,
        'c', 66,
        0x418, 177,
        0x438, 177,
        0x41d, 132,
        0x43d, 132,
        0x41f, 147,
        0x43f, 147,
        0x412, 210,
        0x432, 210,
        0x1c80, 210,
      );
      END_STATE();
    case 14:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(83);
      END_STATE();
    case 15:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(78);
      END_STATE();
    case 16:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 17:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(75);
      END_STATE();
    case 18:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(121);
      END_STATE();
    case 19:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(74);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(44);
      END_STATE();
    case 20:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(95);
      END_STATE();
    case 21:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(96);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        'D', 30,
        'd', 30,
        'E', 72,
        'e', 72,
        'I', 57,
        'i', 57,
        'R', 31,
        'r', 31,
        0x415, 255,
        0x435, 255,
        0x418, 212,
        0x438, 212,
        0x41a, 250,
        0x43a, 250,
        0x423, 243,
        0x443, 243,
        0x412, 256,
        0x432, 256,
        0x1c80, 256,
        0x41e, 145,
        0x43e, 145,
        0x1c82, 145,
      );
      END_STATE();
    case 23:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(29);
      END_STATE();
    case 24:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(341);
      END_STATE();
    case 25:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(317);
      END_STATE();
    case 26:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(127);
      END_STATE();
    case 27:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(18);
      END_STATE();
    case 28:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(43);
      END_STATE();
    case 29:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(55);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(60);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 30:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 31:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(63);
      END_STATE();
    case 32:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 33:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(321);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(59);
      END_STATE();
    case 34:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 35:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(333);
      END_STATE();
    case 36:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(337);
      END_STATE();
    case 37:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(335);
      END_STATE();
    case 38:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(130);
      END_STATE();
    case 39:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(343);
      END_STATE();
    case 40:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(313);
      END_STATE();
    case 41:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(315);
      END_STATE();
    case 42:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(98);
      END_STATE();
    case 43:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(62);
      END_STATE();
    case 44:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 45:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(85);
      END_STATE();
    case 46:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 47:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(25);
      END_STATE();
    case 48:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 49:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(118);
      END_STATE();
    case 50:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(16);
      END_STATE();
    case 51:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 52:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 53:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 54:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(119);
      END_STATE();
    case 55:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(79);
      END_STATE();
    case 56:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(65);
      END_STATE();
    case 57:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(319);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 58:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(117);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(90);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(19);
      END_STATE();
    case 59:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(320);
      END_STATE();
    case 60:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(323);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 61:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(93);
      END_STATE();
    case 62:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(70);
      END_STATE();
    case 63:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(67);
      END_STATE();
    case 64:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(50);
      END_STATE();
    case 65:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(71);
      END_STATE();
    case 66:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(14);
      END_STATE();
    case 67:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(92);
      END_STATE();
    case 68:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(27);
      END_STATE();
    case 69:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(45);
      END_STATE();
    case 70:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(87);
      END_STATE();
    case 71:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(94);
      END_STATE();
    case 72:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(107);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(23);
      END_STATE();
    case 73:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(326);
      END_STATE();
    case 74:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(69);
      END_STATE();
    case 75:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(68);
      END_STATE();
    case 76:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(49);
      END_STATE();
    case 77:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(73);
      END_STATE();
    case 78:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(109);
      END_STATE();
    case 79:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(54);
      END_STATE();
    case 80:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(324);
      END_STATE();
    case 81:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(325);
      END_STATE();
    case 82:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(24);
      END_STATE();
    case 83:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(64);
      END_STATE();
    case 84:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(26);
      END_STATE();
    case 85:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 86:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(28);
      END_STATE();
    case 87:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(47);
      END_STATE();
    case 88:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(120);
      END_STATE();
    case 89:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(123);
      END_STATE();
    case 90:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(124);
      END_STATE();
    case 91:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(20);
      END_STATE();
    case 92:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(80);
      END_STATE();
    case 93:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(105);
      END_STATE();
    case 94:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(81);
      END_STATE();
    case 95:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(88);
      END_STATE();
    case 96:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(89);
      END_STATE();
    case 97:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(21);
      END_STATE();
    case 98:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(339);
      END_STATE();
    case 99:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(128);
      END_STATE();
    case 100:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(347);
      END_STATE();
    case 101:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(353);
      END_STATE();
    case 102:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(112);
      END_STATE();
    case 103:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(126);
      END_STATE();
    case 104:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(114);
      END_STATE();
    case 105:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(36);
      END_STATE();
    case 106:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 107:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(33);
      END_STATE();
    case 108:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(34);
      END_STATE();
    case 109:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(41);
      END_STATE();
    case 110:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(51);
      END_STATE();
    case 111:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(53);
      END_STATE();
    case 112:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(329);
      END_STATE();
    case 113:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(345);
      END_STATE();
    case 114:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(331);
      END_STATE();
    case 115:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(349);
      END_STATE();
    case 116:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(351);
      END_STATE();
    case 117:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(42);
      END_STATE();
    case 118:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(35);
      END_STATE();
    case 119:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(37);
      END_STATE();
    case 120:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(38);
      END_STATE();
    case 121:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(39);
      END_STATE();
    case 122:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(111);
      END_STATE();
    case 123:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(52);
      END_STATE();
    case 124:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(82);
      END_STATE();
    case 125:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(77);
      END_STATE();
    case 126:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(40);
      END_STATE();
    case 127:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(17);
      END_STATE();
    case 128:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(46);
      END_STATE();
    case 129:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(48);
      END_STATE();
    case 130:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(115);
      END_STATE();
    case 131:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(116);
      END_STATE();
    case 132:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(194);
      END_STATE();
    case 133:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(233);
      END_STATE();
    case 134:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(238);
      END_STATE();
    case 135:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(328);
      END_STATE();
    case 136:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(348);
      END_STATE();
    case 137:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(350);
      END_STATE();
    case 138:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(313);
      END_STATE();
    case 139:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(206);
      END_STATE();
    case 140:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(258);
      END_STATE();
    case 141:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(259);
      END_STATE();
    case 142:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(267);
      END_STATE();
    case 143:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(239);
      END_STATE();
    case 144:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(208);
      END_STATE();
    case 145:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(204);
      END_STATE();
    case 146:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(205);
      END_STATE();
    case 147:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(227);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(261);
      END_STATE();
    case 148:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(232);
      END_STATE();
    case 149:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(322);
      END_STATE();
    case 150:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(338);
      END_STATE();
    case 151:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(332);
      END_STATE();
    case 152:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(344);
      END_STATE();
    case 153:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(346);
      END_STATE();
    case 154:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(352);
      END_STATE();
    case 155:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(242);
      END_STATE();
    case 156:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(178);
      END_STATE();
    case 157:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(225);
      END_STATE();
    case 158:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(257);
      END_STATE();
    case 159:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(219);
      END_STATE();
    case 160:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(244);
      END_STATE();
    case 161:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(214);
      END_STATE();
    case 162:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(195);
      END_STATE();
    case 163:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(217);
      END_STATE();
    case 164:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(248);
      END_STATE();
    case 165:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(186);
      END_STATE();
    case 166:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(215);
      END_STATE();
    case 167:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(228);
      END_STATE();
    case 168:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(222);
      END_STATE();
    case 169:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(229);
      END_STATE();
    case 170:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(209);
      END_STATE();
    case 171:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(221);
      END_STATE();
    case 172:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(197);
      END_STATE();
    case 173:
      ADVANCE_MAP(
        0x415, 265,
        0x435, 265,
        0x423, 245,
        0x443, 245,
        0x412, 266,
        0x432, 266,
        0x1c80, 266,
        0x41e, 146,
        0x43e, 146,
        0x1c82, 146,
      );
      END_STATE();
    case 174:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(179);
      END_STATE();
    case 175:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(231);
      END_STATE();
    case 176:
      if (lookahead == 0x416 ||
          lookahead == 0x436) ADVANCE(236);
      END_STATE();
    case 177:
      if (lookahead == 0x417 ||
          lookahead == 0x437) ADVANCE(211);
      END_STATE();
    case 178:
      if (lookahead == 0x417 ||
          lookahead == 0x437) ADVANCE(196);
      END_STATE();
    case 179:
      if (lookahead == 0x417 ||
          lookahead == 0x437) ADVANCE(198);
      END_STATE();
    case 180:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(319);
      END_STATE();
    case 181:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(320);
      END_STATE();
    case 182:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(323);
      END_STATE();
    case 183:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(325);
      END_STATE();
    case 184:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(237);
      END_STATE();
    case 185:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(330);
      END_STATE();
    case 186:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(193);
      END_STATE();
    case 187:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(161);
      END_STATE();
    case 188:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(151);
      END_STATE();
    case 189:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(165);
      END_STATE();
    case 190:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(218);
      END_STATE();
    case 191:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(135);
      END_STATE();
    case 192:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(185);
      END_STATE();
    case 193:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(252);
      END_STATE();
    case 194:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(200);
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(157);
      END_STATE();
    case 195:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(260);
      END_STATE();
    case 196:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(253);
      END_STATE();
    case 197:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(264);
      END_STATE();
    case 198:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(254);
      END_STATE();
    case 199:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(180);
      END_STATE();
    case 200:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(187);
      END_STATE();
    case 201:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(235);
      END_STATE();
    case 202:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(181);
      END_STATE();
    case 203:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(182);
      END_STATE();
    case 204:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(140);
      END_STATE();
    case 205:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(141);
      END_STATE();
    case 206:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(159);
      END_STATE();
    case 207:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(150);
      END_STATE();
    case 208:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(163);
      END_STATE();
    case 209:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(166);
      END_STATE();
    case 210:
      if (lookahead == 0x41c ||
          lookahead == 0x43c) ADVANCE(158);
      END_STATE();
    case 211:
      if (lookahead == 0x41c ||
          lookahead == 0x43c) ADVANCE(168);
      END_STATE();
    case 212:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(133);
      END_STATE();
    case 213:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(148);
      END_STATE();
    case 214:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(276);
      END_STATE();
    case 215:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(249);
      END_STATE();
    case 216:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(270);
      END_STATE();
    case 217:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(184);
      END_STATE();
    case 218:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(138);
      END_STATE();
    case 219:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(188);
      END_STATE();
    case 220:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(277);
      END_STATE();
    case 221:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(189);
      END_STATE();
    case 222:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(171);
      END_STATE();
    case 223:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(279);
      END_STATE();
    case 224:
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(230);
      END_STATE();
    case 225:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(240);
      END_STATE();
    case 226:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(251);
      END_STATE();
    case 227:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(155);
      END_STATE();
    case 228:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(153);
      END_STATE();
    case 229:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(154);
      END_STATE();
    case 230:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(160);
      END_STATE();
    case 231:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(241);
      END_STATE();
    case 232:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(173);
      END_STATE();
    case 233:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(149);
      END_STATE();
    case 234:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(324);
      END_STATE();
    case 235:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(342);
      END_STATE();
    case 236:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(315);
      END_STATE();
    case 237:
      if (lookahead == 0x42f ||
          lookahead == 0x44f) ADVANCE(334);
      END_STATE();
    case 238:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(191);
      END_STATE();
    case 239:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(192);
      END_STATE();
    case 240:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(167);
      END_STATE();
    case 241:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(169);
      END_STATE();
    case 242:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(336);
      END_STATE();
    case 243:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(139);
      END_STATE();
    case 244:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(170);
      END_STATE();
    case 245:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(144);
      END_STATE();
    case 246:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(340);
      END_STATE();
    case 247:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(176);
      END_STATE();
    case 248:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(224);
      END_STATE();
    case 249:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(317);
      END_STATE();
    case 250:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(213);
      END_STATE();
    case 251:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(201);
      END_STATE();
    case 252:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(216);
      END_STATE();
    case 253:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(220);
      END_STATE();
    case 254:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(223);
      END_STATE();
    case 255:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(199);
      END_STATE();
    case 256:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(271);
      END_STATE();
    case 257:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(269);
      END_STATE();
    case 258:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(268);
      END_STATE();
    case 259:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(272);
      END_STATE();
    case 260:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(273);
      END_STATE();
    case 261:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(207);
      END_STATE();
    case 262:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(274);
      END_STATE();
    case 263:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(202);
      END_STATE();
    case 264:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(275);
      END_STATE();
    case 265:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(203);
      END_STATE();
    case 266:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(278);
      END_STATE();
    case 267:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(175);
      END_STATE();
    case 268:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(234);
      END_STATE();
    case 269:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(246);
      END_STATE();
    case 270:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(226);
      END_STATE();
    case 271:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(134);
      END_STATE();
    case 272:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(183);
      END_STATE();
    case 273:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(136);
      END_STATE();
    case 274:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(190);
      END_STATE();
    case 275:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(137);
      END_STATE();
    case 276:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(152);
      END_STATE();
    case 277:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(162);
      END_STATE();
    case 278:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(143);
      END_STATE();
    case 279:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(172);
      END_STATE();
    case 280:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(356);
      END_STATE();
    case 281:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(10);
      END_STATE();
    case 282:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(281);
      END_STATE();
    case 283:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(282);
      END_STATE();
    case 284:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(283);
      END_STATE();
    case 285:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      END_STATE();
    case 286:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(285);
      END_STATE();
    case 287:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(286);
      END_STATE();
    case 288:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(287);
      END_STATE();
    case 289:
      if (eof) ADVANCE(291);
      ADVANCE_MAP(
        '"', 358,
        '#', 22,
        '&', 13,
        '\'', 288,
        '(', 294,
        ')', 295,
        '+', 300,
        ',', 292,
        '-', 299,
        '/', 12,
        ';', 293,
        '?', 11,
        '~', 297,
        'F', 363,
        'f', 363,
        'N', 379,
        'n', 379,
        'T', 377,
        't', 377,
        'U', 375,
        'u', 375,
        0x418, 398,
        0x438, 398,
        0x41b, 395,
        0x43b, 395,
        0x41d, 385,
        0x43d, 385,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(289);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(354);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 290:
      if (eof) ADVANCE(291);
      ADVANCE_MAP(
        '#', 22,
        '%', 308,
        '&', 13,
        '(', 294,
        ')', 295,
        '*', 306,
        '+', 300,
        ',', 292,
        '-', 299,
        '.', 310,
        '/', 307,
        ';', 293,
        '<', 303,
        '=', 296,
        '>', 302,
        '[', 311,
        ']', 312,
        '~', 297,
        'F', 363,
        'f', 363,
        'N', 379,
        'n', 379,
        'T', 377,
        't', 377,
        'U', 375,
        'u', 375,
        0x418, 398,
        0x438, 398,
        0x41b, 395,
        0x43b, 395,
        0x41d, 385,
        0x43d, 385,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym_LT_GT);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(304);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(305);
      if (lookahead == '>') ADVANCE(301);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(401);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(anon_sym_QMARK_LPAREN);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(sym_TRUE_KEYWORD);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(sym_TRUE_KEYWORD);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(sym_FALSE_KEYWORD);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(sym_FALSE_KEYWORD);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(sym_UNDEFINED_KEYWORD);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(sym_UNDEFINED_KEYWORD);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(sym_PREPROC_IF_KEYWORD);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(sym_PREPROC_ELSIF_KEYWORD);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_PREPROC_ELSE_KEYWORD);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(sym_PREPROC_ELSE_KEYWORD);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(263);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(sym_PREPROC_ENDIF_KEYWORD);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_PREPROC_REGION_KEYWORD);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_PREPROC_ENDREGION_KEYWORD);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_NULL_KEYWORD);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_NULL_KEYWORD);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(aux_sym_preprocessor_token1);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(aux_sym_preprocessor_token2);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(aux_sym_preprocessor_token3);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(aux_sym_preprocessor_token4);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(aux_sym_preprocessor_token5);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(aux_sym_preprocessor_token6);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(aux_sym_preprocessor_token7);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(aux_sym_preprocessor_token8);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(aux_sym_preprocessor_token9);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(aux_sym_preprocessor_token10);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(aux_sym_preprocessor_token11);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(aux_sym_preprocessor_token12);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(aux_sym_preprocessor_token13);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(aux_sym_preprocessor_token14);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(aux_sym_preprocessor_token15);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(aux_sym_preprocessor_token16);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(aux_sym_preprocessor_token17);
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(142);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(aux_sym_preprocessor_token18);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(122);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(aux_sym_preprocessor_token19);
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(156);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(aux_sym_preprocessor_token20);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(91);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(aux_sym_preprocessor_token21);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(aux_sym_preprocessor_token22);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(aux_sym_preprocessor_token23);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(aux_sym_preprocessor_token24);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(aux_sym_preprocessor_token25);
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(174);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(aux_sym_preprocessor_token26);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(97);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(280);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(354);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(280);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(355);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(356);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(sym_date);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '"') ADVANCE(2);
      if (lookahead == '/') ADVANCE(360);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(359);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(361);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '"') ADVANCE(2);
      if (lookahead == '/') ADVANCE(361);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(361);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '"') ADVANCE(2);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(361);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(372);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(366);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(318);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(370);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(365);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(371);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(376);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(378);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(327);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(373);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(364);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(369);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(380);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(367);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(374);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(368);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x411 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(388);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(390);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(396);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x416 ||
          lookahead == 0x436) ADVANCE(393);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(389);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(384);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(381);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(397);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(392);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(382);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(383);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(386);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(318);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(399);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(387);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == 0x17f ||
          (0x410 <= lookahead && lookahead <= 0x44f) ||
          (0x1c80 <= lookahead && lookahead <= 0x1c86) ||
          lookahead == 0x212a) ADVANCE(400);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(405);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(aux_sym_line_comment_token1);
      if (lookahead == '/') ADVANCE(404);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(403);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(405);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym_line_comment_token1);
      if (lookahead == '/') ADVANCE(402);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(405);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(aux_sym_line_comment_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(405);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'A', 1,
        'a', 1,
        'B', 2,
        'b', 2,
        'C', 3,
        'c', 3,
        'D', 4,
        'd', 4,
        'E', 5,
        'e', 5,
        'F', 6,
        'f', 6,
        'G', 7,
        'g', 7,
        'I', 8,
        'i', 8,
        'N', 9,
        'n', 9,
        'O', 10,
        'o', 10,
        'P', 11,
        'p', 11,
        'R', 12,
        'r', 12,
        'T', 13,
        't', 13,
        'V', 14,
        'v', 14,
        'W', 15,
        'w', 15,
        0x410, 16,
        0x430, 16,
        0x415, 17,
        0x435, 17,
        0x416, 18,
        0x436, 18,
        0x417, 19,
        0x437, 19,
        0x418, 20,
        0x438, 20,
        0x41a, 21,
        0x43a, 21,
        0x41d, 22,
        0x43d, 22,
        0x41f, 23,
        0x43f, 23,
        0x423, 24,
        0x443, 24,
        0x424, 25,
        0x444, 25,
        0x426, 26,
        0x446, 26,
        0x42d, 27,
        0x44d, 27,
        0x412, 28,
        0x432, 28,
        0x1c80, 28,
        0x414, 29,
        0x434, 29,
        0x1c81, 29,
        0x422, 30,
        0x442, 30,
        0x1c84, 30,
        0x1c85, 30,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        'D', 31,
        'd', 31,
        'N', 32,
        'n', 32,
        'S', 33,
        's', 33,
        'W', 34,
        'w', 34,
      );
      END_STATE();
    case 2:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 3:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(36);
      END_STATE();
    case 4:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(37);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        'A', 38,
        'a', 38,
        'L', 39,
        'l', 39,
        'N', 40,
        'n', 40,
        'X', 41,
        'x', 41,
      );
      END_STATE();
    case 6:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(42);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(43);
      END_STATE();
    case 7:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(44);
      END_STATE();
    case 8:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(45);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(46);
      END_STATE();
    case 9:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(47);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(48);
      END_STATE();
    case 10:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(49);
      END_STATE();
    case 11:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(50);
      END_STATE();
    case 12:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(51);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(52);
      END_STATE();
    case 13:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(53);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(54);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(55);
      END_STATE();
    case 14:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(56);
      END_STATE();
    case 15:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(57);
      END_STATE();
    case 16:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(58);
      END_STATE();
    case 17:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(59);
      END_STATE();
    case 18:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(60);
      END_STATE();
    case 19:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(61);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(sym_AND_KEYWORD);
      ADVANCE_MAP(
        0x417, 46,
        0x437, 46,
        0x41b, 62,
        0x43b, 62,
        0x41d, 63,
        0x43d, 63,
        0x421, 64,
        0x441, 64,
        0x1c83, 64,
      );
      END_STATE();
    case 21:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(65);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(66);
      END_STATE();
    case 22:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(67);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(68);
      END_STATE();
    case 23:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(69);
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(70);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(71);
      END_STATE();
    case 24:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(72);
      END_STATE();
    case 25:
      if (lookahead == 0x423 ||
          lookahead == 0x443) ADVANCE(73);
      END_STATE();
    case 26:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(74);
      END_STATE();
    case 27:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(75);
      END_STATE();
    case 28:
      if (lookahead == 0x42b ||
          lookahead == 0x44b) ADVANCE(76);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(77);
      END_STATE();
    case 29:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(78);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(79);
      END_STATE();
    case 30:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(80);
      END_STATE();
    case 31:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(81);
      END_STATE();
    case 32:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(82);
      END_STATE();
    case 33:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(83);
      END_STATE();
    case 34:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 35:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(85);
      END_STATE();
    case 36:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(86);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(sym_DO_KEYWORD);
      END_STATE();
    case 38:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(87);
      END_STATE();
    case 39:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(88);
      END_STATE();
    case 40:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(89);
      END_STATE();
    case 41:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(90);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(91);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(92);
      END_STATE();
    case 42:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(93);
      END_STATE();
    case 43:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(94);
      END_STATE();
    case 44:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(95);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(sym_IF_KEYWORD);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(sym_IN_KEYWORD);
      END_STATE();
    case 47:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(96);
      END_STATE();
    case 48:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(67);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_OR_KEYWORD);
      END_STATE();
    case 50:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 51:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 52:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(99);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(100);
      END_STATE();
    case 53:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_TO_KEYWORD);
      END_STATE();
    case 55:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(102);
      END_STATE();
    case 56:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(103);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(104);
      END_STATE();
    case 57:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 58:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(106);
      END_STATE();
    case 59:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(107);
      END_STATE();
    case 60:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(108);
      END_STATE();
    case 61:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(109);
      END_STATE();
    case 62:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(49);
      END_STATE();
    case 63:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(110);
      END_STATE();
    case 64:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(111);
      END_STATE();
    case 65:
      if (lookahead == 0x416 ||
          lookahead == 0x436) ADVANCE(112);
      END_STATE();
    case 66:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(113);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_NOT_KEYWORD);
      END_STATE();
    case 68:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(114);
      END_STATE();
    case 69:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(115);
      END_STATE();
    case 70:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(116);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(117);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_TO_KEYWORD);
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(118);
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(119);
      END_STATE();
    case 72:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(120);
      END_STATE();
    case 73:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(121);
      END_STATE();
    case 74:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(122);
      END_STATE();
    case 75:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(123);
      END_STATE();
    case 76:
      if (lookahead == 0x417 ||
          lookahead == 0x437) ADVANCE(124);
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(125);
      END_STATE();
    case 77:
      if (lookahead == 0x417 ||
          lookahead == 0x437) ADVANCE(126);
      END_STATE();
    case 78:
      if (lookahead == 0x42f ||
          lookahead == 0x44f) ADVANCE(93);
      END_STATE();
    case 79:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(127);
      END_STATE();
    case 80:
      if (lookahead == 0x413 ||
          lookahead == 0x433) ADVANCE(128);
      END_STATE();
    case 81:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(129);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_AND_KEYWORD);
      END_STATE();
    case 83:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 84:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(131);
      END_STATE();
    case 85:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(132);
      END_STATE();
    case 86:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(133);
      END_STATE();
    case 87:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(134);
      END_STATE();
    case 88:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(135);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(136);
      END_STATE();
    case 89:
      ADVANCE_MAP(
        'D', 137,
        'd', 137,
        'F', 138,
        'f', 138,
        'I', 139,
        'i', 139,
        'P', 140,
        'p', 140,
        'T', 141,
        't', 141,
      );
      END_STATE();
    case 90:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(142);
      END_STATE();
    case 91:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(143);
      END_STATE();
    case 92:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(144);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_FOR_KEYWORD);
      END_STATE();
    case 94:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(145);
      END_STATE();
    case 95:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(146);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_NEW_KEYWORD);
      END_STATE();
    case 97:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(147);
      END_STATE();
    case 98:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(148);
      END_STATE();
    case 99:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(149);
      END_STATE();
    case 100:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 101:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(151);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_TRY_KEYWORD);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_VAL_KEYWORD);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_VAR_KEYWORD);
      END_STATE();
    case 105:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(152);
      END_STATE();
    case 106:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(153);
      END_STATE();
    case 107:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(45);
      END_STATE();
    case 108:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(154);
      END_STATE();
    case 109:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(103);
      END_STATE();
    case 110:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(155);
      END_STATE();
    case 111:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(156);
      END_STATE();
    case 112:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(157);
      END_STATE();
    case 113:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(158);
      END_STATE();
    case 114:
      if (lookahead == 0x42b ||
          lookahead == 0x44b) ADVANCE(159);
      END_STATE();
    case 115:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(160);
      END_STATE();
    case 116:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(161);
      END_STATE();
    case 117:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(162);
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(163);
      END_STATE();
    case 118:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(164);
      END_STATE();
    case 119:
      if (lookahead == 0x42b ||
          lookahead == 0x44b) ADVANCE(165);
      END_STATE();
    case 120:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(166);
      END_STATE();
    case 121:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(167);
      END_STATE();
    case 122:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(37);
      END_STATE();
    case 123:
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(168);
      END_STATE();
    case 124:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(169);
      END_STATE();
    case 125:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(170);
      END_STATE();
    case 126:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(171);
      END_STATE();
    case 127:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(172);
      END_STATE();
    case 128:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(173);
      END_STATE();
    case 129:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(174);
      END_STATE();
    case 130:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(175);
      END_STATE();
    case 131:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(176);
      END_STATE();
    case 132:
      if (lookahead == 'K' ||
          lookahead == 'k' ||
          lookahead == 0x212a) ADVANCE(177);
      END_STATE();
    case 133:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(178);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_EACH_KEYWORD);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_ELSE_KEYWORD);
      END_STATE();
    case 136:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(179);
      END_STATE();
    case 137:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(180);
      END_STATE();
    case 138:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(181);
      END_STATE();
    case 139:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(182);
      END_STATE();
    case 140:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(183);
      END_STATE();
    case 141:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(184);
      END_STATE();
    case 142:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(185);
      END_STATE();
    case 143:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(186);
      END_STATE();
    case 144:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(187);
      END_STATE();
    case 145:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(188);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(sym_GOTO_KEYWORD);
      END_STATE();
    case 147:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(189);
      END_STATE();
    case 148:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(190);
      END_STATE();
    case 149:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(191);
      END_STATE();
    case 150:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(192);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym_THEN_KEYWORD);
      END_STATE();
    case 152:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 153:
      if (lookahead == 0x425 ||
          lookahead == 0x445) ADVANCE(175);
      END_STATE();
    case 154:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(176);
      END_STATE();
    case 155:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(193);
      END_STATE();
    case 156:
      if (lookahead == 0x42e ||
          lookahead == 0x44e) ADVANCE(194);
      END_STATE();
    case 157:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(195);
      END_STATE();
    case 158:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(196);
      END_STATE();
    case 159:
      if (lookahead == 0x419 ||
          lookahead == 0x439) ADVANCE(96);
      END_STATE();
    case 160:
      if (lookahead == 0x419 ||
          lookahead == 0x439) ADVANCE(197);
      if (lookahead == 0x41c ||
          lookahead == 0x43c) ADVANCE(104);
      END_STATE();
    case 161:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(198);
      END_STATE();
    case 162:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(199);
      END_STATE();
    case 163:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(200);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_WHILE_KEYWORD);
      END_STATE();
    case 165:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(201);
      END_STATE();
    case 166:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(202);
      END_STATE();
    case 167:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(203);
      END_STATE();
    case 168:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(204);
      END_STATE();
    case 169:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(205);
      END_STATE();
    case 170:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(206);
      END_STATE();
    case 171:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(207);
      END_STATE();
    case 172:
      if (lookahead == 0x412 ||
          lookahead == 0x432 ||
          lookahead == 0x1c80) ADVANCE(208);
      END_STATE();
    case 173:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(151);
      END_STATE();
    case 174:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(209);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_ASYNC_KEYWORD);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_AWAIT_KEYWORD);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_BREAK_KEYWORD);
      END_STATE();
    case 178:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(210);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_ELSIF_KEYWORD);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_ENDDO_KEYWORD);
      END_STATE();
    case 181:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(211);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_ENDIF_KEYWORD);
      END_STATE();
    case 183:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(212);
      END_STATE();
    case 184:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(213);
      END_STATE();
    case 185:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(214);
      END_STATE();
    case 186:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(215);
      END_STATE();
    case 187:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(216);
      END_STATE();
    case 188:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(217);
      END_STATE();
    case 189:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(218);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_RAISE_KEYWORD);
      END_STATE();
    case 191:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(219);
      END_STATE();
    case 192:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(220);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_ELSE_KEYWORD);
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(221);
      END_STATE();
    case 194:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(222);
      END_STATE();
    case 195:
      if (lookahead == 0x413 ||
          lookahead == 0x433) ADVANCE(223);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        0x415, 224,
        0x435, 224,
        0x41f, 225,
        0x43f, 225,
        0x424, 226,
        0x444, 226,
        0x426, 227,
        0x446, 227,
      );
      END_STATE();
    case 197:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(228);
      END_STATE();
    case 198:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(229);
      END_STATE();
    case 199:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(230);
      END_STATE();
    case 200:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(231);
      END_STATE();
    case 201:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(232);
      END_STATE();
    case 202:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(233);
      END_STATE();
    case 203:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(234);
      END_STATE();
    case 204:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(235);
      END_STATE();
    case 205:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(236);
      END_STATE();
    case 206:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(237);
      END_STATE();
    case 207:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(238);
      END_STATE();
    case 208:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(239);
      END_STATE();
    case 209:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(240);
      END_STATE();
    case 210:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(241);
      END_STATE();
    case 211:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(242);
      END_STATE();
    case 212:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(243);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(sym_ENDTRY_KEYWORD);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(sym_EXCEPT_KEYWORD);
      END_STATE();
    case 215:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(244);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(sym_EXPORT_KEYWORD);
      END_STATE();
    case 217:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(245);
      END_STATE();
    case 218:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(246);
      END_STATE();
    case 219:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_RETURN_KEYWORD);
      END_STATE();
    case 221:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(248);
      END_STATE();
    case 222:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(249);
      END_STATE();
    case 223:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(134);
      END_STATE();
    case 224:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(250);
      END_STATE();
    case 225:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(251);
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(252);
      END_STATE();
    case 226:
      if (lookahead == 0x423 ||
          lookahead == 0x443) ADVANCE(253);
      END_STATE();
    case 227:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(254);
      END_STATE();
    case 228:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(146);
      END_STATE();
    case 229:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(255);
      END_STATE();
    case 230:
      if (lookahead == 0x423 ||
          lookahead == 0x443) ADVANCE(256);
      END_STATE();
    case 231:
      if (lookahead == 0x416 ||
          lookahead == 0x436) ADVANCE(257);
      END_STATE();
    case 232:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(102);
      END_STATE();
    case 233:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(258);
      END_STATE();
    case 234:
      if (lookahead == 0x42f ||
          lookahead == 0x44f) ADVANCE(259);
      END_STATE();
    case 235:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(216);
      END_STATE();
    case 236:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(260);
      END_STATE();
    case 237:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(261);
      END_STATE();
    case 238:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(220);
      END_STATE();
    case 239:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(262);
      END_STATE();
    case 240:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(263);
      END_STATE();
    case 241:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(264);
      END_STATE();
    case 242:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(265);
      END_STATE();
    case 243:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(266);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(aux_sym_execute_statement_token1);
      END_STATE();
    case 245:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(259);
      END_STATE();
    case 246:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(267);
      END_STATE();
    case 247:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(268);
      END_STATE();
    case 248:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(269);
      END_STATE();
    case 249:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(270);
      END_STATE();
    case 250:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(271);
      END_STATE();
    case 251:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(272);
      END_STATE();
    case 252:
      if (lookahead == 0x41f ||
          lookahead == 0x43f) ADVANCE(273);
      END_STATE();
    case 253:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(274);
      END_STATE();
    case 254:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(275);
      END_STATE();
    case 255:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(177);
      END_STATE();
    case 256:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(276);
      END_STATE();
    case 257:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(277);
      END_STATE();
    case 258:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(278);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(sym_FUNCTION_KEYWORD);
      END_STATE();
    case 260:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(279);
      END_STATE();
    case 261:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(280);
      END_STATE();
    case 262:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(281);
      END_STATE();
    case 263:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(282);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_CONTINUE_KEYWORD);
      END_STATE();
    case 265:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(283);
      END_STATE();
    case 266:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(284);
      END_STATE();
    case 267:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 268:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(286);
      END_STATE();
    case 269:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(179);
      END_STATE();
    case 270:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(287);
      END_STATE();
    case 271:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(182);
      END_STATE();
    case 272:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(288);
      END_STATE();
    case 273:
      if (lookahead == 0x42b ||
          lookahead == 0x44b) ADVANCE(289);
      END_STATE();
    case 274:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(290);
      END_STATE();
    case 275:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(291);
      END_STATE();
    case 276:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(285);
      END_STATE();
    case 277:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(292);
      END_STATE();
    case 278:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(293);
      END_STATE();
    case 279:
      if (lookahead == 0x421 ||
          lookahead == 0x441 ||
          lookahead == 0x1c83) ADVANCE(294);
      END_STATE();
    case 280:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(244);
      END_STATE();
    case 281:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(295);
      END_STATE();
    case 282:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(296);
      END_STATE();
    case 283:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(297);
      END_STATE();
    case 284:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(298);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(sym_PROCEDURE_KEYWORD);
      END_STATE();
    case 286:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(299);
      END_STATE();
    case 287:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(214);
      END_STATE();
    case 288:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(300);
      END_STATE();
    case 289:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(301);
      END_STATE();
    case 290:
      if (lookahead == 0x426 ||
          lookahead == 0x446) ADVANCE(302);
      END_STATE();
    case 291:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(180);
      END_STATE();
    case 292:
      if (lookahead == 0x42c ||
          lookahead == 0x44c) ADVANCE(264);
      END_STATE();
    case 293:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(303);
      END_STATE();
    case 294:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(304);
      END_STATE();
    case 295:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(305);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(sym_ADDHANDLER_KEYWORD);
      END_STATE();
    case 297:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(306);
      END_STATE();
    case 298:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(307);
      END_STATE();
    case 299:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(308);
      END_STATE();
    case 300:
      if (lookahead == 0x414 ||
          lookahead == 0x434 ||
          lookahead == 0x1c81) ADVANCE(309);
      END_STATE();
    case 301:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(310);
      END_STATE();
    case 302:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(311);
      END_STATE();
    case 303:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(312);
      END_STATE();
    case 304:
      if (lookahead == 0x41b ||
          lookahead == 0x43b) ADVANCE(313);
      END_STATE();
    case 305:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(314);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(sym_ENDFUNCTION_KEYWORD);
      END_STATE();
    case 307:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(315);
      END_STATE();
    case 308:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(316);
      END_STATE();
    case 309:
      if (lookahead == 0x423 ||
          lookahead == 0x443) ADVANCE(317);
      END_STATE();
    case 310:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(213);
      END_STATE();
    case 311:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(306);
      END_STATE();
    case 312:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(318);
      END_STATE();
    case 313:
      if (lookahead == 0x42e ||
          lookahead == 0x44e) ADVANCE(319);
      END_STATE();
    case 314:
      if (lookahead == 0x410 ||
          lookahead == 0x430) ADVANCE(320);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(sym_ENDPROCEDURE_KEYWORD);
      END_STATE();
    case 316:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(321);
      END_STATE();
    case 317:
      if (lookahead == 0x420 ||
          lookahead == 0x440) ADVANCE(322);
      END_STATE();
    case 318:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(323);
      END_STATE();
    case 319:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(324);
      END_STATE();
    case 320:
      if (lookahead == 0x411 ||
          lookahead == 0x431) ADVANCE(325);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_REMOVEHANDLER_KEYWORD);
      END_STATE();
    case 322:
      if (lookahead == 0x42b ||
          lookahead == 0x44b) ADVANCE(315);
      END_STATE();
    case 323:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(326);
      END_STATE();
    case 324:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(327);
      END_STATE();
    case 325:
      if (lookahead == 0x41e ||
          lookahead == 0x43e ||
          lookahead == 0x1c82) ADVANCE(328);
      END_STATE();
    case 326:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(329);
      END_STATE();
    case 327:
      if (lookahead == 0x41d ||
          lookahead == 0x43d) ADVANCE(330);
      END_STATE();
    case 328:
      if (lookahead == 0x422 ||
          lookahead == 0x442 ||
          lookahead == 0x1c84 ||
          lookahead == 0x1c85) ADVANCE(331);
      END_STATE();
    case 329:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(332);
      END_STATE();
    case 330:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(333);
      END_STATE();
    case 331:
      if (lookahead == 0x427 ||
          lookahead == 0x447) ADVANCE(334);
      END_STATE();
    case 332:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(321);
      END_STATE();
    case 333:
      if (lookahead == 0x415 ||
          lookahead == 0x435) ADVANCE(190);
      END_STATE();
    case 334:
      if (lookahead == 0x418 ||
          lookahead == 0x438) ADVANCE(335);
      END_STATE();
    case 335:
      if (lookahead == 0x41a ||
          lookahead == 0x43a) ADVANCE(296);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 290, .reserved_word_set_id = 1},
  [2] = {.lex_state = 289, .reserved_word_set_id = 2},
  [3] = {.lex_state = 290, .reserved_word_set_id = 1},
  [4] = {.lex_state = 290, .reserved_word_set_id = 1},
  [5] = {.lex_state = 290, .reserved_word_set_id = 3},
  [6] = {.lex_state = 290, .reserved_word_set_id = 3},
  [7] = {.lex_state = 290, .reserved_word_set_id = 4},
  [8] = {.lex_state = 289, .reserved_word_set_id = 5},
  [9] = {.lex_state = 290, .reserved_word_set_id = 6},
  [10] = {.lex_state = 290, .reserved_word_set_id = 1},
  [11] = {.lex_state = 290, .reserved_word_set_id = 1},
  [12] = {.lex_state = 290, .reserved_word_set_id = 1},
  [13] = {.lex_state = 290, .reserved_word_set_id = 1},
  [14] = {.lex_state = 290, .reserved_word_set_id = 7},
  [15] = {.lex_state = 290, .reserved_word_set_id = 1},
  [16] = {.lex_state = 290, .reserved_word_set_id = 7},
  [17] = {.lex_state = 290, .reserved_word_set_id = 1},
  [18] = {.lex_state = 290, .reserved_word_set_id = 1},
  [19] = {.lex_state = 290, .reserved_word_set_id = 8},
  [20] = {.lex_state = 290, .reserved_word_set_id = 1},
  [21] = {.lex_state = 290, .reserved_word_set_id = 1},
  [22] = {.lex_state = 290, .reserved_word_set_id = 1},
  [23] = {.lex_state = 290, .reserved_word_set_id = 9},
  [24] = {.lex_state = 290, .reserved_word_set_id = 9},
  [25] = {.lex_state = 290, .reserved_word_set_id = 9},
  [26] = {.lex_state = 290, .reserved_word_set_id = 1},
  [27] = {.lex_state = 290, .reserved_word_set_id = 1},
  [28] = {.lex_state = 290, .reserved_word_set_id = 1},
  [29] = {.lex_state = 290, .reserved_word_set_id = 1},
  [30] = {.lex_state = 290, .reserved_word_set_id = 1},
  [31] = {.lex_state = 290, .reserved_word_set_id = 1},
  [32] = {.lex_state = 290, .reserved_word_set_id = 1},
  [33] = {.lex_state = 290, .reserved_word_set_id = 10},
  [34] = {.lex_state = 290, .reserved_word_set_id = 10},
  [35] = {.lex_state = 290, .reserved_word_set_id = 9},
  [36] = {.lex_state = 290, .reserved_word_set_id = 1},
  [37] = {.lex_state = 290, .reserved_word_set_id = 1},
  [38] = {.lex_state = 290, .reserved_word_set_id = 10},
  [39] = {.lex_state = 290, .reserved_word_set_id = 10},
  [40] = {.lex_state = 290, .reserved_word_set_id = 10},
  [41] = {.lex_state = 290, .reserved_word_set_id = 8},
  [42] = {.lex_state = 290, .reserved_word_set_id = 10},
  [43] = {.lex_state = 290, .reserved_word_set_id = 1},
  [44] = {.lex_state = 290, .reserved_word_set_id = 7},
  [45] = {.lex_state = 290, .reserved_word_set_id = 7},
  [46] = {.lex_state = 290, .reserved_word_set_id = 7},
  [47] = {.lex_state = 290, .reserved_word_set_id = 7},
  [48] = {.lex_state = 290, .reserved_word_set_id = 7},
  [49] = {.lex_state = 290, .reserved_word_set_id = 7},
  [50] = {.lex_state = 290, .reserved_word_set_id = 7},
  [51] = {.lex_state = 290, .reserved_word_set_id = 7},
  [52] = {.lex_state = 290, .reserved_word_set_id = 7},
  [53] = {.lex_state = 290, .reserved_word_set_id = 7},
  [54] = {.lex_state = 290, .reserved_word_set_id = 7},
  [55] = {.lex_state = 290, .reserved_word_set_id = 7},
  [56] = {.lex_state = 290, .reserved_word_set_id = 7},
  [57] = {.lex_state = 290, .reserved_word_set_id = 7},
  [58] = {.lex_state = 290, .reserved_word_set_id = 7},
  [59] = {.lex_state = 290, .reserved_word_set_id = 7},
  [60] = {.lex_state = 290, .reserved_word_set_id = 7},
  [61] = {.lex_state = 290, .reserved_word_set_id = 7},
  [62] = {.lex_state = 290, .reserved_word_set_id = 7},
  [63] = {.lex_state = 290, .reserved_word_set_id = 7},
  [64] = {.lex_state = 290, .reserved_word_set_id = 7},
  [65] = {.lex_state = 290, .reserved_word_set_id = 7},
  [66] = {.lex_state = 290, .reserved_word_set_id = 7},
  [67] = {.lex_state = 290, .reserved_word_set_id = 7},
  [68] = {.lex_state = 290, .reserved_word_set_id = 7},
  [69] = {.lex_state = 290, .reserved_word_set_id = 7},
  [70] = {.lex_state = 290, .reserved_word_set_id = 7},
  [71] = {.lex_state = 290, .reserved_word_set_id = 11},
  [72] = {.lex_state = 290, .reserved_word_set_id = 11},
  [73] = {.lex_state = 290, .reserved_word_set_id = 11},
  [74] = {.lex_state = 290, .reserved_word_set_id = 11},
  [75] = {.lex_state = 290, .reserved_word_set_id = 12},
  [76] = {.lex_state = 290, .reserved_word_set_id = 11},
  [77] = {.lex_state = 290, .reserved_word_set_id = 12},
  [78] = {.lex_state = 290, .reserved_word_set_id = 11},
  [79] = {.lex_state = 290, .reserved_word_set_id = 11},
  [80] = {.lex_state = 290, .reserved_word_set_id = 12},
  [81] = {.lex_state = 290, .reserved_word_set_id = 12},
  [82] = {.lex_state = 290, .reserved_word_set_id = 12},
  [83] = {.lex_state = 290, .reserved_word_set_id = 12},
  [84] = {.lex_state = 290, .reserved_word_set_id = 12},
  [85] = {.lex_state = 290, .reserved_word_set_id = 12},
  [86] = {.lex_state = 290, .reserved_word_set_id = 12},
  [87] = {.lex_state = 290, .reserved_word_set_id = 12},
  [88] = {.lex_state = 290, .reserved_word_set_id = 12},
  [89] = {.lex_state = 290, .reserved_word_set_id = 12},
  [90] = {.lex_state = 290, .reserved_word_set_id = 12},
  [91] = {.lex_state = 290, .reserved_word_set_id = 12},
  [92] = {.lex_state = 290, .reserved_word_set_id = 12},
  [93] = {.lex_state = 290, .reserved_word_set_id = 12},
  [94] = {.lex_state = 290, .reserved_word_set_id = 12},
  [95] = {.lex_state = 290, .reserved_word_set_id = 12},
  [96] = {.lex_state = 290, .reserved_word_set_id = 12},
  [97] = {.lex_state = 290, .reserved_word_set_id = 12},
  [98] = {.lex_state = 290, .reserved_word_set_id = 12},
  [99] = {.lex_state = 290, .reserved_word_set_id = 12},
  [100] = {.lex_state = 290, .reserved_word_set_id = 12},
  [101] = {.lex_state = 290, .reserved_word_set_id = 12},
  [102] = {.lex_state = 290, .reserved_word_set_id = 12},
  [103] = {.lex_state = 290, .reserved_word_set_id = 12},
  [104] = {.lex_state = 290, .reserved_word_set_id = 12},
  [105] = {.lex_state = 290, .reserved_word_set_id = 12},
  [106] = {.lex_state = 290, .reserved_word_set_id = 12},
  [107] = {.lex_state = 290, .reserved_word_set_id = 12},
  [108] = {.lex_state = 290, .reserved_word_set_id = 12},
  [109] = {.lex_state = 290, .reserved_word_set_id = 12},
  [110] = {.lex_state = 290, .reserved_word_set_id = 12},
  [111] = {.lex_state = 290, .reserved_word_set_id = 12},
  [112] = {.lex_state = 290, .reserved_word_set_id = 12},
  [113] = {.lex_state = 290, .reserved_word_set_id = 12},
  [114] = {.lex_state = 290, .reserved_word_set_id = 13},
  [115] = {.lex_state = 290, .reserved_word_set_id = 14},
  [116] = {.lex_state = 290, .reserved_word_set_id = 13},
  [117] = {.lex_state = 290, .reserved_word_set_id = 14},
  [118] = {.lex_state = 290, .reserved_word_set_id = 14},
  [119] = {.lex_state = 290, .reserved_word_set_id = 14},
  [120] = {.lex_state = 290, .reserved_word_set_id = 14},
  [121] = {.lex_state = 290, .reserved_word_set_id = 14},
  [122] = {.lex_state = 290, .reserved_word_set_id = 14},
  [123] = {.lex_state = 290, .reserved_word_set_id = 14},
  [124] = {.lex_state = 290, .reserved_word_set_id = 14},
  [125] = {.lex_state = 290, .reserved_word_set_id = 14},
  [126] = {.lex_state = 290, .reserved_word_set_id = 14},
  [127] = {.lex_state = 290, .reserved_word_set_id = 14},
  [128] = {.lex_state = 290, .reserved_word_set_id = 14},
  [129] = {.lex_state = 290, .reserved_word_set_id = 14},
  [130] = {.lex_state = 290, .reserved_word_set_id = 14},
  [131] = {.lex_state = 290, .reserved_word_set_id = 14},
  [132] = {.lex_state = 290, .reserved_word_set_id = 14},
  [133] = {.lex_state = 290, .reserved_word_set_id = 14},
  [134] = {.lex_state = 290, .reserved_word_set_id = 14},
  [135] = {.lex_state = 290, .reserved_word_set_id = 14},
  [136] = {.lex_state = 290, .reserved_word_set_id = 14},
  [137] = {.lex_state = 290, .reserved_word_set_id = 14},
  [138] = {.lex_state = 290, .reserved_word_set_id = 14},
  [139] = {.lex_state = 290, .reserved_word_set_id = 14},
  [140] = {.lex_state = 290, .reserved_word_set_id = 14},
  [141] = {.lex_state = 290, .reserved_word_set_id = 14},
  [142] = {.lex_state = 290, .reserved_word_set_id = 14},
  [143] = {.lex_state = 290, .reserved_word_set_id = 14},
  [144] = {.lex_state = 290, .reserved_word_set_id = 14},
  [145] = {.lex_state = 290, .reserved_word_set_id = 14},
  [146] = {.lex_state = 290, .reserved_word_set_id = 14},
  [147] = {.lex_state = 290, .reserved_word_set_id = 14},
  [148] = {.lex_state = 290, .reserved_word_set_id = 14},
  [149] = {.lex_state = 290, .reserved_word_set_id = 14},
  [150] = {.lex_state = 290, .reserved_word_set_id = 14},
  [151] = {.lex_state = 290, .reserved_word_set_id = 14},
  [152] = {.lex_state = 290, .reserved_word_set_id = 14},
  [153] = {.lex_state = 290, .reserved_word_set_id = 14},
  [154] = {.lex_state = 290, .reserved_word_set_id = 14},
  [155] = {.lex_state = 290, .reserved_word_set_id = 14},
  [156] = {.lex_state = 290, .reserved_word_set_id = 14},
  [157] = {.lex_state = 290, .reserved_word_set_id = 14},
  [158] = {.lex_state = 290, .reserved_word_set_id = 14},
  [159] = {.lex_state = 290, .reserved_word_set_id = 14},
  [160] = {.lex_state = 290, .reserved_word_set_id = 14},
  [161] = {.lex_state = 290, .reserved_word_set_id = 14},
  [162] = {.lex_state = 290, .reserved_word_set_id = 14},
  [163] = {.lex_state = 290, .reserved_word_set_id = 14},
  [164] = {.lex_state = 290, .reserved_word_set_id = 14},
  [165] = {.lex_state = 290, .reserved_word_set_id = 14},
  [166] = {.lex_state = 290, .reserved_word_set_id = 14},
  [167] = {.lex_state = 290, .reserved_word_set_id = 14},
  [168] = {.lex_state = 290, .reserved_word_set_id = 15},
  [169] = {.lex_state = 290, .reserved_word_set_id = 15},
  [170] = {.lex_state = 290, .reserved_word_set_id = 1},
  [171] = {.lex_state = 290, .reserved_word_set_id = 15},
  [172] = {.lex_state = 290, .reserved_word_set_id = 15},
  [173] = {.lex_state = 290, .reserved_word_set_id = 15},
  [174] = {.lex_state = 290, .reserved_word_set_id = 1},
  [175] = {.lex_state = 290, .reserved_word_set_id = 1},
  [176] = {.lex_state = 290, .reserved_word_set_id = 1},
  [177] = {.lex_state = 290, .reserved_word_set_id = 1},
  [178] = {.lex_state = 290, .reserved_word_set_id = 1},
  [179] = {.lex_state = 290, .reserved_word_set_id = 1},
  [180] = {.lex_state = 290, .reserved_word_set_id = 1},
  [181] = {.lex_state = 290, .reserved_word_set_id = 1},
  [182] = {.lex_state = 290, .reserved_word_set_id = 1},
  [183] = {.lex_state = 290, .reserved_word_set_id = 1},
  [184] = {.lex_state = 290, .reserved_word_set_id = 1},
  [185] = {.lex_state = 290, .reserved_word_set_id = 1},
  [186] = {.lex_state = 290, .reserved_word_set_id = 1},
  [187] = {.lex_state = 290, .reserved_word_set_id = 1},
  [188] = {.lex_state = 290, .reserved_word_set_id = 1},
  [189] = {.lex_state = 290, .reserved_word_set_id = 1},
  [190] = {.lex_state = 290, .reserved_word_set_id = 1},
  [191] = {.lex_state = 290, .reserved_word_set_id = 1},
  [192] = {.lex_state = 290, .reserved_word_set_id = 1},
  [193] = {.lex_state = 290, .reserved_word_set_id = 1},
  [194] = {.lex_state = 290, .reserved_word_set_id = 1},
  [195] = {.lex_state = 290, .reserved_word_set_id = 1},
  [196] = {.lex_state = 290, .reserved_word_set_id = 1},
  [197] = {.lex_state = 290, .reserved_word_set_id = 1},
  [198] = {.lex_state = 290, .reserved_word_set_id = 1},
  [199] = {.lex_state = 290, .reserved_word_set_id = 16},
  [200] = {.lex_state = 290, .reserved_word_set_id = 16},
  [201] = {.lex_state = 290, .reserved_word_set_id = 16},
  [202] = {.lex_state = 289, .reserved_word_set_id = 17},
  [203] = {.lex_state = 289, .reserved_word_set_id = 17},
  [204] = {.lex_state = 289, .reserved_word_set_id = 17},
  [205] = {.lex_state = 289, .reserved_word_set_id = 17},
  [206] = {.lex_state = 289, .reserved_word_set_id = 1},
  [207] = {.lex_state = 289, .reserved_word_set_id = 17},
  [208] = {.lex_state = 289, .reserved_word_set_id = 17},
  [209] = {.lex_state = 289, .reserved_word_set_id = 17},
  [210] = {.lex_state = 289, .reserved_word_set_id = 17},
  [211] = {.lex_state = 289, .reserved_word_set_id = 17},
  [212] = {.lex_state = 289, .reserved_word_set_id = 17},
  [213] = {.lex_state = 289, .reserved_word_set_id = 17},
  [214] = {.lex_state = 289, .reserved_word_set_id = 17},
  [215] = {.lex_state = 289, .reserved_word_set_id = 17},
  [216] = {.lex_state = 289, .reserved_word_set_id = 17},
  [217] = {.lex_state = 289, .reserved_word_set_id = 1},
  [218] = {.lex_state = 289, .reserved_word_set_id = 17},
  [219] = {.lex_state = 289, .reserved_word_set_id = 17},
  [220] = {.lex_state = 289, .reserved_word_set_id = 17},
  [221] = {.lex_state = 289, .reserved_word_set_id = 17},
  [222] = {.lex_state = 289, .reserved_word_set_id = 17},
  [223] = {.lex_state = 289, .reserved_word_set_id = 17},
  [224] = {.lex_state = 289, .reserved_word_set_id = 17},
  [225] = {.lex_state = 289, .reserved_word_set_id = 17},
  [226] = {.lex_state = 289, .reserved_word_set_id = 17},
  [227] = {.lex_state = 289, .reserved_word_set_id = 17},
  [228] = {.lex_state = 289, .reserved_word_set_id = 17},
  [229] = {.lex_state = 289, .reserved_word_set_id = 17},
  [230] = {.lex_state = 289, .reserved_word_set_id = 17},
  [231] = {.lex_state = 289, .reserved_word_set_id = 17},
  [232] = {.lex_state = 289, .reserved_word_set_id = 17},
  [233] = {.lex_state = 289, .reserved_word_set_id = 17},
  [234] = {.lex_state = 289, .reserved_word_set_id = 17},
  [235] = {.lex_state = 289, .reserved_word_set_id = 17},
  [236] = {.lex_state = 289, .reserved_word_set_id = 17},
  [237] = {.lex_state = 289, .reserved_word_set_id = 17},
  [238] = {.lex_state = 289, .reserved_word_set_id = 17},
  [239] = {.lex_state = 289, .reserved_word_set_id = 17},
  [240] = {.lex_state = 289, .reserved_word_set_id = 17},
  [241] = {.lex_state = 289, .reserved_word_set_id = 17},
  [242] = {.lex_state = 289, .reserved_word_set_id = 17},
  [243] = {.lex_state = 289, .reserved_word_set_id = 17},
  [244] = {.lex_state = 289, .reserved_word_set_id = 17},
  [245] = {.lex_state = 289, .reserved_word_set_id = 17},
  [246] = {.lex_state = 289, .reserved_word_set_id = 17},
  [247] = {.lex_state = 289, .reserved_word_set_id = 17},
  [248] = {.lex_state = 289, .reserved_word_set_id = 17},
  [249] = {.lex_state = 289, .reserved_word_set_id = 17},
  [250] = {.lex_state = 289, .reserved_word_set_id = 17},
  [251] = {.lex_state = 289, .reserved_word_set_id = 17},
  [252] = {.lex_state = 289, .reserved_word_set_id = 17},
  [253] = {.lex_state = 289, .reserved_word_set_id = 17},
  [254] = {.lex_state = 289, .reserved_word_set_id = 17},
  [255] = {.lex_state = 289, .reserved_word_set_id = 17},
  [256] = {.lex_state = 289, .reserved_word_set_id = 17},
  [257] = {.lex_state = 289, .reserved_word_set_id = 17},
  [258] = {.lex_state = 289, .reserved_word_set_id = 17},
  [259] = {.lex_state = 289, .reserved_word_set_id = 17},
  [260] = {.lex_state = 289, .reserved_word_set_id = 17},
  [261] = {.lex_state = 289, .reserved_word_set_id = 17},
  [262] = {.lex_state = 289, .reserved_word_set_id = 17},
  [263] = {.lex_state = 289, .reserved_word_set_id = 17},
  [264] = {.lex_state = 289, .reserved_word_set_id = 17},
  [265] = {.lex_state = 289, .reserved_word_set_id = 17},
  [266] = {.lex_state = 289, .reserved_word_set_id = 17},
  [267] = {.lex_state = 289, .reserved_word_set_id = 17},
  [268] = {.lex_state = 289, .reserved_word_set_id = 17},
  [269] = {.lex_state = 3},
  [270] = {.lex_state = 3},
  [271] = {.lex_state = 3},
  [272] = {.lex_state = 3},
  [273] = {.lex_state = 3},
  [274] = {.lex_state = 3},
  [275] = {.lex_state = 3},
  [276] = {.lex_state = 3},
  [277] = {.lex_state = 3},
  [278] = {.lex_state = 3},
  [279] = {.lex_state = 3},
  [280] = {.lex_state = 3},
  [281] = {.lex_state = 3},
  [282] = {.lex_state = 3},
  [283] = {.lex_state = 3},
  [284] = {.lex_state = 3},
  [285] = {.lex_state = 3},
  [286] = {.lex_state = 3},
  [287] = {.lex_state = 3},
  [288] = {.lex_state = 3},
  [289] = {.lex_state = 3},
  [290] = {.lex_state = 3},
  [291] = {.lex_state = 3},
  [292] = {.lex_state = 3},
  [293] = {.lex_state = 3},
  [294] = {.lex_state = 3},
  [295] = {.lex_state = 3},
  [296] = {.lex_state = 3},
  [297] = {.lex_state = 3},
  [298] = {.lex_state = 3},
  [299] = {.lex_state = 3},
  [300] = {.lex_state = 3},
  [301] = {.lex_state = 3},
  [302] = {.lex_state = 3},
  [303] = {.lex_state = 3},
  [304] = {.lex_state = 3},
  [305] = {.lex_state = 3},
  [306] = {.lex_state = 3},
  [307] = {.lex_state = 3},
  [308] = {.lex_state = 3},
  [309] = {.lex_state = 3},
  [310] = {.lex_state = 3},
  [311] = {.lex_state = 3},
  [312] = {.lex_state = 3},
  [313] = {.lex_state = 3},
  [314] = {.lex_state = 3},
  [315] = {.lex_state = 3},
  [316] = {.lex_state = 3},
  [317] = {.lex_state = 3},
  [318] = {.lex_state = 3},
  [319] = {.lex_state = 3},
  [320] = {.lex_state = 3},
  [321] = {.lex_state = 3},
  [322] = {.lex_state = 3},
  [323] = {.lex_state = 3},
  [324] = {.lex_state = 3},
  [325] = {.lex_state = 3},
  [326] = {.lex_state = 3},
  [327] = {.lex_state = 3},
  [328] = {.lex_state = 3},
  [329] = {.lex_state = 1},
  [330] = {.lex_state = 1},
  [331] = {.lex_state = 3},
  [332] = {.lex_state = 3},
  [333] = {.lex_state = 0},
  [334] = {.lex_state = 3},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 0},
  [337] = {.lex_state = 290, .reserved_word_set_id = 18},
  [338] = {.lex_state = 0},
  [339] = {.lex_state = 0},
  [340] = {.lex_state = 290, .reserved_word_set_id = 1},
  [341] = {.lex_state = 0},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 0},
  [344] = {.lex_state = 0},
  [345] = {.lex_state = 0},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 0},
  [348] = {.lex_state = 0},
  [349] = {.lex_state = 0},
  [350] = {.lex_state = 0},
  [351] = {.lex_state = 0},
  [352] = {.lex_state = 0},
  [353] = {.lex_state = 0},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 0},
  [357] = {.lex_state = 3},
  [358] = {.lex_state = 0},
  [359] = {.lex_state = 0},
  [360] = {.lex_state = 290, .reserved_word_set_id = 1},
  [361] = {.lex_state = 3},
  [362] = {.lex_state = 290, .reserved_word_set_id = 1},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 290, .reserved_word_set_id = 1},
  [365] = {.lex_state = 290, .reserved_word_set_id = 1},
  [366] = {.lex_state = 0},
  [367] = {.lex_state = 0},
  [368] = {.lex_state = 290, .reserved_word_set_id = 1},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 290, .reserved_word_set_id = 19},
  [371] = {.lex_state = 290, .reserved_word_set_id = 1},
  [372] = {.lex_state = 0},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 0},
  [375] = {.lex_state = 0},
  [376] = {.lex_state = 0},
  [377] = {.lex_state = 0},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 290, .reserved_word_set_id = 1},
  [381] = {.lex_state = 359},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 0},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 0},
  [388] = {.lex_state = 403},
  [389] = {.lex_state = 290, .reserved_word_set_id = 1},
  [390] = {.lex_state = 0},
  [391] = {.lex_state = 290, .reserved_word_set_id = 1},
  [392] = {.lex_state = 3},
  [393] = {.lex_state = 359},
  [394] = {.lex_state = 3},
  [395] = {.lex_state = 290, .reserved_word_set_id = 1},
  [396] = {.lex_state = 359},
  [397] = {.lex_state = 290, .reserved_word_set_id = 1},
  [398] = {.lex_state = 290, .reserved_word_set_id = 1},
  [399] = {.lex_state = 290, .reserved_word_set_id = 1},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 290, .reserved_word_set_id = 1},
  [402] = {.lex_state = 290, .reserved_word_set_id = 1},
  [403] = {.lex_state = 359},
  [404] = {.lex_state = 290, .reserved_word_set_id = 1},
  [405] = {.lex_state = 359},
  [406] = {.lex_state = 0},
  [407] = {.lex_state = 0},
  [408] = {.lex_state = 3},
  [409] = {.lex_state = 290, .reserved_word_set_id = 1},
  [410] = {.lex_state = 290, .reserved_word_set_id = 1},
  [411] = {.lex_state = 3},
  [412] = {.lex_state = 290, .reserved_word_set_id = 1},
  [413] = {(TSStateId)(-1),},
};

static const TSSymbol ts_reserved_words[20][MAX_RESERVED_WORD_SET_SIZE] = {
  [1] = {
    sym_IF_KEYWORD,
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_FOR_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_WHILE_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_GOTO_KEYWORD,
    sym_RETURN_KEYWORD,
    sym_BREAK_KEYWORD,
    sym_CONTINUE_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_VAR_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_TRY_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_RAISE_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_AWAIT_KEYWORD,
    sym_NEW_KEYWORD,
    sym_ADDHANDLER_KEYWORD,
    sym_REMOVEHANDLER_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_PREPROC_IF_KEYWORD,
    sym_PREPROC_ELSIF_KEYWORD,
    sym_PREPROC_ELSE_KEYWORD,
    sym_PREPROC_ENDIF_KEYWORD,
    sym_PREPROC_REGION_KEYWORD,
    sym_PREPROC_ENDREGION_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [2] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
  },
  [3] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [4] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [5] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
  },
  [6] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [7] = {
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_NEW_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [8] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [9] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [10] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [11] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_NEW_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [12] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [13] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [14] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [15] = {
    sym_THEN_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [16] = {
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_NEW_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [17] = {
    sym_IF_KEYWORD,
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_FOR_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_WHILE_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_GOTO_KEYWORD,
    sym_RETURN_KEYWORD,
    sym_BREAK_KEYWORD,
    sym_CONTINUE_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_VAR_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRY_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_RAISE_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_ADDHANDLER_KEYWORD,
    sym_REMOVEHANDLER_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_PREPROC_IF_KEYWORD,
    sym_PREPROC_ELSIF_KEYWORD,
    sym_PREPROC_ELSE_KEYWORD,
    sym_PREPROC_ENDIF_KEYWORD,
    sym_PREPROC_REGION_KEYWORD,
    sym_PREPROC_ENDREGION_KEYWORD,
  },
  [18] = {
    sym_IF_KEYWORD,
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_FOR_KEYWORD,
    sym_EACH_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_WHILE_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_GOTO_KEYWORD,
    sym_RETURN_KEYWORD,
    sym_BREAK_KEYWORD,
    sym_CONTINUE_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_VAR_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_TRY_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_RAISE_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_AWAIT_KEYWORD,
    sym_NEW_KEYWORD,
    sym_ADDHANDLER_KEYWORD,
    sym_REMOVEHANDLER_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_PREPROC_IF_KEYWORD,
    sym_PREPROC_ELSIF_KEYWORD,
    sym_PREPROC_ELSE_KEYWORD,
    sym_PREPROC_ENDIF_KEYWORD,
    sym_PREPROC_REGION_KEYWORD,
    sym_PREPROC_ENDREGION_KEYWORD,
    sym_NULL_KEYWORD,
  },
  [19] = {
    sym_IF_KEYWORD,
    sym_THEN_KEYWORD,
    sym_ELSIF_KEYWORD,
    sym_ELSE_KEYWORD,
    sym_ENDIF_KEYWORD,
    sym_FOR_KEYWORD,
    sym_IN_KEYWORD,
    sym_TO_KEYWORD,
    sym_WHILE_KEYWORD,
    sym_DO_KEYWORD,
    sym_ENDDO_KEYWORD,
    sym_GOTO_KEYWORD,
    sym_RETURN_KEYWORD,
    sym_BREAK_KEYWORD,
    sym_CONTINUE_KEYWORD,
    sym_PROCEDURE_KEYWORD,
    sym_FUNCTION_KEYWORD,
    sym_ENDPROCEDURE_KEYWORD,
    sym_ENDFUNCTION_KEYWORD,
    sym_VAR_KEYWORD,
    sym_EXPORT_KEYWORD,
    sym_VAL_KEYWORD,
    sym_TRUE_KEYWORD,
    sym_FALSE_KEYWORD,
    sym_UNDEFINED_KEYWORD,
    sym_TRY_KEYWORD,
    sym_EXCEPT_KEYWORD,
    sym_RAISE_KEYWORD,
    sym_ENDTRY_KEYWORD,
    sym_ASYNC_KEYWORD,
    sym_AWAIT_KEYWORD,
    sym_NEW_KEYWORD,
    sym_ADDHANDLER_KEYWORD,
    sym_REMOVEHANDLER_KEYWORD,
    sym_AND_KEYWORD,
    sym_OR_KEYWORD,
    sym_NOT_KEYWORD,
    sym_PREPROC_IF_KEYWORD,
    sym_PREPROC_ELSIF_KEYWORD,
    sym_PREPROC_ELSE_KEYWORD,
    sym_PREPROC_ENDIF_KEYWORD,
    sym_PREPROC_REGION_KEYWORD,
    sym_PREPROC_ENDREGION_KEYWORD,
    sym_NULL_KEYWORD,
  },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [sym_line_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [aux_sym_execute_statement_token1] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_LT_GT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_QMARK_LPAREN] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [sym_IF_KEYWORD] = ACTIONS(1),
    [sym_THEN_KEYWORD] = ACTIONS(1),
    [sym_ELSIF_KEYWORD] = ACTIONS(1),
    [sym_ELSE_KEYWORD] = ACTIONS(1),
    [sym_ENDIF_KEYWORD] = ACTIONS(1),
    [sym_FOR_KEYWORD] = ACTIONS(1),
    [sym_EACH_KEYWORD] = ACTIONS(1),
    [sym_IN_KEYWORD] = ACTIONS(1),
    [sym_TO_KEYWORD] = ACTIONS(1),
    [sym_WHILE_KEYWORD] = ACTIONS(1),
    [sym_DO_KEYWORD] = ACTIONS(1),
    [sym_ENDDO_KEYWORD] = ACTIONS(1),
    [sym_GOTO_KEYWORD] = ACTIONS(1),
    [sym_RETURN_KEYWORD] = ACTIONS(1),
    [sym_BREAK_KEYWORD] = ACTIONS(1),
    [sym_CONTINUE_KEYWORD] = ACTIONS(1),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(1),
    [sym_FUNCTION_KEYWORD] = ACTIONS(1),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(1),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(1),
    [sym_VAR_KEYWORD] = ACTIONS(1),
    [sym_EXPORT_KEYWORD] = ACTIONS(1),
    [sym_VAL_KEYWORD] = ACTIONS(1),
    [sym_FALSE_KEYWORD] = ACTIONS(1),
    [sym_UNDEFINED_KEYWORD] = ACTIONS(1),
    [sym_TRY_KEYWORD] = ACTIONS(1),
    [sym_EXCEPT_KEYWORD] = ACTIONS(1),
    [sym_RAISE_KEYWORD] = ACTIONS(1),
    [sym_ENDTRY_KEYWORD] = ACTIONS(1),
    [sym_ASYNC_KEYWORD] = ACTIONS(1),
    [sym_AWAIT_KEYWORD] = ACTIONS(1),
    [sym_NEW_KEYWORD] = ACTIONS(1),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(1),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(1),
    [sym_AND_KEYWORD] = ACTIONS(1),
    [sym_OR_KEYWORD] = ACTIONS(1),
    [sym_NOT_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(1),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(1),
    [sym_NULL_KEYWORD] = ACTIONS(1),
    [aux_sym_preprocessor_token1] = ACTIONS(1),
    [aux_sym_preprocessor_token2] = ACTIONS(1),
    [aux_sym_preprocessor_token3] = ACTIONS(1),
    [aux_sym_preprocessor_token4] = ACTIONS(1),
    [aux_sym_preprocessor_token5] = ACTIONS(1),
    [aux_sym_preprocessor_token6] = ACTIONS(1),
    [aux_sym_preprocessor_token7] = ACTIONS(1),
    [aux_sym_preprocessor_token8] = ACTIONS(1),
    [aux_sym_preprocessor_token9] = ACTIONS(1),
    [aux_sym_preprocessor_token10] = ACTIONS(1),
    [aux_sym_preprocessor_token11] = ACTIONS(1),
    [aux_sym_preprocessor_token12] = ACTIONS(1),
    [aux_sym_preprocessor_token13] = ACTIONS(1),
    [aux_sym_preprocessor_token14] = ACTIONS(1),
    [aux_sym_preprocessor_token15] = ACTIONS(1),
    [aux_sym_preprocessor_token16] = ACTIONS(1),
    [aux_sym_preprocessor_token17] = ACTIONS(1),
    [aux_sym_preprocessor_token18] = ACTIONS(1),
    [aux_sym_preprocessor_token19] = ACTIONS(1),
    [aux_sym_preprocessor_token20] = ACTIONS(1),
    [aux_sym_preprocessor_token21] = ACTIONS(1),
    [aux_sym_preprocessor_token22] = ACTIONS(1),
    [aux_sym_preprocessor_token23] = ACTIONS(1),
    [aux_sym_preprocessor_token24] = ACTIONS(1),
    [aux_sym_preprocessor_token25] = ACTIONS(1),
    [aux_sym_preprocessor_token26] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [sym_date] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(383),
    [sym__definition] = STATE(180),
    [sym_procedure_definition] = STATE(185),
    [sym_function_definition] = STATE(185),
    [sym_var_definition] = STATE(185),
    [sym__statement] = STATE(185),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(1),
    [aux_sym_source_file_repeat1] = STATE(4),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(27),
    [sym_FUNCTION_KEYWORD] = ACTIONS(29),
    [sym_VAR_KEYWORD] = ACTIONS(31),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ASYNC_KEYWORD] = ACTIONS(37),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(2)] = {
    [sym_expression] = STATE(74),
    [sym_unary_expression] = STATE(68),
    [sym_binary_expression] = STATE(68),
    [sym_ternary_expression] = STATE(68),
    [sym_new_expression] = STATE(68),
    [sym_new_expression_method] = STATE(68),
    [sym_call_expression] = STATE(68),
    [sym_await_expression] = STATE(68),
    [sym_property_access] = STATE(68),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(46),
    [sym__const_value] = STATE(57),
    [sym_boolean] = STATE(56),
    [sym_string] = STATE(56),
    [sym_multiline_string] = STATE(56),
    [sym_line_comment] = STATE(2),
    [ts_builtin_sym_end] = ACTIONS(55),
    [sym_identifier] = ACTIONS(57),
    [anon_sym_SEMI] = ACTIONS(59),
    [aux_sym_execute_statement_token1] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(63),
    [anon_sym_QMARK_LPAREN] = ACTIONS(65),
    [sym_IF_KEYWORD] = ACTIONS(61),
    [sym_ENDIF_KEYWORD] = ACTIONS(61),
    [sym_FOR_KEYWORD] = ACTIONS(61),
    [sym_WHILE_KEYWORD] = ACTIONS(61),
    [sym_ENDDO_KEYWORD] = ACTIONS(61),
    [sym_GOTO_KEYWORD] = ACTIONS(61),
    [sym_RETURN_KEYWORD] = ACTIONS(61),
    [sym_BREAK_KEYWORD] = ACTIONS(61),
    [sym_CONTINUE_KEYWORD] = ACTIONS(61),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(61),
    [sym_FUNCTION_KEYWORD] = ACTIONS(61),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(61),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(61),
    [sym_VAR_KEYWORD] = ACTIONS(61),
    [sym_TRUE_KEYWORD] = ACTIONS(67),
    [sym_FALSE_KEYWORD] = ACTIONS(67),
    [sym_UNDEFINED_KEYWORD] = ACTIONS(69),
    [sym_TRY_KEYWORD] = ACTIONS(61),
    [sym_RAISE_KEYWORD] = ACTIONS(61),
    [sym_ENDTRY_KEYWORD] = ACTIONS(61),
    [sym_ASYNC_KEYWORD] = ACTIONS(61),
    [sym_AWAIT_KEYWORD] = ACTIONS(71),
    [sym_NEW_KEYWORD] = ACTIONS(73),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(61),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(61),
    [sym_NOT_KEYWORD] = ACTIONS(75),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(61),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(55),
    [sym_NULL_KEYWORD] = ACTIONS(69),
    [aux_sym_preprocessor_token1] = ACTIONS(55),
    [aux_sym_preprocessor_token2] = ACTIONS(55),
    [aux_sym_preprocessor_token3] = ACTIONS(55),
    [aux_sym_preprocessor_token4] = ACTIONS(55),
    [aux_sym_preprocessor_token5] = ACTIONS(55),
    [aux_sym_preprocessor_token6] = ACTIONS(55),
    [aux_sym_preprocessor_token7] = ACTIONS(55),
    [aux_sym_preprocessor_token8] = ACTIONS(55),
    [aux_sym_preprocessor_token9] = ACTIONS(55),
    [aux_sym_preprocessor_token10] = ACTIONS(55),
    [aux_sym_preprocessor_token11] = ACTIONS(55),
    [aux_sym_preprocessor_token12] = ACTIONS(55),
    [aux_sym_preprocessor_token13] = ACTIONS(55),
    [aux_sym_preprocessor_token14] = ACTIONS(55),
    [aux_sym_preprocessor_token15] = ACTIONS(55),
    [aux_sym_preprocessor_token16] = ACTIONS(55),
    [aux_sym_preprocessor_token17] = ACTIONS(61),
    [aux_sym_preprocessor_token18] = ACTIONS(61),
    [aux_sym_preprocessor_token19] = ACTIONS(61),
    [aux_sym_preprocessor_token20] = ACTIONS(61),
    [aux_sym_preprocessor_token21] = ACTIONS(55),
    [aux_sym_preprocessor_token22] = ACTIONS(55),
    [aux_sym_preprocessor_token23] = ACTIONS(55),
    [aux_sym_preprocessor_token24] = ACTIONS(55),
    [aux_sym_preprocessor_token25] = ACTIONS(61),
    [aux_sym_preprocessor_token26] = ACTIONS(61),
    [sym_number] = ACTIONS(69),
    [sym_date] = ACTIONS(77),
    [anon_sym_DQUOTE] = ACTIONS(79),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(3)] = {
    [sym__definition] = STATE(180),
    [sym_procedure_definition] = STATE(185),
    [sym_function_definition] = STATE(185),
    [sym_var_definition] = STATE(185),
    [sym__statement] = STATE(185),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(3),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [aux_sym_execute_statement_token1] = ACTIONS(86),
    [anon_sym_TILDE] = ACTIONS(89),
    [sym_IF_KEYWORD] = ACTIONS(92),
    [sym_FOR_KEYWORD] = ACTIONS(95),
    [sym_WHILE_KEYWORD] = ACTIONS(98),
    [sym_GOTO_KEYWORD] = ACTIONS(101),
    [sym_RETURN_KEYWORD] = ACTIONS(104),
    [sym_BREAK_KEYWORD] = ACTIONS(107),
    [sym_CONTINUE_KEYWORD] = ACTIONS(110),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(113),
    [sym_FUNCTION_KEYWORD] = ACTIONS(116),
    [sym_VAR_KEYWORD] = ACTIONS(119),
    [sym_TRY_KEYWORD] = ACTIONS(122),
    [sym_RAISE_KEYWORD] = ACTIONS(125),
    [sym_ASYNC_KEYWORD] = ACTIONS(128),
    [sym_AWAIT_KEYWORD] = ACTIONS(131),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(134),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(137),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(140),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(140),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(143),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(146),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(149),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(146),
    [aux_sym_preprocessor_token1] = ACTIONS(146),
    [aux_sym_preprocessor_token2] = ACTIONS(146),
    [aux_sym_preprocessor_token3] = ACTIONS(146),
    [aux_sym_preprocessor_token4] = ACTIONS(146),
    [aux_sym_preprocessor_token5] = ACTIONS(146),
    [aux_sym_preprocessor_token6] = ACTIONS(146),
    [aux_sym_preprocessor_token7] = ACTIONS(146),
    [aux_sym_preprocessor_token8] = ACTIONS(146),
    [aux_sym_preprocessor_token9] = ACTIONS(152),
    [aux_sym_preprocessor_token10] = ACTIONS(152),
    [aux_sym_preprocessor_token11] = ACTIONS(152),
    [aux_sym_preprocessor_token12] = ACTIONS(152),
    [aux_sym_preprocessor_token13] = ACTIONS(152),
    [aux_sym_preprocessor_token14] = ACTIONS(152),
    [aux_sym_preprocessor_token15] = ACTIONS(152),
    [aux_sym_preprocessor_token16] = ACTIONS(152),
    [aux_sym_preprocessor_token17] = ACTIONS(143),
    [aux_sym_preprocessor_token18] = ACTIONS(143),
    [aux_sym_preprocessor_token19] = ACTIONS(143),
    [aux_sym_preprocessor_token20] = ACTIONS(143),
    [aux_sym_preprocessor_token21] = ACTIONS(146),
    [aux_sym_preprocessor_token22] = ACTIONS(146),
    [aux_sym_preprocessor_token23] = ACTIONS(146),
    [aux_sym_preprocessor_token24] = ACTIONS(146),
    [aux_sym_preprocessor_token25] = ACTIONS(143),
    [aux_sym_preprocessor_token26] = ACTIONS(143),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(4)] = {
    [sym__definition] = STATE(180),
    [sym_procedure_definition] = STATE(185),
    [sym_function_definition] = STATE(185),
    [sym_var_definition] = STATE(185),
    [sym__statement] = STATE(185),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(4),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(27),
    [sym_FUNCTION_KEYWORD] = ACTIONS(29),
    [sym_VAR_KEYWORD] = ACTIONS(31),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ASYNC_KEYWORD] = ACTIONS(37),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(5)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_elseif_clause] = STATE(357),
    [sym_else_clause] = STATE(394),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(5),
    [aux_sym_procedure_definition_repeat1] = STATE(6),
    [aux_sym_if_statement_repeat1] = STATE(331),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ELSIF_KEYWORD] = ACTIONS(161),
    [sym_ELSE_KEYWORD] = ACTIONS(163),
    [sym_ENDIF_KEYWORD] = ACTIONS(165),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(6)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_elseif_clause] = STATE(357),
    [sym_else_clause] = STATE(408),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(6),
    [aux_sym_procedure_definition_repeat1] = STATE(9),
    [aux_sym_if_statement_repeat1] = STATE(332),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ELSIF_KEYWORD] = ACTIONS(161),
    [sym_ELSE_KEYWORD] = ACTIONS(163),
    [sym_ENDIF_KEYWORD] = ACTIONS(179),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(7)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(7),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(181),
    [aux_sym_execute_statement_token1] = ACTIONS(184),
    [anon_sym_TILDE] = ACTIONS(187),
    [sym_IF_KEYWORD] = ACTIONS(190),
    [sym_ENDIF_KEYWORD] = ACTIONS(193),
    [sym_FOR_KEYWORD] = ACTIONS(195),
    [sym_WHILE_KEYWORD] = ACTIONS(198),
    [sym_ENDDO_KEYWORD] = ACTIONS(193),
    [sym_GOTO_KEYWORD] = ACTIONS(201),
    [sym_RETURN_KEYWORD] = ACTIONS(204),
    [sym_BREAK_KEYWORD] = ACTIONS(207),
    [sym_CONTINUE_KEYWORD] = ACTIONS(210),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(193),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(193),
    [sym_VAR_KEYWORD] = ACTIONS(213),
    [sym_TRY_KEYWORD] = ACTIONS(216),
    [sym_RAISE_KEYWORD] = ACTIONS(219),
    [sym_ENDTRY_KEYWORD] = ACTIONS(193),
    [sym_AWAIT_KEYWORD] = ACTIONS(222),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(225),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(228),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(231),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(231),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(234),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(237),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(240),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(237),
    [aux_sym_preprocessor_token1] = ACTIONS(237),
    [aux_sym_preprocessor_token2] = ACTIONS(237),
    [aux_sym_preprocessor_token3] = ACTIONS(237),
    [aux_sym_preprocessor_token4] = ACTIONS(237),
    [aux_sym_preprocessor_token5] = ACTIONS(237),
    [aux_sym_preprocessor_token6] = ACTIONS(237),
    [aux_sym_preprocessor_token7] = ACTIONS(237),
    [aux_sym_preprocessor_token8] = ACTIONS(237),
    [aux_sym_preprocessor_token9] = ACTIONS(243),
    [aux_sym_preprocessor_token10] = ACTIONS(243),
    [aux_sym_preprocessor_token11] = ACTIONS(243),
    [aux_sym_preprocessor_token12] = ACTIONS(243),
    [aux_sym_preprocessor_token13] = ACTIONS(243),
    [aux_sym_preprocessor_token14] = ACTIONS(243),
    [aux_sym_preprocessor_token15] = ACTIONS(243),
    [aux_sym_preprocessor_token16] = ACTIONS(243),
    [aux_sym_preprocessor_token17] = ACTIONS(234),
    [aux_sym_preprocessor_token18] = ACTIONS(234),
    [aux_sym_preprocessor_token19] = ACTIONS(234),
    [aux_sym_preprocessor_token20] = ACTIONS(234),
    [aux_sym_preprocessor_token21] = ACTIONS(237),
    [aux_sym_preprocessor_token22] = ACTIONS(237),
    [aux_sym_preprocessor_token23] = ACTIONS(237),
    [aux_sym_preprocessor_token24] = ACTIONS(237),
    [aux_sym_preprocessor_token25] = ACTIONS(234),
    [aux_sym_preprocessor_token26] = ACTIONS(234),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(8)] = {
    [sym_expression] = STATE(112),
    [sym_unary_expression] = STATE(97),
    [sym_binary_expression] = STATE(97),
    [sym_ternary_expression] = STATE(97),
    [sym_new_expression] = STATE(97),
    [sym_new_expression_method] = STATE(97),
    [sym_call_expression] = STATE(97),
    [sym_await_expression] = STATE(97),
    [sym_property_access] = STATE(97),
    [sym_access] = STATE(369),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(81),
    [sym__access_property] = STATE(81),
    [sym_method_call] = STATE(82),
    [sym__const_value] = STATE(98),
    [sym_boolean] = STATE(96),
    [sym_string] = STATE(96),
    [sym_multiline_string] = STATE(96),
    [sym_line_comment] = STATE(8),
    [sym_identifier] = ACTIONS(246),
    [anon_sym_SEMI] = ACTIONS(59),
    [aux_sym_execute_statement_token1] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(55),
    [anon_sym_DASH] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(248),
    [anon_sym_QMARK_LPAREN] = ACTIONS(250),
    [sym_IF_KEYWORD] = ACTIONS(61),
    [sym_ELSIF_KEYWORD] = ACTIONS(61),
    [sym_ELSE_KEYWORD] = ACTIONS(61),
    [sym_ENDIF_KEYWORD] = ACTIONS(61),
    [sym_FOR_KEYWORD] = ACTIONS(61),
    [sym_WHILE_KEYWORD] = ACTIONS(61),
    [sym_GOTO_KEYWORD] = ACTIONS(61),
    [sym_RETURN_KEYWORD] = ACTIONS(61),
    [sym_BREAK_KEYWORD] = ACTIONS(61),
    [sym_CONTINUE_KEYWORD] = ACTIONS(61),
    [sym_VAR_KEYWORD] = ACTIONS(61),
    [sym_TRUE_KEYWORD] = ACTIONS(252),
    [sym_FALSE_KEYWORD] = ACTIONS(252),
    [sym_UNDEFINED_KEYWORD] = ACTIONS(254),
    [sym_TRY_KEYWORD] = ACTIONS(61),
    [sym_EXCEPT_KEYWORD] = ACTIONS(61),
    [sym_RAISE_KEYWORD] = ACTIONS(61),
    [sym_AWAIT_KEYWORD] = ACTIONS(256),
    [sym_NEW_KEYWORD] = ACTIONS(258),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(61),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(61),
    [sym_NOT_KEYWORD] = ACTIONS(260),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(61),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(55),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(55),
    [sym_NULL_KEYWORD] = ACTIONS(254),
    [aux_sym_preprocessor_token1] = ACTIONS(55),
    [aux_sym_preprocessor_token2] = ACTIONS(55),
    [aux_sym_preprocessor_token3] = ACTIONS(55),
    [aux_sym_preprocessor_token4] = ACTIONS(55),
    [aux_sym_preprocessor_token5] = ACTIONS(55),
    [aux_sym_preprocessor_token6] = ACTIONS(55),
    [aux_sym_preprocessor_token7] = ACTIONS(55),
    [aux_sym_preprocessor_token8] = ACTIONS(55),
    [aux_sym_preprocessor_token9] = ACTIONS(55),
    [aux_sym_preprocessor_token10] = ACTIONS(55),
    [aux_sym_preprocessor_token11] = ACTIONS(55),
    [aux_sym_preprocessor_token12] = ACTIONS(55),
    [aux_sym_preprocessor_token13] = ACTIONS(55),
    [aux_sym_preprocessor_token14] = ACTIONS(55),
    [aux_sym_preprocessor_token15] = ACTIONS(55),
    [aux_sym_preprocessor_token16] = ACTIONS(55),
    [aux_sym_preprocessor_token17] = ACTIONS(61),
    [aux_sym_preprocessor_token18] = ACTIONS(61),
    [aux_sym_preprocessor_token19] = ACTIONS(61),
    [aux_sym_preprocessor_token20] = ACTIONS(61),
    [aux_sym_preprocessor_token21] = ACTIONS(55),
    [aux_sym_preprocessor_token22] = ACTIONS(55),
    [aux_sym_preprocessor_token23] = ACTIONS(55),
    [aux_sym_preprocessor_token24] = ACTIONS(55),
    [aux_sym_preprocessor_token25] = ACTIONS(61),
    [aux_sym_preprocessor_token26] = ACTIONS(61),
    [sym_number] = ACTIONS(254),
    [sym_date] = ACTIONS(262),
    [anon_sym_DQUOTE] = ACTIONS(264),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(9)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(9),
    [aux_sym_procedure_definition_repeat1] = STATE(9),
    [sym_identifier] = ACTIONS(266),
    [aux_sym_execute_statement_token1] = ACTIONS(269),
    [anon_sym_TILDE] = ACTIONS(187),
    [sym_IF_KEYWORD] = ACTIONS(190),
    [sym_ELSIF_KEYWORD] = ACTIONS(193),
    [sym_ELSE_KEYWORD] = ACTIONS(193),
    [sym_ENDIF_KEYWORD] = ACTIONS(193),
    [sym_FOR_KEYWORD] = ACTIONS(195),
    [sym_WHILE_KEYWORD] = ACTIONS(198),
    [sym_GOTO_KEYWORD] = ACTIONS(201),
    [sym_RETURN_KEYWORD] = ACTIONS(272),
    [sym_BREAK_KEYWORD] = ACTIONS(207),
    [sym_CONTINUE_KEYWORD] = ACTIONS(210),
    [sym_VAR_KEYWORD] = ACTIONS(213),
    [sym_TRY_KEYWORD] = ACTIONS(216),
    [sym_EXCEPT_KEYWORD] = ACTIONS(193),
    [sym_RAISE_KEYWORD] = ACTIONS(275),
    [sym_AWAIT_KEYWORD] = ACTIONS(278),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(281),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(284),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(231),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(231),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(234),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(237),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(240),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(237),
    [aux_sym_preprocessor_token1] = ACTIONS(237),
    [aux_sym_preprocessor_token2] = ACTIONS(237),
    [aux_sym_preprocessor_token3] = ACTIONS(237),
    [aux_sym_preprocessor_token4] = ACTIONS(237),
    [aux_sym_preprocessor_token5] = ACTIONS(237),
    [aux_sym_preprocessor_token6] = ACTIONS(237),
    [aux_sym_preprocessor_token7] = ACTIONS(237),
    [aux_sym_preprocessor_token8] = ACTIONS(237),
    [aux_sym_preprocessor_token9] = ACTIONS(243),
    [aux_sym_preprocessor_token10] = ACTIONS(243),
    [aux_sym_preprocessor_token11] = ACTIONS(243),
    [aux_sym_preprocessor_token12] = ACTIONS(243),
    [aux_sym_preprocessor_token13] = ACTIONS(243),
    [aux_sym_preprocessor_token14] = ACTIONS(243),
    [aux_sym_preprocessor_token15] = ACTIONS(243),
    [aux_sym_preprocessor_token16] = ACTIONS(243),
    [aux_sym_preprocessor_token17] = ACTIONS(234),
    [aux_sym_preprocessor_token18] = ACTIONS(234),
    [aux_sym_preprocessor_token19] = ACTIONS(234),
    [aux_sym_preprocessor_token20] = ACTIONS(234),
    [aux_sym_preprocessor_token21] = ACTIONS(237),
    [aux_sym_preprocessor_token22] = ACTIONS(237),
    [aux_sym_preprocessor_token23] = ACTIONS(237),
    [aux_sym_preprocessor_token24] = ACTIONS(237),
    [aux_sym_preprocessor_token25] = ACTIONS(234),
    [aux_sym_preprocessor_token26] = ACTIONS(234),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(10)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(10),
    [aux_sym_procedure_definition_repeat1] = STATE(11),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ELSIF_KEYWORD] = ACTIONS(287),
    [sym_ELSE_KEYWORD] = ACTIONS(287),
    [sym_ENDIF_KEYWORD] = ACTIONS(287),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(11)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(11),
    [aux_sym_procedure_definition_repeat1] = STATE(9),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ELSIF_KEYWORD] = ACTIONS(289),
    [sym_ELSE_KEYWORD] = ACTIONS(289),
    [sym_ENDIF_KEYWORD] = ACTIONS(289),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(12)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(12),
    [aux_sym_procedure_definition_repeat1] = STATE(20),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(291),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_EXPORT_KEYWORD] = ACTIONS(293),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(13)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(13),
    [aux_sym_procedure_definition_repeat1] = STATE(22),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(295),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_EXPORT_KEYWORD] = ACTIONS(297),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(14)] = {
    [sym_arguments] = STATE(53),
    [sym_line_comment] = STATE(14),
    [ts_builtin_sym_end] = ACTIONS(299),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_RPAREN] = ACTIONS(299),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_RBRACK] = ACTIONS(299),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_THEN_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_DO_KEYWORD] = ACTIONS(301),
    [sym_ENDDO_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_FUNCTION_KEYWORD] = ACTIONS(301),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_ENDTRY_KEYWORD] = ACTIONS(301),
    [sym_ASYNC_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(15)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(15),
    [aux_sym_procedure_definition_repeat1] = STATE(30),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(307),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_EXPORT_KEYWORD] = ACTIONS(309),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(16)] = {
    [sym_arguments] = STATE(53),
    [sym_line_comment] = STATE(16),
    [ts_builtin_sym_end] = ACTIONS(311),
    [sym_identifier] = ACTIONS(313),
    [anon_sym_COMMA] = ACTIONS(311),
    [anon_sym_SEMI] = ACTIONS(311),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_RPAREN] = ACTIONS(311),
    [anon_sym_EQ] = ACTIONS(311),
    [aux_sym_execute_statement_token1] = ACTIONS(313),
    [anon_sym_TILDE] = ACTIONS(311),
    [anon_sym_DASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(311),
    [anon_sym_LT_GT] = ACTIONS(311),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT_EQ] = ACTIONS(311),
    [anon_sym_LT_EQ] = ACTIONS(311),
    [anon_sym_STAR] = ACTIONS(311),
    [anon_sym_SLASH] = ACTIONS(313),
    [anon_sym_PERCENT] = ACTIONS(311),
    [anon_sym_DOT] = ACTIONS(311),
    [anon_sym_LBRACK] = ACTIONS(311),
    [anon_sym_RBRACK] = ACTIONS(311),
    [sym_IF_KEYWORD] = ACTIONS(313),
    [sym_THEN_KEYWORD] = ACTIONS(313),
    [sym_ENDIF_KEYWORD] = ACTIONS(313),
    [sym_FOR_KEYWORD] = ACTIONS(313),
    [sym_WHILE_KEYWORD] = ACTIONS(313),
    [sym_DO_KEYWORD] = ACTIONS(313),
    [sym_ENDDO_KEYWORD] = ACTIONS(313),
    [sym_GOTO_KEYWORD] = ACTIONS(313),
    [sym_RETURN_KEYWORD] = ACTIONS(313),
    [sym_BREAK_KEYWORD] = ACTIONS(313),
    [sym_CONTINUE_KEYWORD] = ACTIONS(313),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(313),
    [sym_FUNCTION_KEYWORD] = ACTIONS(313),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(313),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(313),
    [sym_VAR_KEYWORD] = ACTIONS(313),
    [sym_TRY_KEYWORD] = ACTIONS(313),
    [sym_RAISE_KEYWORD] = ACTIONS(313),
    [sym_ENDTRY_KEYWORD] = ACTIONS(313),
    [sym_ASYNC_KEYWORD] = ACTIONS(313),
    [sym_AWAIT_KEYWORD] = ACTIONS(313),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(313),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(313),
    [sym_AND_KEYWORD] = ACTIONS(313),
    [sym_OR_KEYWORD] = ACTIONS(313),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(313),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(311),
    [aux_sym_preprocessor_token1] = ACTIONS(311),
    [aux_sym_preprocessor_token2] = ACTIONS(311),
    [aux_sym_preprocessor_token3] = ACTIONS(311),
    [aux_sym_preprocessor_token4] = ACTIONS(311),
    [aux_sym_preprocessor_token5] = ACTIONS(311),
    [aux_sym_preprocessor_token6] = ACTIONS(311),
    [aux_sym_preprocessor_token7] = ACTIONS(311),
    [aux_sym_preprocessor_token8] = ACTIONS(311),
    [aux_sym_preprocessor_token9] = ACTIONS(311),
    [aux_sym_preprocessor_token10] = ACTIONS(311),
    [aux_sym_preprocessor_token11] = ACTIONS(311),
    [aux_sym_preprocessor_token12] = ACTIONS(311),
    [aux_sym_preprocessor_token13] = ACTIONS(311),
    [aux_sym_preprocessor_token14] = ACTIONS(311),
    [aux_sym_preprocessor_token15] = ACTIONS(311),
    [aux_sym_preprocessor_token16] = ACTIONS(311),
    [aux_sym_preprocessor_token17] = ACTIONS(313),
    [aux_sym_preprocessor_token18] = ACTIONS(313),
    [aux_sym_preprocessor_token19] = ACTIONS(313),
    [aux_sym_preprocessor_token20] = ACTIONS(313),
    [aux_sym_preprocessor_token21] = ACTIONS(311),
    [aux_sym_preprocessor_token22] = ACTIONS(311),
    [aux_sym_preprocessor_token23] = ACTIONS(311),
    [aux_sym_preprocessor_token24] = ACTIONS(311),
    [aux_sym_preprocessor_token25] = ACTIONS(313),
    [aux_sym_preprocessor_token26] = ACTIONS(313),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(17)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(17),
    [aux_sym_procedure_definition_repeat1] = STATE(32),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(315),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_EXPORT_KEYWORD] = ACTIONS(317),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(18)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(18),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(319),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(19)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(19),
    [aux_sym_procedure_definition_repeat1] = STATE(41),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_EXCEPT_KEYWORD] = ACTIONS(321),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(20)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(20),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(323),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(21)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(21),
    [aux_sym_procedure_definition_repeat1] = STATE(28),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(325),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(22)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(22),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(327),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(23)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(23),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ENDTRY_KEYWORD] = ACTIONS(329),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(24)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(24),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ENDTRY_KEYWORD] = ACTIONS(331),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(25)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(25),
    [aux_sym_procedure_definition_repeat1] = STATE(23),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ENDTRY_KEYWORD] = ACTIONS(331),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(26)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(26),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ENDIF_KEYWORD] = ACTIONS(333),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(27)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(27),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(335),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(28)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(28),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(337),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(29)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(29),
    [aux_sym_procedure_definition_repeat1] = STATE(18),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(339),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(30)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(30),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(341),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(31)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(31),
    [aux_sym_procedure_definition_repeat1] = STATE(36),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(343),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(32)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(32),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(345),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(33)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(33),
    [aux_sym_procedure_definition_repeat1] = STATE(42),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(347),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(34)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(34),
    [aux_sym_procedure_definition_repeat1] = STATE(38),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(349),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(35)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(35),
    [aux_sym_procedure_definition_repeat1] = STATE(24),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_ENDTRY_KEYWORD] = ACTIONS(351),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(36)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(36),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(353),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(37)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(37),
    [aux_sym_procedure_definition_repeat1] = STATE(26),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_ENDIF_KEYWORD] = ACTIONS(355),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(38)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(38),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(357),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(39)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(39),
    [aux_sym_procedure_definition_repeat1] = STATE(40),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(359),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(40)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(40),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(361),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(41)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(382),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(367),
    [sym__access_call] = STATE(80),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(41),
    [aux_sym_procedure_definition_repeat1] = STATE(9),
    [sym_identifier] = ACTIONS(157),
    [aux_sym_execute_statement_token1] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(167),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_EXCEPT_KEYWORD] = ACTIONS(363),
    [sym_RAISE_KEYWORD] = ACTIONS(171),
    [sym_AWAIT_KEYWORD] = ACTIONS(173),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(175),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(177),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(42)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(42),
    [aux_sym_procedure_definition_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_ENDDO_KEYWORD] = ACTIONS(365),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(43)] = {
    [sym__statement] = STATE(173),
    [sym_call_statement] = STATE(142),
    [sym_assignment_statement] = STATE(142),
    [sym_return_statement] = STATE(142),
    [sym_try_statement] = STATE(142),
    [sym_rise_error_statement] = STATE(142),
    [sym_var_statement] = STATE(142),
    [sym_if_statement] = STATE(142),
    [sym_while_statement] = STATE(142),
    [sym_for_statement] = STATE(142),
    [sym_for_each_statement] = STATE(142),
    [sym_continue_statement] = STATE(142),
    [sym_break_statement] = STATE(142),
    [sym_execute_statement] = STATE(142),
    [sym_goto_statement] = STATE(142),
    [sym_label_statement] = STATE(142),
    [sym_add_handler_statement] = STATE(142),
    [sym_remove_handler_statement] = STATE(142),
    [sym_await_statement] = STATE(142),
    [sym_call_expression] = STATE(132),
    [sym_await_expression] = STATE(119),
    [sym__assignment_member] = STATE(400),
    [sym_property_access] = STATE(386),
    [sym_access] = STATE(363),
    [sym__access_call] = STATE(45),
    [sym__access_index] = STATE(44),
    [sym__access_property] = STATE(44),
    [sym_method_call] = STATE(115),
    [sym_preprocessor] = STATE(142),
    [sym_line_comment] = STATE(43),
    [aux_sym_procedure_definition_repeat1] = STATE(27),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_execute_statement_token1] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [sym_IF_KEYWORD] = ACTIONS(13),
    [sym_FOR_KEYWORD] = ACTIONS(15),
    [sym_WHILE_KEYWORD] = ACTIONS(17),
    [sym_GOTO_KEYWORD] = ACTIONS(19),
    [sym_RETURN_KEYWORD] = ACTIONS(21),
    [sym_BREAK_KEYWORD] = ACTIONS(23),
    [sym_CONTINUE_KEYWORD] = ACTIONS(25),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(367),
    [sym_VAR_KEYWORD] = ACTIONS(169),
    [sym_TRY_KEYWORD] = ACTIONS(33),
    [sym_RAISE_KEYWORD] = ACTIONS(35),
    [sym_AWAIT_KEYWORD] = ACTIONS(39),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(41),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(43),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(45),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(47),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(49),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(51),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(49),
    [aux_sym_preprocessor_token1] = ACTIONS(49),
    [aux_sym_preprocessor_token2] = ACTIONS(49),
    [aux_sym_preprocessor_token3] = ACTIONS(49),
    [aux_sym_preprocessor_token4] = ACTIONS(49),
    [aux_sym_preprocessor_token5] = ACTIONS(49),
    [aux_sym_preprocessor_token6] = ACTIONS(49),
    [aux_sym_preprocessor_token7] = ACTIONS(49),
    [aux_sym_preprocessor_token8] = ACTIONS(49),
    [aux_sym_preprocessor_token9] = ACTIONS(53),
    [aux_sym_preprocessor_token10] = ACTIONS(53),
    [aux_sym_preprocessor_token11] = ACTIONS(53),
    [aux_sym_preprocessor_token12] = ACTIONS(53),
    [aux_sym_preprocessor_token13] = ACTIONS(53),
    [aux_sym_preprocessor_token14] = ACTIONS(53),
    [aux_sym_preprocessor_token15] = ACTIONS(53),
    [aux_sym_preprocessor_token16] = ACTIONS(53),
    [aux_sym_preprocessor_token17] = ACTIONS(47),
    [aux_sym_preprocessor_token18] = ACTIONS(47),
    [aux_sym_preprocessor_token19] = ACTIONS(47),
    [aux_sym_preprocessor_token20] = ACTIONS(47),
    [aux_sym_preprocessor_token21] = ACTIONS(49),
    [aux_sym_preprocessor_token22] = ACTIONS(49),
    [aux_sym_preprocessor_token23] = ACTIONS(49),
    [aux_sym_preprocessor_token24] = ACTIONS(49),
    [aux_sym_preprocessor_token25] = ACTIONS(47),
    [aux_sym_preprocessor_token26] = ACTIONS(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(44)] = {
    [sym_line_comment] = STATE(44),
    [ts_builtin_sym_end] = ACTIONS(369),
    [sym_identifier] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(369),
    [aux_sym_execute_statement_token1] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_LT_GT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_RBRACK] = ACTIONS(369),
    [sym_IF_KEYWORD] = ACTIONS(371),
    [sym_THEN_KEYWORD] = ACTIONS(371),
    [sym_ENDIF_KEYWORD] = ACTIONS(371),
    [sym_FOR_KEYWORD] = ACTIONS(371),
    [sym_WHILE_KEYWORD] = ACTIONS(371),
    [sym_DO_KEYWORD] = ACTIONS(371),
    [sym_ENDDO_KEYWORD] = ACTIONS(371),
    [sym_GOTO_KEYWORD] = ACTIONS(371),
    [sym_RETURN_KEYWORD] = ACTIONS(371),
    [sym_BREAK_KEYWORD] = ACTIONS(371),
    [sym_CONTINUE_KEYWORD] = ACTIONS(371),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(371),
    [sym_FUNCTION_KEYWORD] = ACTIONS(371),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(371),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(371),
    [sym_VAR_KEYWORD] = ACTIONS(371),
    [sym_TRY_KEYWORD] = ACTIONS(371),
    [sym_RAISE_KEYWORD] = ACTIONS(371),
    [sym_ENDTRY_KEYWORD] = ACTIONS(371),
    [sym_ASYNC_KEYWORD] = ACTIONS(371),
    [sym_AWAIT_KEYWORD] = ACTIONS(371),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(371),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(371),
    [sym_AND_KEYWORD] = ACTIONS(371),
    [sym_OR_KEYWORD] = ACTIONS(371),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(371),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(369),
    [aux_sym_preprocessor_token1] = ACTIONS(369),
    [aux_sym_preprocessor_token2] = ACTIONS(369),
    [aux_sym_preprocessor_token3] = ACTIONS(369),
    [aux_sym_preprocessor_token4] = ACTIONS(369),
    [aux_sym_preprocessor_token5] = ACTIONS(369),
    [aux_sym_preprocessor_token6] = ACTIONS(369),
    [aux_sym_preprocessor_token7] = ACTIONS(369),
    [aux_sym_preprocessor_token8] = ACTIONS(369),
    [aux_sym_preprocessor_token9] = ACTIONS(369),
    [aux_sym_preprocessor_token10] = ACTIONS(369),
    [aux_sym_preprocessor_token11] = ACTIONS(369),
    [aux_sym_preprocessor_token12] = ACTIONS(369),
    [aux_sym_preprocessor_token13] = ACTIONS(369),
    [aux_sym_preprocessor_token14] = ACTIONS(369),
    [aux_sym_preprocessor_token15] = ACTIONS(369),
    [aux_sym_preprocessor_token16] = ACTIONS(369),
    [aux_sym_preprocessor_token17] = ACTIONS(371),
    [aux_sym_preprocessor_token18] = ACTIONS(371),
    [aux_sym_preprocessor_token19] = ACTIONS(371),
    [aux_sym_preprocessor_token20] = ACTIONS(371),
    [aux_sym_preprocessor_token21] = ACTIONS(369),
    [aux_sym_preprocessor_token22] = ACTIONS(369),
    [aux_sym_preprocessor_token23] = ACTIONS(369),
    [aux_sym_preprocessor_token24] = ACTIONS(369),
    [aux_sym_preprocessor_token25] = ACTIONS(371),
    [aux_sym_preprocessor_token26] = ACTIONS(371),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(45)] = {
    [sym_line_comment] = STATE(45),
    [ts_builtin_sym_end] = ACTIONS(373),
    [sym_identifier] = ACTIONS(375),
    [anon_sym_COMMA] = ACTIONS(373),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_RPAREN] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(373),
    [aux_sym_execute_statement_token1] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(373),
    [anon_sym_DASH] = ACTIONS(373),
    [anon_sym_PLUS] = ACTIONS(373),
    [anon_sym_LT_GT] = ACTIONS(373),
    [anon_sym_GT] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(373),
    [anon_sym_LT_EQ] = ACTIONS(373),
    [anon_sym_STAR] = ACTIONS(373),
    [anon_sym_SLASH] = ACTIONS(375),
    [anon_sym_PERCENT] = ACTIONS(373),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_RBRACK] = ACTIONS(373),
    [sym_IF_KEYWORD] = ACTIONS(375),
    [sym_THEN_KEYWORD] = ACTIONS(375),
    [sym_ENDIF_KEYWORD] = ACTIONS(375),
    [sym_FOR_KEYWORD] = ACTIONS(375),
    [sym_WHILE_KEYWORD] = ACTIONS(375),
    [sym_DO_KEYWORD] = ACTIONS(375),
    [sym_ENDDO_KEYWORD] = ACTIONS(375),
    [sym_GOTO_KEYWORD] = ACTIONS(375),
    [sym_RETURN_KEYWORD] = ACTIONS(375),
    [sym_BREAK_KEYWORD] = ACTIONS(375),
    [sym_CONTINUE_KEYWORD] = ACTIONS(375),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(375),
    [sym_FUNCTION_KEYWORD] = ACTIONS(375),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(375),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(375),
    [sym_VAR_KEYWORD] = ACTIONS(375),
    [sym_TRY_KEYWORD] = ACTIONS(375),
    [sym_RAISE_KEYWORD] = ACTIONS(375),
    [sym_ENDTRY_KEYWORD] = ACTIONS(375),
    [sym_ASYNC_KEYWORD] = ACTIONS(375),
    [sym_AWAIT_KEYWORD] = ACTIONS(375),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(375),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(375),
    [sym_AND_KEYWORD] = ACTIONS(375),
    [sym_OR_KEYWORD] = ACTIONS(375),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(375),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(373),
    [aux_sym_preprocessor_token1] = ACTIONS(373),
    [aux_sym_preprocessor_token2] = ACTIONS(373),
    [aux_sym_preprocessor_token3] = ACTIONS(373),
    [aux_sym_preprocessor_token4] = ACTIONS(373),
    [aux_sym_preprocessor_token5] = ACTIONS(373),
    [aux_sym_preprocessor_token6] = ACTIONS(373),
    [aux_sym_preprocessor_token7] = ACTIONS(373),
    [aux_sym_preprocessor_token8] = ACTIONS(373),
    [aux_sym_preprocessor_token9] = ACTIONS(373),
    [aux_sym_preprocessor_token10] = ACTIONS(373),
    [aux_sym_preprocessor_token11] = ACTIONS(373),
    [aux_sym_preprocessor_token12] = ACTIONS(373),
    [aux_sym_preprocessor_token13] = ACTIONS(373),
    [aux_sym_preprocessor_token14] = ACTIONS(373),
    [aux_sym_preprocessor_token15] = ACTIONS(373),
    [aux_sym_preprocessor_token16] = ACTIONS(373),
    [aux_sym_preprocessor_token17] = ACTIONS(375),
    [aux_sym_preprocessor_token18] = ACTIONS(375),
    [aux_sym_preprocessor_token19] = ACTIONS(375),
    [aux_sym_preprocessor_token20] = ACTIONS(375),
    [aux_sym_preprocessor_token21] = ACTIONS(373),
    [aux_sym_preprocessor_token22] = ACTIONS(373),
    [aux_sym_preprocessor_token23] = ACTIONS(373),
    [aux_sym_preprocessor_token24] = ACTIONS(373),
    [aux_sym_preprocessor_token25] = ACTIONS(375),
    [aux_sym_preprocessor_token26] = ACTIONS(375),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(46)] = {
    [sym_line_comment] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(299),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_RPAREN] = ACTIONS(299),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [anon_sym_RBRACK] = ACTIONS(299),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_THEN_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_DO_KEYWORD] = ACTIONS(301),
    [sym_ENDDO_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_FUNCTION_KEYWORD] = ACTIONS(301),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_ENDTRY_KEYWORD] = ACTIONS(301),
    [sym_ASYNC_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(47)] = {
    [sym_line_comment] = STATE(47),
    [ts_builtin_sym_end] = ACTIONS(377),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_COMMA] = ACTIONS(377),
    [anon_sym_SEMI] = ACTIONS(377),
    [anon_sym_RPAREN] = ACTIONS(377),
    [anon_sym_EQ] = ACTIONS(377),
    [aux_sym_execute_statement_token1] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_LT_GT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(377),
    [anon_sym_LT_EQ] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_SLASH] = ACTIONS(379),
    [anon_sym_PERCENT] = ACTIONS(377),
    [anon_sym_DOT] = ACTIONS(377),
    [anon_sym_LBRACK] = ACTIONS(377),
    [anon_sym_RBRACK] = ACTIONS(377),
    [sym_IF_KEYWORD] = ACTIONS(379),
    [sym_THEN_KEYWORD] = ACTIONS(379),
    [sym_ENDIF_KEYWORD] = ACTIONS(379),
    [sym_FOR_KEYWORD] = ACTIONS(379),
    [sym_WHILE_KEYWORD] = ACTIONS(379),
    [sym_DO_KEYWORD] = ACTIONS(379),
    [sym_ENDDO_KEYWORD] = ACTIONS(379),
    [sym_GOTO_KEYWORD] = ACTIONS(379),
    [sym_RETURN_KEYWORD] = ACTIONS(379),
    [sym_BREAK_KEYWORD] = ACTIONS(379),
    [sym_CONTINUE_KEYWORD] = ACTIONS(379),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(379),
    [sym_FUNCTION_KEYWORD] = ACTIONS(379),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(379),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(379),
    [sym_VAR_KEYWORD] = ACTIONS(379),
    [sym_TRY_KEYWORD] = ACTIONS(379),
    [sym_RAISE_KEYWORD] = ACTIONS(379),
    [sym_ENDTRY_KEYWORD] = ACTIONS(379),
    [sym_ASYNC_KEYWORD] = ACTIONS(379),
    [sym_AWAIT_KEYWORD] = ACTIONS(379),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(379),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(379),
    [sym_AND_KEYWORD] = ACTIONS(379),
    [sym_OR_KEYWORD] = ACTIONS(379),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(379),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(377),
    [aux_sym_preprocessor_token1] = ACTIONS(377),
    [aux_sym_preprocessor_token2] = ACTIONS(377),
    [aux_sym_preprocessor_token3] = ACTIONS(377),
    [aux_sym_preprocessor_token4] = ACTIONS(377),
    [aux_sym_preprocessor_token5] = ACTIONS(377),
    [aux_sym_preprocessor_token6] = ACTIONS(377),
    [aux_sym_preprocessor_token7] = ACTIONS(377),
    [aux_sym_preprocessor_token8] = ACTIONS(377),
    [aux_sym_preprocessor_token9] = ACTIONS(377),
    [aux_sym_preprocessor_token10] = ACTIONS(377),
    [aux_sym_preprocessor_token11] = ACTIONS(377),
    [aux_sym_preprocessor_token12] = ACTIONS(377),
    [aux_sym_preprocessor_token13] = ACTIONS(377),
    [aux_sym_preprocessor_token14] = ACTIONS(377),
    [aux_sym_preprocessor_token15] = ACTIONS(377),
    [aux_sym_preprocessor_token16] = ACTIONS(377),
    [aux_sym_preprocessor_token17] = ACTIONS(379),
    [aux_sym_preprocessor_token18] = ACTIONS(379),
    [aux_sym_preprocessor_token19] = ACTIONS(379),
    [aux_sym_preprocessor_token20] = ACTIONS(379),
    [aux_sym_preprocessor_token21] = ACTIONS(377),
    [aux_sym_preprocessor_token22] = ACTIONS(377),
    [aux_sym_preprocessor_token23] = ACTIONS(377),
    [aux_sym_preprocessor_token24] = ACTIONS(377),
    [aux_sym_preprocessor_token25] = ACTIONS(379),
    [aux_sym_preprocessor_token26] = ACTIONS(379),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(48)] = {
    [sym_line_comment] = STATE(48),
    [ts_builtin_sym_end] = ACTIONS(381),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_COMMA] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(381),
    [anon_sym_RPAREN] = ACTIONS(381),
    [anon_sym_EQ] = ACTIONS(381),
    [aux_sym_execute_statement_token1] = ACTIONS(383),
    [anon_sym_TILDE] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_LT_GT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(383),
    [anon_sym_GT_EQ] = ACTIONS(381),
    [anon_sym_LT_EQ] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_SLASH] = ACTIONS(383),
    [anon_sym_PERCENT] = ACTIONS(381),
    [anon_sym_DOT] = ACTIONS(381),
    [anon_sym_LBRACK] = ACTIONS(381),
    [anon_sym_RBRACK] = ACTIONS(381),
    [sym_IF_KEYWORD] = ACTIONS(383),
    [sym_THEN_KEYWORD] = ACTIONS(383),
    [sym_ENDIF_KEYWORD] = ACTIONS(383),
    [sym_FOR_KEYWORD] = ACTIONS(383),
    [sym_WHILE_KEYWORD] = ACTIONS(383),
    [sym_DO_KEYWORD] = ACTIONS(383),
    [sym_ENDDO_KEYWORD] = ACTIONS(383),
    [sym_GOTO_KEYWORD] = ACTIONS(383),
    [sym_RETURN_KEYWORD] = ACTIONS(383),
    [sym_BREAK_KEYWORD] = ACTIONS(383),
    [sym_CONTINUE_KEYWORD] = ACTIONS(383),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(383),
    [sym_FUNCTION_KEYWORD] = ACTIONS(383),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(383),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(383),
    [sym_VAR_KEYWORD] = ACTIONS(383),
    [sym_TRY_KEYWORD] = ACTIONS(383),
    [sym_RAISE_KEYWORD] = ACTIONS(383),
    [sym_ENDTRY_KEYWORD] = ACTIONS(383),
    [sym_ASYNC_KEYWORD] = ACTIONS(383),
    [sym_AWAIT_KEYWORD] = ACTIONS(383),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(383),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(383),
    [sym_AND_KEYWORD] = ACTIONS(383),
    [sym_OR_KEYWORD] = ACTIONS(383),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(383),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(381),
    [aux_sym_preprocessor_token1] = ACTIONS(381),
    [aux_sym_preprocessor_token2] = ACTIONS(381),
    [aux_sym_preprocessor_token3] = ACTIONS(381),
    [aux_sym_preprocessor_token4] = ACTIONS(381),
    [aux_sym_preprocessor_token5] = ACTIONS(381),
    [aux_sym_preprocessor_token6] = ACTIONS(381),
    [aux_sym_preprocessor_token7] = ACTIONS(381),
    [aux_sym_preprocessor_token8] = ACTIONS(381),
    [aux_sym_preprocessor_token9] = ACTIONS(381),
    [aux_sym_preprocessor_token10] = ACTIONS(381),
    [aux_sym_preprocessor_token11] = ACTIONS(381),
    [aux_sym_preprocessor_token12] = ACTIONS(381),
    [aux_sym_preprocessor_token13] = ACTIONS(381),
    [aux_sym_preprocessor_token14] = ACTIONS(381),
    [aux_sym_preprocessor_token15] = ACTIONS(381),
    [aux_sym_preprocessor_token16] = ACTIONS(381),
    [aux_sym_preprocessor_token17] = ACTIONS(383),
    [aux_sym_preprocessor_token18] = ACTIONS(383),
    [aux_sym_preprocessor_token19] = ACTIONS(383),
    [aux_sym_preprocessor_token20] = ACTIONS(383),
    [aux_sym_preprocessor_token21] = ACTIONS(381),
    [aux_sym_preprocessor_token22] = ACTIONS(381),
    [aux_sym_preprocessor_token23] = ACTIONS(381),
    [aux_sym_preprocessor_token24] = ACTIONS(381),
    [aux_sym_preprocessor_token25] = ACTIONS(383),
    [aux_sym_preprocessor_token26] = ACTIONS(383),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(49)] = {
    [sym_line_comment] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(385),
    [sym_identifier] = ACTIONS(387),
    [anon_sym_COMMA] = ACTIONS(385),
    [anon_sym_SEMI] = ACTIONS(385),
    [anon_sym_RPAREN] = ACTIONS(385),
    [anon_sym_EQ] = ACTIONS(385),
    [aux_sym_execute_statement_token1] = ACTIONS(387),
    [anon_sym_TILDE] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(385),
    [anon_sym_PLUS] = ACTIONS(385),
    [anon_sym_LT_GT] = ACTIONS(385),
    [anon_sym_GT] = ACTIONS(387),
    [anon_sym_LT] = ACTIONS(387),
    [anon_sym_GT_EQ] = ACTIONS(385),
    [anon_sym_LT_EQ] = ACTIONS(385),
    [anon_sym_STAR] = ACTIONS(385),
    [anon_sym_SLASH] = ACTIONS(387),
    [anon_sym_PERCENT] = ACTIONS(385),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_LBRACK] = ACTIONS(385),
    [anon_sym_RBRACK] = ACTIONS(385),
    [sym_IF_KEYWORD] = ACTIONS(387),
    [sym_THEN_KEYWORD] = ACTIONS(387),
    [sym_ENDIF_KEYWORD] = ACTIONS(387),
    [sym_FOR_KEYWORD] = ACTIONS(387),
    [sym_WHILE_KEYWORD] = ACTIONS(387),
    [sym_DO_KEYWORD] = ACTIONS(387),
    [sym_ENDDO_KEYWORD] = ACTIONS(387),
    [sym_GOTO_KEYWORD] = ACTIONS(387),
    [sym_RETURN_KEYWORD] = ACTIONS(387),
    [sym_BREAK_KEYWORD] = ACTIONS(387),
    [sym_CONTINUE_KEYWORD] = ACTIONS(387),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(387),
    [sym_FUNCTION_KEYWORD] = ACTIONS(387),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(387),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(387),
    [sym_VAR_KEYWORD] = ACTIONS(387),
    [sym_TRY_KEYWORD] = ACTIONS(387),
    [sym_RAISE_KEYWORD] = ACTIONS(387),
    [sym_ENDTRY_KEYWORD] = ACTIONS(387),
    [sym_ASYNC_KEYWORD] = ACTIONS(387),
    [sym_AWAIT_KEYWORD] = ACTIONS(387),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(387),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(387),
    [sym_AND_KEYWORD] = ACTIONS(387),
    [sym_OR_KEYWORD] = ACTIONS(387),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(387),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(385),
    [aux_sym_preprocessor_token1] = ACTIONS(385),
    [aux_sym_preprocessor_token2] = ACTIONS(385),
    [aux_sym_preprocessor_token3] = ACTIONS(385),
    [aux_sym_preprocessor_token4] = ACTIONS(385),
    [aux_sym_preprocessor_token5] = ACTIONS(385),
    [aux_sym_preprocessor_token6] = ACTIONS(385),
    [aux_sym_preprocessor_token7] = ACTIONS(385),
    [aux_sym_preprocessor_token8] = ACTIONS(385),
    [aux_sym_preprocessor_token9] = ACTIONS(385),
    [aux_sym_preprocessor_token10] = ACTIONS(385),
    [aux_sym_preprocessor_token11] = ACTIONS(385),
    [aux_sym_preprocessor_token12] = ACTIONS(385),
    [aux_sym_preprocessor_token13] = ACTIONS(385),
    [aux_sym_preprocessor_token14] = ACTIONS(385),
    [aux_sym_preprocessor_token15] = ACTIONS(385),
    [aux_sym_preprocessor_token16] = ACTIONS(385),
    [aux_sym_preprocessor_token17] = ACTIONS(387),
    [aux_sym_preprocessor_token18] = ACTIONS(387),
    [aux_sym_preprocessor_token19] = ACTIONS(387),
    [aux_sym_preprocessor_token20] = ACTIONS(387),
    [aux_sym_preprocessor_token21] = ACTIONS(385),
    [aux_sym_preprocessor_token22] = ACTIONS(385),
    [aux_sym_preprocessor_token23] = ACTIONS(385),
    [aux_sym_preprocessor_token24] = ACTIONS(385),
    [aux_sym_preprocessor_token25] = ACTIONS(387),
    [aux_sym_preprocessor_token26] = ACTIONS(387),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(50)] = {
    [sym_line_comment] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(389),
    [sym_identifier] = ACTIONS(391),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_RPAREN] = ACTIONS(389),
    [anon_sym_EQ] = ACTIONS(389),
    [aux_sym_execute_statement_token1] = ACTIONS(391),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(389),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_STAR] = ACTIONS(389),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_PERCENT] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(389),
    [anon_sym_LBRACK] = ACTIONS(389),
    [anon_sym_RBRACK] = ACTIONS(389),
    [sym_IF_KEYWORD] = ACTIONS(391),
    [sym_THEN_KEYWORD] = ACTIONS(391),
    [sym_ENDIF_KEYWORD] = ACTIONS(391),
    [sym_FOR_KEYWORD] = ACTIONS(391),
    [sym_WHILE_KEYWORD] = ACTIONS(391),
    [sym_DO_KEYWORD] = ACTIONS(391),
    [sym_ENDDO_KEYWORD] = ACTIONS(391),
    [sym_GOTO_KEYWORD] = ACTIONS(391),
    [sym_RETURN_KEYWORD] = ACTIONS(391),
    [sym_BREAK_KEYWORD] = ACTIONS(391),
    [sym_CONTINUE_KEYWORD] = ACTIONS(391),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(391),
    [sym_FUNCTION_KEYWORD] = ACTIONS(391),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(391),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(391),
    [sym_VAR_KEYWORD] = ACTIONS(391),
    [sym_TRY_KEYWORD] = ACTIONS(391),
    [sym_RAISE_KEYWORD] = ACTIONS(391),
    [sym_ENDTRY_KEYWORD] = ACTIONS(391),
    [sym_ASYNC_KEYWORD] = ACTIONS(391),
    [sym_AWAIT_KEYWORD] = ACTIONS(391),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(391),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(391),
    [sym_AND_KEYWORD] = ACTIONS(391),
    [sym_OR_KEYWORD] = ACTIONS(391),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(391),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(389),
    [aux_sym_preprocessor_token1] = ACTIONS(389),
    [aux_sym_preprocessor_token2] = ACTIONS(389),
    [aux_sym_preprocessor_token3] = ACTIONS(389),
    [aux_sym_preprocessor_token4] = ACTIONS(389),
    [aux_sym_preprocessor_token5] = ACTIONS(389),
    [aux_sym_preprocessor_token6] = ACTIONS(389),
    [aux_sym_preprocessor_token7] = ACTIONS(389),
    [aux_sym_preprocessor_token8] = ACTIONS(389),
    [aux_sym_preprocessor_token9] = ACTIONS(389),
    [aux_sym_preprocessor_token10] = ACTIONS(389),
    [aux_sym_preprocessor_token11] = ACTIONS(389),
    [aux_sym_preprocessor_token12] = ACTIONS(389),
    [aux_sym_preprocessor_token13] = ACTIONS(389),
    [aux_sym_preprocessor_token14] = ACTIONS(389),
    [aux_sym_preprocessor_token15] = ACTIONS(389),
    [aux_sym_preprocessor_token16] = ACTIONS(389),
    [aux_sym_preprocessor_token17] = ACTIONS(391),
    [aux_sym_preprocessor_token18] = ACTIONS(391),
    [aux_sym_preprocessor_token19] = ACTIONS(391),
    [aux_sym_preprocessor_token20] = ACTIONS(391),
    [aux_sym_preprocessor_token21] = ACTIONS(389),
    [aux_sym_preprocessor_token22] = ACTIONS(389),
    [aux_sym_preprocessor_token23] = ACTIONS(389),
    [aux_sym_preprocessor_token24] = ACTIONS(389),
    [aux_sym_preprocessor_token25] = ACTIONS(391),
    [aux_sym_preprocessor_token26] = ACTIONS(391),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(51)] = {
    [sym_line_comment] = STATE(51),
    [ts_builtin_sym_end] = ACTIONS(393),
    [sym_identifier] = ACTIONS(395),
    [anon_sym_COMMA] = ACTIONS(393),
    [anon_sym_SEMI] = ACTIONS(393),
    [anon_sym_RPAREN] = ACTIONS(393),
    [anon_sym_EQ] = ACTIONS(393),
    [aux_sym_execute_statement_token1] = ACTIONS(395),
    [anon_sym_TILDE] = ACTIONS(393),
    [anon_sym_DASH] = ACTIONS(393),
    [anon_sym_PLUS] = ACTIONS(393),
    [anon_sym_LT_GT] = ACTIONS(393),
    [anon_sym_GT] = ACTIONS(395),
    [anon_sym_LT] = ACTIONS(395),
    [anon_sym_GT_EQ] = ACTIONS(393),
    [anon_sym_LT_EQ] = ACTIONS(393),
    [anon_sym_STAR] = ACTIONS(393),
    [anon_sym_SLASH] = ACTIONS(395),
    [anon_sym_PERCENT] = ACTIONS(393),
    [anon_sym_DOT] = ACTIONS(393),
    [anon_sym_LBRACK] = ACTIONS(393),
    [anon_sym_RBRACK] = ACTIONS(393),
    [sym_IF_KEYWORD] = ACTIONS(395),
    [sym_THEN_KEYWORD] = ACTIONS(395),
    [sym_ENDIF_KEYWORD] = ACTIONS(395),
    [sym_FOR_KEYWORD] = ACTIONS(395),
    [sym_WHILE_KEYWORD] = ACTIONS(395),
    [sym_DO_KEYWORD] = ACTIONS(395),
    [sym_ENDDO_KEYWORD] = ACTIONS(395),
    [sym_GOTO_KEYWORD] = ACTIONS(395),
    [sym_RETURN_KEYWORD] = ACTIONS(395),
    [sym_BREAK_KEYWORD] = ACTIONS(395),
    [sym_CONTINUE_KEYWORD] = ACTIONS(395),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(395),
    [sym_FUNCTION_KEYWORD] = ACTIONS(395),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(395),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(395),
    [sym_VAR_KEYWORD] = ACTIONS(395),
    [sym_TRY_KEYWORD] = ACTIONS(395),
    [sym_RAISE_KEYWORD] = ACTIONS(395),
    [sym_ENDTRY_KEYWORD] = ACTIONS(395),
    [sym_ASYNC_KEYWORD] = ACTIONS(395),
    [sym_AWAIT_KEYWORD] = ACTIONS(395),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(395),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(395),
    [sym_AND_KEYWORD] = ACTIONS(395),
    [sym_OR_KEYWORD] = ACTIONS(395),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(395),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(393),
    [aux_sym_preprocessor_token1] = ACTIONS(393),
    [aux_sym_preprocessor_token2] = ACTIONS(393),
    [aux_sym_preprocessor_token3] = ACTIONS(393),
    [aux_sym_preprocessor_token4] = ACTIONS(393),
    [aux_sym_preprocessor_token5] = ACTIONS(393),
    [aux_sym_preprocessor_token6] = ACTIONS(393),
    [aux_sym_preprocessor_token7] = ACTIONS(393),
    [aux_sym_preprocessor_token8] = ACTIONS(393),
    [aux_sym_preprocessor_token9] = ACTIONS(393),
    [aux_sym_preprocessor_token10] = ACTIONS(393),
    [aux_sym_preprocessor_token11] = ACTIONS(393),
    [aux_sym_preprocessor_token12] = ACTIONS(393),
    [aux_sym_preprocessor_token13] = ACTIONS(393),
    [aux_sym_preprocessor_token14] = ACTIONS(393),
    [aux_sym_preprocessor_token15] = ACTIONS(393),
    [aux_sym_preprocessor_token16] = ACTIONS(393),
    [aux_sym_preprocessor_token17] = ACTIONS(395),
    [aux_sym_preprocessor_token18] = ACTIONS(395),
    [aux_sym_preprocessor_token19] = ACTIONS(395),
    [aux_sym_preprocessor_token20] = ACTIONS(395),
    [aux_sym_preprocessor_token21] = ACTIONS(393),
    [aux_sym_preprocessor_token22] = ACTIONS(393),
    [aux_sym_preprocessor_token23] = ACTIONS(393),
    [aux_sym_preprocessor_token24] = ACTIONS(393),
    [aux_sym_preprocessor_token25] = ACTIONS(395),
    [aux_sym_preprocessor_token26] = ACTIONS(395),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(52)] = {
    [sym_arguments] = STATE(59),
    [sym_line_comment] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(397),
    [sym_identifier] = ACTIONS(399),
    [anon_sym_COMMA] = ACTIONS(397),
    [anon_sym_SEMI] = ACTIONS(397),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_RPAREN] = ACTIONS(397),
    [anon_sym_EQ] = ACTIONS(397),
    [aux_sym_execute_statement_token1] = ACTIONS(399),
    [anon_sym_TILDE] = ACTIONS(397),
    [anon_sym_DASH] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(397),
    [anon_sym_LT_GT] = ACTIONS(397),
    [anon_sym_GT] = ACTIONS(399),
    [anon_sym_LT] = ACTIONS(399),
    [anon_sym_GT_EQ] = ACTIONS(397),
    [anon_sym_LT_EQ] = ACTIONS(397),
    [anon_sym_STAR] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(399),
    [anon_sym_PERCENT] = ACTIONS(397),
    [anon_sym_RBRACK] = ACTIONS(397),
    [sym_IF_KEYWORD] = ACTIONS(399),
    [sym_THEN_KEYWORD] = ACTIONS(399),
    [sym_ENDIF_KEYWORD] = ACTIONS(399),
    [sym_FOR_KEYWORD] = ACTIONS(399),
    [sym_WHILE_KEYWORD] = ACTIONS(399),
    [sym_DO_KEYWORD] = ACTIONS(399),
    [sym_ENDDO_KEYWORD] = ACTIONS(399),
    [sym_GOTO_KEYWORD] = ACTIONS(399),
    [sym_RETURN_KEYWORD] = ACTIONS(399),
    [sym_BREAK_KEYWORD] = ACTIONS(399),
    [sym_CONTINUE_KEYWORD] = ACTIONS(399),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(399),
    [sym_FUNCTION_KEYWORD] = ACTIONS(399),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(399),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(399),
    [sym_VAR_KEYWORD] = ACTIONS(399),
    [sym_TRY_KEYWORD] = ACTIONS(399),
    [sym_RAISE_KEYWORD] = ACTIONS(399),
    [sym_ENDTRY_KEYWORD] = ACTIONS(399),
    [sym_ASYNC_KEYWORD] = ACTIONS(399),
    [sym_AWAIT_KEYWORD] = ACTIONS(399),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(399),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(399),
    [sym_AND_KEYWORD] = ACTIONS(399),
    [sym_OR_KEYWORD] = ACTIONS(399),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(399),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(397),
    [aux_sym_preprocessor_token1] = ACTIONS(397),
    [aux_sym_preprocessor_token2] = ACTIONS(397),
    [aux_sym_preprocessor_token3] = ACTIONS(397),
    [aux_sym_preprocessor_token4] = ACTIONS(397),
    [aux_sym_preprocessor_token5] = ACTIONS(397),
    [aux_sym_preprocessor_token6] = ACTIONS(397),
    [aux_sym_preprocessor_token7] = ACTIONS(397),
    [aux_sym_preprocessor_token8] = ACTIONS(397),
    [aux_sym_preprocessor_token9] = ACTIONS(397),
    [aux_sym_preprocessor_token10] = ACTIONS(397),
    [aux_sym_preprocessor_token11] = ACTIONS(397),
    [aux_sym_preprocessor_token12] = ACTIONS(397),
    [aux_sym_preprocessor_token13] = ACTIONS(397),
    [aux_sym_preprocessor_token14] = ACTIONS(397),
    [aux_sym_preprocessor_token15] = ACTIONS(397),
    [aux_sym_preprocessor_token16] = ACTIONS(397),
    [aux_sym_preprocessor_token17] = ACTIONS(399),
    [aux_sym_preprocessor_token18] = ACTIONS(399),
    [aux_sym_preprocessor_token19] = ACTIONS(399),
    [aux_sym_preprocessor_token20] = ACTIONS(399),
    [aux_sym_preprocessor_token21] = ACTIONS(397),
    [aux_sym_preprocessor_token22] = ACTIONS(397),
    [aux_sym_preprocessor_token23] = ACTIONS(397),
    [aux_sym_preprocessor_token24] = ACTIONS(397),
    [aux_sym_preprocessor_token25] = ACTIONS(399),
    [aux_sym_preprocessor_token26] = ACTIONS(399),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(53)] = {
    [sym_line_comment] = STATE(53),
    [ts_builtin_sym_end] = ACTIONS(401),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_COMMA] = ACTIONS(401),
    [anon_sym_SEMI] = ACTIONS(401),
    [anon_sym_RPAREN] = ACTIONS(401),
    [anon_sym_EQ] = ACTIONS(401),
    [aux_sym_execute_statement_token1] = ACTIONS(403),
    [anon_sym_TILDE] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_LT_GT] = ACTIONS(401),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(401),
    [anon_sym_LT_EQ] = ACTIONS(401),
    [anon_sym_STAR] = ACTIONS(401),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(401),
    [anon_sym_DOT] = ACTIONS(401),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_RBRACK] = ACTIONS(401),
    [sym_IF_KEYWORD] = ACTIONS(403),
    [sym_THEN_KEYWORD] = ACTIONS(403),
    [sym_ENDIF_KEYWORD] = ACTIONS(403),
    [sym_FOR_KEYWORD] = ACTIONS(403),
    [sym_WHILE_KEYWORD] = ACTIONS(403),
    [sym_DO_KEYWORD] = ACTIONS(403),
    [sym_ENDDO_KEYWORD] = ACTIONS(403),
    [sym_GOTO_KEYWORD] = ACTIONS(403),
    [sym_RETURN_KEYWORD] = ACTIONS(403),
    [sym_BREAK_KEYWORD] = ACTIONS(403),
    [sym_CONTINUE_KEYWORD] = ACTIONS(403),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(403),
    [sym_FUNCTION_KEYWORD] = ACTIONS(403),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(403),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(403),
    [sym_VAR_KEYWORD] = ACTIONS(403),
    [sym_TRY_KEYWORD] = ACTIONS(403),
    [sym_RAISE_KEYWORD] = ACTIONS(403),
    [sym_ENDTRY_KEYWORD] = ACTIONS(403),
    [sym_ASYNC_KEYWORD] = ACTIONS(403),
    [sym_AWAIT_KEYWORD] = ACTIONS(403),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(403),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(403),
    [sym_AND_KEYWORD] = ACTIONS(403),
    [sym_OR_KEYWORD] = ACTIONS(403),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(403),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(401),
    [aux_sym_preprocessor_token1] = ACTIONS(401),
    [aux_sym_preprocessor_token2] = ACTIONS(401),
    [aux_sym_preprocessor_token3] = ACTIONS(401),
    [aux_sym_preprocessor_token4] = ACTIONS(401),
    [aux_sym_preprocessor_token5] = ACTIONS(401),
    [aux_sym_preprocessor_token6] = ACTIONS(401),
    [aux_sym_preprocessor_token7] = ACTIONS(401),
    [aux_sym_preprocessor_token8] = ACTIONS(401),
    [aux_sym_preprocessor_token9] = ACTIONS(401),
    [aux_sym_preprocessor_token10] = ACTIONS(401),
    [aux_sym_preprocessor_token11] = ACTIONS(401),
    [aux_sym_preprocessor_token12] = ACTIONS(401),
    [aux_sym_preprocessor_token13] = ACTIONS(401),
    [aux_sym_preprocessor_token14] = ACTIONS(401),
    [aux_sym_preprocessor_token15] = ACTIONS(401),
    [aux_sym_preprocessor_token16] = ACTIONS(401),
    [aux_sym_preprocessor_token17] = ACTIONS(403),
    [aux_sym_preprocessor_token18] = ACTIONS(403),
    [aux_sym_preprocessor_token19] = ACTIONS(403),
    [aux_sym_preprocessor_token20] = ACTIONS(403),
    [aux_sym_preprocessor_token21] = ACTIONS(401),
    [aux_sym_preprocessor_token22] = ACTIONS(401),
    [aux_sym_preprocessor_token23] = ACTIONS(401),
    [aux_sym_preprocessor_token24] = ACTIONS(401),
    [aux_sym_preprocessor_token25] = ACTIONS(403),
    [aux_sym_preprocessor_token26] = ACTIONS(403),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(54)] = {
    [sym_line_comment] = STATE(54),
    [ts_builtin_sym_end] = ACTIONS(405),
    [sym_identifier] = ACTIONS(407),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_RPAREN] = ACTIONS(405),
    [anon_sym_EQ] = ACTIONS(405),
    [aux_sym_execute_statement_token1] = ACTIONS(407),
    [anon_sym_TILDE] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(405),
    [anon_sym_PLUS] = ACTIONS(405),
    [anon_sym_LT_GT] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(407),
    [anon_sym_PERCENT] = ACTIONS(405),
    [anon_sym_RBRACK] = ACTIONS(405),
    [sym_IF_KEYWORD] = ACTIONS(407),
    [sym_THEN_KEYWORD] = ACTIONS(407),
    [sym_ENDIF_KEYWORD] = ACTIONS(407),
    [sym_FOR_KEYWORD] = ACTIONS(407),
    [sym_WHILE_KEYWORD] = ACTIONS(407),
    [sym_DO_KEYWORD] = ACTIONS(407),
    [sym_ENDDO_KEYWORD] = ACTIONS(407),
    [sym_GOTO_KEYWORD] = ACTIONS(407),
    [sym_RETURN_KEYWORD] = ACTIONS(407),
    [sym_BREAK_KEYWORD] = ACTIONS(407),
    [sym_CONTINUE_KEYWORD] = ACTIONS(407),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(407),
    [sym_FUNCTION_KEYWORD] = ACTIONS(407),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(407),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(407),
    [sym_VAR_KEYWORD] = ACTIONS(407),
    [sym_TRY_KEYWORD] = ACTIONS(407),
    [sym_RAISE_KEYWORD] = ACTIONS(407),
    [sym_ENDTRY_KEYWORD] = ACTIONS(407),
    [sym_ASYNC_KEYWORD] = ACTIONS(407),
    [sym_AWAIT_KEYWORD] = ACTIONS(407),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(407),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(407),
    [sym_AND_KEYWORD] = ACTIONS(407),
    [sym_OR_KEYWORD] = ACTIONS(407),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(407),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(405),
    [aux_sym_preprocessor_token1] = ACTIONS(405),
    [aux_sym_preprocessor_token2] = ACTIONS(405),
    [aux_sym_preprocessor_token3] = ACTIONS(405),
    [aux_sym_preprocessor_token4] = ACTIONS(405),
    [aux_sym_preprocessor_token5] = ACTIONS(405),
    [aux_sym_preprocessor_token6] = ACTIONS(405),
    [aux_sym_preprocessor_token7] = ACTIONS(405),
    [aux_sym_preprocessor_token8] = ACTIONS(405),
    [aux_sym_preprocessor_token9] = ACTIONS(405),
    [aux_sym_preprocessor_token10] = ACTIONS(405),
    [aux_sym_preprocessor_token11] = ACTIONS(405),
    [aux_sym_preprocessor_token12] = ACTIONS(405),
    [aux_sym_preprocessor_token13] = ACTIONS(405),
    [aux_sym_preprocessor_token14] = ACTIONS(405),
    [aux_sym_preprocessor_token15] = ACTIONS(405),
    [aux_sym_preprocessor_token16] = ACTIONS(405),
    [aux_sym_preprocessor_token17] = ACTIONS(407),
    [aux_sym_preprocessor_token18] = ACTIONS(407),
    [aux_sym_preprocessor_token19] = ACTIONS(407),
    [aux_sym_preprocessor_token20] = ACTIONS(407),
    [aux_sym_preprocessor_token21] = ACTIONS(405),
    [aux_sym_preprocessor_token22] = ACTIONS(405),
    [aux_sym_preprocessor_token23] = ACTIONS(405),
    [aux_sym_preprocessor_token24] = ACTIONS(405),
    [aux_sym_preprocessor_token25] = ACTIONS(407),
    [aux_sym_preprocessor_token26] = ACTIONS(407),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(55)] = {
    [sym_line_comment] = STATE(55),
    [ts_builtin_sym_end] = ACTIONS(409),
    [sym_identifier] = ACTIONS(411),
    [anon_sym_COMMA] = ACTIONS(409),
    [anon_sym_SEMI] = ACTIONS(409),
    [anon_sym_RPAREN] = ACTIONS(409),
    [anon_sym_EQ] = ACTIONS(409),
    [aux_sym_execute_statement_token1] = ACTIONS(411),
    [anon_sym_TILDE] = ACTIONS(409),
    [anon_sym_DASH] = ACTIONS(409),
    [anon_sym_PLUS] = ACTIONS(409),
    [anon_sym_LT_GT] = ACTIONS(409),
    [anon_sym_GT] = ACTIONS(411),
    [anon_sym_LT] = ACTIONS(411),
    [anon_sym_GT_EQ] = ACTIONS(409),
    [anon_sym_LT_EQ] = ACTIONS(409),
    [anon_sym_STAR] = ACTIONS(409),
    [anon_sym_SLASH] = ACTIONS(411),
    [anon_sym_PERCENT] = ACTIONS(409),
    [anon_sym_RBRACK] = ACTIONS(409),
    [sym_IF_KEYWORD] = ACTIONS(411),
    [sym_THEN_KEYWORD] = ACTIONS(411),
    [sym_ENDIF_KEYWORD] = ACTIONS(411),
    [sym_FOR_KEYWORD] = ACTIONS(411),
    [sym_WHILE_KEYWORD] = ACTIONS(411),
    [sym_DO_KEYWORD] = ACTIONS(411),
    [sym_ENDDO_KEYWORD] = ACTIONS(411),
    [sym_GOTO_KEYWORD] = ACTIONS(411),
    [sym_RETURN_KEYWORD] = ACTIONS(411),
    [sym_BREAK_KEYWORD] = ACTIONS(411),
    [sym_CONTINUE_KEYWORD] = ACTIONS(411),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(411),
    [sym_FUNCTION_KEYWORD] = ACTIONS(411),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(411),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(411),
    [sym_VAR_KEYWORD] = ACTIONS(411),
    [sym_TRY_KEYWORD] = ACTIONS(411),
    [sym_RAISE_KEYWORD] = ACTIONS(411),
    [sym_ENDTRY_KEYWORD] = ACTIONS(411),
    [sym_ASYNC_KEYWORD] = ACTIONS(411),
    [sym_AWAIT_KEYWORD] = ACTIONS(411),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(411),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(411),
    [sym_AND_KEYWORD] = ACTIONS(411),
    [sym_OR_KEYWORD] = ACTIONS(411),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(411),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(409),
    [aux_sym_preprocessor_token1] = ACTIONS(409),
    [aux_sym_preprocessor_token2] = ACTIONS(409),
    [aux_sym_preprocessor_token3] = ACTIONS(409),
    [aux_sym_preprocessor_token4] = ACTIONS(409),
    [aux_sym_preprocessor_token5] = ACTIONS(409),
    [aux_sym_preprocessor_token6] = ACTIONS(409),
    [aux_sym_preprocessor_token7] = ACTIONS(409),
    [aux_sym_preprocessor_token8] = ACTIONS(409),
    [aux_sym_preprocessor_token9] = ACTIONS(409),
    [aux_sym_preprocessor_token10] = ACTIONS(409),
    [aux_sym_preprocessor_token11] = ACTIONS(409),
    [aux_sym_preprocessor_token12] = ACTIONS(409),
    [aux_sym_preprocessor_token13] = ACTIONS(409),
    [aux_sym_preprocessor_token14] = ACTIONS(409),
    [aux_sym_preprocessor_token15] = ACTIONS(409),
    [aux_sym_preprocessor_token16] = ACTIONS(409),
    [aux_sym_preprocessor_token17] = ACTIONS(411),
    [aux_sym_preprocessor_token18] = ACTIONS(411),
    [aux_sym_preprocessor_token19] = ACTIONS(411),
    [aux_sym_preprocessor_token20] = ACTIONS(411),
    [aux_sym_preprocessor_token21] = ACTIONS(409),
    [aux_sym_preprocessor_token22] = ACTIONS(409),
    [aux_sym_preprocessor_token23] = ACTIONS(409),
    [aux_sym_preprocessor_token24] = ACTIONS(409),
    [aux_sym_preprocessor_token25] = ACTIONS(411),
    [aux_sym_preprocessor_token26] = ACTIONS(411),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(56)] = {
    [sym_line_comment] = STATE(56),
    [ts_builtin_sym_end] = ACTIONS(413),
    [sym_identifier] = ACTIONS(415),
    [anon_sym_COMMA] = ACTIONS(413),
    [anon_sym_SEMI] = ACTIONS(413),
    [anon_sym_RPAREN] = ACTIONS(413),
    [anon_sym_EQ] = ACTIONS(413),
    [aux_sym_execute_statement_token1] = ACTIONS(415),
    [anon_sym_TILDE] = ACTIONS(413),
    [anon_sym_DASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(413),
    [anon_sym_LT_GT] = ACTIONS(413),
    [anon_sym_GT] = ACTIONS(415),
    [anon_sym_LT] = ACTIONS(415),
    [anon_sym_GT_EQ] = ACTIONS(413),
    [anon_sym_LT_EQ] = ACTIONS(413),
    [anon_sym_STAR] = ACTIONS(413),
    [anon_sym_SLASH] = ACTIONS(415),
    [anon_sym_PERCENT] = ACTIONS(413),
    [anon_sym_RBRACK] = ACTIONS(413),
    [sym_IF_KEYWORD] = ACTIONS(415),
    [sym_THEN_KEYWORD] = ACTIONS(415),
    [sym_ENDIF_KEYWORD] = ACTIONS(415),
    [sym_FOR_KEYWORD] = ACTIONS(415),
    [sym_WHILE_KEYWORD] = ACTIONS(415),
    [sym_DO_KEYWORD] = ACTIONS(415),
    [sym_ENDDO_KEYWORD] = ACTIONS(415),
    [sym_GOTO_KEYWORD] = ACTIONS(415),
    [sym_RETURN_KEYWORD] = ACTIONS(415),
    [sym_BREAK_KEYWORD] = ACTIONS(415),
    [sym_CONTINUE_KEYWORD] = ACTIONS(415),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(415),
    [sym_FUNCTION_KEYWORD] = ACTIONS(415),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(415),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(415),
    [sym_VAR_KEYWORD] = ACTIONS(415),
    [sym_TRY_KEYWORD] = ACTIONS(415),
    [sym_RAISE_KEYWORD] = ACTIONS(415),
    [sym_ENDTRY_KEYWORD] = ACTIONS(415),
    [sym_ASYNC_KEYWORD] = ACTIONS(415),
    [sym_AWAIT_KEYWORD] = ACTIONS(415),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(415),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(415),
    [sym_AND_KEYWORD] = ACTIONS(415),
    [sym_OR_KEYWORD] = ACTIONS(415),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(415),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(413),
    [aux_sym_preprocessor_token1] = ACTIONS(413),
    [aux_sym_preprocessor_token2] = ACTIONS(413),
    [aux_sym_preprocessor_token3] = ACTIONS(413),
    [aux_sym_preprocessor_token4] = ACTIONS(413),
    [aux_sym_preprocessor_token5] = ACTIONS(413),
    [aux_sym_preprocessor_token6] = ACTIONS(413),
    [aux_sym_preprocessor_token7] = ACTIONS(413),
    [aux_sym_preprocessor_token8] = ACTIONS(413),
    [aux_sym_preprocessor_token9] = ACTIONS(413),
    [aux_sym_preprocessor_token10] = ACTIONS(413),
    [aux_sym_preprocessor_token11] = ACTIONS(413),
    [aux_sym_preprocessor_token12] = ACTIONS(413),
    [aux_sym_preprocessor_token13] = ACTIONS(413),
    [aux_sym_preprocessor_token14] = ACTIONS(413),
    [aux_sym_preprocessor_token15] = ACTIONS(413),
    [aux_sym_preprocessor_token16] = ACTIONS(413),
    [aux_sym_preprocessor_token17] = ACTIONS(415),
    [aux_sym_preprocessor_token18] = ACTIONS(415),
    [aux_sym_preprocessor_token19] = ACTIONS(415),
    [aux_sym_preprocessor_token20] = ACTIONS(415),
    [aux_sym_preprocessor_token21] = ACTIONS(413),
    [aux_sym_preprocessor_token22] = ACTIONS(413),
    [aux_sym_preprocessor_token23] = ACTIONS(413),
    [aux_sym_preprocessor_token24] = ACTIONS(413),
    [aux_sym_preprocessor_token25] = ACTIONS(415),
    [aux_sym_preprocessor_token26] = ACTIONS(415),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(57)] = {
    [sym_line_comment] = STATE(57),
    [ts_builtin_sym_end] = ACTIONS(417),
    [sym_identifier] = ACTIONS(419),
    [anon_sym_COMMA] = ACTIONS(417),
    [anon_sym_SEMI] = ACTIONS(417),
    [anon_sym_RPAREN] = ACTIONS(417),
    [anon_sym_EQ] = ACTIONS(417),
    [aux_sym_execute_statement_token1] = ACTIONS(419),
    [anon_sym_TILDE] = ACTIONS(417),
    [anon_sym_DASH] = ACTIONS(417),
    [anon_sym_PLUS] = ACTIONS(417),
    [anon_sym_LT_GT] = ACTIONS(417),
    [anon_sym_GT] = ACTIONS(419),
    [anon_sym_LT] = ACTIONS(419),
    [anon_sym_GT_EQ] = ACTIONS(417),
    [anon_sym_LT_EQ] = ACTIONS(417),
    [anon_sym_STAR] = ACTIONS(417),
    [anon_sym_SLASH] = ACTIONS(419),
    [anon_sym_PERCENT] = ACTIONS(417),
    [anon_sym_RBRACK] = ACTIONS(417),
    [sym_IF_KEYWORD] = ACTIONS(419),
    [sym_THEN_KEYWORD] = ACTIONS(419),
    [sym_ENDIF_KEYWORD] = ACTIONS(419),
    [sym_FOR_KEYWORD] = ACTIONS(419),
    [sym_WHILE_KEYWORD] = ACTIONS(419),
    [sym_DO_KEYWORD] = ACTIONS(419),
    [sym_ENDDO_KEYWORD] = ACTIONS(419),
    [sym_GOTO_KEYWORD] = ACTIONS(419),
    [sym_RETURN_KEYWORD] = ACTIONS(419),
    [sym_BREAK_KEYWORD] = ACTIONS(419),
    [sym_CONTINUE_KEYWORD] = ACTIONS(419),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(419),
    [sym_FUNCTION_KEYWORD] = ACTIONS(419),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(419),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(419),
    [sym_VAR_KEYWORD] = ACTIONS(419),
    [sym_TRY_KEYWORD] = ACTIONS(419),
    [sym_RAISE_KEYWORD] = ACTIONS(419),
    [sym_ENDTRY_KEYWORD] = ACTIONS(419),
    [sym_ASYNC_KEYWORD] = ACTIONS(419),
    [sym_AWAIT_KEYWORD] = ACTIONS(419),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(419),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(419),
    [sym_AND_KEYWORD] = ACTIONS(419),
    [sym_OR_KEYWORD] = ACTIONS(419),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(419),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(417),
    [aux_sym_preprocessor_token1] = ACTIONS(417),
    [aux_sym_preprocessor_token2] = ACTIONS(417),
    [aux_sym_preprocessor_token3] = ACTIONS(417),
    [aux_sym_preprocessor_token4] = ACTIONS(417),
    [aux_sym_preprocessor_token5] = ACTIONS(417),
    [aux_sym_preprocessor_token6] = ACTIONS(417),
    [aux_sym_preprocessor_token7] = ACTIONS(417),
    [aux_sym_preprocessor_token8] = ACTIONS(417),
    [aux_sym_preprocessor_token9] = ACTIONS(417),
    [aux_sym_preprocessor_token10] = ACTIONS(417),
    [aux_sym_preprocessor_token11] = ACTIONS(417),
    [aux_sym_preprocessor_token12] = ACTIONS(417),
    [aux_sym_preprocessor_token13] = ACTIONS(417),
    [aux_sym_preprocessor_token14] = ACTIONS(417),
    [aux_sym_preprocessor_token15] = ACTIONS(417),
    [aux_sym_preprocessor_token16] = ACTIONS(417),
    [aux_sym_preprocessor_token17] = ACTIONS(419),
    [aux_sym_preprocessor_token18] = ACTIONS(419),
    [aux_sym_preprocessor_token19] = ACTIONS(419),
    [aux_sym_preprocessor_token20] = ACTIONS(419),
    [aux_sym_preprocessor_token21] = ACTIONS(417),
    [aux_sym_preprocessor_token22] = ACTIONS(417),
    [aux_sym_preprocessor_token23] = ACTIONS(417),
    [aux_sym_preprocessor_token24] = ACTIONS(417),
    [aux_sym_preprocessor_token25] = ACTIONS(419),
    [aux_sym_preprocessor_token26] = ACTIONS(419),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(58)] = {
    [sym_line_comment] = STATE(58),
    [ts_builtin_sym_end] = ACTIONS(421),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(425),
    [anon_sym_SEMI] = ACTIONS(421),
    [anon_sym_RPAREN] = ACTIONS(421),
    [anon_sym_EQ] = ACTIONS(421),
    [aux_sym_execute_statement_token1] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(421),
    [anon_sym_DASH] = ACTIONS(421),
    [anon_sym_PLUS] = ACTIONS(421),
    [anon_sym_LT_GT] = ACTIONS(421),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(421),
    [anon_sym_LT_EQ] = ACTIONS(421),
    [anon_sym_STAR] = ACTIONS(421),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(421),
    [anon_sym_RBRACK] = ACTIONS(421),
    [sym_IF_KEYWORD] = ACTIONS(423),
    [sym_THEN_KEYWORD] = ACTIONS(423),
    [sym_ENDIF_KEYWORD] = ACTIONS(423),
    [sym_FOR_KEYWORD] = ACTIONS(423),
    [sym_WHILE_KEYWORD] = ACTIONS(423),
    [sym_DO_KEYWORD] = ACTIONS(423),
    [sym_ENDDO_KEYWORD] = ACTIONS(423),
    [sym_GOTO_KEYWORD] = ACTIONS(423),
    [sym_RETURN_KEYWORD] = ACTIONS(423),
    [sym_BREAK_KEYWORD] = ACTIONS(423),
    [sym_CONTINUE_KEYWORD] = ACTIONS(423),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(423),
    [sym_FUNCTION_KEYWORD] = ACTIONS(423),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(423),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(423),
    [sym_VAR_KEYWORD] = ACTIONS(423),
    [sym_TRY_KEYWORD] = ACTIONS(423),
    [sym_RAISE_KEYWORD] = ACTIONS(423),
    [sym_ENDTRY_KEYWORD] = ACTIONS(423),
    [sym_ASYNC_KEYWORD] = ACTIONS(423),
    [sym_AWAIT_KEYWORD] = ACTIONS(423),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(423),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(423),
    [sym_AND_KEYWORD] = ACTIONS(423),
    [sym_OR_KEYWORD] = ACTIONS(423),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(423),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(421),
    [aux_sym_preprocessor_token1] = ACTIONS(421),
    [aux_sym_preprocessor_token2] = ACTIONS(421),
    [aux_sym_preprocessor_token3] = ACTIONS(421),
    [aux_sym_preprocessor_token4] = ACTIONS(421),
    [aux_sym_preprocessor_token5] = ACTIONS(421),
    [aux_sym_preprocessor_token6] = ACTIONS(421),
    [aux_sym_preprocessor_token7] = ACTIONS(421),
    [aux_sym_preprocessor_token8] = ACTIONS(421),
    [aux_sym_preprocessor_token9] = ACTIONS(421),
    [aux_sym_preprocessor_token10] = ACTIONS(421),
    [aux_sym_preprocessor_token11] = ACTIONS(421),
    [aux_sym_preprocessor_token12] = ACTIONS(421),
    [aux_sym_preprocessor_token13] = ACTIONS(421),
    [aux_sym_preprocessor_token14] = ACTIONS(421),
    [aux_sym_preprocessor_token15] = ACTIONS(421),
    [aux_sym_preprocessor_token16] = ACTIONS(421),
    [aux_sym_preprocessor_token17] = ACTIONS(423),
    [aux_sym_preprocessor_token18] = ACTIONS(423),
    [aux_sym_preprocessor_token19] = ACTIONS(423),
    [aux_sym_preprocessor_token20] = ACTIONS(423),
    [aux_sym_preprocessor_token21] = ACTIONS(421),
    [aux_sym_preprocessor_token22] = ACTIONS(421),
    [aux_sym_preprocessor_token23] = ACTIONS(421),
    [aux_sym_preprocessor_token24] = ACTIONS(421),
    [aux_sym_preprocessor_token25] = ACTIONS(423),
    [aux_sym_preprocessor_token26] = ACTIONS(423),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(59)] = {
    [sym_line_comment] = STATE(59),
    [ts_builtin_sym_end] = ACTIONS(427),
    [sym_identifier] = ACTIONS(429),
    [anon_sym_COMMA] = ACTIONS(427),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_RPAREN] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(427),
    [aux_sym_execute_statement_token1] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(427),
    [anon_sym_PLUS] = ACTIONS(427),
    [anon_sym_LT_GT] = ACTIONS(427),
    [anon_sym_GT] = ACTIONS(429),
    [anon_sym_LT] = ACTIONS(429),
    [anon_sym_GT_EQ] = ACTIONS(427),
    [anon_sym_LT_EQ] = ACTIONS(427),
    [anon_sym_STAR] = ACTIONS(427),
    [anon_sym_SLASH] = ACTIONS(429),
    [anon_sym_PERCENT] = ACTIONS(427),
    [anon_sym_RBRACK] = ACTIONS(427),
    [sym_IF_KEYWORD] = ACTIONS(429),
    [sym_THEN_KEYWORD] = ACTIONS(429),
    [sym_ENDIF_KEYWORD] = ACTIONS(429),
    [sym_FOR_KEYWORD] = ACTIONS(429),
    [sym_WHILE_KEYWORD] = ACTIONS(429),
    [sym_DO_KEYWORD] = ACTIONS(429),
    [sym_ENDDO_KEYWORD] = ACTIONS(429),
    [sym_GOTO_KEYWORD] = ACTIONS(429),
    [sym_RETURN_KEYWORD] = ACTIONS(429),
    [sym_BREAK_KEYWORD] = ACTIONS(429),
    [sym_CONTINUE_KEYWORD] = ACTIONS(429),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(429),
    [sym_FUNCTION_KEYWORD] = ACTIONS(429),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(429),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(429),
    [sym_VAR_KEYWORD] = ACTIONS(429),
    [sym_TRY_KEYWORD] = ACTIONS(429),
    [sym_RAISE_KEYWORD] = ACTIONS(429),
    [sym_ENDTRY_KEYWORD] = ACTIONS(429),
    [sym_ASYNC_KEYWORD] = ACTIONS(429),
    [sym_AWAIT_KEYWORD] = ACTIONS(429),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(429),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(429),
    [sym_AND_KEYWORD] = ACTIONS(429),
    [sym_OR_KEYWORD] = ACTIONS(429),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(429),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(427),
    [aux_sym_preprocessor_token1] = ACTIONS(427),
    [aux_sym_preprocessor_token2] = ACTIONS(427),
    [aux_sym_preprocessor_token3] = ACTIONS(427),
    [aux_sym_preprocessor_token4] = ACTIONS(427),
    [aux_sym_preprocessor_token5] = ACTIONS(427),
    [aux_sym_preprocessor_token6] = ACTIONS(427),
    [aux_sym_preprocessor_token7] = ACTIONS(427),
    [aux_sym_preprocessor_token8] = ACTIONS(427),
    [aux_sym_preprocessor_token9] = ACTIONS(427),
    [aux_sym_preprocessor_token10] = ACTIONS(427),
    [aux_sym_preprocessor_token11] = ACTIONS(427),
    [aux_sym_preprocessor_token12] = ACTIONS(427),
    [aux_sym_preprocessor_token13] = ACTIONS(427),
    [aux_sym_preprocessor_token14] = ACTIONS(427),
    [aux_sym_preprocessor_token15] = ACTIONS(427),
    [aux_sym_preprocessor_token16] = ACTIONS(427),
    [aux_sym_preprocessor_token17] = ACTIONS(429),
    [aux_sym_preprocessor_token18] = ACTIONS(429),
    [aux_sym_preprocessor_token19] = ACTIONS(429),
    [aux_sym_preprocessor_token20] = ACTIONS(429),
    [aux_sym_preprocessor_token21] = ACTIONS(427),
    [aux_sym_preprocessor_token22] = ACTIONS(427),
    [aux_sym_preprocessor_token23] = ACTIONS(427),
    [aux_sym_preprocessor_token24] = ACTIONS(427),
    [aux_sym_preprocessor_token25] = ACTIONS(429),
    [aux_sym_preprocessor_token26] = ACTIONS(429),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(60)] = {
    [sym_line_comment] = STATE(60),
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [anon_sym_RBRACK] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_THEN_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_DO_KEYWORD] = ACTIONS(433),
    [sym_ENDDO_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_FUNCTION_KEYWORD] = ACTIONS(433),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_ENDTRY_KEYWORD] = ACTIONS(433),
    [sym_ASYNC_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(61)] = {
    [sym_line_comment] = STATE(61),
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(431),
    [anon_sym_PLUS] = ACTIONS(431),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [anon_sym_RBRACK] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_THEN_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_DO_KEYWORD] = ACTIONS(433),
    [sym_ENDDO_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_FUNCTION_KEYWORD] = ACTIONS(433),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_ENDTRY_KEYWORD] = ACTIONS(433),
    [sym_ASYNC_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(62)] = {
    [sym_line_comment] = STATE(62),
    [ts_builtin_sym_end] = ACTIONS(441),
    [sym_identifier] = ACTIONS(443),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_RPAREN] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [aux_sym_execute_statement_token1] = ACTIONS(443),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_LT_GT] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(443),
    [anon_sym_LT] = ACTIONS(443),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(443),
    [anon_sym_PERCENT] = ACTIONS(441),
    [anon_sym_RBRACK] = ACTIONS(441),
    [sym_IF_KEYWORD] = ACTIONS(443),
    [sym_THEN_KEYWORD] = ACTIONS(443),
    [sym_ENDIF_KEYWORD] = ACTIONS(443),
    [sym_FOR_KEYWORD] = ACTIONS(443),
    [sym_WHILE_KEYWORD] = ACTIONS(443),
    [sym_DO_KEYWORD] = ACTIONS(443),
    [sym_ENDDO_KEYWORD] = ACTIONS(443),
    [sym_GOTO_KEYWORD] = ACTIONS(443),
    [sym_RETURN_KEYWORD] = ACTIONS(443),
    [sym_BREAK_KEYWORD] = ACTIONS(443),
    [sym_CONTINUE_KEYWORD] = ACTIONS(443),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(443),
    [sym_FUNCTION_KEYWORD] = ACTIONS(443),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(443),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(443),
    [sym_VAR_KEYWORD] = ACTIONS(443),
    [sym_TRY_KEYWORD] = ACTIONS(443),
    [sym_RAISE_KEYWORD] = ACTIONS(443),
    [sym_ENDTRY_KEYWORD] = ACTIONS(443),
    [sym_ASYNC_KEYWORD] = ACTIONS(443),
    [sym_AWAIT_KEYWORD] = ACTIONS(443),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(443),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(443),
    [sym_AND_KEYWORD] = ACTIONS(443),
    [sym_OR_KEYWORD] = ACTIONS(443),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(443),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(441),
    [aux_sym_preprocessor_token1] = ACTIONS(441),
    [aux_sym_preprocessor_token2] = ACTIONS(441),
    [aux_sym_preprocessor_token3] = ACTIONS(441),
    [aux_sym_preprocessor_token4] = ACTIONS(441),
    [aux_sym_preprocessor_token5] = ACTIONS(441),
    [aux_sym_preprocessor_token6] = ACTIONS(441),
    [aux_sym_preprocessor_token7] = ACTIONS(441),
    [aux_sym_preprocessor_token8] = ACTIONS(441),
    [aux_sym_preprocessor_token9] = ACTIONS(441),
    [aux_sym_preprocessor_token10] = ACTIONS(441),
    [aux_sym_preprocessor_token11] = ACTIONS(441),
    [aux_sym_preprocessor_token12] = ACTIONS(441),
    [aux_sym_preprocessor_token13] = ACTIONS(441),
    [aux_sym_preprocessor_token14] = ACTIONS(441),
    [aux_sym_preprocessor_token15] = ACTIONS(441),
    [aux_sym_preprocessor_token16] = ACTIONS(441),
    [aux_sym_preprocessor_token17] = ACTIONS(443),
    [aux_sym_preprocessor_token18] = ACTIONS(443),
    [aux_sym_preprocessor_token19] = ACTIONS(443),
    [aux_sym_preprocessor_token20] = ACTIONS(443),
    [aux_sym_preprocessor_token21] = ACTIONS(441),
    [aux_sym_preprocessor_token22] = ACTIONS(441),
    [aux_sym_preprocessor_token23] = ACTIONS(441),
    [aux_sym_preprocessor_token24] = ACTIONS(441),
    [aux_sym_preprocessor_token25] = ACTIONS(443),
    [aux_sym_preprocessor_token26] = ACTIONS(443),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(63)] = {
    [sym_line_comment] = STATE(63),
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(431),
    [anon_sym_PLUS] = ACTIONS(431),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(431),
    [anon_sym_SLASH] = ACTIONS(433),
    [anon_sym_PERCENT] = ACTIONS(431),
    [anon_sym_RBRACK] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_THEN_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_DO_KEYWORD] = ACTIONS(433),
    [sym_ENDDO_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_FUNCTION_KEYWORD] = ACTIONS(433),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_ENDTRY_KEYWORD] = ACTIONS(433),
    [sym_ASYNC_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(64)] = {
    [sym_line_comment] = STATE(64),
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [anon_sym_RBRACK] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_THEN_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_DO_KEYWORD] = ACTIONS(433),
    [sym_ENDDO_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_FUNCTION_KEYWORD] = ACTIONS(433),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_ENDTRY_KEYWORD] = ACTIONS(433),
    [sym_ASYNC_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(65)] = {
    [sym_line_comment] = STATE(65),
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_RPAREN] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [anon_sym_RBRACK] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_THEN_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_DO_KEYWORD] = ACTIONS(433),
    [sym_ENDDO_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_FUNCTION_KEYWORD] = ACTIONS(433),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(433),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_ENDTRY_KEYWORD] = ACTIONS(433),
    [sym_ASYNC_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(66)] = {
    [sym_line_comment] = STATE(66),
    [ts_builtin_sym_end] = ACTIONS(451),
    [sym_identifier] = ACTIONS(453),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_RPAREN] = ACTIONS(451),
    [anon_sym_EQ] = ACTIONS(451),
    [aux_sym_execute_statement_token1] = ACTIONS(453),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_LT_GT] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(453),
    [anon_sym_PERCENT] = ACTIONS(451),
    [anon_sym_RBRACK] = ACTIONS(451),
    [sym_IF_KEYWORD] = ACTIONS(453),
    [sym_THEN_KEYWORD] = ACTIONS(453),
    [sym_ENDIF_KEYWORD] = ACTIONS(453),
    [sym_FOR_KEYWORD] = ACTIONS(453),
    [sym_WHILE_KEYWORD] = ACTIONS(453),
    [sym_DO_KEYWORD] = ACTIONS(453),
    [sym_ENDDO_KEYWORD] = ACTIONS(453),
    [sym_GOTO_KEYWORD] = ACTIONS(453),
    [sym_RETURN_KEYWORD] = ACTIONS(453),
    [sym_BREAK_KEYWORD] = ACTIONS(453),
    [sym_CONTINUE_KEYWORD] = ACTIONS(453),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(453),
    [sym_FUNCTION_KEYWORD] = ACTIONS(453),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(453),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(453),
    [sym_VAR_KEYWORD] = ACTIONS(453),
    [sym_TRY_KEYWORD] = ACTIONS(453),
    [sym_RAISE_KEYWORD] = ACTIONS(453),
    [sym_ENDTRY_KEYWORD] = ACTIONS(453),
    [sym_ASYNC_KEYWORD] = ACTIONS(453),
    [sym_AWAIT_KEYWORD] = ACTIONS(453),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(453),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(453),
    [sym_AND_KEYWORD] = ACTIONS(453),
    [sym_OR_KEYWORD] = ACTIONS(453),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(453),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(451),
    [aux_sym_preprocessor_token1] = ACTIONS(451),
    [aux_sym_preprocessor_token2] = ACTIONS(451),
    [aux_sym_preprocessor_token3] = ACTIONS(451),
    [aux_sym_preprocessor_token4] = ACTIONS(451),
    [aux_sym_preprocessor_token5] = ACTIONS(451),
    [aux_sym_preprocessor_token6] = ACTIONS(451),
    [aux_sym_preprocessor_token7] = ACTIONS(451),
    [aux_sym_preprocessor_token8] = ACTIONS(451),
    [aux_sym_preprocessor_token9] = ACTIONS(451),
    [aux_sym_preprocessor_token10] = ACTIONS(451),
    [aux_sym_preprocessor_token11] = ACTIONS(451),
    [aux_sym_preprocessor_token12] = ACTIONS(451),
    [aux_sym_preprocessor_token13] = ACTIONS(451),
    [aux_sym_preprocessor_token14] = ACTIONS(451),
    [aux_sym_preprocessor_token15] = ACTIONS(451),
    [aux_sym_preprocessor_token16] = ACTIONS(451),
    [aux_sym_preprocessor_token17] = ACTIONS(453),
    [aux_sym_preprocessor_token18] = ACTIONS(453),
    [aux_sym_preprocessor_token19] = ACTIONS(453),
    [aux_sym_preprocessor_token20] = ACTIONS(453),
    [aux_sym_preprocessor_token21] = ACTIONS(451),
    [aux_sym_preprocessor_token22] = ACTIONS(451),
    [aux_sym_preprocessor_token23] = ACTIONS(451),
    [aux_sym_preprocessor_token24] = ACTIONS(451),
    [aux_sym_preprocessor_token25] = ACTIONS(453),
    [aux_sym_preprocessor_token26] = ACTIONS(453),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(67)] = {
    [sym_line_comment] = STATE(67),
    [ts_builtin_sym_end] = ACTIONS(455),
    [sym_identifier] = ACTIONS(457),
    [anon_sym_COMMA] = ACTIONS(455),
    [anon_sym_SEMI] = ACTIONS(455),
    [anon_sym_RPAREN] = ACTIONS(455),
    [anon_sym_EQ] = ACTIONS(455),
    [aux_sym_execute_statement_token1] = ACTIONS(457),
    [anon_sym_TILDE] = ACTIONS(455),
    [anon_sym_DASH] = ACTIONS(455),
    [anon_sym_PLUS] = ACTIONS(455),
    [anon_sym_LT_GT] = ACTIONS(455),
    [anon_sym_GT] = ACTIONS(457),
    [anon_sym_LT] = ACTIONS(457),
    [anon_sym_GT_EQ] = ACTIONS(455),
    [anon_sym_LT_EQ] = ACTIONS(455),
    [anon_sym_STAR] = ACTIONS(455),
    [anon_sym_SLASH] = ACTIONS(457),
    [anon_sym_PERCENT] = ACTIONS(455),
    [anon_sym_RBRACK] = ACTIONS(455),
    [sym_IF_KEYWORD] = ACTIONS(457),
    [sym_THEN_KEYWORD] = ACTIONS(457),
    [sym_ENDIF_KEYWORD] = ACTIONS(457),
    [sym_FOR_KEYWORD] = ACTIONS(457),
    [sym_WHILE_KEYWORD] = ACTIONS(457),
    [sym_DO_KEYWORD] = ACTIONS(457),
    [sym_ENDDO_KEYWORD] = ACTIONS(457),
    [sym_GOTO_KEYWORD] = ACTIONS(457),
    [sym_RETURN_KEYWORD] = ACTIONS(457),
    [sym_BREAK_KEYWORD] = ACTIONS(457),
    [sym_CONTINUE_KEYWORD] = ACTIONS(457),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(457),
    [sym_FUNCTION_KEYWORD] = ACTIONS(457),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(457),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(457),
    [sym_VAR_KEYWORD] = ACTIONS(457),
    [sym_TRY_KEYWORD] = ACTIONS(457),
    [sym_RAISE_KEYWORD] = ACTIONS(457),
    [sym_ENDTRY_KEYWORD] = ACTIONS(457),
    [sym_ASYNC_KEYWORD] = ACTIONS(457),
    [sym_AWAIT_KEYWORD] = ACTIONS(457),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(457),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(457),
    [sym_AND_KEYWORD] = ACTIONS(457),
    [sym_OR_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(455),
    [aux_sym_preprocessor_token1] = ACTIONS(455),
    [aux_sym_preprocessor_token2] = ACTIONS(455),
    [aux_sym_preprocessor_token3] = ACTIONS(455),
    [aux_sym_preprocessor_token4] = ACTIONS(455),
    [aux_sym_preprocessor_token5] = ACTIONS(455),
    [aux_sym_preprocessor_token6] = ACTIONS(455),
    [aux_sym_preprocessor_token7] = ACTIONS(455),
    [aux_sym_preprocessor_token8] = ACTIONS(455),
    [aux_sym_preprocessor_token9] = ACTIONS(455),
    [aux_sym_preprocessor_token10] = ACTIONS(455),
    [aux_sym_preprocessor_token11] = ACTIONS(455),
    [aux_sym_preprocessor_token12] = ACTIONS(455),
    [aux_sym_preprocessor_token13] = ACTIONS(455),
    [aux_sym_preprocessor_token14] = ACTIONS(455),
    [aux_sym_preprocessor_token15] = ACTIONS(455),
    [aux_sym_preprocessor_token16] = ACTIONS(455),
    [aux_sym_preprocessor_token17] = ACTIONS(457),
    [aux_sym_preprocessor_token18] = ACTIONS(457),
    [aux_sym_preprocessor_token19] = ACTIONS(457),
    [aux_sym_preprocessor_token20] = ACTIONS(457),
    [aux_sym_preprocessor_token21] = ACTIONS(455),
    [aux_sym_preprocessor_token22] = ACTIONS(455),
    [aux_sym_preprocessor_token23] = ACTIONS(455),
    [aux_sym_preprocessor_token24] = ACTIONS(455),
    [aux_sym_preprocessor_token25] = ACTIONS(457),
    [aux_sym_preprocessor_token26] = ACTIONS(457),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(68)] = {
    [sym_line_comment] = STATE(68),
    [ts_builtin_sym_end] = ACTIONS(299),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_RPAREN] = ACTIONS(299),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [anon_sym_RBRACK] = ACTIONS(299),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_THEN_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_DO_KEYWORD] = ACTIONS(301),
    [sym_ENDDO_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_FUNCTION_KEYWORD] = ACTIONS(301),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(301),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_ENDTRY_KEYWORD] = ACTIONS(301),
    [sym_ASYNC_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(69)] = {
    [sym_line_comment] = STATE(69),
    [ts_builtin_sym_end] = ACTIONS(459),
    [sym_identifier] = ACTIONS(461),
    [anon_sym_COMMA] = ACTIONS(459),
    [anon_sym_SEMI] = ACTIONS(459),
    [anon_sym_RPAREN] = ACTIONS(459),
    [anon_sym_EQ] = ACTIONS(459),
    [aux_sym_execute_statement_token1] = ACTIONS(461),
    [anon_sym_TILDE] = ACTIONS(459),
    [anon_sym_DASH] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(459),
    [anon_sym_LT_GT] = ACTIONS(459),
    [anon_sym_GT] = ACTIONS(461),
    [anon_sym_LT] = ACTIONS(461),
    [anon_sym_GT_EQ] = ACTIONS(459),
    [anon_sym_LT_EQ] = ACTIONS(459),
    [anon_sym_STAR] = ACTIONS(459),
    [anon_sym_SLASH] = ACTIONS(461),
    [anon_sym_PERCENT] = ACTIONS(459),
    [anon_sym_RBRACK] = ACTIONS(459),
    [sym_IF_KEYWORD] = ACTIONS(461),
    [sym_THEN_KEYWORD] = ACTIONS(461),
    [sym_ENDIF_KEYWORD] = ACTIONS(461),
    [sym_FOR_KEYWORD] = ACTIONS(461),
    [sym_WHILE_KEYWORD] = ACTIONS(461),
    [sym_DO_KEYWORD] = ACTIONS(461),
    [sym_ENDDO_KEYWORD] = ACTIONS(461),
    [sym_GOTO_KEYWORD] = ACTIONS(461),
    [sym_RETURN_KEYWORD] = ACTIONS(461),
    [sym_BREAK_KEYWORD] = ACTIONS(461),
    [sym_CONTINUE_KEYWORD] = ACTIONS(461),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(461),
    [sym_FUNCTION_KEYWORD] = ACTIONS(461),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(461),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(461),
    [sym_VAR_KEYWORD] = ACTIONS(461),
    [sym_TRY_KEYWORD] = ACTIONS(461),
    [sym_RAISE_KEYWORD] = ACTIONS(461),
    [sym_ENDTRY_KEYWORD] = ACTIONS(461),
    [sym_ASYNC_KEYWORD] = ACTIONS(461),
    [sym_AWAIT_KEYWORD] = ACTIONS(461),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(461),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(461),
    [sym_AND_KEYWORD] = ACTIONS(461),
    [sym_OR_KEYWORD] = ACTIONS(461),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(461),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(459),
    [aux_sym_preprocessor_token1] = ACTIONS(459),
    [aux_sym_preprocessor_token2] = ACTIONS(459),
    [aux_sym_preprocessor_token3] = ACTIONS(459),
    [aux_sym_preprocessor_token4] = ACTIONS(459),
    [aux_sym_preprocessor_token5] = ACTIONS(459),
    [aux_sym_preprocessor_token6] = ACTIONS(459),
    [aux_sym_preprocessor_token7] = ACTIONS(459),
    [aux_sym_preprocessor_token8] = ACTIONS(459),
    [aux_sym_preprocessor_token9] = ACTIONS(459),
    [aux_sym_preprocessor_token10] = ACTIONS(459),
    [aux_sym_preprocessor_token11] = ACTIONS(459),
    [aux_sym_preprocessor_token12] = ACTIONS(459),
    [aux_sym_preprocessor_token13] = ACTIONS(459),
    [aux_sym_preprocessor_token14] = ACTIONS(459),
    [aux_sym_preprocessor_token15] = ACTIONS(459),
    [aux_sym_preprocessor_token16] = ACTIONS(459),
    [aux_sym_preprocessor_token17] = ACTIONS(461),
    [aux_sym_preprocessor_token18] = ACTIONS(461),
    [aux_sym_preprocessor_token19] = ACTIONS(461),
    [aux_sym_preprocessor_token20] = ACTIONS(461),
    [aux_sym_preprocessor_token21] = ACTIONS(459),
    [aux_sym_preprocessor_token22] = ACTIONS(459),
    [aux_sym_preprocessor_token23] = ACTIONS(459),
    [aux_sym_preprocessor_token24] = ACTIONS(459),
    [aux_sym_preprocessor_token25] = ACTIONS(461),
    [aux_sym_preprocessor_token26] = ACTIONS(461),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(70)] = {
    [sym_line_comment] = STATE(70),
    [ts_builtin_sym_end] = ACTIONS(463),
    [sym_identifier] = ACTIONS(465),
    [anon_sym_COMMA] = ACTIONS(463),
    [anon_sym_SEMI] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(463),
    [anon_sym_EQ] = ACTIONS(463),
    [aux_sym_execute_statement_token1] = ACTIONS(465),
    [anon_sym_TILDE] = ACTIONS(463),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PLUS] = ACTIONS(463),
    [anon_sym_LT_GT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(465),
    [anon_sym_LT] = ACTIONS(465),
    [anon_sym_GT_EQ] = ACTIONS(463),
    [anon_sym_LT_EQ] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(463),
    [anon_sym_SLASH] = ACTIONS(465),
    [anon_sym_PERCENT] = ACTIONS(463),
    [anon_sym_RBRACK] = ACTIONS(463),
    [sym_IF_KEYWORD] = ACTIONS(465),
    [sym_THEN_KEYWORD] = ACTIONS(465),
    [sym_ENDIF_KEYWORD] = ACTIONS(465),
    [sym_FOR_KEYWORD] = ACTIONS(465),
    [sym_WHILE_KEYWORD] = ACTIONS(465),
    [sym_DO_KEYWORD] = ACTIONS(465),
    [sym_ENDDO_KEYWORD] = ACTIONS(465),
    [sym_GOTO_KEYWORD] = ACTIONS(465),
    [sym_RETURN_KEYWORD] = ACTIONS(465),
    [sym_BREAK_KEYWORD] = ACTIONS(465),
    [sym_CONTINUE_KEYWORD] = ACTIONS(465),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(465),
    [sym_FUNCTION_KEYWORD] = ACTIONS(465),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(465),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(465),
    [sym_VAR_KEYWORD] = ACTIONS(465),
    [sym_TRY_KEYWORD] = ACTIONS(465),
    [sym_RAISE_KEYWORD] = ACTIONS(465),
    [sym_ENDTRY_KEYWORD] = ACTIONS(465),
    [sym_ASYNC_KEYWORD] = ACTIONS(465),
    [sym_AWAIT_KEYWORD] = ACTIONS(465),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(465),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(465),
    [sym_AND_KEYWORD] = ACTIONS(465),
    [sym_OR_KEYWORD] = ACTIONS(465),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(465),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(463),
    [aux_sym_preprocessor_token1] = ACTIONS(463),
    [aux_sym_preprocessor_token2] = ACTIONS(463),
    [aux_sym_preprocessor_token3] = ACTIONS(463),
    [aux_sym_preprocessor_token4] = ACTIONS(463),
    [aux_sym_preprocessor_token5] = ACTIONS(463),
    [aux_sym_preprocessor_token6] = ACTIONS(463),
    [aux_sym_preprocessor_token7] = ACTIONS(463),
    [aux_sym_preprocessor_token8] = ACTIONS(463),
    [aux_sym_preprocessor_token9] = ACTIONS(463),
    [aux_sym_preprocessor_token10] = ACTIONS(463),
    [aux_sym_preprocessor_token11] = ACTIONS(463),
    [aux_sym_preprocessor_token12] = ACTIONS(463),
    [aux_sym_preprocessor_token13] = ACTIONS(463),
    [aux_sym_preprocessor_token14] = ACTIONS(463),
    [aux_sym_preprocessor_token15] = ACTIONS(463),
    [aux_sym_preprocessor_token16] = ACTIONS(463),
    [aux_sym_preprocessor_token17] = ACTIONS(465),
    [aux_sym_preprocessor_token18] = ACTIONS(465),
    [aux_sym_preprocessor_token19] = ACTIONS(465),
    [aux_sym_preprocessor_token20] = ACTIONS(465),
    [aux_sym_preprocessor_token21] = ACTIONS(463),
    [aux_sym_preprocessor_token22] = ACTIONS(463),
    [aux_sym_preprocessor_token23] = ACTIONS(463),
    [aux_sym_preprocessor_token24] = ACTIONS(463),
    [aux_sym_preprocessor_token25] = ACTIONS(465),
    [aux_sym_preprocessor_token26] = ACTIONS(465),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(71)] = {
    [sym_line_comment] = STATE(71),
    [ts_builtin_sym_end] = ACTIONS(467),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_SEMI] = ACTIONS(471),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(469),
    [anon_sym_TILDE] = ACTIONS(467),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(469),
    [sym_ENDIF_KEYWORD] = ACTIONS(469),
    [sym_FOR_KEYWORD] = ACTIONS(469),
    [sym_WHILE_KEYWORD] = ACTIONS(469),
    [sym_ENDDO_KEYWORD] = ACTIONS(469),
    [sym_GOTO_KEYWORD] = ACTIONS(469),
    [sym_RETURN_KEYWORD] = ACTIONS(469),
    [sym_BREAK_KEYWORD] = ACTIONS(469),
    [sym_CONTINUE_KEYWORD] = ACTIONS(469),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(469),
    [sym_FUNCTION_KEYWORD] = ACTIONS(469),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(469),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(469),
    [sym_VAR_KEYWORD] = ACTIONS(469),
    [sym_TRY_KEYWORD] = ACTIONS(469),
    [sym_RAISE_KEYWORD] = ACTIONS(469),
    [sym_ENDTRY_KEYWORD] = ACTIONS(469),
    [sym_ASYNC_KEYWORD] = ACTIONS(469),
    [sym_AWAIT_KEYWORD] = ACTIONS(469),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(469),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(469),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(469),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(467),
    [aux_sym_preprocessor_token1] = ACTIONS(467),
    [aux_sym_preprocessor_token2] = ACTIONS(467),
    [aux_sym_preprocessor_token3] = ACTIONS(467),
    [aux_sym_preprocessor_token4] = ACTIONS(467),
    [aux_sym_preprocessor_token5] = ACTIONS(467),
    [aux_sym_preprocessor_token6] = ACTIONS(467),
    [aux_sym_preprocessor_token7] = ACTIONS(467),
    [aux_sym_preprocessor_token8] = ACTIONS(467),
    [aux_sym_preprocessor_token9] = ACTIONS(467),
    [aux_sym_preprocessor_token10] = ACTIONS(467),
    [aux_sym_preprocessor_token11] = ACTIONS(467),
    [aux_sym_preprocessor_token12] = ACTIONS(467),
    [aux_sym_preprocessor_token13] = ACTIONS(467),
    [aux_sym_preprocessor_token14] = ACTIONS(467),
    [aux_sym_preprocessor_token15] = ACTIONS(467),
    [aux_sym_preprocessor_token16] = ACTIONS(467),
    [aux_sym_preprocessor_token17] = ACTIONS(469),
    [aux_sym_preprocessor_token18] = ACTIONS(469),
    [aux_sym_preprocessor_token19] = ACTIONS(469),
    [aux_sym_preprocessor_token20] = ACTIONS(469),
    [aux_sym_preprocessor_token21] = ACTIONS(467),
    [aux_sym_preprocessor_token22] = ACTIONS(467),
    [aux_sym_preprocessor_token23] = ACTIONS(467),
    [aux_sym_preprocessor_token24] = ACTIONS(467),
    [aux_sym_preprocessor_token25] = ACTIONS(469),
    [aux_sym_preprocessor_token26] = ACTIONS(469),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(72)] = {
    [sym_line_comment] = STATE(72),
    [ts_builtin_sym_end] = ACTIONS(475),
    [sym_identifier] = ACTIONS(477),
    [anon_sym_SEMI] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(477),
    [anon_sym_TILDE] = ACTIONS(475),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(477),
    [sym_ENDIF_KEYWORD] = ACTIONS(477),
    [sym_FOR_KEYWORD] = ACTIONS(477),
    [sym_WHILE_KEYWORD] = ACTIONS(477),
    [sym_ENDDO_KEYWORD] = ACTIONS(477),
    [sym_GOTO_KEYWORD] = ACTIONS(477),
    [sym_RETURN_KEYWORD] = ACTIONS(477),
    [sym_BREAK_KEYWORD] = ACTIONS(477),
    [sym_CONTINUE_KEYWORD] = ACTIONS(477),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(477),
    [sym_FUNCTION_KEYWORD] = ACTIONS(477),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(477),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(477),
    [sym_VAR_KEYWORD] = ACTIONS(477),
    [sym_TRY_KEYWORD] = ACTIONS(477),
    [sym_RAISE_KEYWORD] = ACTIONS(477),
    [sym_ENDTRY_KEYWORD] = ACTIONS(477),
    [sym_ASYNC_KEYWORD] = ACTIONS(477),
    [sym_AWAIT_KEYWORD] = ACTIONS(477),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(477),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(477),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(477),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(475),
    [aux_sym_preprocessor_token1] = ACTIONS(475),
    [aux_sym_preprocessor_token2] = ACTIONS(475),
    [aux_sym_preprocessor_token3] = ACTIONS(475),
    [aux_sym_preprocessor_token4] = ACTIONS(475),
    [aux_sym_preprocessor_token5] = ACTIONS(475),
    [aux_sym_preprocessor_token6] = ACTIONS(475),
    [aux_sym_preprocessor_token7] = ACTIONS(475),
    [aux_sym_preprocessor_token8] = ACTIONS(475),
    [aux_sym_preprocessor_token9] = ACTIONS(475),
    [aux_sym_preprocessor_token10] = ACTIONS(475),
    [aux_sym_preprocessor_token11] = ACTIONS(475),
    [aux_sym_preprocessor_token12] = ACTIONS(475),
    [aux_sym_preprocessor_token13] = ACTIONS(475),
    [aux_sym_preprocessor_token14] = ACTIONS(475),
    [aux_sym_preprocessor_token15] = ACTIONS(475),
    [aux_sym_preprocessor_token16] = ACTIONS(475),
    [aux_sym_preprocessor_token17] = ACTIONS(477),
    [aux_sym_preprocessor_token18] = ACTIONS(477),
    [aux_sym_preprocessor_token19] = ACTIONS(477),
    [aux_sym_preprocessor_token20] = ACTIONS(477),
    [aux_sym_preprocessor_token21] = ACTIONS(475),
    [aux_sym_preprocessor_token22] = ACTIONS(475),
    [aux_sym_preprocessor_token23] = ACTIONS(475),
    [aux_sym_preprocessor_token24] = ACTIONS(475),
    [aux_sym_preprocessor_token25] = ACTIONS(477),
    [aux_sym_preprocessor_token26] = ACTIONS(477),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(73)] = {
    [sym_line_comment] = STATE(73),
    [ts_builtin_sym_end] = ACTIONS(455),
    [sym_identifier] = ACTIONS(457),
    [anon_sym_SEMI] = ACTIONS(455),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(457),
    [anon_sym_TILDE] = ACTIONS(455),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(457),
    [sym_ENDIF_KEYWORD] = ACTIONS(457),
    [sym_FOR_KEYWORD] = ACTIONS(457),
    [sym_WHILE_KEYWORD] = ACTIONS(457),
    [sym_ENDDO_KEYWORD] = ACTIONS(457),
    [sym_GOTO_KEYWORD] = ACTIONS(457),
    [sym_RETURN_KEYWORD] = ACTIONS(457),
    [sym_BREAK_KEYWORD] = ACTIONS(457),
    [sym_CONTINUE_KEYWORD] = ACTIONS(457),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(457),
    [sym_FUNCTION_KEYWORD] = ACTIONS(457),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(457),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(457),
    [sym_VAR_KEYWORD] = ACTIONS(457),
    [sym_TRY_KEYWORD] = ACTIONS(457),
    [sym_RAISE_KEYWORD] = ACTIONS(457),
    [sym_ENDTRY_KEYWORD] = ACTIONS(457),
    [sym_ASYNC_KEYWORD] = ACTIONS(457),
    [sym_AWAIT_KEYWORD] = ACTIONS(457),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(457),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(457),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(455),
    [aux_sym_preprocessor_token1] = ACTIONS(455),
    [aux_sym_preprocessor_token2] = ACTIONS(455),
    [aux_sym_preprocessor_token3] = ACTIONS(455),
    [aux_sym_preprocessor_token4] = ACTIONS(455),
    [aux_sym_preprocessor_token5] = ACTIONS(455),
    [aux_sym_preprocessor_token6] = ACTIONS(455),
    [aux_sym_preprocessor_token7] = ACTIONS(455),
    [aux_sym_preprocessor_token8] = ACTIONS(455),
    [aux_sym_preprocessor_token9] = ACTIONS(455),
    [aux_sym_preprocessor_token10] = ACTIONS(455),
    [aux_sym_preprocessor_token11] = ACTIONS(455),
    [aux_sym_preprocessor_token12] = ACTIONS(455),
    [aux_sym_preprocessor_token13] = ACTIONS(455),
    [aux_sym_preprocessor_token14] = ACTIONS(455),
    [aux_sym_preprocessor_token15] = ACTIONS(455),
    [aux_sym_preprocessor_token16] = ACTIONS(455),
    [aux_sym_preprocessor_token17] = ACTIONS(457),
    [aux_sym_preprocessor_token18] = ACTIONS(457),
    [aux_sym_preprocessor_token19] = ACTIONS(457),
    [aux_sym_preprocessor_token20] = ACTIONS(457),
    [aux_sym_preprocessor_token21] = ACTIONS(455),
    [aux_sym_preprocessor_token22] = ACTIONS(455),
    [aux_sym_preprocessor_token23] = ACTIONS(455),
    [aux_sym_preprocessor_token24] = ACTIONS(455),
    [aux_sym_preprocessor_token25] = ACTIONS(457),
    [aux_sym_preprocessor_token26] = ACTIONS(457),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(74)] = {
    [sym_line_comment] = STATE(74),
    [ts_builtin_sym_end] = ACTIONS(481),
    [sym_identifier] = ACTIONS(483),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(483),
    [anon_sym_TILDE] = ACTIONS(481),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(483),
    [sym_ENDIF_KEYWORD] = ACTIONS(483),
    [sym_FOR_KEYWORD] = ACTIONS(483),
    [sym_WHILE_KEYWORD] = ACTIONS(483),
    [sym_ENDDO_KEYWORD] = ACTIONS(483),
    [sym_GOTO_KEYWORD] = ACTIONS(483),
    [sym_RETURN_KEYWORD] = ACTIONS(483),
    [sym_BREAK_KEYWORD] = ACTIONS(483),
    [sym_CONTINUE_KEYWORD] = ACTIONS(483),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(483),
    [sym_FUNCTION_KEYWORD] = ACTIONS(483),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(483),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(483),
    [sym_VAR_KEYWORD] = ACTIONS(483),
    [sym_TRY_KEYWORD] = ACTIONS(483),
    [sym_RAISE_KEYWORD] = ACTIONS(483),
    [sym_ENDTRY_KEYWORD] = ACTIONS(483),
    [sym_ASYNC_KEYWORD] = ACTIONS(483),
    [sym_AWAIT_KEYWORD] = ACTIONS(483),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(483),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(483),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(483),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(481),
    [aux_sym_preprocessor_token1] = ACTIONS(481),
    [aux_sym_preprocessor_token2] = ACTIONS(481),
    [aux_sym_preprocessor_token3] = ACTIONS(481),
    [aux_sym_preprocessor_token4] = ACTIONS(481),
    [aux_sym_preprocessor_token5] = ACTIONS(481),
    [aux_sym_preprocessor_token6] = ACTIONS(481),
    [aux_sym_preprocessor_token7] = ACTIONS(481),
    [aux_sym_preprocessor_token8] = ACTIONS(481),
    [aux_sym_preprocessor_token9] = ACTIONS(481),
    [aux_sym_preprocessor_token10] = ACTIONS(481),
    [aux_sym_preprocessor_token11] = ACTIONS(481),
    [aux_sym_preprocessor_token12] = ACTIONS(481),
    [aux_sym_preprocessor_token13] = ACTIONS(481),
    [aux_sym_preprocessor_token14] = ACTIONS(481),
    [aux_sym_preprocessor_token15] = ACTIONS(481),
    [aux_sym_preprocessor_token16] = ACTIONS(481),
    [aux_sym_preprocessor_token17] = ACTIONS(483),
    [aux_sym_preprocessor_token18] = ACTIONS(483),
    [aux_sym_preprocessor_token19] = ACTIONS(483),
    [aux_sym_preprocessor_token20] = ACTIONS(483),
    [aux_sym_preprocessor_token21] = ACTIONS(481),
    [aux_sym_preprocessor_token22] = ACTIONS(481),
    [aux_sym_preprocessor_token23] = ACTIONS(481),
    [aux_sym_preprocessor_token24] = ACTIONS(481),
    [aux_sym_preprocessor_token25] = ACTIONS(483),
    [aux_sym_preprocessor_token26] = ACTIONS(483),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(75)] = {
    [sym_arguments] = STATE(83),
    [sym_line_comment] = STATE(75),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_ELSIF_KEYWORD] = ACTIONS(301),
    [sym_ELSE_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_EXCEPT_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(76)] = {
    [sym_line_comment] = STATE(76),
    [ts_builtin_sym_end] = ACTIONS(489),
    [sym_identifier] = ACTIONS(491),
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(491),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(491),
    [sym_ENDIF_KEYWORD] = ACTIONS(491),
    [sym_FOR_KEYWORD] = ACTIONS(491),
    [sym_WHILE_KEYWORD] = ACTIONS(491),
    [sym_ENDDO_KEYWORD] = ACTIONS(491),
    [sym_GOTO_KEYWORD] = ACTIONS(491),
    [sym_RETURN_KEYWORD] = ACTIONS(491),
    [sym_BREAK_KEYWORD] = ACTIONS(491),
    [sym_CONTINUE_KEYWORD] = ACTIONS(491),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(491),
    [sym_FUNCTION_KEYWORD] = ACTIONS(491),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(491),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(491),
    [sym_VAR_KEYWORD] = ACTIONS(491),
    [sym_TRY_KEYWORD] = ACTIONS(491),
    [sym_RAISE_KEYWORD] = ACTIONS(491),
    [sym_ENDTRY_KEYWORD] = ACTIONS(491),
    [sym_ASYNC_KEYWORD] = ACTIONS(491),
    [sym_AWAIT_KEYWORD] = ACTIONS(491),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(491),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(491),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(491),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(489),
    [aux_sym_preprocessor_token1] = ACTIONS(489),
    [aux_sym_preprocessor_token2] = ACTIONS(489),
    [aux_sym_preprocessor_token3] = ACTIONS(489),
    [aux_sym_preprocessor_token4] = ACTIONS(489),
    [aux_sym_preprocessor_token5] = ACTIONS(489),
    [aux_sym_preprocessor_token6] = ACTIONS(489),
    [aux_sym_preprocessor_token7] = ACTIONS(489),
    [aux_sym_preprocessor_token8] = ACTIONS(489),
    [aux_sym_preprocessor_token9] = ACTIONS(489),
    [aux_sym_preprocessor_token10] = ACTIONS(489),
    [aux_sym_preprocessor_token11] = ACTIONS(489),
    [aux_sym_preprocessor_token12] = ACTIONS(489),
    [aux_sym_preprocessor_token13] = ACTIONS(489),
    [aux_sym_preprocessor_token14] = ACTIONS(489),
    [aux_sym_preprocessor_token15] = ACTIONS(489),
    [aux_sym_preprocessor_token16] = ACTIONS(489),
    [aux_sym_preprocessor_token17] = ACTIONS(491),
    [aux_sym_preprocessor_token18] = ACTIONS(491),
    [aux_sym_preprocessor_token19] = ACTIONS(491),
    [aux_sym_preprocessor_token20] = ACTIONS(491),
    [aux_sym_preprocessor_token21] = ACTIONS(489),
    [aux_sym_preprocessor_token22] = ACTIONS(489),
    [aux_sym_preprocessor_token23] = ACTIONS(489),
    [aux_sym_preprocessor_token24] = ACTIONS(489),
    [aux_sym_preprocessor_token25] = ACTIONS(491),
    [aux_sym_preprocessor_token26] = ACTIONS(491),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(77)] = {
    [sym_arguments] = STATE(83),
    [sym_line_comment] = STATE(77),
    [sym_identifier] = ACTIONS(313),
    [anon_sym_COMMA] = ACTIONS(311),
    [anon_sym_SEMI] = ACTIONS(311),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_EQ] = ACTIONS(311),
    [aux_sym_execute_statement_token1] = ACTIONS(313),
    [anon_sym_TILDE] = ACTIONS(311),
    [anon_sym_DASH] = ACTIONS(311),
    [anon_sym_PLUS] = ACTIONS(311),
    [anon_sym_LT_GT] = ACTIONS(311),
    [anon_sym_GT] = ACTIONS(313),
    [anon_sym_LT] = ACTIONS(313),
    [anon_sym_GT_EQ] = ACTIONS(311),
    [anon_sym_LT_EQ] = ACTIONS(311),
    [anon_sym_STAR] = ACTIONS(311),
    [anon_sym_SLASH] = ACTIONS(313),
    [anon_sym_PERCENT] = ACTIONS(311),
    [anon_sym_DOT] = ACTIONS(311),
    [anon_sym_LBRACK] = ACTIONS(311),
    [sym_IF_KEYWORD] = ACTIONS(313),
    [sym_ELSIF_KEYWORD] = ACTIONS(313),
    [sym_ELSE_KEYWORD] = ACTIONS(313),
    [sym_ENDIF_KEYWORD] = ACTIONS(313),
    [sym_FOR_KEYWORD] = ACTIONS(313),
    [sym_WHILE_KEYWORD] = ACTIONS(313),
    [sym_GOTO_KEYWORD] = ACTIONS(313),
    [sym_RETURN_KEYWORD] = ACTIONS(313),
    [sym_BREAK_KEYWORD] = ACTIONS(313),
    [sym_CONTINUE_KEYWORD] = ACTIONS(313),
    [sym_VAR_KEYWORD] = ACTIONS(313),
    [sym_TRY_KEYWORD] = ACTIONS(313),
    [sym_EXCEPT_KEYWORD] = ACTIONS(313),
    [sym_RAISE_KEYWORD] = ACTIONS(313),
    [sym_AWAIT_KEYWORD] = ACTIONS(313),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(313),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(313),
    [sym_AND_KEYWORD] = ACTIONS(313),
    [sym_OR_KEYWORD] = ACTIONS(313),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(313),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(311),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(311),
    [aux_sym_preprocessor_token1] = ACTIONS(311),
    [aux_sym_preprocessor_token2] = ACTIONS(311),
    [aux_sym_preprocessor_token3] = ACTIONS(311),
    [aux_sym_preprocessor_token4] = ACTIONS(311),
    [aux_sym_preprocessor_token5] = ACTIONS(311),
    [aux_sym_preprocessor_token6] = ACTIONS(311),
    [aux_sym_preprocessor_token7] = ACTIONS(311),
    [aux_sym_preprocessor_token8] = ACTIONS(311),
    [aux_sym_preprocessor_token9] = ACTIONS(311),
    [aux_sym_preprocessor_token10] = ACTIONS(311),
    [aux_sym_preprocessor_token11] = ACTIONS(311),
    [aux_sym_preprocessor_token12] = ACTIONS(311),
    [aux_sym_preprocessor_token13] = ACTIONS(311),
    [aux_sym_preprocessor_token14] = ACTIONS(311),
    [aux_sym_preprocessor_token15] = ACTIONS(311),
    [aux_sym_preprocessor_token16] = ACTIONS(311),
    [aux_sym_preprocessor_token17] = ACTIONS(313),
    [aux_sym_preprocessor_token18] = ACTIONS(313),
    [aux_sym_preprocessor_token19] = ACTIONS(313),
    [aux_sym_preprocessor_token20] = ACTIONS(313),
    [aux_sym_preprocessor_token21] = ACTIONS(311),
    [aux_sym_preprocessor_token22] = ACTIONS(311),
    [aux_sym_preprocessor_token23] = ACTIONS(311),
    [aux_sym_preprocessor_token24] = ACTIONS(311),
    [aux_sym_preprocessor_token25] = ACTIONS(313),
    [aux_sym_preprocessor_token26] = ACTIONS(313),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(78)] = {
    [sym_line_comment] = STATE(78),
    [ts_builtin_sym_end] = ACTIONS(495),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_SEMI] = ACTIONS(499),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(497),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(497),
    [sym_ENDIF_KEYWORD] = ACTIONS(497),
    [sym_FOR_KEYWORD] = ACTIONS(497),
    [sym_WHILE_KEYWORD] = ACTIONS(497),
    [sym_ENDDO_KEYWORD] = ACTIONS(497),
    [sym_GOTO_KEYWORD] = ACTIONS(497),
    [sym_RETURN_KEYWORD] = ACTIONS(497),
    [sym_BREAK_KEYWORD] = ACTIONS(497),
    [sym_CONTINUE_KEYWORD] = ACTIONS(497),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(497),
    [sym_FUNCTION_KEYWORD] = ACTIONS(497),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(497),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(497),
    [sym_VAR_KEYWORD] = ACTIONS(497),
    [sym_TRY_KEYWORD] = ACTIONS(497),
    [sym_RAISE_KEYWORD] = ACTIONS(497),
    [sym_ENDTRY_KEYWORD] = ACTIONS(497),
    [sym_ASYNC_KEYWORD] = ACTIONS(497),
    [sym_AWAIT_KEYWORD] = ACTIONS(497),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(497),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(497),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(497),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(495),
    [aux_sym_preprocessor_token1] = ACTIONS(495),
    [aux_sym_preprocessor_token2] = ACTIONS(495),
    [aux_sym_preprocessor_token3] = ACTIONS(495),
    [aux_sym_preprocessor_token4] = ACTIONS(495),
    [aux_sym_preprocessor_token5] = ACTIONS(495),
    [aux_sym_preprocessor_token6] = ACTIONS(495),
    [aux_sym_preprocessor_token7] = ACTIONS(495),
    [aux_sym_preprocessor_token8] = ACTIONS(495),
    [aux_sym_preprocessor_token9] = ACTIONS(495),
    [aux_sym_preprocessor_token10] = ACTIONS(495),
    [aux_sym_preprocessor_token11] = ACTIONS(495),
    [aux_sym_preprocessor_token12] = ACTIONS(495),
    [aux_sym_preprocessor_token13] = ACTIONS(495),
    [aux_sym_preprocessor_token14] = ACTIONS(495),
    [aux_sym_preprocessor_token15] = ACTIONS(495),
    [aux_sym_preprocessor_token16] = ACTIONS(495),
    [aux_sym_preprocessor_token17] = ACTIONS(497),
    [aux_sym_preprocessor_token18] = ACTIONS(497),
    [aux_sym_preprocessor_token19] = ACTIONS(497),
    [aux_sym_preprocessor_token20] = ACTIONS(497),
    [aux_sym_preprocessor_token21] = ACTIONS(495),
    [aux_sym_preprocessor_token22] = ACTIONS(495),
    [aux_sym_preprocessor_token23] = ACTIONS(495),
    [aux_sym_preprocessor_token24] = ACTIONS(495),
    [aux_sym_preprocessor_token25] = ACTIONS(497),
    [aux_sym_preprocessor_token26] = ACTIONS(497),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(79)] = {
    [sym_line_comment] = STATE(79),
    [ts_builtin_sym_end] = ACTIONS(501),
    [sym_identifier] = ACTIONS(503),
    [anon_sym_SEMI] = ACTIONS(505),
    [anon_sym_EQ] = ACTIONS(445),
    [aux_sym_execute_statement_token1] = ACTIONS(503),
    [anon_sym_TILDE] = ACTIONS(501),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_LT_GT] = ACTIONS(445),
    [anon_sym_GT] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(447),
    [anon_sym_GT_EQ] = ACTIONS(445),
    [anon_sym_LT_EQ] = ACTIONS(445),
    [anon_sym_STAR] = ACTIONS(437),
    [anon_sym_SLASH] = ACTIONS(439),
    [anon_sym_PERCENT] = ACTIONS(437),
    [sym_IF_KEYWORD] = ACTIONS(503),
    [sym_ENDIF_KEYWORD] = ACTIONS(503),
    [sym_FOR_KEYWORD] = ACTIONS(503),
    [sym_WHILE_KEYWORD] = ACTIONS(503),
    [sym_ENDDO_KEYWORD] = ACTIONS(503),
    [sym_GOTO_KEYWORD] = ACTIONS(503),
    [sym_RETURN_KEYWORD] = ACTIONS(503),
    [sym_BREAK_KEYWORD] = ACTIONS(503),
    [sym_CONTINUE_KEYWORD] = ACTIONS(503),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(503),
    [sym_FUNCTION_KEYWORD] = ACTIONS(503),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(503),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(503),
    [sym_VAR_KEYWORD] = ACTIONS(503),
    [sym_TRY_KEYWORD] = ACTIONS(503),
    [sym_RAISE_KEYWORD] = ACTIONS(503),
    [sym_ENDTRY_KEYWORD] = ACTIONS(503),
    [sym_ASYNC_KEYWORD] = ACTIONS(503),
    [sym_AWAIT_KEYWORD] = ACTIONS(503),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(503),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(503),
    [sym_AND_KEYWORD] = ACTIONS(449),
    [sym_OR_KEYWORD] = ACTIONS(473),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(503),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(501),
    [aux_sym_preprocessor_token1] = ACTIONS(501),
    [aux_sym_preprocessor_token2] = ACTIONS(501),
    [aux_sym_preprocessor_token3] = ACTIONS(501),
    [aux_sym_preprocessor_token4] = ACTIONS(501),
    [aux_sym_preprocessor_token5] = ACTIONS(501),
    [aux_sym_preprocessor_token6] = ACTIONS(501),
    [aux_sym_preprocessor_token7] = ACTIONS(501),
    [aux_sym_preprocessor_token8] = ACTIONS(501),
    [aux_sym_preprocessor_token9] = ACTIONS(501),
    [aux_sym_preprocessor_token10] = ACTIONS(501),
    [aux_sym_preprocessor_token11] = ACTIONS(501),
    [aux_sym_preprocessor_token12] = ACTIONS(501),
    [aux_sym_preprocessor_token13] = ACTIONS(501),
    [aux_sym_preprocessor_token14] = ACTIONS(501),
    [aux_sym_preprocessor_token15] = ACTIONS(501),
    [aux_sym_preprocessor_token16] = ACTIONS(501),
    [aux_sym_preprocessor_token17] = ACTIONS(503),
    [aux_sym_preprocessor_token18] = ACTIONS(503),
    [aux_sym_preprocessor_token19] = ACTIONS(503),
    [aux_sym_preprocessor_token20] = ACTIONS(503),
    [aux_sym_preprocessor_token21] = ACTIONS(501),
    [aux_sym_preprocessor_token22] = ACTIONS(501),
    [aux_sym_preprocessor_token23] = ACTIONS(501),
    [aux_sym_preprocessor_token24] = ACTIONS(501),
    [aux_sym_preprocessor_token25] = ACTIONS(503),
    [aux_sym_preprocessor_token26] = ACTIONS(503),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(80)] = {
    [sym_line_comment] = STATE(80),
    [sym_identifier] = ACTIONS(375),
    [anon_sym_COMMA] = ACTIONS(373),
    [anon_sym_SEMI] = ACTIONS(373),
    [anon_sym_EQ] = ACTIONS(373),
    [aux_sym_execute_statement_token1] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(373),
    [anon_sym_DASH] = ACTIONS(373),
    [anon_sym_PLUS] = ACTIONS(373),
    [anon_sym_LT_GT] = ACTIONS(373),
    [anon_sym_GT] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(373),
    [anon_sym_LT_EQ] = ACTIONS(373),
    [anon_sym_STAR] = ACTIONS(373),
    [anon_sym_SLASH] = ACTIONS(375),
    [anon_sym_PERCENT] = ACTIONS(373),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [sym_IF_KEYWORD] = ACTIONS(375),
    [sym_ELSIF_KEYWORD] = ACTIONS(375),
    [sym_ELSE_KEYWORD] = ACTIONS(375),
    [sym_ENDIF_KEYWORD] = ACTIONS(375),
    [sym_FOR_KEYWORD] = ACTIONS(375),
    [sym_WHILE_KEYWORD] = ACTIONS(375),
    [sym_GOTO_KEYWORD] = ACTIONS(375),
    [sym_RETURN_KEYWORD] = ACTIONS(375),
    [sym_BREAK_KEYWORD] = ACTIONS(375),
    [sym_CONTINUE_KEYWORD] = ACTIONS(375),
    [sym_VAR_KEYWORD] = ACTIONS(375),
    [sym_TRY_KEYWORD] = ACTIONS(375),
    [sym_EXCEPT_KEYWORD] = ACTIONS(375),
    [sym_RAISE_KEYWORD] = ACTIONS(375),
    [sym_AWAIT_KEYWORD] = ACTIONS(375),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(375),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(375),
    [sym_AND_KEYWORD] = ACTIONS(375),
    [sym_OR_KEYWORD] = ACTIONS(375),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(375),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(373),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(373),
    [aux_sym_preprocessor_token1] = ACTIONS(373),
    [aux_sym_preprocessor_token2] = ACTIONS(373),
    [aux_sym_preprocessor_token3] = ACTIONS(373),
    [aux_sym_preprocessor_token4] = ACTIONS(373),
    [aux_sym_preprocessor_token5] = ACTIONS(373),
    [aux_sym_preprocessor_token6] = ACTIONS(373),
    [aux_sym_preprocessor_token7] = ACTIONS(373),
    [aux_sym_preprocessor_token8] = ACTIONS(373),
    [aux_sym_preprocessor_token9] = ACTIONS(373),
    [aux_sym_preprocessor_token10] = ACTIONS(373),
    [aux_sym_preprocessor_token11] = ACTIONS(373),
    [aux_sym_preprocessor_token12] = ACTIONS(373),
    [aux_sym_preprocessor_token13] = ACTIONS(373),
    [aux_sym_preprocessor_token14] = ACTIONS(373),
    [aux_sym_preprocessor_token15] = ACTIONS(373),
    [aux_sym_preprocessor_token16] = ACTIONS(373),
    [aux_sym_preprocessor_token17] = ACTIONS(375),
    [aux_sym_preprocessor_token18] = ACTIONS(375),
    [aux_sym_preprocessor_token19] = ACTIONS(375),
    [aux_sym_preprocessor_token20] = ACTIONS(375),
    [aux_sym_preprocessor_token21] = ACTIONS(373),
    [aux_sym_preprocessor_token22] = ACTIONS(373),
    [aux_sym_preprocessor_token23] = ACTIONS(373),
    [aux_sym_preprocessor_token24] = ACTIONS(373),
    [aux_sym_preprocessor_token25] = ACTIONS(375),
    [aux_sym_preprocessor_token26] = ACTIONS(375),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(81)] = {
    [sym_line_comment] = STATE(81),
    [sym_identifier] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_SEMI] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(369),
    [aux_sym_execute_statement_token1] = ACTIONS(371),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(369),
    [anon_sym_LT_GT] = ACTIONS(369),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [sym_IF_KEYWORD] = ACTIONS(371),
    [sym_ELSIF_KEYWORD] = ACTIONS(371),
    [sym_ELSE_KEYWORD] = ACTIONS(371),
    [sym_ENDIF_KEYWORD] = ACTIONS(371),
    [sym_FOR_KEYWORD] = ACTIONS(371),
    [sym_WHILE_KEYWORD] = ACTIONS(371),
    [sym_GOTO_KEYWORD] = ACTIONS(371),
    [sym_RETURN_KEYWORD] = ACTIONS(371),
    [sym_BREAK_KEYWORD] = ACTIONS(371),
    [sym_CONTINUE_KEYWORD] = ACTIONS(371),
    [sym_VAR_KEYWORD] = ACTIONS(371),
    [sym_TRY_KEYWORD] = ACTIONS(371),
    [sym_EXCEPT_KEYWORD] = ACTIONS(371),
    [sym_RAISE_KEYWORD] = ACTIONS(371),
    [sym_AWAIT_KEYWORD] = ACTIONS(371),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(371),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(371),
    [sym_AND_KEYWORD] = ACTIONS(371),
    [sym_OR_KEYWORD] = ACTIONS(371),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(371),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(369),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(369),
    [aux_sym_preprocessor_token1] = ACTIONS(369),
    [aux_sym_preprocessor_token2] = ACTIONS(369),
    [aux_sym_preprocessor_token3] = ACTIONS(369),
    [aux_sym_preprocessor_token4] = ACTIONS(369),
    [aux_sym_preprocessor_token5] = ACTIONS(369),
    [aux_sym_preprocessor_token6] = ACTIONS(369),
    [aux_sym_preprocessor_token7] = ACTIONS(369),
    [aux_sym_preprocessor_token8] = ACTIONS(369),
    [aux_sym_preprocessor_token9] = ACTIONS(369),
    [aux_sym_preprocessor_token10] = ACTIONS(369),
    [aux_sym_preprocessor_token11] = ACTIONS(369),
    [aux_sym_preprocessor_token12] = ACTIONS(369),
    [aux_sym_preprocessor_token13] = ACTIONS(369),
    [aux_sym_preprocessor_token14] = ACTIONS(369),
    [aux_sym_preprocessor_token15] = ACTIONS(369),
    [aux_sym_preprocessor_token16] = ACTIONS(369),
    [aux_sym_preprocessor_token17] = ACTIONS(371),
    [aux_sym_preprocessor_token18] = ACTIONS(371),
    [aux_sym_preprocessor_token19] = ACTIONS(371),
    [aux_sym_preprocessor_token20] = ACTIONS(371),
    [aux_sym_preprocessor_token21] = ACTIONS(369),
    [aux_sym_preprocessor_token22] = ACTIONS(369),
    [aux_sym_preprocessor_token23] = ACTIONS(369),
    [aux_sym_preprocessor_token24] = ACTIONS(369),
    [aux_sym_preprocessor_token25] = ACTIONS(371),
    [aux_sym_preprocessor_token26] = ACTIONS(371),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(82)] = {
    [sym_line_comment] = STATE(82),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_ELSIF_KEYWORD] = ACTIONS(301),
    [sym_ELSE_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_EXCEPT_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(83)] = {
    [sym_line_comment] = STATE(83),
    [sym_identifier] = ACTIONS(403),
    [anon_sym_COMMA] = ACTIONS(401),
    [anon_sym_SEMI] = ACTIONS(401),
    [anon_sym_EQ] = ACTIONS(401),
    [aux_sym_execute_statement_token1] = ACTIONS(403),
    [anon_sym_TILDE] = ACTIONS(401),
    [anon_sym_DASH] = ACTIONS(401),
    [anon_sym_PLUS] = ACTIONS(401),
    [anon_sym_LT_GT] = ACTIONS(401),
    [anon_sym_GT] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [anon_sym_GT_EQ] = ACTIONS(401),
    [anon_sym_LT_EQ] = ACTIONS(401),
    [anon_sym_STAR] = ACTIONS(401),
    [anon_sym_SLASH] = ACTIONS(403),
    [anon_sym_PERCENT] = ACTIONS(401),
    [anon_sym_DOT] = ACTIONS(401),
    [anon_sym_LBRACK] = ACTIONS(401),
    [sym_IF_KEYWORD] = ACTIONS(403),
    [sym_ELSIF_KEYWORD] = ACTIONS(403),
    [sym_ELSE_KEYWORD] = ACTIONS(403),
    [sym_ENDIF_KEYWORD] = ACTIONS(403),
    [sym_FOR_KEYWORD] = ACTIONS(403),
    [sym_WHILE_KEYWORD] = ACTIONS(403),
    [sym_GOTO_KEYWORD] = ACTIONS(403),
    [sym_RETURN_KEYWORD] = ACTIONS(403),
    [sym_BREAK_KEYWORD] = ACTIONS(403),
    [sym_CONTINUE_KEYWORD] = ACTIONS(403),
    [sym_VAR_KEYWORD] = ACTIONS(403),
    [sym_TRY_KEYWORD] = ACTIONS(403),
    [sym_EXCEPT_KEYWORD] = ACTIONS(403),
    [sym_RAISE_KEYWORD] = ACTIONS(403),
    [sym_AWAIT_KEYWORD] = ACTIONS(403),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(403),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(403),
    [sym_AND_KEYWORD] = ACTIONS(403),
    [sym_OR_KEYWORD] = ACTIONS(403),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(403),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(401),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(401),
    [aux_sym_preprocessor_token1] = ACTIONS(401),
    [aux_sym_preprocessor_token2] = ACTIONS(401),
    [aux_sym_preprocessor_token3] = ACTIONS(401),
    [aux_sym_preprocessor_token4] = ACTIONS(401),
    [aux_sym_preprocessor_token5] = ACTIONS(401),
    [aux_sym_preprocessor_token6] = ACTIONS(401),
    [aux_sym_preprocessor_token7] = ACTIONS(401),
    [aux_sym_preprocessor_token8] = ACTIONS(401),
    [aux_sym_preprocessor_token9] = ACTIONS(401),
    [aux_sym_preprocessor_token10] = ACTIONS(401),
    [aux_sym_preprocessor_token11] = ACTIONS(401),
    [aux_sym_preprocessor_token12] = ACTIONS(401),
    [aux_sym_preprocessor_token13] = ACTIONS(401),
    [aux_sym_preprocessor_token14] = ACTIONS(401),
    [aux_sym_preprocessor_token15] = ACTIONS(401),
    [aux_sym_preprocessor_token16] = ACTIONS(401),
    [aux_sym_preprocessor_token17] = ACTIONS(403),
    [aux_sym_preprocessor_token18] = ACTIONS(403),
    [aux_sym_preprocessor_token19] = ACTIONS(403),
    [aux_sym_preprocessor_token20] = ACTIONS(403),
    [aux_sym_preprocessor_token21] = ACTIONS(401),
    [aux_sym_preprocessor_token22] = ACTIONS(401),
    [aux_sym_preprocessor_token23] = ACTIONS(401),
    [aux_sym_preprocessor_token24] = ACTIONS(401),
    [aux_sym_preprocessor_token25] = ACTIONS(403),
    [aux_sym_preprocessor_token26] = ACTIONS(403),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(84)] = {
    [sym_arguments] = STATE(101),
    [sym_line_comment] = STATE(84),
    [sym_identifier] = ACTIONS(399),
    [anon_sym_COMMA] = ACTIONS(397),
    [anon_sym_SEMI] = ACTIONS(397),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_EQ] = ACTIONS(397),
    [aux_sym_execute_statement_token1] = ACTIONS(399),
    [anon_sym_TILDE] = ACTIONS(397),
    [anon_sym_DASH] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(397),
    [anon_sym_LT_GT] = ACTIONS(397),
    [anon_sym_GT] = ACTIONS(399),
    [anon_sym_LT] = ACTIONS(399),
    [anon_sym_GT_EQ] = ACTIONS(397),
    [anon_sym_LT_EQ] = ACTIONS(397),
    [anon_sym_STAR] = ACTIONS(397),
    [anon_sym_SLASH] = ACTIONS(399),
    [anon_sym_PERCENT] = ACTIONS(397),
    [sym_IF_KEYWORD] = ACTIONS(399),
    [sym_ELSIF_KEYWORD] = ACTIONS(399),
    [sym_ELSE_KEYWORD] = ACTIONS(399),
    [sym_ENDIF_KEYWORD] = ACTIONS(399),
    [sym_FOR_KEYWORD] = ACTIONS(399),
    [sym_WHILE_KEYWORD] = ACTIONS(399),
    [sym_GOTO_KEYWORD] = ACTIONS(399),
    [sym_RETURN_KEYWORD] = ACTIONS(399),
    [sym_BREAK_KEYWORD] = ACTIONS(399),
    [sym_CONTINUE_KEYWORD] = ACTIONS(399),
    [sym_VAR_KEYWORD] = ACTIONS(399),
    [sym_TRY_KEYWORD] = ACTIONS(399),
    [sym_EXCEPT_KEYWORD] = ACTIONS(399),
    [sym_RAISE_KEYWORD] = ACTIONS(399),
    [sym_AWAIT_KEYWORD] = ACTIONS(399),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(399),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(399),
    [sym_AND_KEYWORD] = ACTIONS(399),
    [sym_OR_KEYWORD] = ACTIONS(399),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(399),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(397),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(397),
    [aux_sym_preprocessor_token1] = ACTIONS(397),
    [aux_sym_preprocessor_token2] = ACTIONS(397),
    [aux_sym_preprocessor_token3] = ACTIONS(397),
    [aux_sym_preprocessor_token4] = ACTIONS(397),
    [aux_sym_preprocessor_token5] = ACTIONS(397),
    [aux_sym_preprocessor_token6] = ACTIONS(397),
    [aux_sym_preprocessor_token7] = ACTIONS(397),
    [aux_sym_preprocessor_token8] = ACTIONS(397),
    [aux_sym_preprocessor_token9] = ACTIONS(397),
    [aux_sym_preprocessor_token10] = ACTIONS(397),
    [aux_sym_preprocessor_token11] = ACTIONS(397),
    [aux_sym_preprocessor_token12] = ACTIONS(397),
    [aux_sym_preprocessor_token13] = ACTIONS(397),
    [aux_sym_preprocessor_token14] = ACTIONS(397),
    [aux_sym_preprocessor_token15] = ACTIONS(397),
    [aux_sym_preprocessor_token16] = ACTIONS(397),
    [aux_sym_preprocessor_token17] = ACTIONS(399),
    [aux_sym_preprocessor_token18] = ACTIONS(399),
    [aux_sym_preprocessor_token19] = ACTIONS(399),
    [aux_sym_preprocessor_token20] = ACTIONS(399),
    [aux_sym_preprocessor_token21] = ACTIONS(397),
    [aux_sym_preprocessor_token22] = ACTIONS(397),
    [aux_sym_preprocessor_token23] = ACTIONS(397),
    [aux_sym_preprocessor_token24] = ACTIONS(397),
    [aux_sym_preprocessor_token25] = ACTIONS(399),
    [aux_sym_preprocessor_token26] = ACTIONS(399),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(85)] = {
    [sym_line_comment] = STATE(85),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_COMMA] = ACTIONS(377),
    [anon_sym_SEMI] = ACTIONS(377),
    [anon_sym_EQ] = ACTIONS(377),
    [aux_sym_execute_statement_token1] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_LT_GT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(377),
    [anon_sym_LT_EQ] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_SLASH] = ACTIONS(379),
    [anon_sym_PERCENT] = ACTIONS(377),
    [anon_sym_DOT] = ACTIONS(377),
    [anon_sym_LBRACK] = ACTIONS(377),
    [sym_IF_KEYWORD] = ACTIONS(379),
    [sym_ELSIF_KEYWORD] = ACTIONS(379),
    [sym_ELSE_KEYWORD] = ACTIONS(379),
    [sym_ENDIF_KEYWORD] = ACTIONS(379),
    [sym_FOR_KEYWORD] = ACTIONS(379),
    [sym_WHILE_KEYWORD] = ACTIONS(379),
    [sym_GOTO_KEYWORD] = ACTIONS(379),
    [sym_RETURN_KEYWORD] = ACTIONS(379),
    [sym_BREAK_KEYWORD] = ACTIONS(379),
    [sym_CONTINUE_KEYWORD] = ACTIONS(379),
    [sym_VAR_KEYWORD] = ACTIONS(379),
    [sym_TRY_KEYWORD] = ACTIONS(379),
    [sym_EXCEPT_KEYWORD] = ACTIONS(379),
    [sym_RAISE_KEYWORD] = ACTIONS(379),
    [sym_AWAIT_KEYWORD] = ACTIONS(379),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(379),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(379),
    [sym_AND_KEYWORD] = ACTIONS(379),
    [sym_OR_KEYWORD] = ACTIONS(379),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(379),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(377),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(377),
    [aux_sym_preprocessor_token1] = ACTIONS(377),
    [aux_sym_preprocessor_token2] = ACTIONS(377),
    [aux_sym_preprocessor_token3] = ACTIONS(377),
    [aux_sym_preprocessor_token4] = ACTIONS(377),
    [aux_sym_preprocessor_token5] = ACTIONS(377),
    [aux_sym_preprocessor_token6] = ACTIONS(377),
    [aux_sym_preprocessor_token7] = ACTIONS(377),
    [aux_sym_preprocessor_token8] = ACTIONS(377),
    [aux_sym_preprocessor_token9] = ACTIONS(377),
    [aux_sym_preprocessor_token10] = ACTIONS(377),
    [aux_sym_preprocessor_token11] = ACTIONS(377),
    [aux_sym_preprocessor_token12] = ACTIONS(377),
    [aux_sym_preprocessor_token13] = ACTIONS(377),
    [aux_sym_preprocessor_token14] = ACTIONS(377),
    [aux_sym_preprocessor_token15] = ACTIONS(377),
    [aux_sym_preprocessor_token16] = ACTIONS(377),
    [aux_sym_preprocessor_token17] = ACTIONS(379),
    [aux_sym_preprocessor_token18] = ACTIONS(379),
    [aux_sym_preprocessor_token19] = ACTIONS(379),
    [aux_sym_preprocessor_token20] = ACTIONS(379),
    [aux_sym_preprocessor_token21] = ACTIONS(377),
    [aux_sym_preprocessor_token22] = ACTIONS(377),
    [aux_sym_preprocessor_token23] = ACTIONS(377),
    [aux_sym_preprocessor_token24] = ACTIONS(377),
    [aux_sym_preprocessor_token25] = ACTIONS(379),
    [aux_sym_preprocessor_token26] = ACTIONS(379),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(86)] = {
    [sym_line_comment] = STATE(86),
    [sym_identifier] = ACTIONS(395),
    [anon_sym_COMMA] = ACTIONS(393),
    [anon_sym_SEMI] = ACTIONS(393),
    [anon_sym_EQ] = ACTIONS(393),
    [aux_sym_execute_statement_token1] = ACTIONS(395),
    [anon_sym_TILDE] = ACTIONS(393),
    [anon_sym_DASH] = ACTIONS(393),
    [anon_sym_PLUS] = ACTIONS(393),
    [anon_sym_LT_GT] = ACTIONS(393),
    [anon_sym_GT] = ACTIONS(395),
    [anon_sym_LT] = ACTIONS(395),
    [anon_sym_GT_EQ] = ACTIONS(393),
    [anon_sym_LT_EQ] = ACTIONS(393),
    [anon_sym_STAR] = ACTIONS(393),
    [anon_sym_SLASH] = ACTIONS(395),
    [anon_sym_PERCENT] = ACTIONS(393),
    [anon_sym_DOT] = ACTIONS(393),
    [anon_sym_LBRACK] = ACTIONS(393),
    [sym_IF_KEYWORD] = ACTIONS(395),
    [sym_ELSIF_KEYWORD] = ACTIONS(395),
    [sym_ELSE_KEYWORD] = ACTIONS(395),
    [sym_ENDIF_KEYWORD] = ACTIONS(395),
    [sym_FOR_KEYWORD] = ACTIONS(395),
    [sym_WHILE_KEYWORD] = ACTIONS(395),
    [sym_GOTO_KEYWORD] = ACTIONS(395),
    [sym_RETURN_KEYWORD] = ACTIONS(395),
    [sym_BREAK_KEYWORD] = ACTIONS(395),
    [sym_CONTINUE_KEYWORD] = ACTIONS(395),
    [sym_VAR_KEYWORD] = ACTIONS(395),
    [sym_TRY_KEYWORD] = ACTIONS(395),
    [sym_EXCEPT_KEYWORD] = ACTIONS(395),
    [sym_RAISE_KEYWORD] = ACTIONS(395),
    [sym_AWAIT_KEYWORD] = ACTIONS(395),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(395),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(395),
    [sym_AND_KEYWORD] = ACTIONS(395),
    [sym_OR_KEYWORD] = ACTIONS(395),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(395),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(393),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(393),
    [aux_sym_preprocessor_token1] = ACTIONS(393),
    [aux_sym_preprocessor_token2] = ACTIONS(393),
    [aux_sym_preprocessor_token3] = ACTIONS(393),
    [aux_sym_preprocessor_token4] = ACTIONS(393),
    [aux_sym_preprocessor_token5] = ACTIONS(393),
    [aux_sym_preprocessor_token6] = ACTIONS(393),
    [aux_sym_preprocessor_token7] = ACTIONS(393),
    [aux_sym_preprocessor_token8] = ACTIONS(393),
    [aux_sym_preprocessor_token9] = ACTIONS(393),
    [aux_sym_preprocessor_token10] = ACTIONS(393),
    [aux_sym_preprocessor_token11] = ACTIONS(393),
    [aux_sym_preprocessor_token12] = ACTIONS(393),
    [aux_sym_preprocessor_token13] = ACTIONS(393),
    [aux_sym_preprocessor_token14] = ACTIONS(393),
    [aux_sym_preprocessor_token15] = ACTIONS(393),
    [aux_sym_preprocessor_token16] = ACTIONS(393),
    [aux_sym_preprocessor_token17] = ACTIONS(395),
    [aux_sym_preprocessor_token18] = ACTIONS(395),
    [aux_sym_preprocessor_token19] = ACTIONS(395),
    [aux_sym_preprocessor_token20] = ACTIONS(395),
    [aux_sym_preprocessor_token21] = ACTIONS(393),
    [aux_sym_preprocessor_token22] = ACTIONS(393),
    [aux_sym_preprocessor_token23] = ACTIONS(393),
    [aux_sym_preprocessor_token24] = ACTIONS(393),
    [aux_sym_preprocessor_token25] = ACTIONS(395),
    [aux_sym_preprocessor_token26] = ACTIONS(395),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(87)] = {
    [sym_line_comment] = STATE(87),
    [sym_identifier] = ACTIONS(391),
    [anon_sym_COMMA] = ACTIONS(389),
    [anon_sym_SEMI] = ACTIONS(389),
    [anon_sym_EQ] = ACTIONS(389),
    [aux_sym_execute_statement_token1] = ACTIONS(391),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(389),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_LT_GT] = ACTIONS(389),
    [anon_sym_GT] = ACTIONS(391),
    [anon_sym_LT] = ACTIONS(391),
    [anon_sym_GT_EQ] = ACTIONS(389),
    [anon_sym_LT_EQ] = ACTIONS(389),
    [anon_sym_STAR] = ACTIONS(389),
    [anon_sym_SLASH] = ACTIONS(391),
    [anon_sym_PERCENT] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(389),
    [anon_sym_LBRACK] = ACTIONS(389),
    [sym_IF_KEYWORD] = ACTIONS(391),
    [sym_ELSIF_KEYWORD] = ACTIONS(391),
    [sym_ELSE_KEYWORD] = ACTIONS(391),
    [sym_ENDIF_KEYWORD] = ACTIONS(391),
    [sym_FOR_KEYWORD] = ACTIONS(391),
    [sym_WHILE_KEYWORD] = ACTIONS(391),
    [sym_GOTO_KEYWORD] = ACTIONS(391),
    [sym_RETURN_KEYWORD] = ACTIONS(391),
    [sym_BREAK_KEYWORD] = ACTIONS(391),
    [sym_CONTINUE_KEYWORD] = ACTIONS(391),
    [sym_VAR_KEYWORD] = ACTIONS(391),
    [sym_TRY_KEYWORD] = ACTIONS(391),
    [sym_EXCEPT_KEYWORD] = ACTIONS(391),
    [sym_RAISE_KEYWORD] = ACTIONS(391),
    [sym_AWAIT_KEYWORD] = ACTIONS(391),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(391),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(391),
    [sym_AND_KEYWORD] = ACTIONS(391),
    [sym_OR_KEYWORD] = ACTIONS(391),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(391),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(389),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(389),
    [aux_sym_preprocessor_token1] = ACTIONS(389),
    [aux_sym_preprocessor_token2] = ACTIONS(389),
    [aux_sym_preprocessor_token3] = ACTIONS(389),
    [aux_sym_preprocessor_token4] = ACTIONS(389),
    [aux_sym_preprocessor_token5] = ACTIONS(389),
    [aux_sym_preprocessor_token6] = ACTIONS(389),
    [aux_sym_preprocessor_token7] = ACTIONS(389),
    [aux_sym_preprocessor_token8] = ACTIONS(389),
    [aux_sym_preprocessor_token9] = ACTIONS(389),
    [aux_sym_preprocessor_token10] = ACTIONS(389),
    [aux_sym_preprocessor_token11] = ACTIONS(389),
    [aux_sym_preprocessor_token12] = ACTIONS(389),
    [aux_sym_preprocessor_token13] = ACTIONS(389),
    [aux_sym_preprocessor_token14] = ACTIONS(389),
    [aux_sym_preprocessor_token15] = ACTIONS(389),
    [aux_sym_preprocessor_token16] = ACTIONS(389),
    [aux_sym_preprocessor_token17] = ACTIONS(391),
    [aux_sym_preprocessor_token18] = ACTIONS(391),
    [aux_sym_preprocessor_token19] = ACTIONS(391),
    [aux_sym_preprocessor_token20] = ACTIONS(391),
    [aux_sym_preprocessor_token21] = ACTIONS(389),
    [aux_sym_preprocessor_token22] = ACTIONS(389),
    [aux_sym_preprocessor_token23] = ACTIONS(389),
    [aux_sym_preprocessor_token24] = ACTIONS(389),
    [aux_sym_preprocessor_token25] = ACTIONS(391),
    [aux_sym_preprocessor_token26] = ACTIONS(391),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(88)] = {
    [sym_line_comment] = STATE(88),
    [sym_identifier] = ACTIONS(387),
    [anon_sym_COMMA] = ACTIONS(385),
    [anon_sym_SEMI] = ACTIONS(385),
    [anon_sym_EQ] = ACTIONS(385),
    [aux_sym_execute_statement_token1] = ACTIONS(387),
    [anon_sym_TILDE] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(385),
    [anon_sym_PLUS] = ACTIONS(385),
    [anon_sym_LT_GT] = ACTIONS(385),
    [anon_sym_GT] = ACTIONS(387),
    [anon_sym_LT] = ACTIONS(387),
    [anon_sym_GT_EQ] = ACTIONS(385),
    [anon_sym_LT_EQ] = ACTIONS(385),
    [anon_sym_STAR] = ACTIONS(385),
    [anon_sym_SLASH] = ACTIONS(387),
    [anon_sym_PERCENT] = ACTIONS(385),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_LBRACK] = ACTIONS(385),
    [sym_IF_KEYWORD] = ACTIONS(387),
    [sym_ELSIF_KEYWORD] = ACTIONS(387),
    [sym_ELSE_KEYWORD] = ACTIONS(387),
    [sym_ENDIF_KEYWORD] = ACTIONS(387),
    [sym_FOR_KEYWORD] = ACTIONS(387),
    [sym_WHILE_KEYWORD] = ACTIONS(387),
    [sym_GOTO_KEYWORD] = ACTIONS(387),
    [sym_RETURN_KEYWORD] = ACTIONS(387),
    [sym_BREAK_KEYWORD] = ACTIONS(387),
    [sym_CONTINUE_KEYWORD] = ACTIONS(387),
    [sym_VAR_KEYWORD] = ACTIONS(387),
    [sym_TRY_KEYWORD] = ACTIONS(387),
    [sym_EXCEPT_KEYWORD] = ACTIONS(387),
    [sym_RAISE_KEYWORD] = ACTIONS(387),
    [sym_AWAIT_KEYWORD] = ACTIONS(387),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(387),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(387),
    [sym_AND_KEYWORD] = ACTIONS(387),
    [sym_OR_KEYWORD] = ACTIONS(387),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(387),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(385),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(385),
    [aux_sym_preprocessor_token1] = ACTIONS(385),
    [aux_sym_preprocessor_token2] = ACTIONS(385),
    [aux_sym_preprocessor_token3] = ACTIONS(385),
    [aux_sym_preprocessor_token4] = ACTIONS(385),
    [aux_sym_preprocessor_token5] = ACTIONS(385),
    [aux_sym_preprocessor_token6] = ACTIONS(385),
    [aux_sym_preprocessor_token7] = ACTIONS(385),
    [aux_sym_preprocessor_token8] = ACTIONS(385),
    [aux_sym_preprocessor_token9] = ACTIONS(385),
    [aux_sym_preprocessor_token10] = ACTIONS(385),
    [aux_sym_preprocessor_token11] = ACTIONS(385),
    [aux_sym_preprocessor_token12] = ACTIONS(385),
    [aux_sym_preprocessor_token13] = ACTIONS(385),
    [aux_sym_preprocessor_token14] = ACTIONS(385),
    [aux_sym_preprocessor_token15] = ACTIONS(385),
    [aux_sym_preprocessor_token16] = ACTIONS(385),
    [aux_sym_preprocessor_token17] = ACTIONS(387),
    [aux_sym_preprocessor_token18] = ACTIONS(387),
    [aux_sym_preprocessor_token19] = ACTIONS(387),
    [aux_sym_preprocessor_token20] = ACTIONS(387),
    [aux_sym_preprocessor_token21] = ACTIONS(385),
    [aux_sym_preprocessor_token22] = ACTIONS(385),
    [aux_sym_preprocessor_token23] = ACTIONS(385),
    [aux_sym_preprocessor_token24] = ACTIONS(385),
    [aux_sym_preprocessor_token25] = ACTIONS(387),
    [aux_sym_preprocessor_token26] = ACTIONS(387),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(89)] = {
    [sym_line_comment] = STATE(89),
    [sym_identifier] = ACTIONS(383),
    [anon_sym_COMMA] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(381),
    [anon_sym_EQ] = ACTIONS(381),
    [aux_sym_execute_statement_token1] = ACTIONS(383),
    [anon_sym_TILDE] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_LT_GT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(383),
    [anon_sym_GT_EQ] = ACTIONS(381),
    [anon_sym_LT_EQ] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_SLASH] = ACTIONS(383),
    [anon_sym_PERCENT] = ACTIONS(381),
    [anon_sym_DOT] = ACTIONS(381),
    [anon_sym_LBRACK] = ACTIONS(381),
    [sym_IF_KEYWORD] = ACTIONS(383),
    [sym_ELSIF_KEYWORD] = ACTIONS(383),
    [sym_ELSE_KEYWORD] = ACTIONS(383),
    [sym_ENDIF_KEYWORD] = ACTIONS(383),
    [sym_FOR_KEYWORD] = ACTIONS(383),
    [sym_WHILE_KEYWORD] = ACTIONS(383),
    [sym_GOTO_KEYWORD] = ACTIONS(383),
    [sym_RETURN_KEYWORD] = ACTIONS(383),
    [sym_BREAK_KEYWORD] = ACTIONS(383),
    [sym_CONTINUE_KEYWORD] = ACTIONS(383),
    [sym_VAR_KEYWORD] = ACTIONS(383),
    [sym_TRY_KEYWORD] = ACTIONS(383),
    [sym_EXCEPT_KEYWORD] = ACTIONS(383),
    [sym_RAISE_KEYWORD] = ACTIONS(383),
    [sym_AWAIT_KEYWORD] = ACTIONS(383),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(383),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(383),
    [sym_AND_KEYWORD] = ACTIONS(383),
    [sym_OR_KEYWORD] = ACTIONS(383),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(383),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(381),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(381),
    [aux_sym_preprocessor_token1] = ACTIONS(381),
    [aux_sym_preprocessor_token2] = ACTIONS(381),
    [aux_sym_preprocessor_token3] = ACTIONS(381),
    [aux_sym_preprocessor_token4] = ACTIONS(381),
    [aux_sym_preprocessor_token5] = ACTIONS(381),
    [aux_sym_preprocessor_token6] = ACTIONS(381),
    [aux_sym_preprocessor_token7] = ACTIONS(381),
    [aux_sym_preprocessor_token8] = ACTIONS(381),
    [aux_sym_preprocessor_token9] = ACTIONS(381),
    [aux_sym_preprocessor_token10] = ACTIONS(381),
    [aux_sym_preprocessor_token11] = ACTIONS(381),
    [aux_sym_preprocessor_token12] = ACTIONS(381),
    [aux_sym_preprocessor_token13] = ACTIONS(381),
    [aux_sym_preprocessor_token14] = ACTIONS(381),
    [aux_sym_preprocessor_token15] = ACTIONS(381),
    [aux_sym_preprocessor_token16] = ACTIONS(381),
    [aux_sym_preprocessor_token17] = ACTIONS(383),
    [aux_sym_preprocessor_token18] = ACTIONS(383),
    [aux_sym_preprocessor_token19] = ACTIONS(383),
    [aux_sym_preprocessor_token20] = ACTIONS(383),
    [aux_sym_preprocessor_token21] = ACTIONS(381),
    [aux_sym_preprocessor_token22] = ACTIONS(381),
    [aux_sym_preprocessor_token23] = ACTIONS(381),
    [aux_sym_preprocessor_token24] = ACTIONS(381),
    [aux_sym_preprocessor_token25] = ACTIONS(383),
    [aux_sym_preprocessor_token26] = ACTIONS(383),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(90)] = {
    [sym_line_comment] = STATE(90),
    [sym_identifier] = ACTIONS(461),
    [anon_sym_COMMA] = ACTIONS(459),
    [anon_sym_SEMI] = ACTIONS(459),
    [anon_sym_EQ] = ACTIONS(459),
    [aux_sym_execute_statement_token1] = ACTIONS(461),
    [anon_sym_TILDE] = ACTIONS(459),
    [anon_sym_DASH] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(459),
    [anon_sym_LT_GT] = ACTIONS(459),
    [anon_sym_GT] = ACTIONS(461),
    [anon_sym_LT] = ACTIONS(461),
    [anon_sym_GT_EQ] = ACTIONS(459),
    [anon_sym_LT_EQ] = ACTIONS(459),
    [anon_sym_STAR] = ACTIONS(459),
    [anon_sym_SLASH] = ACTIONS(461),
    [anon_sym_PERCENT] = ACTIONS(459),
    [sym_IF_KEYWORD] = ACTIONS(461),
    [sym_ELSIF_KEYWORD] = ACTIONS(461),
    [sym_ELSE_KEYWORD] = ACTIONS(461),
    [sym_ENDIF_KEYWORD] = ACTIONS(461),
    [sym_FOR_KEYWORD] = ACTIONS(461),
    [sym_WHILE_KEYWORD] = ACTIONS(461),
    [sym_GOTO_KEYWORD] = ACTIONS(461),
    [sym_RETURN_KEYWORD] = ACTIONS(461),
    [sym_BREAK_KEYWORD] = ACTIONS(461),
    [sym_CONTINUE_KEYWORD] = ACTIONS(461),
    [sym_VAR_KEYWORD] = ACTIONS(461),
    [sym_TRY_KEYWORD] = ACTIONS(461),
    [sym_EXCEPT_KEYWORD] = ACTIONS(461),
    [sym_RAISE_KEYWORD] = ACTIONS(461),
    [sym_AWAIT_KEYWORD] = ACTIONS(461),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(461),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(461),
    [sym_AND_KEYWORD] = ACTIONS(461),
    [sym_OR_KEYWORD] = ACTIONS(461),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(461),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(459),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(459),
    [aux_sym_preprocessor_token1] = ACTIONS(459),
    [aux_sym_preprocessor_token2] = ACTIONS(459),
    [aux_sym_preprocessor_token3] = ACTIONS(459),
    [aux_sym_preprocessor_token4] = ACTIONS(459),
    [aux_sym_preprocessor_token5] = ACTIONS(459),
    [aux_sym_preprocessor_token6] = ACTIONS(459),
    [aux_sym_preprocessor_token7] = ACTIONS(459),
    [aux_sym_preprocessor_token8] = ACTIONS(459),
    [aux_sym_preprocessor_token9] = ACTIONS(459),
    [aux_sym_preprocessor_token10] = ACTIONS(459),
    [aux_sym_preprocessor_token11] = ACTIONS(459),
    [aux_sym_preprocessor_token12] = ACTIONS(459),
    [aux_sym_preprocessor_token13] = ACTIONS(459),
    [aux_sym_preprocessor_token14] = ACTIONS(459),
    [aux_sym_preprocessor_token15] = ACTIONS(459),
    [aux_sym_preprocessor_token16] = ACTIONS(459),
    [aux_sym_preprocessor_token17] = ACTIONS(461),
    [aux_sym_preprocessor_token18] = ACTIONS(461),
    [aux_sym_preprocessor_token19] = ACTIONS(461),
    [aux_sym_preprocessor_token20] = ACTIONS(461),
    [aux_sym_preprocessor_token21] = ACTIONS(459),
    [aux_sym_preprocessor_token22] = ACTIONS(459),
    [aux_sym_preprocessor_token23] = ACTIONS(459),
    [aux_sym_preprocessor_token24] = ACTIONS(459),
    [aux_sym_preprocessor_token25] = ACTIONS(461),
    [aux_sym_preprocessor_token26] = ACTIONS(461),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(91)] = {
    [sym_line_comment] = STATE(91),
    [sym_identifier] = ACTIONS(457),
    [anon_sym_COMMA] = ACTIONS(455),
    [anon_sym_SEMI] = ACTIONS(455),
    [anon_sym_EQ] = ACTIONS(455),
    [aux_sym_execute_statement_token1] = ACTIONS(457),
    [anon_sym_TILDE] = ACTIONS(455),
    [anon_sym_DASH] = ACTIONS(455),
    [anon_sym_PLUS] = ACTIONS(455),
    [anon_sym_LT_GT] = ACTIONS(455),
    [anon_sym_GT] = ACTIONS(457),
    [anon_sym_LT] = ACTIONS(457),
    [anon_sym_GT_EQ] = ACTIONS(455),
    [anon_sym_LT_EQ] = ACTIONS(455),
    [anon_sym_STAR] = ACTIONS(455),
    [anon_sym_SLASH] = ACTIONS(457),
    [anon_sym_PERCENT] = ACTIONS(455),
    [sym_IF_KEYWORD] = ACTIONS(457),
    [sym_ELSIF_KEYWORD] = ACTIONS(457),
    [sym_ELSE_KEYWORD] = ACTIONS(457),
    [sym_ENDIF_KEYWORD] = ACTIONS(457),
    [sym_FOR_KEYWORD] = ACTIONS(457),
    [sym_WHILE_KEYWORD] = ACTIONS(457),
    [sym_GOTO_KEYWORD] = ACTIONS(457),
    [sym_RETURN_KEYWORD] = ACTIONS(457),
    [sym_BREAK_KEYWORD] = ACTIONS(457),
    [sym_CONTINUE_KEYWORD] = ACTIONS(457),
    [sym_VAR_KEYWORD] = ACTIONS(457),
    [sym_TRY_KEYWORD] = ACTIONS(457),
    [sym_EXCEPT_KEYWORD] = ACTIONS(457),
    [sym_RAISE_KEYWORD] = ACTIONS(457),
    [sym_AWAIT_KEYWORD] = ACTIONS(457),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(457),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(457),
    [sym_AND_KEYWORD] = ACTIONS(457),
    [sym_OR_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(455),
    [aux_sym_preprocessor_token1] = ACTIONS(455),
    [aux_sym_preprocessor_token2] = ACTIONS(455),
    [aux_sym_preprocessor_token3] = ACTIONS(455),
    [aux_sym_preprocessor_token4] = ACTIONS(455),
    [aux_sym_preprocessor_token5] = ACTIONS(455),
    [aux_sym_preprocessor_token6] = ACTIONS(455),
    [aux_sym_preprocessor_token7] = ACTIONS(455),
    [aux_sym_preprocessor_token8] = ACTIONS(455),
    [aux_sym_preprocessor_token9] = ACTIONS(455),
    [aux_sym_preprocessor_token10] = ACTIONS(455),
    [aux_sym_preprocessor_token11] = ACTIONS(455),
    [aux_sym_preprocessor_token12] = ACTIONS(455),
    [aux_sym_preprocessor_token13] = ACTIONS(455),
    [aux_sym_preprocessor_token14] = ACTIONS(455),
    [aux_sym_preprocessor_token15] = ACTIONS(455),
    [aux_sym_preprocessor_token16] = ACTIONS(455),
    [aux_sym_preprocessor_token17] = ACTIONS(457),
    [aux_sym_preprocessor_token18] = ACTIONS(457),
    [aux_sym_preprocessor_token19] = ACTIONS(457),
    [aux_sym_preprocessor_token20] = ACTIONS(457),
    [aux_sym_preprocessor_token21] = ACTIONS(455),
    [aux_sym_preprocessor_token22] = ACTIONS(455),
    [aux_sym_preprocessor_token23] = ACTIONS(455),
    [aux_sym_preprocessor_token24] = ACTIONS(455),
    [aux_sym_preprocessor_token25] = ACTIONS(457),
    [aux_sym_preprocessor_token26] = ACTIONS(457),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(92)] = {
    [sym_line_comment] = STATE(92),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_ELSIF_KEYWORD] = ACTIONS(433),
    [sym_ELSE_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_EXCEPT_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(93)] = {
    [sym_line_comment] = STATE(93),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(431),
    [anon_sym_PLUS] = ACTIONS(431),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_ELSIF_KEYWORD] = ACTIONS(433),
    [sym_ELSE_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_EXCEPT_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(94)] = {
    [sym_line_comment] = STATE(94),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_ELSIF_KEYWORD] = ACTIONS(433),
    [sym_ELSE_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_EXCEPT_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(95)] = {
    [sym_line_comment] = STATE(95),
    [sym_identifier] = ACTIONS(411),
    [anon_sym_COMMA] = ACTIONS(409),
    [anon_sym_SEMI] = ACTIONS(409),
    [anon_sym_EQ] = ACTIONS(409),
    [aux_sym_execute_statement_token1] = ACTIONS(411),
    [anon_sym_TILDE] = ACTIONS(409),
    [anon_sym_DASH] = ACTIONS(409),
    [anon_sym_PLUS] = ACTIONS(409),
    [anon_sym_LT_GT] = ACTIONS(409),
    [anon_sym_GT] = ACTIONS(411),
    [anon_sym_LT] = ACTIONS(411),
    [anon_sym_GT_EQ] = ACTIONS(409),
    [anon_sym_LT_EQ] = ACTIONS(409),
    [anon_sym_STAR] = ACTIONS(409),
    [anon_sym_SLASH] = ACTIONS(411),
    [anon_sym_PERCENT] = ACTIONS(409),
    [sym_IF_KEYWORD] = ACTIONS(411),
    [sym_ELSIF_KEYWORD] = ACTIONS(411),
    [sym_ELSE_KEYWORD] = ACTIONS(411),
    [sym_ENDIF_KEYWORD] = ACTIONS(411),
    [sym_FOR_KEYWORD] = ACTIONS(411),
    [sym_WHILE_KEYWORD] = ACTIONS(411),
    [sym_GOTO_KEYWORD] = ACTIONS(411),
    [sym_RETURN_KEYWORD] = ACTIONS(411),
    [sym_BREAK_KEYWORD] = ACTIONS(411),
    [sym_CONTINUE_KEYWORD] = ACTIONS(411),
    [sym_VAR_KEYWORD] = ACTIONS(411),
    [sym_TRY_KEYWORD] = ACTIONS(411),
    [sym_EXCEPT_KEYWORD] = ACTIONS(411),
    [sym_RAISE_KEYWORD] = ACTIONS(411),
    [sym_AWAIT_KEYWORD] = ACTIONS(411),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(411),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(411),
    [sym_AND_KEYWORD] = ACTIONS(411),
    [sym_OR_KEYWORD] = ACTIONS(411),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(411),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(409),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(409),
    [aux_sym_preprocessor_token1] = ACTIONS(409),
    [aux_sym_preprocessor_token2] = ACTIONS(409),
    [aux_sym_preprocessor_token3] = ACTIONS(409),
    [aux_sym_preprocessor_token4] = ACTIONS(409),
    [aux_sym_preprocessor_token5] = ACTIONS(409),
    [aux_sym_preprocessor_token6] = ACTIONS(409),
    [aux_sym_preprocessor_token7] = ACTIONS(409),
    [aux_sym_preprocessor_token8] = ACTIONS(409),
    [aux_sym_preprocessor_token9] = ACTIONS(409),
    [aux_sym_preprocessor_token10] = ACTIONS(409),
    [aux_sym_preprocessor_token11] = ACTIONS(409),
    [aux_sym_preprocessor_token12] = ACTIONS(409),
    [aux_sym_preprocessor_token13] = ACTIONS(409),
    [aux_sym_preprocessor_token14] = ACTIONS(409),
    [aux_sym_preprocessor_token15] = ACTIONS(409),
    [aux_sym_preprocessor_token16] = ACTIONS(409),
    [aux_sym_preprocessor_token17] = ACTIONS(411),
    [aux_sym_preprocessor_token18] = ACTIONS(411),
    [aux_sym_preprocessor_token19] = ACTIONS(411),
    [aux_sym_preprocessor_token20] = ACTIONS(411),
    [aux_sym_preprocessor_token21] = ACTIONS(409),
    [aux_sym_preprocessor_token22] = ACTIONS(409),
    [aux_sym_preprocessor_token23] = ACTIONS(409),
    [aux_sym_preprocessor_token24] = ACTIONS(409),
    [aux_sym_preprocessor_token25] = ACTIONS(411),
    [aux_sym_preprocessor_token26] = ACTIONS(411),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(96)] = {
    [sym_line_comment] = STATE(96),
    [sym_identifier] = ACTIONS(415),
    [anon_sym_COMMA] = ACTIONS(413),
    [anon_sym_SEMI] = ACTIONS(413),
    [anon_sym_EQ] = ACTIONS(413),
    [aux_sym_execute_statement_token1] = ACTIONS(415),
    [anon_sym_TILDE] = ACTIONS(413),
    [anon_sym_DASH] = ACTIONS(413),
    [anon_sym_PLUS] = ACTIONS(413),
    [anon_sym_LT_GT] = ACTIONS(413),
    [anon_sym_GT] = ACTIONS(415),
    [anon_sym_LT] = ACTIONS(415),
    [anon_sym_GT_EQ] = ACTIONS(413),
    [anon_sym_LT_EQ] = ACTIONS(413),
    [anon_sym_STAR] = ACTIONS(413),
    [anon_sym_SLASH] = ACTIONS(415),
    [anon_sym_PERCENT] = ACTIONS(413),
    [sym_IF_KEYWORD] = ACTIONS(415),
    [sym_ELSIF_KEYWORD] = ACTIONS(415),
    [sym_ELSE_KEYWORD] = ACTIONS(415),
    [sym_ENDIF_KEYWORD] = ACTIONS(415),
    [sym_FOR_KEYWORD] = ACTIONS(415),
    [sym_WHILE_KEYWORD] = ACTIONS(415),
    [sym_GOTO_KEYWORD] = ACTIONS(415),
    [sym_RETURN_KEYWORD] = ACTIONS(415),
    [sym_BREAK_KEYWORD] = ACTIONS(415),
    [sym_CONTINUE_KEYWORD] = ACTIONS(415),
    [sym_VAR_KEYWORD] = ACTIONS(415),
    [sym_TRY_KEYWORD] = ACTIONS(415),
    [sym_EXCEPT_KEYWORD] = ACTIONS(415),
    [sym_RAISE_KEYWORD] = ACTIONS(415),
    [sym_AWAIT_KEYWORD] = ACTIONS(415),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(415),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(415),
    [sym_AND_KEYWORD] = ACTIONS(415),
    [sym_OR_KEYWORD] = ACTIONS(415),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(415),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(413),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(413),
    [aux_sym_preprocessor_token1] = ACTIONS(413),
    [aux_sym_preprocessor_token2] = ACTIONS(413),
    [aux_sym_preprocessor_token3] = ACTIONS(413),
    [aux_sym_preprocessor_token4] = ACTIONS(413),
    [aux_sym_preprocessor_token5] = ACTIONS(413),
    [aux_sym_preprocessor_token6] = ACTIONS(413),
    [aux_sym_preprocessor_token7] = ACTIONS(413),
    [aux_sym_preprocessor_token8] = ACTIONS(413),
    [aux_sym_preprocessor_token9] = ACTIONS(413),
    [aux_sym_preprocessor_token10] = ACTIONS(413),
    [aux_sym_preprocessor_token11] = ACTIONS(413),
    [aux_sym_preprocessor_token12] = ACTIONS(413),
    [aux_sym_preprocessor_token13] = ACTIONS(413),
    [aux_sym_preprocessor_token14] = ACTIONS(413),
    [aux_sym_preprocessor_token15] = ACTIONS(413),
    [aux_sym_preprocessor_token16] = ACTIONS(413),
    [aux_sym_preprocessor_token17] = ACTIONS(415),
    [aux_sym_preprocessor_token18] = ACTIONS(415),
    [aux_sym_preprocessor_token19] = ACTIONS(415),
    [aux_sym_preprocessor_token20] = ACTIONS(415),
    [aux_sym_preprocessor_token21] = ACTIONS(413),
    [aux_sym_preprocessor_token22] = ACTIONS(413),
    [aux_sym_preprocessor_token23] = ACTIONS(413),
    [aux_sym_preprocessor_token24] = ACTIONS(413),
    [aux_sym_preprocessor_token25] = ACTIONS(415),
    [aux_sym_preprocessor_token26] = ACTIONS(415),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(97)] = {
    [sym_line_comment] = STATE(97),
    [sym_identifier] = ACTIONS(301),
    [anon_sym_COMMA] = ACTIONS(299),
    [anon_sym_SEMI] = ACTIONS(299),
    [anon_sym_EQ] = ACTIONS(299),
    [aux_sym_execute_statement_token1] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(299),
    [anon_sym_DASH] = ACTIONS(299),
    [anon_sym_PLUS] = ACTIONS(299),
    [anon_sym_LT_GT] = ACTIONS(299),
    [anon_sym_GT] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(301),
    [anon_sym_GT_EQ] = ACTIONS(299),
    [anon_sym_LT_EQ] = ACTIONS(299),
    [anon_sym_STAR] = ACTIONS(299),
    [anon_sym_SLASH] = ACTIONS(301),
    [anon_sym_PERCENT] = ACTIONS(299),
    [sym_IF_KEYWORD] = ACTIONS(301),
    [sym_ELSIF_KEYWORD] = ACTIONS(301),
    [sym_ELSE_KEYWORD] = ACTIONS(301),
    [sym_ENDIF_KEYWORD] = ACTIONS(301),
    [sym_FOR_KEYWORD] = ACTIONS(301),
    [sym_WHILE_KEYWORD] = ACTIONS(301),
    [sym_GOTO_KEYWORD] = ACTIONS(301),
    [sym_RETURN_KEYWORD] = ACTIONS(301),
    [sym_BREAK_KEYWORD] = ACTIONS(301),
    [sym_CONTINUE_KEYWORD] = ACTIONS(301),
    [sym_VAR_KEYWORD] = ACTIONS(301),
    [sym_TRY_KEYWORD] = ACTIONS(301),
    [sym_EXCEPT_KEYWORD] = ACTIONS(301),
    [sym_RAISE_KEYWORD] = ACTIONS(301),
    [sym_AWAIT_KEYWORD] = ACTIONS(301),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(301),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(301),
    [sym_AND_KEYWORD] = ACTIONS(301),
    [sym_OR_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(301),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(299),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(299),
    [aux_sym_preprocessor_token1] = ACTIONS(299),
    [aux_sym_preprocessor_token2] = ACTIONS(299),
    [aux_sym_preprocessor_token3] = ACTIONS(299),
    [aux_sym_preprocessor_token4] = ACTIONS(299),
    [aux_sym_preprocessor_token5] = ACTIONS(299),
    [aux_sym_preprocessor_token6] = ACTIONS(299),
    [aux_sym_preprocessor_token7] = ACTIONS(299),
    [aux_sym_preprocessor_token8] = ACTIONS(299),
    [aux_sym_preprocessor_token9] = ACTIONS(299),
    [aux_sym_preprocessor_token10] = ACTIONS(299),
    [aux_sym_preprocessor_token11] = ACTIONS(299),
    [aux_sym_preprocessor_token12] = ACTIONS(299),
    [aux_sym_preprocessor_token13] = ACTIONS(299),
    [aux_sym_preprocessor_token14] = ACTIONS(299),
    [aux_sym_preprocessor_token15] = ACTIONS(299),
    [aux_sym_preprocessor_token16] = ACTIONS(299),
    [aux_sym_preprocessor_token17] = ACTIONS(301),
    [aux_sym_preprocessor_token18] = ACTIONS(301),
    [aux_sym_preprocessor_token19] = ACTIONS(301),
    [aux_sym_preprocessor_token20] = ACTIONS(301),
    [aux_sym_preprocessor_token21] = ACTIONS(299),
    [aux_sym_preprocessor_token22] = ACTIONS(299),
    [aux_sym_preprocessor_token23] = ACTIONS(299),
    [aux_sym_preprocessor_token24] = ACTIONS(299),
    [aux_sym_preprocessor_token25] = ACTIONS(301),
    [aux_sym_preprocessor_token26] = ACTIONS(301),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(98)] = {
    [sym_line_comment] = STATE(98),
    [sym_identifier] = ACTIONS(419),
    [anon_sym_COMMA] = ACTIONS(417),
    [anon_sym_SEMI] = ACTIONS(417),
    [anon_sym_EQ] = ACTIONS(417),
    [aux_sym_execute_statement_token1] = ACTIONS(419),
    [anon_sym_TILDE] = ACTIONS(417),
    [anon_sym_DASH] = ACTIONS(417),
    [anon_sym_PLUS] = ACTIONS(417),
    [anon_sym_LT_GT] = ACTIONS(417),
    [anon_sym_GT] = ACTIONS(419),
    [anon_sym_LT] = ACTIONS(419),
    [anon_sym_GT_EQ] = ACTIONS(417),
    [anon_sym_LT_EQ] = ACTIONS(417),
    [anon_sym_STAR] = ACTIONS(417),
    [anon_sym_SLASH] = ACTIONS(419),
    [anon_sym_PERCENT] = ACTIONS(417),
    [sym_IF_KEYWORD] = ACTIONS(419),
    [sym_ELSIF_KEYWORD] = ACTIONS(419),
    [sym_ELSE_KEYWORD] = ACTIONS(419),
    [sym_ENDIF_KEYWORD] = ACTIONS(419),
    [sym_FOR_KEYWORD] = ACTIONS(419),
    [sym_WHILE_KEYWORD] = ACTIONS(419),
    [sym_GOTO_KEYWORD] = ACTIONS(419),
    [sym_RETURN_KEYWORD] = ACTIONS(419),
    [sym_BREAK_KEYWORD] = ACTIONS(419),
    [sym_CONTINUE_KEYWORD] = ACTIONS(419),
    [sym_VAR_KEYWORD] = ACTIONS(419),
    [sym_TRY_KEYWORD] = ACTIONS(419),
    [sym_EXCEPT_KEYWORD] = ACTIONS(419),
    [sym_RAISE_KEYWORD] = ACTIONS(419),
    [sym_AWAIT_KEYWORD] = ACTIONS(419),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(419),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(419),
    [sym_AND_KEYWORD] = ACTIONS(419),
    [sym_OR_KEYWORD] = ACTIONS(419),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(419),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(417),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(417),
    [aux_sym_preprocessor_token1] = ACTIONS(417),
    [aux_sym_preprocessor_token2] = ACTIONS(417),
    [aux_sym_preprocessor_token3] = ACTIONS(417),
    [aux_sym_preprocessor_token4] = ACTIONS(417),
    [aux_sym_preprocessor_token5] = ACTIONS(417),
    [aux_sym_preprocessor_token6] = ACTIONS(417),
    [aux_sym_preprocessor_token7] = ACTIONS(417),
    [aux_sym_preprocessor_token8] = ACTIONS(417),
    [aux_sym_preprocessor_token9] = ACTIONS(417),
    [aux_sym_preprocessor_token10] = ACTIONS(417),
    [aux_sym_preprocessor_token11] = ACTIONS(417),
    [aux_sym_preprocessor_token12] = ACTIONS(417),
    [aux_sym_preprocessor_token13] = ACTIONS(417),
    [aux_sym_preprocessor_token14] = ACTIONS(417),
    [aux_sym_preprocessor_token15] = ACTIONS(417),
    [aux_sym_preprocessor_token16] = ACTIONS(417),
    [aux_sym_preprocessor_token17] = ACTIONS(419),
    [aux_sym_preprocessor_token18] = ACTIONS(419),
    [aux_sym_preprocessor_token19] = ACTIONS(419),
    [aux_sym_preprocessor_token20] = ACTIONS(419),
    [aux_sym_preprocessor_token21] = ACTIONS(417),
    [aux_sym_preprocessor_token22] = ACTIONS(417),
    [aux_sym_preprocessor_token23] = ACTIONS(417),
    [aux_sym_preprocessor_token24] = ACTIONS(417),
    [aux_sym_preprocessor_token25] = ACTIONS(419),
    [aux_sym_preprocessor_token26] = ACTIONS(419),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(99)] = {
    [sym_line_comment] = STATE(99),
    [sym_identifier] = ACTIONS(465),
    [anon_sym_COMMA] = ACTIONS(463),
    [anon_sym_SEMI] = ACTIONS(463),
    [anon_sym_EQ] = ACTIONS(463),
    [aux_sym_execute_statement_token1] = ACTIONS(465),
    [anon_sym_TILDE] = ACTIONS(463),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PLUS] = ACTIONS(463),
    [anon_sym_LT_GT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(465),
    [anon_sym_LT] = ACTIONS(465),
    [anon_sym_GT_EQ] = ACTIONS(463),
    [anon_sym_LT_EQ] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(463),
    [anon_sym_SLASH] = ACTIONS(465),
    [anon_sym_PERCENT] = ACTIONS(463),
    [sym_IF_KEYWORD] = ACTIONS(465),
    [sym_ELSIF_KEYWORD] = ACTIONS(465),
    [sym_ELSE_KEYWORD] = ACTIONS(465),
    [sym_ENDIF_KEYWORD] = ACTIONS(465),
    [sym_FOR_KEYWORD] = ACTIONS(465),
    [sym_WHILE_KEYWORD] = ACTIONS(465),
    [sym_GOTO_KEYWORD] = ACTIONS(465),
    [sym_RETURN_KEYWORD] = ACTIONS(465),
    [sym_BREAK_KEYWORD] = ACTIONS(465),
    [sym_CONTINUE_KEYWORD] = ACTIONS(465),
    [sym_VAR_KEYWORD] = ACTIONS(465),
    [sym_TRY_KEYWORD] = ACTIONS(465),
    [sym_EXCEPT_KEYWORD] = ACTIONS(465),
    [sym_RAISE_KEYWORD] = ACTIONS(465),
    [sym_AWAIT_KEYWORD] = ACTIONS(465),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(465),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(465),
    [sym_AND_KEYWORD] = ACTIONS(465),
    [sym_OR_KEYWORD] = ACTIONS(465),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(465),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(463),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(463),
    [aux_sym_preprocessor_token1] = ACTIONS(463),
    [aux_sym_preprocessor_token2] = ACTIONS(463),
    [aux_sym_preprocessor_token3] = ACTIONS(463),
    [aux_sym_preprocessor_token4] = ACTIONS(463),
    [aux_sym_preprocessor_token5] = ACTIONS(463),
    [aux_sym_preprocessor_token6] = ACTIONS(463),
    [aux_sym_preprocessor_token7] = ACTIONS(463),
    [aux_sym_preprocessor_token8] = ACTIONS(463),
    [aux_sym_preprocessor_token9] = ACTIONS(463),
    [aux_sym_preprocessor_token10] = ACTIONS(463),
    [aux_sym_preprocessor_token11] = ACTIONS(463),
    [aux_sym_preprocessor_token12] = ACTIONS(463),
    [aux_sym_preprocessor_token13] = ACTIONS(463),
    [aux_sym_preprocessor_token14] = ACTIONS(463),
    [aux_sym_preprocessor_token15] = ACTIONS(463),
    [aux_sym_preprocessor_token16] = ACTIONS(463),
    [aux_sym_preprocessor_token17] = ACTIONS(465),
    [aux_sym_preprocessor_token18] = ACTIONS(465),
    [aux_sym_preprocessor_token19] = ACTIONS(465),
    [aux_sym_preprocessor_token20] = ACTIONS(465),
    [aux_sym_preprocessor_token21] = ACTIONS(463),
    [aux_sym_preprocessor_token22] = ACTIONS(463),
    [aux_sym_preprocessor_token23] = ACTIONS(463),
    [aux_sym_preprocessor_token24] = ACTIONS(463),
    [aux_sym_preprocessor_token25] = ACTIONS(465),
    [aux_sym_preprocessor_token26] = ACTIONS(465),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(100)] = {
    [sym_line_comment] = STATE(100),
    [sym_identifier] = ACTIONS(423),
    [anon_sym_COMMA] = ACTIONS(519),
    [anon_sym_SEMI] = ACTIONS(421),
    [anon_sym_EQ] = ACTIONS(421),
    [aux_sym_execute_statement_token1] = ACTIONS(423),
    [anon_sym_TILDE] = ACTIONS(421),
    [anon_sym_DASH] = ACTIONS(421),
    [anon_sym_PLUS] = ACTIONS(421),
    [anon_sym_LT_GT] = ACTIONS(421),
    [anon_sym_GT] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [anon_sym_GT_EQ] = ACTIONS(421),
    [anon_sym_LT_EQ] = ACTIONS(421),
    [anon_sym_STAR] = ACTIONS(421),
    [anon_sym_SLASH] = ACTIONS(423),
    [anon_sym_PERCENT] = ACTIONS(421),
    [sym_IF_KEYWORD] = ACTIONS(423),
    [sym_ELSIF_KEYWORD] = ACTIONS(423),
    [sym_ELSE_KEYWORD] = ACTIONS(423),
    [sym_ENDIF_KEYWORD] = ACTIONS(423),
    [sym_FOR_KEYWORD] = ACTIONS(423),
    [sym_WHILE_KEYWORD] = ACTIONS(423),
    [sym_GOTO_KEYWORD] = ACTIONS(423),
    [sym_RETURN_KEYWORD] = ACTIONS(423),
    [sym_BREAK_KEYWORD] = ACTIONS(423),
    [sym_CONTINUE_KEYWORD] = ACTIONS(423),
    [sym_VAR_KEYWORD] = ACTIONS(423),
    [sym_TRY_KEYWORD] = ACTIONS(423),
    [sym_EXCEPT_KEYWORD] = ACTIONS(423),
    [sym_RAISE_KEYWORD] = ACTIONS(423),
    [sym_AWAIT_KEYWORD] = ACTIONS(423),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(423),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(423),
    [sym_AND_KEYWORD] = ACTIONS(423),
    [sym_OR_KEYWORD] = ACTIONS(423),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(423),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(421),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(421),
    [aux_sym_preprocessor_token1] = ACTIONS(421),
    [aux_sym_preprocessor_token2] = ACTIONS(421),
    [aux_sym_preprocessor_token3] = ACTIONS(421),
    [aux_sym_preprocessor_token4] = ACTIONS(421),
    [aux_sym_preprocessor_token5] = ACTIONS(421),
    [aux_sym_preprocessor_token6] = ACTIONS(421),
    [aux_sym_preprocessor_token7] = ACTIONS(421),
    [aux_sym_preprocessor_token8] = ACTIONS(421),
    [aux_sym_preprocessor_token9] = ACTIONS(421),
    [aux_sym_preprocessor_token10] = ACTIONS(421),
    [aux_sym_preprocessor_token11] = ACTIONS(421),
    [aux_sym_preprocessor_token12] = ACTIONS(421),
    [aux_sym_preprocessor_token13] = ACTIONS(421),
    [aux_sym_preprocessor_token14] = ACTIONS(421),
    [aux_sym_preprocessor_token15] = ACTIONS(421),
    [aux_sym_preprocessor_token16] = ACTIONS(421),
    [aux_sym_preprocessor_token17] = ACTIONS(423),
    [aux_sym_preprocessor_token18] = ACTIONS(423),
    [aux_sym_preprocessor_token19] = ACTIONS(423),
    [aux_sym_preprocessor_token20] = ACTIONS(423),
    [aux_sym_preprocessor_token21] = ACTIONS(421),
    [aux_sym_preprocessor_token22] = ACTIONS(421),
    [aux_sym_preprocessor_token23] = ACTIONS(421),
    [aux_sym_preprocessor_token24] = ACTIONS(421),
    [aux_sym_preprocessor_token25] = ACTIONS(423),
    [aux_sym_preprocessor_token26] = ACTIONS(423),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(101)] = {
    [sym_line_comment] = STATE(101),
    [sym_identifier] = ACTIONS(429),
    [anon_sym_COMMA] = ACTIONS(427),
    [anon_sym_SEMI] = ACTIONS(427),
    [anon_sym_EQ] = ACTIONS(427),
    [aux_sym_execute_statement_token1] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(427),
    [anon_sym_DASH] = ACTIONS(427),
    [anon_sym_PLUS] = ACTIONS(427),
    [anon_sym_LT_GT] = ACTIONS(427),
    [anon_sym_GT] = ACTIONS(429),
    [anon_sym_LT] = ACTIONS(429),
    [anon_sym_GT_EQ] = ACTIONS(427),
    [anon_sym_LT_EQ] = ACTIONS(427),
    [anon_sym_STAR] = ACTIONS(427),
    [anon_sym_SLASH] = ACTIONS(429),
    [anon_sym_PERCENT] = ACTIONS(427),
    [sym_IF_KEYWORD] = ACTIONS(429),
    [sym_ELSIF_KEYWORD] = ACTIONS(429),
    [sym_ELSE_KEYWORD] = ACTIONS(429),
    [sym_ENDIF_KEYWORD] = ACTIONS(429),
    [sym_FOR_KEYWORD] = ACTIONS(429),
    [sym_WHILE_KEYWORD] = ACTIONS(429),
    [sym_GOTO_KEYWORD] = ACTIONS(429),
    [sym_RETURN_KEYWORD] = ACTIONS(429),
    [sym_BREAK_KEYWORD] = ACTIONS(429),
    [sym_CONTINUE_KEYWORD] = ACTIONS(429),
    [sym_VAR_KEYWORD] = ACTIONS(429),
    [sym_TRY_KEYWORD] = ACTIONS(429),
    [sym_EXCEPT_KEYWORD] = ACTIONS(429),
    [sym_RAISE_KEYWORD] = ACTIONS(429),
    [sym_AWAIT_KEYWORD] = ACTIONS(429),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(429),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(429),
    [sym_AND_KEYWORD] = ACTIONS(429),
    [sym_OR_KEYWORD] = ACTIONS(429),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(429),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(427),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(427),
    [aux_sym_preprocessor_token1] = ACTIONS(427),
    [aux_sym_preprocessor_token2] = ACTIONS(427),
    [aux_sym_preprocessor_token3] = ACTIONS(427),
    [aux_sym_preprocessor_token4] = ACTIONS(427),
    [aux_sym_preprocessor_token5] = ACTIONS(427),
    [aux_sym_preprocessor_token6] = ACTIONS(427),
    [aux_sym_preprocessor_token7] = ACTIONS(427),
    [aux_sym_preprocessor_token8] = ACTIONS(427),
    [aux_sym_preprocessor_token9] = ACTIONS(427),
    [aux_sym_preprocessor_token10] = ACTIONS(427),
    [aux_sym_preprocessor_token11] = ACTIONS(427),
    [aux_sym_preprocessor_token12] = ACTIONS(427),
    [aux_sym_preprocessor_token13] = ACTIONS(427),
    [aux_sym_preprocessor_token14] = ACTIONS(427),
    [aux_sym_preprocessor_token15] = ACTIONS(427),
    [aux_sym_preprocessor_token16] = ACTIONS(427),
    [aux_sym_preprocessor_token17] = ACTIONS(429),
    [aux_sym_preprocessor_token18] = ACTIONS(429),
    [aux_sym_preprocessor_token19] = ACTIONS(429),
    [aux_sym_preprocessor_token20] = ACTIONS(429),
    [aux_sym_preprocessor_token21] = ACTIONS(427),
    [aux_sym_preprocessor_token22] = ACTIONS(427),
    [aux_sym_preprocessor_token23] = ACTIONS(427),
    [aux_sym_preprocessor_token24] = ACTIONS(427),
    [aux_sym_preprocessor_token25] = ACTIONS(429),
    [aux_sym_preprocessor_token26] = ACTIONS(429),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(102)] = {
    [sym_line_comment] = STATE(102),
    [sym_identifier] = ACTIONS(407),
    [anon_sym_COMMA] = ACTIONS(405),
    [anon_sym_SEMI] = ACTIONS(405),
    [anon_sym_EQ] = ACTIONS(405),
    [aux_sym_execute_statement_token1] = ACTIONS(407),
    [anon_sym_TILDE] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(405),
    [anon_sym_PLUS] = ACTIONS(405),
    [anon_sym_LT_GT] = ACTIONS(405),
    [anon_sym_GT] = ACTIONS(407),
    [anon_sym_LT] = ACTIONS(407),
    [anon_sym_GT_EQ] = ACTIONS(405),
    [anon_sym_LT_EQ] = ACTIONS(405),
    [anon_sym_STAR] = ACTIONS(405),
    [anon_sym_SLASH] = ACTIONS(407),
    [anon_sym_PERCENT] = ACTIONS(405),
    [sym_IF_KEYWORD] = ACTIONS(407),
    [sym_ELSIF_KEYWORD] = ACTIONS(407),
    [sym_ELSE_KEYWORD] = ACTIONS(407),
    [sym_ENDIF_KEYWORD] = ACTIONS(407),
    [sym_FOR_KEYWORD] = ACTIONS(407),
    [sym_WHILE_KEYWORD] = ACTIONS(407),
    [sym_GOTO_KEYWORD] = ACTIONS(407),
    [sym_RETURN_KEYWORD] = ACTIONS(407),
    [sym_BREAK_KEYWORD] = ACTIONS(407),
    [sym_CONTINUE_KEYWORD] = ACTIONS(407),
    [sym_VAR_KEYWORD] = ACTIONS(407),
    [sym_TRY_KEYWORD] = ACTIONS(407),
    [sym_EXCEPT_KEYWORD] = ACTIONS(407),
    [sym_RAISE_KEYWORD] = ACTIONS(407),
    [sym_AWAIT_KEYWORD] = ACTIONS(407),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(407),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(407),
    [sym_AND_KEYWORD] = ACTIONS(407),
    [sym_OR_KEYWORD] = ACTIONS(407),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(407),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(405),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(405),
    [aux_sym_preprocessor_token1] = ACTIONS(405),
    [aux_sym_preprocessor_token2] = ACTIONS(405),
    [aux_sym_preprocessor_token3] = ACTIONS(405),
    [aux_sym_preprocessor_token4] = ACTIONS(405),
    [aux_sym_preprocessor_token5] = ACTIONS(405),
    [aux_sym_preprocessor_token6] = ACTIONS(405),
    [aux_sym_preprocessor_token7] = ACTIONS(405),
    [aux_sym_preprocessor_token8] = ACTIONS(405),
    [aux_sym_preprocessor_token9] = ACTIONS(405),
    [aux_sym_preprocessor_token10] = ACTIONS(405),
    [aux_sym_preprocessor_token11] = ACTIONS(405),
    [aux_sym_preprocessor_token12] = ACTIONS(405),
    [aux_sym_preprocessor_token13] = ACTIONS(405),
    [aux_sym_preprocessor_token14] = ACTIONS(405),
    [aux_sym_preprocessor_token15] = ACTIONS(405),
    [aux_sym_preprocessor_token16] = ACTIONS(405),
    [aux_sym_preprocessor_token17] = ACTIONS(407),
    [aux_sym_preprocessor_token18] = ACTIONS(407),
    [aux_sym_preprocessor_token19] = ACTIONS(407),
    [aux_sym_preprocessor_token20] = ACTIONS(407),
    [aux_sym_preprocessor_token21] = ACTIONS(405),
    [aux_sym_preprocessor_token22] = ACTIONS(405),
    [aux_sym_preprocessor_token23] = ACTIONS(405),
    [aux_sym_preprocessor_token24] = ACTIONS(405),
    [aux_sym_preprocessor_token25] = ACTIONS(407),
    [aux_sym_preprocessor_token26] = ACTIONS(407),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(103)] = {
    [sym_line_comment] = STATE(103),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(431),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(431),
    [anon_sym_PLUS] = ACTIONS(431),
    [anon_sym_LT_GT] = ACTIONS(431),
    [anon_sym_GT] = ACTIONS(433),
    [anon_sym_LT] = ACTIONS(433),
    [anon_sym_GT_EQ] = ACTIONS(431),
    [anon_sym_LT_EQ] = ACTIONS(431),
    [anon_sym_STAR] = ACTIONS(431),
    [anon_sym_SLASH] = ACTIONS(433),
    [anon_sym_PERCENT] = ACTIONS(431),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_ELSIF_KEYWORD] = ACTIONS(433),
    [sym_ELSE_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_EXCEPT_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(104)] = {
    [sym_line_comment] = STATE(104),
    [sym_identifier] = ACTIONS(443),
    [anon_sym_COMMA] = ACTIONS(441),
    [anon_sym_SEMI] = ACTIONS(441),
    [anon_sym_EQ] = ACTIONS(441),
    [aux_sym_execute_statement_token1] = ACTIONS(443),
    [anon_sym_TILDE] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(441),
    [anon_sym_PLUS] = ACTIONS(441),
    [anon_sym_LT_GT] = ACTIONS(441),
    [anon_sym_GT] = ACTIONS(443),
    [anon_sym_LT] = ACTIONS(443),
    [anon_sym_GT_EQ] = ACTIONS(441),
    [anon_sym_LT_EQ] = ACTIONS(441),
    [anon_sym_STAR] = ACTIONS(441),
    [anon_sym_SLASH] = ACTIONS(443),
    [anon_sym_PERCENT] = ACTIONS(441),
    [sym_IF_KEYWORD] = ACTIONS(443),
    [sym_ELSIF_KEYWORD] = ACTIONS(443),
    [sym_ELSE_KEYWORD] = ACTIONS(443),
    [sym_ENDIF_KEYWORD] = ACTIONS(443),
    [sym_FOR_KEYWORD] = ACTIONS(443),
    [sym_WHILE_KEYWORD] = ACTIONS(443),
    [sym_GOTO_KEYWORD] = ACTIONS(443),
    [sym_RETURN_KEYWORD] = ACTIONS(443),
    [sym_BREAK_KEYWORD] = ACTIONS(443),
    [sym_CONTINUE_KEYWORD] = ACTIONS(443),
    [sym_VAR_KEYWORD] = ACTIONS(443),
    [sym_TRY_KEYWORD] = ACTIONS(443),
    [sym_EXCEPT_KEYWORD] = ACTIONS(443),
    [sym_RAISE_KEYWORD] = ACTIONS(443),
    [sym_AWAIT_KEYWORD] = ACTIONS(443),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(443),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(443),
    [sym_AND_KEYWORD] = ACTIONS(443),
    [sym_OR_KEYWORD] = ACTIONS(443),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(443),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(441),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(441),
    [aux_sym_preprocessor_token1] = ACTIONS(441),
    [aux_sym_preprocessor_token2] = ACTIONS(441),
    [aux_sym_preprocessor_token3] = ACTIONS(441),
    [aux_sym_preprocessor_token4] = ACTIONS(441),
    [aux_sym_preprocessor_token5] = ACTIONS(441),
    [aux_sym_preprocessor_token6] = ACTIONS(441),
    [aux_sym_preprocessor_token7] = ACTIONS(441),
    [aux_sym_preprocessor_token8] = ACTIONS(441),
    [aux_sym_preprocessor_token9] = ACTIONS(441),
    [aux_sym_preprocessor_token10] = ACTIONS(441),
    [aux_sym_preprocessor_token11] = ACTIONS(441),
    [aux_sym_preprocessor_token12] = ACTIONS(441),
    [aux_sym_preprocessor_token13] = ACTIONS(441),
    [aux_sym_preprocessor_token14] = ACTIONS(441),
    [aux_sym_preprocessor_token15] = ACTIONS(441),
    [aux_sym_preprocessor_token16] = ACTIONS(441),
    [aux_sym_preprocessor_token17] = ACTIONS(443),
    [aux_sym_preprocessor_token18] = ACTIONS(443),
    [aux_sym_preprocessor_token19] = ACTIONS(443),
    [aux_sym_preprocessor_token20] = ACTIONS(443),
    [aux_sym_preprocessor_token21] = ACTIONS(441),
    [aux_sym_preprocessor_token22] = ACTIONS(441),
    [aux_sym_preprocessor_token23] = ACTIONS(441),
    [aux_sym_preprocessor_token24] = ACTIONS(441),
    [aux_sym_preprocessor_token25] = ACTIONS(443),
    [aux_sym_preprocessor_token26] = ACTIONS(443),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(105)] = {
    [sym_line_comment] = STATE(105),
    [sym_identifier] = ACTIONS(453),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_EQ] = ACTIONS(451),
    [aux_sym_execute_statement_token1] = ACTIONS(453),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_LT_GT] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(453),
    [anon_sym_PERCENT] = ACTIONS(451),
    [sym_IF_KEYWORD] = ACTIONS(453),
    [sym_ELSIF_KEYWORD] = ACTIONS(453),
    [sym_ELSE_KEYWORD] = ACTIONS(453),
    [sym_ENDIF_KEYWORD] = ACTIONS(453),
    [sym_FOR_KEYWORD] = ACTIONS(453),
    [sym_WHILE_KEYWORD] = ACTIONS(453),
    [sym_GOTO_KEYWORD] = ACTIONS(453),
    [sym_RETURN_KEYWORD] = ACTIONS(453),
    [sym_BREAK_KEYWORD] = ACTIONS(453),
    [sym_CONTINUE_KEYWORD] = ACTIONS(453),
    [sym_VAR_KEYWORD] = ACTIONS(453),
    [sym_TRY_KEYWORD] = ACTIONS(453),
    [sym_EXCEPT_KEYWORD] = ACTIONS(453),
    [sym_RAISE_KEYWORD] = ACTIONS(453),
    [sym_AWAIT_KEYWORD] = ACTIONS(453),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(453),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(453),
    [sym_AND_KEYWORD] = ACTIONS(453),
    [sym_OR_KEYWORD] = ACTIONS(453),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(453),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(451),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(451),
    [aux_sym_preprocessor_token1] = ACTIONS(451),
    [aux_sym_preprocessor_token2] = ACTIONS(451),
    [aux_sym_preprocessor_token3] = ACTIONS(451),
    [aux_sym_preprocessor_token4] = ACTIONS(451),
    [aux_sym_preprocessor_token5] = ACTIONS(451),
    [aux_sym_preprocessor_token6] = ACTIONS(451),
    [aux_sym_preprocessor_token7] = ACTIONS(451),
    [aux_sym_preprocessor_token8] = ACTIONS(451),
    [aux_sym_preprocessor_token9] = ACTIONS(451),
    [aux_sym_preprocessor_token10] = ACTIONS(451),
    [aux_sym_preprocessor_token11] = ACTIONS(451),
    [aux_sym_preprocessor_token12] = ACTIONS(451),
    [aux_sym_preprocessor_token13] = ACTIONS(451),
    [aux_sym_preprocessor_token14] = ACTIONS(451),
    [aux_sym_preprocessor_token15] = ACTIONS(451),
    [aux_sym_preprocessor_token16] = ACTIONS(451),
    [aux_sym_preprocessor_token17] = ACTIONS(453),
    [aux_sym_preprocessor_token18] = ACTIONS(453),
    [aux_sym_preprocessor_token19] = ACTIONS(453),
    [aux_sym_preprocessor_token20] = ACTIONS(453),
    [aux_sym_preprocessor_token21] = ACTIONS(451),
    [aux_sym_preprocessor_token22] = ACTIONS(451),
    [aux_sym_preprocessor_token23] = ACTIONS(451),
    [aux_sym_preprocessor_token24] = ACTIONS(451),
    [aux_sym_preprocessor_token25] = ACTIONS(453),
    [aux_sym_preprocessor_token26] = ACTIONS(453),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(106)] = {
    [sym_line_comment] = STATE(106),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_COMMA] = ACTIONS(431),
    [anon_sym_SEMI] = ACTIONS(431),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(433),
    [sym_ELSIF_KEYWORD] = ACTIONS(433),
    [sym_ELSE_KEYWORD] = ACTIONS(433),
    [sym_ENDIF_KEYWORD] = ACTIONS(433),
    [sym_FOR_KEYWORD] = ACTIONS(433),
    [sym_WHILE_KEYWORD] = ACTIONS(433),
    [sym_GOTO_KEYWORD] = ACTIONS(433),
    [sym_RETURN_KEYWORD] = ACTIONS(433),
    [sym_BREAK_KEYWORD] = ACTIONS(433),
    [sym_CONTINUE_KEYWORD] = ACTIONS(433),
    [sym_VAR_KEYWORD] = ACTIONS(433),
    [sym_TRY_KEYWORD] = ACTIONS(433),
    [sym_EXCEPT_KEYWORD] = ACTIONS(433),
    [sym_RAISE_KEYWORD] = ACTIONS(433),
    [sym_AWAIT_KEYWORD] = ACTIONS(433),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(433),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(433),
    [sym_AND_KEYWORD] = ACTIONS(433),
    [sym_OR_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(433),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(431),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(431),
    [aux_sym_preprocessor_token1] = ACTIONS(431),
    [aux_sym_preprocessor_token2] = ACTIONS(431),
    [aux_sym_preprocessor_token3] = ACTIONS(431),
    [aux_sym_preprocessor_token4] = ACTIONS(431),
    [aux_sym_preprocessor_token5] = ACTIONS(431),
    [aux_sym_preprocessor_token6] = ACTIONS(431),
    [aux_sym_preprocessor_token7] = ACTIONS(431),
    [aux_sym_preprocessor_token8] = ACTIONS(431),
    [aux_sym_preprocessor_token9] = ACTIONS(431),
    [aux_sym_preprocessor_token10] = ACTIONS(431),
    [aux_sym_preprocessor_token11] = ACTIONS(431),
    [aux_sym_preprocessor_token12] = ACTIONS(431),
    [aux_sym_preprocessor_token13] = ACTIONS(431),
    [aux_sym_preprocessor_token14] = ACTIONS(431),
    [aux_sym_preprocessor_token15] = ACTIONS(431),
    [aux_sym_preprocessor_token16] = ACTIONS(431),
    [aux_sym_preprocessor_token17] = ACTIONS(433),
    [aux_sym_preprocessor_token18] = ACTIONS(433),
    [aux_sym_preprocessor_token19] = ACTIONS(433),
    [aux_sym_preprocessor_token20] = ACTIONS(433),
    [aux_sym_preprocessor_token21] = ACTIONS(431),
    [aux_sym_preprocessor_token22] = ACTIONS(431),
    [aux_sym_preprocessor_token23] = ACTIONS(431),
    [aux_sym_preprocessor_token24] = ACTIONS(431),
    [aux_sym_preprocessor_token25] = ACTIONS(433),
    [aux_sym_preprocessor_token26] = ACTIONS(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(107)] = {
    [sym_line_comment] = STATE(107),
    [sym_identifier] = ACTIONS(457),
    [anon_sym_SEMI] = ACTIONS(455),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(457),
    [anon_sym_TILDE] = ACTIONS(455),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(457),
    [sym_ELSIF_KEYWORD] = ACTIONS(457),
    [sym_ELSE_KEYWORD] = ACTIONS(457),
    [sym_ENDIF_KEYWORD] = ACTIONS(457),
    [sym_FOR_KEYWORD] = ACTIONS(457),
    [sym_WHILE_KEYWORD] = ACTIONS(457),
    [sym_GOTO_KEYWORD] = ACTIONS(457),
    [sym_RETURN_KEYWORD] = ACTIONS(457),
    [sym_BREAK_KEYWORD] = ACTIONS(457),
    [sym_CONTINUE_KEYWORD] = ACTIONS(457),
    [sym_VAR_KEYWORD] = ACTIONS(457),
    [sym_TRY_KEYWORD] = ACTIONS(457),
    [sym_EXCEPT_KEYWORD] = ACTIONS(457),
    [sym_RAISE_KEYWORD] = ACTIONS(457),
    [sym_AWAIT_KEYWORD] = ACTIONS(457),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(457),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(457),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(457),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(455),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(455),
    [aux_sym_preprocessor_token1] = ACTIONS(455),
    [aux_sym_preprocessor_token2] = ACTIONS(455),
    [aux_sym_preprocessor_token3] = ACTIONS(455),
    [aux_sym_preprocessor_token4] = ACTIONS(455),
    [aux_sym_preprocessor_token5] = ACTIONS(455),
    [aux_sym_preprocessor_token6] = ACTIONS(455),
    [aux_sym_preprocessor_token7] = ACTIONS(455),
    [aux_sym_preprocessor_token8] = ACTIONS(455),
    [aux_sym_preprocessor_token9] = ACTIONS(455),
    [aux_sym_preprocessor_token10] = ACTIONS(455),
    [aux_sym_preprocessor_token11] = ACTIONS(455),
    [aux_sym_preprocessor_token12] = ACTIONS(455),
    [aux_sym_preprocessor_token13] = ACTIONS(455),
    [aux_sym_preprocessor_token14] = ACTIONS(455),
    [aux_sym_preprocessor_token15] = ACTIONS(455),
    [aux_sym_preprocessor_token16] = ACTIONS(455),
    [aux_sym_preprocessor_token17] = ACTIONS(457),
    [aux_sym_preprocessor_token18] = ACTIONS(457),
    [aux_sym_preprocessor_token19] = ACTIONS(457),
    [aux_sym_preprocessor_token20] = ACTIONS(457),
    [aux_sym_preprocessor_token21] = ACTIONS(455),
    [aux_sym_preprocessor_token22] = ACTIONS(455),
    [aux_sym_preprocessor_token23] = ACTIONS(455),
    [aux_sym_preprocessor_token24] = ACTIONS(455),
    [aux_sym_preprocessor_token25] = ACTIONS(457),
    [aux_sym_preprocessor_token26] = ACTIONS(457),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(108)] = {
    [sym_line_comment] = STATE(108),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_SEMI] = ACTIONS(499),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(497),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(497),
    [sym_ELSIF_KEYWORD] = ACTIONS(497),
    [sym_ELSE_KEYWORD] = ACTIONS(497),
    [sym_ENDIF_KEYWORD] = ACTIONS(497),
    [sym_FOR_KEYWORD] = ACTIONS(497),
    [sym_WHILE_KEYWORD] = ACTIONS(497),
    [sym_GOTO_KEYWORD] = ACTIONS(497),
    [sym_RETURN_KEYWORD] = ACTIONS(497),
    [sym_BREAK_KEYWORD] = ACTIONS(497),
    [sym_CONTINUE_KEYWORD] = ACTIONS(497),
    [sym_VAR_KEYWORD] = ACTIONS(497),
    [sym_TRY_KEYWORD] = ACTIONS(497),
    [sym_EXCEPT_KEYWORD] = ACTIONS(497),
    [sym_RAISE_KEYWORD] = ACTIONS(497),
    [sym_AWAIT_KEYWORD] = ACTIONS(497),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(497),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(497),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(497),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(495),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(495),
    [aux_sym_preprocessor_token1] = ACTIONS(495),
    [aux_sym_preprocessor_token2] = ACTIONS(495),
    [aux_sym_preprocessor_token3] = ACTIONS(495),
    [aux_sym_preprocessor_token4] = ACTIONS(495),
    [aux_sym_preprocessor_token5] = ACTIONS(495),
    [aux_sym_preprocessor_token6] = ACTIONS(495),
    [aux_sym_preprocessor_token7] = ACTIONS(495),
    [aux_sym_preprocessor_token8] = ACTIONS(495),
    [aux_sym_preprocessor_token9] = ACTIONS(495),
    [aux_sym_preprocessor_token10] = ACTIONS(495),
    [aux_sym_preprocessor_token11] = ACTIONS(495),
    [aux_sym_preprocessor_token12] = ACTIONS(495),
    [aux_sym_preprocessor_token13] = ACTIONS(495),
    [aux_sym_preprocessor_token14] = ACTIONS(495),
    [aux_sym_preprocessor_token15] = ACTIONS(495),
    [aux_sym_preprocessor_token16] = ACTIONS(495),
    [aux_sym_preprocessor_token17] = ACTIONS(497),
    [aux_sym_preprocessor_token18] = ACTIONS(497),
    [aux_sym_preprocessor_token19] = ACTIONS(497),
    [aux_sym_preprocessor_token20] = ACTIONS(497),
    [aux_sym_preprocessor_token21] = ACTIONS(495),
    [aux_sym_preprocessor_token22] = ACTIONS(495),
    [aux_sym_preprocessor_token23] = ACTIONS(495),
    [aux_sym_preprocessor_token24] = ACTIONS(495),
    [aux_sym_preprocessor_token25] = ACTIONS(497),
    [aux_sym_preprocessor_token26] = ACTIONS(497),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(109)] = {
    [sym_line_comment] = STATE(109),
    [sym_identifier] = ACTIONS(491),
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(491),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(491),
    [sym_ELSIF_KEYWORD] = ACTIONS(491),
    [sym_ELSE_KEYWORD] = ACTIONS(491),
    [sym_ENDIF_KEYWORD] = ACTIONS(491),
    [sym_FOR_KEYWORD] = ACTIONS(491),
    [sym_WHILE_KEYWORD] = ACTIONS(491),
    [sym_GOTO_KEYWORD] = ACTIONS(491),
    [sym_RETURN_KEYWORD] = ACTIONS(491),
    [sym_BREAK_KEYWORD] = ACTIONS(491),
    [sym_CONTINUE_KEYWORD] = ACTIONS(491),
    [sym_VAR_KEYWORD] = ACTIONS(491),
    [sym_TRY_KEYWORD] = ACTIONS(491),
    [sym_EXCEPT_KEYWORD] = ACTIONS(491),
    [sym_RAISE_KEYWORD] = ACTIONS(491),
    [sym_AWAIT_KEYWORD] = ACTIONS(491),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(491),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(491),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(491),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(489),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(489),
    [aux_sym_preprocessor_token1] = ACTIONS(489),
    [aux_sym_preprocessor_token2] = ACTIONS(489),
    [aux_sym_preprocessor_token3] = ACTIONS(489),
    [aux_sym_preprocessor_token4] = ACTIONS(489),
    [aux_sym_preprocessor_token5] = ACTIONS(489),
    [aux_sym_preprocessor_token6] = ACTIONS(489),
    [aux_sym_preprocessor_token7] = ACTIONS(489),
    [aux_sym_preprocessor_token8] = ACTIONS(489),
    [aux_sym_preprocessor_token9] = ACTIONS(489),
    [aux_sym_preprocessor_token10] = ACTIONS(489),
    [aux_sym_preprocessor_token11] = ACTIONS(489),
    [aux_sym_preprocessor_token12] = ACTIONS(489),
    [aux_sym_preprocessor_token13] = ACTIONS(489),
    [aux_sym_preprocessor_token14] = ACTIONS(489),
    [aux_sym_preprocessor_token15] = ACTIONS(489),
    [aux_sym_preprocessor_token16] = ACTIONS(489),
    [aux_sym_preprocessor_token17] = ACTIONS(491),
    [aux_sym_preprocessor_token18] = ACTIONS(491),
    [aux_sym_preprocessor_token19] = ACTIONS(491),
    [aux_sym_preprocessor_token20] = ACTIONS(491),
    [aux_sym_preprocessor_token21] = ACTIONS(489),
    [aux_sym_preprocessor_token22] = ACTIONS(489),
    [aux_sym_preprocessor_token23] = ACTIONS(489),
    [aux_sym_preprocessor_token24] = ACTIONS(489),
    [aux_sym_preprocessor_token25] = ACTIONS(491),
    [aux_sym_preprocessor_token26] = ACTIONS(491),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(110)] = {
    [sym_line_comment] = STATE(110),
    [sym_identifier] = ACTIONS(477),
    [anon_sym_SEMI] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(477),
    [anon_sym_TILDE] = ACTIONS(475),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(477),
    [sym_ELSIF_KEYWORD] = ACTIONS(477),
    [sym_ELSE_KEYWORD] = ACTIONS(477),
    [sym_ENDIF_KEYWORD] = ACTIONS(477),
    [sym_FOR_KEYWORD] = ACTIONS(477),
    [sym_WHILE_KEYWORD] = ACTIONS(477),
    [sym_GOTO_KEYWORD] = ACTIONS(477),
    [sym_RETURN_KEYWORD] = ACTIONS(477),
    [sym_BREAK_KEYWORD] = ACTIONS(477),
    [sym_CONTINUE_KEYWORD] = ACTIONS(477),
    [sym_VAR_KEYWORD] = ACTIONS(477),
    [sym_TRY_KEYWORD] = ACTIONS(477),
    [sym_EXCEPT_KEYWORD] = ACTIONS(477),
    [sym_RAISE_KEYWORD] = ACTIONS(477),
    [sym_AWAIT_KEYWORD] = ACTIONS(477),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(477),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(477),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(477),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(475),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(475),
    [aux_sym_preprocessor_token1] = ACTIONS(475),
    [aux_sym_preprocessor_token2] = ACTIONS(475),
    [aux_sym_preprocessor_token3] = ACTIONS(475),
    [aux_sym_preprocessor_token4] = ACTIONS(475),
    [aux_sym_preprocessor_token5] = ACTIONS(475),
    [aux_sym_preprocessor_token6] = ACTIONS(475),
    [aux_sym_preprocessor_token7] = ACTIONS(475),
    [aux_sym_preprocessor_token8] = ACTIONS(475),
    [aux_sym_preprocessor_token9] = ACTIONS(475),
    [aux_sym_preprocessor_token10] = ACTIONS(475),
    [aux_sym_preprocessor_token11] = ACTIONS(475),
    [aux_sym_preprocessor_token12] = ACTIONS(475),
    [aux_sym_preprocessor_token13] = ACTIONS(475),
    [aux_sym_preprocessor_token14] = ACTIONS(475),
    [aux_sym_preprocessor_token15] = ACTIONS(475),
    [aux_sym_preprocessor_token16] = ACTIONS(475),
    [aux_sym_preprocessor_token17] = ACTIONS(477),
    [aux_sym_preprocessor_token18] = ACTIONS(477),
    [aux_sym_preprocessor_token19] = ACTIONS(477),
    [aux_sym_preprocessor_token20] = ACTIONS(477),
    [aux_sym_preprocessor_token21] = ACTIONS(475),
    [aux_sym_preprocessor_token22] = ACTIONS(475),
    [aux_sym_preprocessor_token23] = ACTIONS(475),
    [aux_sym_preprocessor_token24] = ACTIONS(475),
    [aux_sym_preprocessor_token25] = ACTIONS(477),
    [aux_sym_preprocessor_token26] = ACTIONS(477),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(111)] = {
    [sym_line_comment] = STATE(111),
    [sym_identifier] = ACTIONS(469),
    [anon_sym_SEMI] = ACTIONS(471),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(469),
    [anon_sym_TILDE] = ACTIONS(467),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(469),
    [sym_ELSIF_KEYWORD] = ACTIONS(469),
    [sym_ELSE_KEYWORD] = ACTIONS(469),
    [sym_ENDIF_KEYWORD] = ACTIONS(469),
    [sym_FOR_KEYWORD] = ACTIONS(469),
    [sym_WHILE_KEYWORD] = ACTIONS(469),
    [sym_GOTO_KEYWORD] = ACTIONS(469),
    [sym_RETURN_KEYWORD] = ACTIONS(469),
    [sym_BREAK_KEYWORD] = ACTIONS(469),
    [sym_CONTINUE_KEYWORD] = ACTIONS(469),
    [sym_VAR_KEYWORD] = ACTIONS(469),
    [sym_TRY_KEYWORD] = ACTIONS(469),
    [sym_EXCEPT_KEYWORD] = ACTIONS(469),
    [sym_RAISE_KEYWORD] = ACTIONS(469),
    [sym_AWAIT_KEYWORD] = ACTIONS(469),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(469),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(469),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(469),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(467),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(467),
    [aux_sym_preprocessor_token1] = ACTIONS(467),
    [aux_sym_preprocessor_token2] = ACTIONS(467),
    [aux_sym_preprocessor_token3] = ACTIONS(467),
    [aux_sym_preprocessor_token4] = ACTIONS(467),
    [aux_sym_preprocessor_token5] = ACTIONS(467),
    [aux_sym_preprocessor_token6] = ACTIONS(467),
    [aux_sym_preprocessor_token7] = ACTIONS(467),
    [aux_sym_preprocessor_token8] = ACTIONS(467),
    [aux_sym_preprocessor_token9] = ACTIONS(467),
    [aux_sym_preprocessor_token10] = ACTIONS(467),
    [aux_sym_preprocessor_token11] = ACTIONS(467),
    [aux_sym_preprocessor_token12] = ACTIONS(467),
    [aux_sym_preprocessor_token13] = ACTIONS(467),
    [aux_sym_preprocessor_token14] = ACTIONS(467),
    [aux_sym_preprocessor_token15] = ACTIONS(467),
    [aux_sym_preprocessor_token16] = ACTIONS(467),
    [aux_sym_preprocessor_token17] = ACTIONS(469),
    [aux_sym_preprocessor_token18] = ACTIONS(469),
    [aux_sym_preprocessor_token19] = ACTIONS(469),
    [aux_sym_preprocessor_token20] = ACTIONS(469),
    [aux_sym_preprocessor_token21] = ACTIONS(467),
    [aux_sym_preprocessor_token22] = ACTIONS(467),
    [aux_sym_preprocessor_token23] = ACTIONS(467),
    [aux_sym_preprocessor_token24] = ACTIONS(467),
    [aux_sym_preprocessor_token25] = ACTIONS(469),
    [aux_sym_preprocessor_token26] = ACTIONS(469),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(112)] = {
    [sym_line_comment] = STATE(112),
    [sym_identifier] = ACTIONS(483),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(483),
    [anon_sym_TILDE] = ACTIONS(481),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(483),
    [sym_ELSIF_KEYWORD] = ACTIONS(483),
    [sym_ELSE_KEYWORD] = ACTIONS(483),
    [sym_ENDIF_KEYWORD] = ACTIONS(483),
    [sym_FOR_KEYWORD] = ACTIONS(483),
    [sym_WHILE_KEYWORD] = ACTIONS(483),
    [sym_GOTO_KEYWORD] = ACTIONS(483),
    [sym_RETURN_KEYWORD] = ACTIONS(483),
    [sym_BREAK_KEYWORD] = ACTIONS(483),
    [sym_CONTINUE_KEYWORD] = ACTIONS(483),
    [sym_VAR_KEYWORD] = ACTIONS(483),
    [sym_TRY_KEYWORD] = ACTIONS(483),
    [sym_EXCEPT_KEYWORD] = ACTIONS(483),
    [sym_RAISE_KEYWORD] = ACTIONS(483),
    [sym_AWAIT_KEYWORD] = ACTIONS(483),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(483),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(483),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(483),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(481),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(481),
    [aux_sym_preprocessor_token1] = ACTIONS(481),
    [aux_sym_preprocessor_token2] = ACTIONS(481),
    [aux_sym_preprocessor_token3] = ACTIONS(481),
    [aux_sym_preprocessor_token4] = ACTIONS(481),
    [aux_sym_preprocessor_token5] = ACTIONS(481),
    [aux_sym_preprocessor_token6] = ACTIONS(481),
    [aux_sym_preprocessor_token7] = ACTIONS(481),
    [aux_sym_preprocessor_token8] = ACTIONS(481),
    [aux_sym_preprocessor_token9] = ACTIONS(481),
    [aux_sym_preprocessor_token10] = ACTIONS(481),
    [aux_sym_preprocessor_token11] = ACTIONS(481),
    [aux_sym_preprocessor_token12] = ACTIONS(481),
    [aux_sym_preprocessor_token13] = ACTIONS(481),
    [aux_sym_preprocessor_token14] = ACTIONS(481),
    [aux_sym_preprocessor_token15] = ACTIONS(481),
    [aux_sym_preprocessor_token16] = ACTIONS(481),
    [aux_sym_preprocessor_token17] = ACTIONS(483),
    [aux_sym_preprocessor_token18] = ACTIONS(483),
    [aux_sym_preprocessor_token19] = ACTIONS(483),
    [aux_sym_preprocessor_token20] = ACTIONS(483),
    [aux_sym_preprocessor_token21] = ACTIONS(481),
    [aux_sym_preprocessor_token22] = ACTIONS(481),
    [aux_sym_preprocessor_token23] = ACTIONS(481),
    [aux_sym_preprocessor_token24] = ACTIONS(481),
    [aux_sym_preprocessor_token25] = ACTIONS(483),
    [aux_sym_preprocessor_token26] = ACTIONS(483),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(113)] = {
    [sym_line_comment] = STATE(113),
    [sym_identifier] = ACTIONS(503),
    [anon_sym_SEMI] = ACTIONS(505),
    [anon_sym_EQ] = ACTIONS(513),
    [aux_sym_execute_statement_token1] = ACTIONS(503),
    [anon_sym_TILDE] = ACTIONS(501),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_LT_GT] = ACTIONS(513),
    [anon_sym_GT] = ACTIONS(515),
    [anon_sym_LT] = ACTIONS(515),
    [anon_sym_GT_EQ] = ACTIONS(513),
    [anon_sym_LT_EQ] = ACTIONS(513),
    [anon_sym_STAR] = ACTIONS(509),
    [anon_sym_SLASH] = ACTIONS(511),
    [anon_sym_PERCENT] = ACTIONS(509),
    [sym_IF_KEYWORD] = ACTIONS(503),
    [sym_ELSIF_KEYWORD] = ACTIONS(503),
    [sym_ELSE_KEYWORD] = ACTIONS(503),
    [sym_ENDIF_KEYWORD] = ACTIONS(503),
    [sym_FOR_KEYWORD] = ACTIONS(503),
    [sym_WHILE_KEYWORD] = ACTIONS(503),
    [sym_GOTO_KEYWORD] = ACTIONS(503),
    [sym_RETURN_KEYWORD] = ACTIONS(503),
    [sym_BREAK_KEYWORD] = ACTIONS(503),
    [sym_CONTINUE_KEYWORD] = ACTIONS(503),
    [sym_VAR_KEYWORD] = ACTIONS(503),
    [sym_TRY_KEYWORD] = ACTIONS(503),
    [sym_EXCEPT_KEYWORD] = ACTIONS(503),
    [sym_RAISE_KEYWORD] = ACTIONS(503),
    [sym_AWAIT_KEYWORD] = ACTIONS(503),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(503),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(503),
    [sym_AND_KEYWORD] = ACTIONS(517),
    [sym_OR_KEYWORD] = ACTIONS(521),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(503),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(501),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(501),
    [aux_sym_preprocessor_token1] = ACTIONS(501),
    [aux_sym_preprocessor_token2] = ACTIONS(501),
    [aux_sym_preprocessor_token3] = ACTIONS(501),
    [aux_sym_preprocessor_token4] = ACTIONS(501),
    [aux_sym_preprocessor_token5] = ACTIONS(501),
    [aux_sym_preprocessor_token6] = ACTIONS(501),
    [aux_sym_preprocessor_token7] = ACTIONS(501),
    [aux_sym_preprocessor_token8] = ACTIONS(501),
    [aux_sym_preprocessor_token9] = ACTIONS(501),
    [aux_sym_preprocessor_token10] = ACTIONS(501),
    [aux_sym_preprocessor_token11] = ACTIONS(501),
    [aux_sym_preprocessor_token12] = ACTIONS(501),
    [aux_sym_preprocessor_token13] = ACTIONS(501),
    [aux_sym_preprocessor_token14] = ACTIONS(501),
    [aux_sym_preprocessor_token15] = ACTIONS(501),
    [aux_sym_preprocessor_token16] = ACTIONS(501),
    [aux_sym_preprocessor_token17] = ACTIONS(503),
    [aux_sym_preprocessor_token18] = ACTIONS(503),
    [aux_sym_preprocessor_token19] = ACTIONS(503),
    [aux_sym_preprocessor_token20] = ACTIONS(503),
    [aux_sym_preprocessor_token21] = ACTIONS(501),
    [aux_sym_preprocessor_token22] = ACTIONS(501),
    [aux_sym_preprocessor_token23] = ACTIONS(501),
    [aux_sym_preprocessor_token24] = ACTIONS(501),
    [aux_sym_preprocessor_token25] = ACTIONS(503),
    [aux_sym_preprocessor_token26] = ACTIONS(503),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(114)] = {
    [sym_line_comment] = STATE(114),
    [aux_sym_var_definition_repeat1] = STATE(114),
    [ts_builtin_sym_end] = ACTIONS(523),
    [sym_identifier] = ACTIONS(525),
    [anon_sym_COMMA] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(523),
    [aux_sym_execute_statement_token1] = ACTIONS(525),
    [anon_sym_TILDE] = ACTIONS(523),
    [sym_IF_KEYWORD] = ACTIONS(525),
    [sym_ELSIF_KEYWORD] = ACTIONS(525),
    [sym_ELSE_KEYWORD] = ACTIONS(525),
    [sym_ENDIF_KEYWORD] = ACTIONS(525),
    [sym_FOR_KEYWORD] = ACTIONS(525),
    [sym_WHILE_KEYWORD] = ACTIONS(525),
    [sym_ENDDO_KEYWORD] = ACTIONS(525),
    [sym_GOTO_KEYWORD] = ACTIONS(525),
    [sym_RETURN_KEYWORD] = ACTIONS(525),
    [sym_BREAK_KEYWORD] = ACTIONS(525),
    [sym_CONTINUE_KEYWORD] = ACTIONS(525),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(525),
    [sym_FUNCTION_KEYWORD] = ACTIONS(525),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(525),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(525),
    [sym_VAR_KEYWORD] = ACTIONS(525),
    [sym_EXPORT_KEYWORD] = ACTIONS(525),
    [sym_TRY_KEYWORD] = ACTIONS(525),
    [sym_EXCEPT_KEYWORD] = ACTIONS(525),
    [sym_RAISE_KEYWORD] = ACTIONS(525),
    [sym_ENDTRY_KEYWORD] = ACTIONS(525),
    [sym_ASYNC_KEYWORD] = ACTIONS(525),
    [sym_AWAIT_KEYWORD] = ACTIONS(525),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(525),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(525),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(523),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(523),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(525),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(523),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(523),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(523),
    [aux_sym_preprocessor_token1] = ACTIONS(523),
    [aux_sym_preprocessor_token2] = ACTIONS(523),
    [aux_sym_preprocessor_token3] = ACTIONS(523),
    [aux_sym_preprocessor_token4] = ACTIONS(523),
    [aux_sym_preprocessor_token5] = ACTIONS(523),
    [aux_sym_preprocessor_token6] = ACTIONS(523),
    [aux_sym_preprocessor_token7] = ACTIONS(523),
    [aux_sym_preprocessor_token8] = ACTIONS(523),
    [aux_sym_preprocessor_token9] = ACTIONS(523),
    [aux_sym_preprocessor_token10] = ACTIONS(523),
    [aux_sym_preprocessor_token11] = ACTIONS(523),
    [aux_sym_preprocessor_token12] = ACTIONS(523),
    [aux_sym_preprocessor_token13] = ACTIONS(523),
    [aux_sym_preprocessor_token14] = ACTIONS(523),
    [aux_sym_preprocessor_token15] = ACTIONS(523),
    [aux_sym_preprocessor_token16] = ACTIONS(523),
    [aux_sym_preprocessor_token17] = ACTIONS(525),
    [aux_sym_preprocessor_token18] = ACTIONS(525),
    [aux_sym_preprocessor_token19] = ACTIONS(525),
    [aux_sym_preprocessor_token20] = ACTIONS(525),
    [aux_sym_preprocessor_token21] = ACTIONS(523),
    [aux_sym_preprocessor_token22] = ACTIONS(523),
    [aux_sym_preprocessor_token23] = ACTIONS(523),
    [aux_sym_preprocessor_token24] = ACTIONS(523),
    [aux_sym_preprocessor_token25] = ACTIONS(525),
    [aux_sym_preprocessor_token26] = ACTIONS(525),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(115)] = {
    [sym_line_comment] = STATE(115),
    [ts_builtin_sym_end] = ACTIONS(530),
    [sym_identifier] = ACTIONS(532),
    [anon_sym_SEMI] = ACTIONS(534),
    [aux_sym_execute_statement_token1] = ACTIONS(532),
    [anon_sym_TILDE] = ACTIONS(530),
    [anon_sym_DOT] = ACTIONS(305),
    [anon_sym_LBRACK] = ACTIONS(305),
    [sym_IF_KEYWORD] = ACTIONS(532),
    [sym_ELSIF_KEYWORD] = ACTIONS(532),
    [sym_ELSE_KEYWORD] = ACTIONS(532),
    [sym_ENDIF_KEYWORD] = ACTIONS(532),
    [sym_FOR_KEYWORD] = ACTIONS(532),
    [sym_WHILE_KEYWORD] = ACTIONS(532),
    [sym_ENDDO_KEYWORD] = ACTIONS(532),
    [sym_GOTO_KEYWORD] = ACTIONS(532),
    [sym_RETURN_KEYWORD] = ACTIONS(532),
    [sym_BREAK_KEYWORD] = ACTIONS(532),
    [sym_CONTINUE_KEYWORD] = ACTIONS(532),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(532),
    [sym_FUNCTION_KEYWORD] = ACTIONS(532),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(532),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(532),
    [sym_VAR_KEYWORD] = ACTIONS(532),
    [sym_TRY_KEYWORD] = ACTIONS(532),
    [sym_EXCEPT_KEYWORD] = ACTIONS(532),
    [sym_RAISE_KEYWORD] = ACTIONS(532),
    [sym_ENDTRY_KEYWORD] = ACTIONS(532),
    [sym_ASYNC_KEYWORD] = ACTIONS(532),
    [sym_AWAIT_KEYWORD] = ACTIONS(532),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(532),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(532),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(530),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(530),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(532),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(530),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(530),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(530),
    [aux_sym_preprocessor_token1] = ACTIONS(530),
    [aux_sym_preprocessor_token2] = ACTIONS(530),
    [aux_sym_preprocessor_token3] = ACTIONS(530),
    [aux_sym_preprocessor_token4] = ACTIONS(530),
    [aux_sym_preprocessor_token5] = ACTIONS(530),
    [aux_sym_preprocessor_token6] = ACTIONS(530),
    [aux_sym_preprocessor_token7] = ACTIONS(530),
    [aux_sym_preprocessor_token8] = ACTIONS(530),
    [aux_sym_preprocessor_token9] = ACTIONS(530),
    [aux_sym_preprocessor_token10] = ACTIONS(530),
    [aux_sym_preprocessor_token11] = ACTIONS(530),
    [aux_sym_preprocessor_token12] = ACTIONS(530),
    [aux_sym_preprocessor_token13] = ACTIONS(530),
    [aux_sym_preprocessor_token14] = ACTIONS(530),
    [aux_sym_preprocessor_token15] = ACTIONS(530),
    [aux_sym_preprocessor_token16] = ACTIONS(530),
    [aux_sym_preprocessor_token17] = ACTIONS(532),
    [aux_sym_preprocessor_token18] = ACTIONS(532),
    [aux_sym_preprocessor_token19] = ACTIONS(532),
    [aux_sym_preprocessor_token20] = ACTIONS(532),
    [aux_sym_preprocessor_token21] = ACTIONS(530),
    [aux_sym_preprocessor_token22] = ACTIONS(530),
    [aux_sym_preprocessor_token23] = ACTIONS(530),
    [aux_sym_preprocessor_token24] = ACTIONS(530),
    [aux_sym_preprocessor_token25] = ACTIONS(532),
    [aux_sym_preprocessor_token26] = ACTIONS(532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
  [STATE(116)] = {
    [sym_line_comment] = STATE(116),
    [ts_builtin_sym_end] = ACTIONS(536),
    [sym_identifier] = ACTIONS(538),
    [anon_sym_COMMA] = ACTIONS(536),
    [anon_sym_SEMI] = ACTIONS(536),
    [aux_sym_execute_statement_token1] = ACTIONS(538),
    [anon_sym_TILDE] = ACTIONS(536),
    [sym_IF_KEYWORD] = ACTIONS(538),
    [sym_ELSIF_KEYWORD] = ACTIONS(538),
    [sym_ELSE_KEYWORD] = ACTIONS(538),
    [sym_ENDIF_KEYWORD] = ACTIONS(538),
    [sym_FOR_KEYWORD] = ACTIONS(538),
    [sym_WHILE_KEYWORD] = ACTIONS(538),
    [sym_ENDDO_KEYWORD] = ACTIONS(538),
    [sym_GOTO_KEYWORD] = ACTIONS(538),
    [sym_RETURN_KEYWORD] = ACTIONS(538),
    [sym_BREAK_KEYWORD] = ACTIONS(538),
    [sym_CONTINUE_KEYWORD] = ACTIONS(538),
    [sym_PROCEDURE_KEYWORD] = ACTIONS(538),
    [sym_FUNCTION_KEYWORD] = ACTIONS(538),
    [sym_ENDPROCEDURE_KEYWORD] = ACTIONS(538),
    [sym_ENDFUNCTION_KEYWORD] = ACTIONS(538),
    [sym_VAR_KEYWORD] = ACTIONS(538),
    [sym_EXPORT_KEYWORD] = ACTIONS(538),
    [sym_TRY_KEYWORD] = ACTIONS(538),
    [sym_EXCEPT_KEYWORD] = ACTIONS(538),
    [sym_RAISE_KEYWORD] = ACTIONS(538),
    [sym_ENDTRY_KEYWORD] = ACTIONS(538),
    [sym_ASYNC_KEYWORD] = ACTIONS(538),
    [sym_AWAIT_KEYWORD] = ACTIONS(538),
    [sym_ADDHANDLER_KEYWORD] = ACTIONS(538),
    [sym_REMOVEHANDLER_KEYWORD] = ACTIONS(538),
    [sym_PREPROC_IF_KEYWORD] = ACTIONS(536),
    [sym_PREPROC_ELSIF_KEYWORD] = ACTIONS(536),
    [sym_PREPROC_ELSE_KEYWORD] = ACTIONS(538),
    [sym_PREPROC_ENDIF_KEYWORD] = ACTIONS(536),
    [sym_PREPROC_REGION_KEYWORD] = ACTIONS(536),
    [sym_PREPROC_ENDREGION_KEYWORD] = ACTIONS(536),
    [aux_sym_preprocessor_token1] = ACTIONS(536),
    [aux_sym_preprocessor_token2] = ACTIONS(536),
    [aux_sym_preprocessor_token3] = ACTIONS(536),
    [aux_sym_preprocessor_token4] = ACTIONS(536),
    [aux_sym_preprocessor_token5] = ACTIONS(536),
    [aux_sym_preprocessor_token6] = ACTIONS(536),
    [aux_sym_preprocessor_token7] = ACTIONS(536),
    [aux_sym_preprocessor_token8] = ACTIONS(536),
    [aux_sym_preprocessor_token9] = ACTIONS(536),
    [aux_sym_preprocessor_token10] = ACTIONS(536),
    [aux_sym_preprocessor_token11] = ACTIONS(536),
    [aux_sym_preprocessor_token12] = ACTIONS(536),
    [aux_sym_preprocessor_token13] = ACTIONS(536),
    [aux_sym_preprocessor_token14] = ACTIONS(536),
    [aux_sym_preprocessor_token15] = ACTIONS(536),
    [aux_sym_preprocessor_token16] = ACTIONS(536),
    [aux_sym_preprocessor_token17] = ACTIONS(538),
    [aux_sym_preprocessor_token18] = ACTIONS(538),
    [aux_sym_preprocessor_token19] = ACTIONS(538),
    [aux_sym_preprocessor_token20] = ACTIONS(538),
    [aux_sym_preprocessor_token21] = ACTIONS(536),
    [aux_sym_preprocessor_token22] = ACTIONS(536),
    [aux_sym_preprocessor_token23] = ACTIONS(536),
    [aux_sym_preprocessor_token24] = ACTIONS(536),
    [aux_sym_preprocessor_token25] = ACTIONS(538),
    [aux_sym_preprocessor_token26] = ACTIONS(538),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(544), 1,
      anon_sym_SEMI,
    STATE(117), 1,
      sym_line_comment,
    ACTIONS(540), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(542), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [74] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(550), 1,
      anon_sym_SEMI,
    STATE(118), 1,
      sym_line_comment,
    ACTIONS(546), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(548), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(556), 1,
      anon_sym_SEMI,
    STATE(119), 1,
      sym_line_comment,
    ACTIONS(552), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(554), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(562), 1,
      anon_sym_SEMI,
    STATE(120), 1,
      sym_line_comment,
    ACTIONS(558), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(560), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(568), 1,
      anon_sym_SEMI,
    STATE(121), 1,
      sym_line_comment,
    ACTIONS(564), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(566), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(574), 1,
      anon_sym_SEMI,
    STATE(122), 1,
      sym_line_comment,
    ACTIONS(570), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(572), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(580), 1,
      anon_sym_SEMI,
    STATE(123), 1,
      sym_line_comment,
    ACTIONS(576), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(578), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(586), 1,
      anon_sym_SEMI,
    STATE(124), 1,
      sym_line_comment,
    ACTIONS(582), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(584), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(592), 1,
      anon_sym_SEMI,
    STATE(125), 1,
      sym_line_comment,
    ACTIONS(588), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(590), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(505), 1,
      anon_sym_SEMI,
    STATE(126), 1,
      sym_line_comment,
    ACTIONS(501), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(503), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [740] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(598), 1,
      anon_sym_SEMI,
    STATE(127), 1,
      sym_line_comment,
    ACTIONS(594), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(596), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(604), 1,
      anon_sym_SEMI,
    STATE(128), 1,
      sym_line_comment,
    ACTIONS(600), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(602), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(610), 1,
      anon_sym_SEMI,
    STATE(129), 1,
      sym_line_comment,
    ACTIONS(606), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(608), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(616), 1,
      anon_sym_SEMI,
    STATE(130), 1,
      sym_line_comment,
    ACTIONS(612), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(614), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(622), 1,
      anon_sym_SEMI,
    STATE(131), 1,
      sym_line_comment,
    ACTIONS(618), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(620), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(534), 1,
      anon_sym_SEMI,
    STATE(132), 1,
      sym_line_comment,
    ACTIONS(530), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(532), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(628), 1,
      anon_sym_SEMI,
    STATE(133), 1,
      sym_line_comment,
    ACTIONS(624), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(626), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(634), 1,
      anon_sym_SEMI,
    STATE(134), 1,
      sym_line_comment,
    ACTIONS(630), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(632), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1332] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(640), 1,
      anon_sym_SEMI,
    STATE(135), 1,
      sym_line_comment,
    ACTIONS(636), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(638), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(136), 1,
      sym_line_comment,
    ACTIONS(642), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(644), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(137), 1,
      sym_line_comment,
    ACTIONS(646), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(648), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(138), 1,
      sym_line_comment,
    ACTIONS(594), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(596), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(139), 1,
      sym_line_comment,
    ACTIONS(650), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(652), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(140), 1,
      sym_line_comment,
    ACTIONS(654), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(656), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(141), 1,
      sym_line_comment,
    ACTIONS(658), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(660), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(142), 1,
      sym_line_comment,
    ACTIONS(662), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(664), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(143), 1,
      sym_line_comment,
    ACTIONS(666), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(668), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [1974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(144), 1,
      sym_line_comment,
    ACTIONS(606), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(608), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(145), 1,
      sym_line_comment,
    ACTIONS(670), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(672), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(146), 1,
      sym_line_comment,
    ACTIONS(540), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(542), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(147), 1,
      sym_line_comment,
    ACTIONS(674), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(676), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(148), 1,
      sym_line_comment,
    ACTIONS(678), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(680), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(149), 1,
      sym_line_comment,
    ACTIONS(624), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(626), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(150), 1,
      sym_line_comment,
    ACTIONS(682), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(684), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(151), 1,
      sym_line_comment,
    ACTIONS(686), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(688), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(152), 1,
      sym_line_comment,
    ACTIONS(690), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(692), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(153), 1,
      sym_line_comment,
    ACTIONS(694), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(696), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(154), 1,
      sym_line_comment,
    ACTIONS(698), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(700), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(155), 1,
      sym_line_comment,
    ACTIONS(702), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(704), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(156), 1,
      sym_line_comment,
    ACTIONS(576), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(578), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(157), 1,
      sym_line_comment,
    ACTIONS(706), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(708), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [2968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(158), 1,
      sym_line_comment,
    ACTIONS(710), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(712), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(159), 1,
      sym_line_comment,
    ACTIONS(714), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(716), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(160), 1,
      sym_line_comment,
    ACTIONS(718), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(720), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(161), 1,
      sym_line_comment,
    ACTIONS(722), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(724), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(162), 1,
      sym_line_comment,
    ACTIONS(726), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(728), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(163), 1,
      sym_line_comment,
    ACTIONS(730), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(732), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(164), 1,
      sym_line_comment,
    ACTIONS(734), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(736), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(165), 1,
      sym_line_comment,
    ACTIONS(738), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(740), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(166), 1,
      sym_line_comment,
    ACTIONS(582), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(584), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(167), 1,
      sym_line_comment,
    ACTIONS(564), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(566), 33,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3678] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(744), 1,
      anon_sym_COMMA,
    ACTIONS(746), 1,
      anon_sym_SEMI,
    STATE(114), 1,
      aux_sym_var_definition_repeat1,
    STATE(168), 1,
      sym_line_comment,
    ACTIONS(748), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(742), 30,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3754] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(744), 1,
      anon_sym_COMMA,
    ACTIONS(752), 1,
      anon_sym_SEMI,
    STATE(168), 1,
      aux_sym_var_definition_repeat1,
    STATE(169), 1,
      sym_line_comment,
    ACTIONS(754), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(750), 30,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3830] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(744), 1,
      anon_sym_COMMA,
    ACTIONS(760), 1,
      anon_sym_SEMI,
    ACTIONS(762), 1,
      sym_EXPORT_KEYWORD,
    STATE(170), 1,
      sym_line_comment,
    STATE(174), 1,
      aux_sym_var_definition_repeat1,
    ACTIONS(758), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(756), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [3905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(171), 1,
      sym_line_comment,
    ACTIONS(766), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(764), 30,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [3972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(172), 1,
      sym_line_comment,
    ACTIONS(770), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(768), 30,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [4039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(173), 1,
      sym_line_comment,
    ACTIONS(774), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
    ACTIONS(772), 30,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_ELSIF_KEYWORD,
      sym_ELSE_KEYWORD,
      sym_ENDIF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_ENDDO_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_EXCEPT_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ENDTRY_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
  [4106] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(744), 1,
      anon_sym_COMMA,
    ACTIONS(780), 1,
      anon_sym_SEMI,
    ACTIONS(782), 1,
      sym_EXPORT_KEYWORD,
    STATE(114), 1,
      aux_sym_var_definition_repeat1,
    STATE(174), 1,
      sym_line_comment,
    ACTIONS(778), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(776), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(788), 1,
      anon_sym_SEMI,
    STATE(175), 1,
      sym_line_comment,
    ACTIONS(786), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(784), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(794), 1,
      anon_sym_SEMI,
    STATE(176), 1,
      sym_line_comment,
    ACTIONS(792), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(790), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(177), 1,
      sym_line_comment,
    ACTIONS(798), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(796), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(178), 1,
      sym_line_comment,
    ACTIONS(802), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(800), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(179), 1,
      sym_line_comment,
    ACTIONS(806), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(804), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(180), 1,
      sym_line_comment,
    ACTIONS(810), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(808), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(181), 1,
      sym_line_comment,
    ACTIONS(814), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(812), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(182), 1,
      sym_line_comment,
    ACTIONS(818), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(816), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(183), 1,
      sym_line_comment,
    ACTIONS(822), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(820), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(184), 1,
      sym_line_comment,
    ACTIONS(826), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(824), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(185), 1,
      sym_line_comment,
    ACTIONS(830), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(828), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(186), 1,
      sym_line_comment,
    ACTIONS(834), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(832), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [4943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(187), 1,
      sym_line_comment,
    ACTIONS(838), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(836), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(188), 1,
      sym_line_comment,
    ACTIONS(842), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(840), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(189), 1,
      sym_line_comment,
    ACTIONS(846), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(844), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(190), 1,
      sym_line_comment,
    ACTIONS(850), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(848), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(191), 1,
      sym_line_comment,
    ACTIONS(854), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(852), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(192), 1,
      sym_line_comment,
    ACTIONS(858), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(856), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(193), 1,
      sym_line_comment,
    ACTIONS(862), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(860), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(194), 1,
      sym_line_comment,
    ACTIONS(866), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(864), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(195), 1,
      sym_line_comment,
    ACTIONS(870), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(868), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(196), 1,
      sym_line_comment,
    ACTIONS(874), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(872), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(197), 1,
      sym_line_comment,
    ACTIONS(878), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(876), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(198), 1,
      sym_line_comment,
    ACTIONS(882), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_PROCEDURE_KEYWORD,
      sym_FUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_ASYNC_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(880), 27,
      ts_builtin_sym_end,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(199), 1,
      sym_line_comment,
    ACTIONS(884), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_EXPORT_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(886), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(200), 1,
      sym_line_comment,
    ACTIONS(888), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_EXPORT_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(890), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(201), 1,
      sym_line_comment,
    ACTIONS(892), 25,
      aux_sym_execute_statement_token1,
      sym_IF_KEYWORD,
      sym_FOR_KEYWORD,
      sym_WHILE_KEYWORD,
      sym_GOTO_KEYWORD,
      sym_RETURN_KEYWORD,
      sym_BREAK_KEYWORD,
      sym_CONTINUE_KEYWORD,
      sym_ENDPROCEDURE_KEYWORD,
      sym_ENDFUNCTION_KEYWORD,
      sym_VAR_KEYWORD,
      sym_EXPORT_KEYWORD,
      sym_TRY_KEYWORD,
      sym_RAISE_KEYWORD,
      sym_AWAIT_KEYWORD,
      sym_ADDHANDLER_KEYWORD,
      sym_REMOVEHANDLER_KEYWORD,
      sym_PREPROC_ELSE_KEYWORD,
      aux_sym_preprocessor_token17,
      aux_sym_preprocessor_token18,
      aux_sym_preprocessor_token19,
      aux_sym_preprocessor_token20,
      aux_sym_preprocessor_token25,
      aux_sym_preprocessor_token26,
      sym_identifier,
    ACTIONS(894), 26,
      anon_sym_TILDE,
      sym_PREPROC_IF_KEYWORD,
      sym_PREPROC_ELSIF_KEYWORD,
      sym_PREPROC_ENDIF_KEYWORD,
      sym_PREPROC_REGION_KEYWORD,
      sym_PREPROC_ENDREGION_KEYWORD,
      aux_sym_preprocessor_token1,
      aux_sym_preprocessor_token2,
      aux_sym_preprocessor_token3,
      aux_sym_preprocessor_token4,
      aux_sym_preprocessor_token5,
      aux_sym_preprocessor_token6,
      aux_sym_preprocessor_token7,
      aux_sym_preprocessor_token8,
      aux_sym_preprocessor_token9,
      aux_sym_preprocessor_token10,
      aux_sym_preprocessor_token11,
      aux_sym_preprocessor_token12,
      aux_sym_preprocessor_token13,
      aux_sym_preprocessor_token14,
      aux_sym_preprocessor_token15,
      aux_sym_preprocessor_token16,
      aux_sym_preprocessor_token21,
      aux_sym_preprocessor_token22,
      aux_sym_preprocessor_token23,
      aux_sym_preprocessor_token24,
  [5885] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(898), 1,
      anon_sym_RPAREN,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(202), 1,
      sym_line_comment,
    STATE(281), 1,
      sym_expression,
    STATE(344), 1,
      aux_sym_arguments_repeat1,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [5969] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(900), 1,
      anon_sym_RPAREN,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(203), 1,
      sym_line_comment,
    STATE(282), 1,
      sym_expression,
    STATE(341), 1,
      aux_sym_arguments_repeat1,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6053] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(902), 1,
      anon_sym_RPAREN,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(204), 1,
      sym_line_comment,
    STATE(283), 1,
      sym_expression,
    STATE(348), 1,
      aux_sym_arguments_repeat1,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6137] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(113), 1,
      sym_expression,
    STATE(126), 1,
      sym_arguments,
    STATE(205), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6218] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(206), 1,
      sym_line_comment,
    STATE(299), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    ACTIONS(904), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6297] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(79), 1,
      sym_expression,
    STATE(126), 1,
      sym_arguments,
    STATE(207), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6378] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    ACTIONS(906), 1,
      anon_sym_LPAREN,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(71), 1,
      sym_expression,
    STATE(208), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6456] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    ACTIONS(906), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(111), 1,
      sym_expression,
    STATE(209), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6534] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(99), 1,
      sym_expression,
    STATE(210), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6609] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(211), 1,
      sym_line_comment,
    STATE(326), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6684] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(72), 1,
      sym_expression,
    STATE(212), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6759] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(76), 1,
      sym_expression,
    STATE(213), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6834] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(214), 1,
      sym_line_comment,
    STATE(327), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6909] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(215), 1,
      sym_line_comment,
    STATE(303), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [6984] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(216), 1,
      sym_line_comment,
    STATE(308), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7059] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(217), 1,
      sym_line_comment,
    STATE(309), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7134] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(218), 1,
      sym_line_comment,
    STATE(318), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7209] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(219), 1,
      sym_line_comment,
    STATE(311), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7284] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(220), 1,
      sym_line_comment,
    STATE(305), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7359] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(78), 1,
      sym_expression,
    STATE(221), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7434] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(222), 1,
      sym_line_comment,
    STATE(306), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7509] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(70), 1,
      sym_expression,
    STATE(223), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7584] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(224), 1,
      sym_line_comment,
    STATE(322), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7659] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(108), 1,
      sym_expression,
    STATE(225), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7734] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(100), 1,
      sym_expression,
    STATE(226), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7809] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(92), 1,
      sym_expression,
    STATE(98), 1,
      sym__const_value,
    STATE(227), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7884] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(93), 1,
      sym_expression,
    STATE(98), 1,
      sym__const_value,
    STATE(228), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [7959] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(103), 1,
      sym_expression,
    STATE(229), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8034] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(106), 1,
      sym_expression,
    STATE(230), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8109] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(94), 1,
      sym_expression,
    STATE(98), 1,
      sym__const_value,
    STATE(231), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8184] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(110), 1,
      sym_expression,
    STATE(232), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8259] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(109), 1,
      sym_expression,
    STATE(233), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8334] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(58), 1,
      sym_expression,
    STATE(234), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8409] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(73), 1,
      sym_expression,
    STATE(235), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8484] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(236), 1,
      sym_line_comment,
    STATE(323), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8559] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(60), 1,
      sym_expression,
    STATE(237), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8634] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(61), 1,
      sym_expression,
    STATE(238), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8709] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(63), 1,
      sym_expression,
    STATE(239), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8784] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(64), 1,
      sym_expression,
    STATE(240), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8859] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(65), 1,
      sym_expression,
    STATE(241), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [8934] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(242), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(301), 1,
      sym__const_value,
    STATE(304), 1,
      sym_expression,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9009] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(243), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(285), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9084] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(244), 1,
      sym_line_comment,
    STATE(325), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9159] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(245), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(291), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9234] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(246), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(293), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9309] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(247), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(284), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9384] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(248), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(296), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9459] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(249), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(298), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9534] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(250), 1,
      sym_line_comment,
    STATE(312), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9609] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(251), 1,
      sym_line_comment,
    STATE(307), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9684] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(67), 1,
      sym_expression,
    STATE(252), 1,
      sym_line_comment,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9759] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(253), 1,
      sym_line_comment,
    STATE(314), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9834] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(98), 1,
      sym__const_value,
    STATE(107), 1,
      sym_expression,
    STATE(254), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9909] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(255), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(286), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [9984] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(246), 1,
      sym_identifier,
    ACTIONS(250), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(256), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(258), 1,
      sym_NEW_KEYWORD,
    ACTIONS(260), 1,
      sym_NOT_KEYWORD,
    ACTIONS(262), 1,
      sym_date,
    ACTIONS(264), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym__access_call,
    STATE(82), 1,
      sym_method_call,
    STATE(91), 1,
      sym_expression,
    STATE(98), 1,
      sym__const_value,
    STATE(256), 1,
      sym_line_comment,
    STATE(369), 1,
      sym_access,
    ACTIONS(248), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(252), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(81), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(254), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(96), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(97), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10059] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(918), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(920), 1,
      sym_NEW_KEYWORD,
    ACTIONS(922), 1,
      sym_NOT_KEYWORD,
    ACTIONS(924), 1,
      sym_date,
    ACTIONS(926), 1,
      anon_sym_DQUOTE,
    STATE(257), 1,
      sym_line_comment,
    STATE(271), 1,
      sym__access_call,
    STATE(280), 1,
      sym_method_call,
    STATE(300), 1,
      sym_expression,
    STATE(301), 1,
      sym__const_value,
    STATE(372), 1,
      sym_access,
    ACTIONS(910), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(914), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(275), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(916), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(290), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(297), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10134] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(258), 1,
      sym_line_comment,
    STATE(328), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10209] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(259), 1,
      sym_line_comment,
    STATE(313), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10284] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(260), 1,
      sym_line_comment,
    STATE(315), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10359] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(261), 1,
      sym_line_comment,
    STATE(316), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10434] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(262), 1,
      sym_line_comment,
    STATE(317), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10509] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(263), 1,
      sym_line_comment,
    STATE(319), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10584] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(264), 1,
      sym_line_comment,
    STATE(320), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10659] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(265), 1,
      sym_line_comment,
    STATE(321), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10734] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(266), 1,
      sym_line_comment,
    STATE(324), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10809] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(267), 1,
      sym_line_comment,
    STATE(302), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10884] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(57), 1,
      sym_identifier,
    ACTIONS(65), 1,
      anon_sym_QMARK_LPAREN,
    ACTIONS(71), 1,
      sym_AWAIT_KEYWORD,
    ACTIONS(73), 1,
      sym_NEW_KEYWORD,
    ACTIONS(75), 1,
      sym_NOT_KEYWORD,
    ACTIONS(77), 1,
      sym_date,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(45), 1,
      sym__access_call,
    STATE(46), 1,
      sym_method_call,
    STATE(57), 1,
      sym__const_value,
    STATE(268), 1,
      sym_line_comment,
    STATE(310), 1,
      sym_expression,
    STATE(363), 1,
      sym_access,
    ACTIONS(63), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(67), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(44), 2,
      sym__access_index,
      sym__access_property,
    ACTIONS(69), 3,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    STATE(68), 8,
      sym_unary_expression,
      sym_binary_expression,
      sym_ternary_expression,
      sym_new_expression,
      sym_new_expression_method,
      sym_call_expression,
      sym_await_expression,
      sym_property_access,
  [10959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    STATE(269), 1,
      sym_line_comment,
    STATE(272), 1,
      sym_arguments,
    ACTIONS(313), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(311), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [10993] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    STATE(270), 1,
      sym_line_comment,
    STATE(272), 1,
      sym_arguments,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
    ACTIONS(301), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(299), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(271), 1,
      sym_line_comment,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
    ACTIONS(375), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(373), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(272), 1,
      sym_line_comment,
    ACTIONS(403), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(401), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11087] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(273), 1,
      sym_line_comment,
    ACTIONS(387), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(385), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(274), 1,
      sym_line_comment,
    ACTIONS(395), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(393), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(275), 1,
      sym_line_comment,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
    ACTIONS(371), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(369), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(276), 1,
      sym_line_comment,
    ACTIONS(379), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(377), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11201] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    STATE(277), 1,
      sym_line_comment,
    STATE(288), 1,
      sym_arguments,
    ACTIONS(399), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(397), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(278), 1,
      sym_line_comment,
    ACTIONS(383), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(381), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(279), 1,
      sym_line_comment,
    ACTIONS(391), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(389), 13,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(280), 1,
      sym_line_comment,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
    ACTIONS(301), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(299), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11319] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(930), 1,
      anon_sym_RPAREN,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    STATE(281), 1,
      sym_line_comment,
    STATE(349), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11362] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(934), 1,
      anon_sym_RPAREN,
    STATE(282), 1,
      sym_line_comment,
    STATE(343), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11405] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(936), 1,
      anon_sym_RPAREN,
    STATE(283), 1,
      sym_line_comment,
    STATE(351), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(284), 1,
      sym_line_comment,
    ACTIONS(433), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(431), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(938), 1,
      anon_sym_COMMA,
    STATE(285), 1,
      sym_line_comment,
    ACTIONS(423), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(421), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(286), 1,
      sym_line_comment,
    ACTIONS(465), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(463), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(287), 1,
      sym_line_comment,
    ACTIONS(411), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(409), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(288), 1,
      sym_line_comment,
    ACTIONS(429), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(427), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(289), 1,
      sym_line_comment,
    ACTIONS(407), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(405), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(290), 1,
      sym_line_comment,
    ACTIONS(415), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(413), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11632] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(944), 1,
      anon_sym_SLASH,
    STATE(291), 1,
      sym_line_comment,
    ACTIONS(940), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(942), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(433), 3,
      anon_sym_GT,
      anon_sym_LT,
      sym_AND_KEYWORD,
    ACTIONS(431), 7,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11664] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(292), 1,
      sym_line_comment,
    ACTIONS(461), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(459), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11690] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(944), 1,
      anon_sym_SLASH,
    STATE(293), 1,
      sym_line_comment,
    ACTIONS(942), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(433), 3,
      anon_sym_GT,
      anon_sym_LT,
      sym_AND_KEYWORD,
    ACTIONS(431), 9,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(294), 1,
      sym_line_comment,
    ACTIONS(443), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(441), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(295), 1,
      sym_line_comment,
    ACTIONS(453), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(451), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11772] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(433), 1,
      sym_AND_KEYWORD,
    ACTIONS(944), 1,
      anon_sym_SLASH,
    STATE(296), 1,
      sym_line_comment,
    ACTIONS(940), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(942), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(948), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(431), 3,
      anon_sym_COMMA,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
    ACTIONS(946), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(297), 1,
      sym_line_comment,
    ACTIONS(301), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(299), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11834] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(944), 1,
      anon_sym_SLASH,
    ACTIONS(950), 1,
      sym_AND_KEYWORD,
    STATE(298), 1,
      sym_line_comment,
    ACTIONS(940), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(942), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(948), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(431), 3,
      anon_sym_COMMA,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
    ACTIONS(946), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11870] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    STATE(299), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(952), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(300), 1,
      sym_line_comment,
    ACTIONS(457), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(455), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(301), 1,
      sym_line_comment,
    ACTIONS(419), 4,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      sym_AND_KEYWORD,
    ACTIONS(417), 11,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR,
      anon_sym_PERCENT,
      sym_TO_KEYWORD,
      sym_OR_KEYWORD,
  [11960] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(954), 1,
      anon_sym_COMMA,
    STATE(302), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [11997] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(956), 1,
      anon_sym_RPAREN,
    STATE(303), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12034] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(944), 1,
      anon_sym_SLASH,
    ACTIONS(950), 1,
      sym_AND_KEYWORD,
    ACTIONS(958), 1,
      sym_TO_KEYWORD,
    ACTIONS(960), 1,
      sym_OR_KEYWORD,
    STATE(304), 1,
      sym_line_comment,
    ACTIONS(940), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(942), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(948), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(946), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12071] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(962), 1,
      anon_sym_RPAREN,
    STATE(305), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12108] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(964), 1,
      anon_sym_RBRACK,
    STATE(306), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12145] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(966), 1,
      anon_sym_RPAREN,
    STATE(307), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12182] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(968), 1,
      anon_sym_COMMA,
    STATE(308), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12219] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(970), 1,
      sym_THEN_KEYWORD,
    STATE(309), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12256] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(972), 1,
      sym_THEN_KEYWORD,
    STATE(310), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12293] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(974), 1,
      sym_DO_KEYWORD,
    STATE(311), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12330] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(976), 1,
      sym_THEN_KEYWORD,
    STATE(312), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12367] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(978), 1,
      anon_sym_COMMA,
    STATE(313), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12404] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(980), 1,
      sym_DO_KEYWORD,
    STATE(314), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12441] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(982), 1,
      anon_sym_RBRACK,
    STATE(315), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12478] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(984), 1,
      anon_sym_RPAREN,
    STATE(316), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12515] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(986), 1,
      anon_sym_RPAREN,
    STATE(317), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12552] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(988), 1,
      sym_DO_KEYWORD,
    STATE(318), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12589] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
    STATE(319), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12626] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(992), 1,
      anon_sym_RPAREN,
    STATE(320), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12663] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    STATE(321), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12700] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(996), 1,
      anon_sym_COMMA,
    STATE(322), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12737] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(998), 1,
      anon_sym_COMMA,
    STATE(323), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12774] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(1000), 1,
      anon_sym_COMMA,
    STATE(324), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12811] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(1002), 1,
      anon_sym_COMMA,
    STATE(325), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12848] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(1004), 1,
      anon_sym_COMMA,
    STATE(326), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12885] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(1006), 1,
      anon_sym_COMMA,
    STATE(327), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12922] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(439), 1,
      anon_sym_SLASH,
    ACTIONS(449), 1,
      sym_AND_KEYWORD,
    ACTIONS(932), 1,
      sym_OR_KEYWORD,
    ACTIONS(1008), 1,
      anon_sym_COMMA,
    STATE(328), 1,
      sym_line_comment,
    ACTIONS(435), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(437), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(447), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(445), 4,
      anon_sym_EQ,
      anon_sym_LT_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [12959] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(329), 1,
      sym_line_comment,
    STATE(379), 1,
      sym__const_value,
    ACTIONS(1010), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    ACTIONS(77), 4,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
      sym_date,
  [12987] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(79), 1,
      anon_sym_DQUOTE,
    STATE(330), 1,
      sym_line_comment,
    STATE(359), 1,
      sym__const_value,
    ACTIONS(1010), 2,
      sym_TRUE_KEYWORD,
      sym_FALSE_KEYWORD,
    STATE(56), 3,
      sym_boolean,
      sym_string,
      sym_multiline_string,
    ACTIONS(77), 4,
      sym_UNDEFINED_KEYWORD,
      sym_NULL_KEYWORD,
      sym_number,
      sym_date,
  [13015] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(163), 1,
      sym_ELSE_KEYWORD,
    ACTIONS(1012), 1,
      sym_ELSIF_KEYWORD,
    ACTIONS(1014), 1,
      sym_ENDIF_KEYWORD,
    STATE(331), 1,
      sym_line_comment,
    STATE(334), 1,
      aux_sym_if_statement_repeat1,
    STATE(357), 1,
      sym_elseif_clause,
    STATE(408), 1,
      sym_else_clause,
  [13040] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(163), 1,
      sym_ELSE_KEYWORD,
    ACTIONS(1012), 1,
      sym_ELSIF_KEYWORD,
    ACTIONS(1016), 1,
      sym_ENDIF_KEYWORD,
    STATE(332), 1,
      sym_line_comment,
    STATE(334), 1,
      aux_sym_if_statement_repeat1,
    STATE(357), 1,
      sym_elseif_clause,
    STATE(411), 1,
      sym_else_clause,
  [13065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    ACTIONS(1018), 1,
      anon_sym_EQ,
    STATE(83), 1,
      sym_arguments,
    STATE(333), 1,
      sym_line_comment,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
  [13085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1020), 1,
      sym_ELSIF_KEYWORD,
    ACTIONS(1023), 1,
      sym_ELSE_KEYWORD,
    ACTIONS(1025), 1,
      sym_ENDIF_KEYWORD,
    STATE(357), 1,
      sym_elseif_clause,
    STATE(334), 2,
      sym_line_comment,
      aux_sym_if_statement_repeat1,
  [13105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(303), 1,
      anon_sym_LPAREN,
    ACTIONS(1018), 1,
      anon_sym_EQ,
    STATE(53), 1,
      sym_arguments,
    STATE(335), 1,
      sym_line_comment,
    ACTIONS(305), 2,
      anon_sym_DOT,
      anon_sym_LBRACK,
  [13125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(487), 1,
      anon_sym_LPAREN,
    STATE(83), 1,
      sym_arguments,
    STATE(336), 1,
      sym_line_comment,
    ACTIONS(311), 3,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_LBRACK,
  [13143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1027), 1,
      sym_identifier,
    ACTIONS(1029), 1,
      anon_sym_RPAREN,
    ACTIONS(1031), 1,
      sym_VAL_KEYWORD,
    STATE(337), 1,
      sym_line_comment,
    STATE(353), 1,
      sym_parameter,
  [13162] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1033), 1,
      anon_sym_DQUOTE,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    STATE(338), 1,
      sym_line_comment,
    STATE(345), 1,
      aux_sym_multiline_string_repeat1,
  [13178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    ACTIONS(1037), 1,
      anon_sym_DQUOTE,
    STATE(339), 1,
      sym_line_comment,
    STATE(342), 1,
      aux_sym_multiline_string_repeat1,
  [13194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1027), 1,
      sym_identifier,
    ACTIONS(1031), 1,
      sym_VAL_KEYWORD,
    STATE(340), 1,
      sym_line_comment,
    STATE(374), 1,
      sym_parameter,
  [13210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(934), 1,
      anon_sym_RPAREN,
    STATE(341), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    ACTIONS(1039), 1,
      anon_sym_DQUOTE,
    STATE(342), 1,
      sym_line_comment,
    STATE(345), 1,
      aux_sym_multiline_string_repeat1,
  [13242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(1041), 1,
      anon_sym_RPAREN,
    STATE(343), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(930), 1,
      anon_sym_RPAREN,
    STATE(344), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13274] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1043), 1,
      anon_sym_DQUOTE,
    ACTIONS(1045), 1,
      anon_sym_PIPE,
    STATE(345), 2,
      sym_line_comment,
      aux_sym_multiline_string_repeat1,
  [13288] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1050), 1,
      anon_sym_EQ,
    STATE(346), 1,
      sym_line_comment,
    ACTIONS(1048), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    ACTIONS(1052), 1,
      anon_sym_DQUOTE,
    STATE(347), 1,
      sym_line_comment,
    STATE(358), 1,
      aux_sym_multiline_string_repeat1,
  [13318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(936), 1,
      anon_sym_RPAREN,
    STATE(348), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(1054), 1,
      anon_sym_RPAREN,
    STATE(349), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    ACTIONS(1056), 1,
      anon_sym_DQUOTE,
    STATE(338), 1,
      aux_sym_multiline_string_repeat1,
    STATE(350), 1,
      sym_line_comment,
  [13366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(896), 1,
      anon_sym_COMMA,
    ACTIONS(1058), 1,
      anon_sym_RPAREN,
    STATE(351), 1,
      sym_line_comment,
    STATE(352), 1,
      aux_sym_arguments_repeat1,
  [13382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(952), 1,
      anon_sym_RPAREN,
    ACTIONS(1060), 1,
      anon_sym_COMMA,
    STATE(352), 2,
      sym_line_comment,
      aux_sym_arguments_repeat1,
  [13396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1063), 1,
      anon_sym_COMMA,
    ACTIONS(1065), 1,
      anon_sym_RPAREN,
    STATE(353), 1,
      sym_line_comment,
    STATE(355), 1,
      aux_sym_parameters_repeat1,
  [13412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1067), 1,
      anon_sym_COMMA,
    ACTIONS(1070), 1,
      anon_sym_RPAREN,
    STATE(354), 2,
      sym_line_comment,
      aux_sym_parameters_repeat1,
  [13426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1063), 1,
      anon_sym_COMMA,
    ACTIONS(1072), 1,
      anon_sym_RPAREN,
    STATE(354), 1,
      aux_sym_parameters_repeat1,
    STATE(355), 1,
      sym_line_comment,
  [13442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1076), 1,
      anon_sym_EQ,
    STATE(356), 1,
      sym_line_comment,
    ACTIONS(1074), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1080), 1,
      sym_ELSE_KEYWORD,
    STATE(357), 1,
      sym_line_comment,
    ACTIONS(1078), 2,
      sym_ELSIF_KEYWORD,
      sym_ENDIF_KEYWORD,
  [13470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1035), 1,
      anon_sym_PIPE,
    ACTIONS(1082), 1,
      anon_sym_DQUOTE,
    STATE(345), 1,
      aux_sym_multiline_string_repeat1,
    STATE(358), 1,
      sym_line_comment,
  [13486] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(359), 1,
      sym_line_comment,
    ACTIONS(1084), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1086), 1,
      sym_identifier,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    STATE(360), 1,
      sym_line_comment,
  [13510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1090), 1,
      sym_PROCEDURE_KEYWORD,
    ACTIONS(1092), 1,
      sym_FUNCTION_KEYWORD,
    STATE(361), 1,
      sym_line_comment,
  [13523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1094), 1,
      sym_identifier,
    STATE(86), 1,
      sym_method_call,
    STATE(362), 1,
      sym_line_comment,
  [13536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1096), 1,
      anon_sym_DOT,
    ACTIONS(1098), 1,
      anon_sym_LBRACK,
    STATE(363), 1,
      sym_line_comment,
  [13549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1100), 1,
      sym_identifier,
    STATE(274), 1,
      sym_method_call,
    STATE(364), 1,
      sym_line_comment,
  [13562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1104), 1,
      anon_sym_LPAREN,
    STATE(365), 1,
      sym_line_comment,
  [13575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    STATE(15), 1,
      sym_parameters,
    STATE(366), 1,
      sym_line_comment,
  [13588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1098), 1,
      anon_sym_LBRACK,
    ACTIONS(1108), 1,
      anon_sym_DOT,
    STATE(367), 1,
      sym_line_comment,
  [13601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1110), 1,
      sym_identifier,
    STATE(51), 1,
      sym_method_call,
    STATE(368), 1,
      sym_line_comment,
  [13614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1112), 1,
      anon_sym_DOT,
    ACTIONS(1114), 1,
      anon_sym_LBRACK,
    STATE(369), 1,
      sym_line_comment,
  [13627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1116), 1,
      sym_identifier,
    ACTIONS(1118), 1,
      sym_EACH_KEYWORD,
    STATE(370), 1,
      sym_line_comment,
  [13640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1120), 1,
      sym_identifier,
    ACTIONS(1122), 1,
      anon_sym_LPAREN,
    STATE(371), 1,
      sym_line_comment,
  [13653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1124), 1,
      anon_sym_DOT,
    ACTIONS(1126), 1,
      anon_sym_LBRACK,
    STATE(372), 1,
      sym_line_comment,
  [13666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    STATE(13), 1,
      sym_parameters,
    STATE(373), 1,
      sym_line_comment,
  [13679] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(374), 1,
      sym_line_comment,
    ACTIONS(1128), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13690] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(375), 1,
      sym_line_comment,
    ACTIONS(1043), 2,
      anon_sym_DQUOTE,
      anon_sym_PIPE,
  [13701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    STATE(12), 1,
      sym_parameters,
    STATE(376), 1,
      sym_line_comment,
  [13714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1130), 1,
      anon_sym_DQUOTE,
    STATE(377), 1,
      sym_line_comment,
    STATE(406), 1,
      sym_string,
  [13727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    STATE(17), 1,
      sym_parameters,
    STATE(378), 1,
      sym_line_comment,
  [13740] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    STATE(379), 1,
      sym_line_comment,
    ACTIONS(1132), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [13751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1134), 1,
      sym_identifier,
    STATE(86), 1,
      sym_method_call,
    STATE(380), 1,
      sym_line_comment,
  [13764] = 3,
    ACTIONS(1136), 1,
      aux_sym_string_token1,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    STATE(381), 1,
      sym_line_comment,
  [13774] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1140), 1,
      anon_sym_EQ,
    STATE(382), 1,
      sym_line_comment,
  [13784] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1142), 1,
      ts_builtin_sym_end,
    STATE(383), 1,
      sym_line_comment,
  [13794] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1056), 1,
      anon_sym_DQUOTE,
    STATE(384), 1,
      sym_line_comment,
  [13804] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1144), 1,
      anon_sym_TILDE,
    STATE(385), 1,
      sym_line_comment,
  [13814] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1018), 1,
      anon_sym_EQ,
    STATE(386), 1,
      sym_line_comment,
  [13824] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1146), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym_line_comment,
  [13834] = 3,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1148), 1,
      aux_sym_line_comment_token1,
    STATE(388), 1,
      sym_line_comment,
  [13844] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1150), 1,
      sym_identifier,
    STATE(389), 1,
      sym_line_comment,
  [13854] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_line_comment,
  [13864] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1154), 1,
      sym_identifier,
    STATE(391), 1,
      sym_line_comment,
  [13874] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1156), 1,
      sym_IN_KEYWORD,
    STATE(392), 1,
      sym_line_comment,
  [13884] = 3,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1158), 1,
      aux_sym_string_token1,
    STATE(393), 1,
      sym_line_comment,
  [13894] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1014), 1,
      sym_ENDIF_KEYWORD,
    STATE(394), 1,
      sym_line_comment,
  [13904] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1160), 1,
      sym_identifier,
    STATE(395), 1,
      sym_line_comment,
  [13914] = 3,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1162), 1,
      aux_sym_string_token1,
    STATE(396), 1,
      sym_line_comment,
  [13924] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1164), 1,
      sym_identifier,
    STATE(397), 1,
      sym_line_comment,
  [13934] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1166), 1,
      sym_identifier,
    STATE(398), 1,
      sym_line_comment,
  [13944] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1168), 1,
      sym_identifier,
    STATE(399), 1,
      sym_line_comment,
  [13954] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1170), 1,
      anon_sym_EQ,
    STATE(400), 1,
      sym_line_comment,
  [13964] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1172), 1,
      sym_identifier,
    STATE(401), 1,
      sym_line_comment,
  [13974] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1174), 1,
      sym_identifier,
    STATE(402), 1,
      sym_line_comment,
  [13984] = 3,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1176), 1,
      aux_sym_string_token1,
    STATE(403), 1,
      sym_line_comment,
  [13994] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1178), 1,
      sym_identifier,
    STATE(404), 1,
      sym_line_comment,
  [14004] = 3,
    ACTIONS(1138), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1180), 1,
      aux_sym_string_token1,
    STATE(405), 1,
      sym_line_comment,
  [14014] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(406), 1,
      sym_line_comment,
  [14024] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1184), 1,
      anon_sym_COLON,
    STATE(407), 1,
      sym_line_comment,
  [14034] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1016), 1,
      sym_ENDIF_KEYWORD,
    STATE(408), 1,
      sym_line_comment,
  [14044] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1186), 1,
      sym_identifier,
    STATE(409), 1,
      sym_line_comment,
  [14054] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1188), 1,
      sym_identifier,
    STATE(410), 1,
      sym_line_comment,
  [14064] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1190), 1,
      sym_ENDIF_KEYWORD,
    STATE(411), 1,
      sym_line_comment,
  [14074] = 3,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(1192), 1,
      sym_identifier,
    STATE(412), 1,
      sym_line_comment,
  [14084] = 1,
    ACTIONS(1194), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(117)] = 0,
  [SMALL_STATE(118)] = 74,
  [SMALL_STATE(119)] = 148,
  [SMALL_STATE(120)] = 222,
  [SMALL_STATE(121)] = 296,
  [SMALL_STATE(122)] = 370,
  [SMALL_STATE(123)] = 444,
  [SMALL_STATE(124)] = 518,
  [SMALL_STATE(125)] = 592,
  [SMALL_STATE(126)] = 666,
  [SMALL_STATE(127)] = 740,
  [SMALL_STATE(128)] = 814,
  [SMALL_STATE(129)] = 888,
  [SMALL_STATE(130)] = 962,
  [SMALL_STATE(131)] = 1036,
  [SMALL_STATE(132)] = 1110,
  [SMALL_STATE(133)] = 1184,
  [SMALL_STATE(134)] = 1258,
  [SMALL_STATE(135)] = 1332,
  [SMALL_STATE(136)] = 1406,
  [SMALL_STATE(137)] = 1477,
  [SMALL_STATE(138)] = 1548,
  [SMALL_STATE(139)] = 1619,
  [SMALL_STATE(140)] = 1690,
  [SMALL_STATE(141)] = 1761,
  [SMALL_STATE(142)] = 1832,
  [SMALL_STATE(143)] = 1903,
  [SMALL_STATE(144)] = 1974,
  [SMALL_STATE(145)] = 2045,
  [SMALL_STATE(146)] = 2116,
  [SMALL_STATE(147)] = 2187,
  [SMALL_STATE(148)] = 2258,
  [SMALL_STATE(149)] = 2329,
  [SMALL_STATE(150)] = 2400,
  [SMALL_STATE(151)] = 2471,
  [SMALL_STATE(152)] = 2542,
  [SMALL_STATE(153)] = 2613,
  [SMALL_STATE(154)] = 2684,
  [SMALL_STATE(155)] = 2755,
  [SMALL_STATE(156)] = 2826,
  [SMALL_STATE(157)] = 2897,
  [SMALL_STATE(158)] = 2968,
  [SMALL_STATE(159)] = 3039,
  [SMALL_STATE(160)] = 3110,
  [SMALL_STATE(161)] = 3181,
  [SMALL_STATE(162)] = 3252,
  [SMALL_STATE(163)] = 3323,
  [SMALL_STATE(164)] = 3394,
  [SMALL_STATE(165)] = 3465,
  [SMALL_STATE(166)] = 3536,
  [SMALL_STATE(167)] = 3607,
  [SMALL_STATE(168)] = 3678,
  [SMALL_STATE(169)] = 3754,
  [SMALL_STATE(170)] = 3830,
  [SMALL_STATE(171)] = 3905,
  [SMALL_STATE(172)] = 3972,
  [SMALL_STATE(173)] = 4039,
  [SMALL_STATE(174)] = 4106,
  [SMALL_STATE(175)] = 4181,
  [SMALL_STATE(176)] = 4247,
  [SMALL_STATE(177)] = 4313,
  [SMALL_STATE(178)] = 4376,
  [SMALL_STATE(179)] = 4439,
  [SMALL_STATE(180)] = 4502,
  [SMALL_STATE(181)] = 4565,
  [SMALL_STATE(182)] = 4628,
  [SMALL_STATE(183)] = 4691,
  [SMALL_STATE(184)] = 4754,
  [SMALL_STATE(185)] = 4817,
  [SMALL_STATE(186)] = 4880,
  [SMALL_STATE(187)] = 4943,
  [SMALL_STATE(188)] = 5006,
  [SMALL_STATE(189)] = 5069,
  [SMALL_STATE(190)] = 5132,
  [SMALL_STATE(191)] = 5195,
  [SMALL_STATE(192)] = 5258,
  [SMALL_STATE(193)] = 5321,
  [SMALL_STATE(194)] = 5384,
  [SMALL_STATE(195)] = 5447,
  [SMALL_STATE(196)] = 5510,
  [SMALL_STATE(197)] = 5573,
  [SMALL_STATE(198)] = 5636,
  [SMALL_STATE(199)] = 5699,
  [SMALL_STATE(200)] = 5761,
  [SMALL_STATE(201)] = 5823,
  [SMALL_STATE(202)] = 5885,
  [SMALL_STATE(203)] = 5969,
  [SMALL_STATE(204)] = 6053,
  [SMALL_STATE(205)] = 6137,
  [SMALL_STATE(206)] = 6218,
  [SMALL_STATE(207)] = 6297,
  [SMALL_STATE(208)] = 6378,
  [SMALL_STATE(209)] = 6456,
  [SMALL_STATE(210)] = 6534,
  [SMALL_STATE(211)] = 6609,
  [SMALL_STATE(212)] = 6684,
  [SMALL_STATE(213)] = 6759,
  [SMALL_STATE(214)] = 6834,
  [SMALL_STATE(215)] = 6909,
  [SMALL_STATE(216)] = 6984,
  [SMALL_STATE(217)] = 7059,
  [SMALL_STATE(218)] = 7134,
  [SMALL_STATE(219)] = 7209,
  [SMALL_STATE(220)] = 7284,
  [SMALL_STATE(221)] = 7359,
  [SMALL_STATE(222)] = 7434,
  [SMALL_STATE(223)] = 7509,
  [SMALL_STATE(224)] = 7584,
  [SMALL_STATE(225)] = 7659,
  [SMALL_STATE(226)] = 7734,
  [SMALL_STATE(227)] = 7809,
  [SMALL_STATE(228)] = 7884,
  [SMALL_STATE(229)] = 7959,
  [SMALL_STATE(230)] = 8034,
  [SMALL_STATE(231)] = 8109,
  [SMALL_STATE(232)] = 8184,
  [SMALL_STATE(233)] = 8259,
  [SMALL_STATE(234)] = 8334,
  [SMALL_STATE(235)] = 8409,
  [SMALL_STATE(236)] = 8484,
  [SMALL_STATE(237)] = 8559,
  [SMALL_STATE(238)] = 8634,
  [SMALL_STATE(239)] = 8709,
  [SMALL_STATE(240)] = 8784,
  [SMALL_STATE(241)] = 8859,
  [SMALL_STATE(242)] = 8934,
  [SMALL_STATE(243)] = 9009,
  [SMALL_STATE(244)] = 9084,
  [SMALL_STATE(245)] = 9159,
  [SMALL_STATE(246)] = 9234,
  [SMALL_STATE(247)] = 9309,
  [SMALL_STATE(248)] = 9384,
  [SMALL_STATE(249)] = 9459,
  [SMALL_STATE(250)] = 9534,
  [SMALL_STATE(251)] = 9609,
  [SMALL_STATE(252)] = 9684,
  [SMALL_STATE(253)] = 9759,
  [SMALL_STATE(254)] = 9834,
  [SMALL_STATE(255)] = 9909,
  [SMALL_STATE(256)] = 9984,
  [SMALL_STATE(257)] = 10059,
  [SMALL_STATE(258)] = 10134,
  [SMALL_STATE(259)] = 10209,
  [SMALL_STATE(260)] = 10284,
  [SMALL_STATE(261)] = 10359,
  [SMALL_STATE(262)] = 10434,
  [SMALL_STATE(263)] = 10509,
  [SMALL_STATE(264)] = 10584,
  [SMALL_STATE(265)] = 10659,
  [SMALL_STATE(266)] = 10734,
  [SMALL_STATE(267)] = 10809,
  [SMALL_STATE(268)] = 10884,
  [SMALL_STATE(269)] = 10959,
  [SMALL_STATE(270)] = 10993,
  [SMALL_STATE(271)] = 11029,
  [SMALL_STATE(272)] = 11059,
  [SMALL_STATE(273)] = 11087,
  [SMALL_STATE(274)] = 11115,
  [SMALL_STATE(275)] = 11143,
  [SMALL_STATE(276)] = 11173,
  [SMALL_STATE(277)] = 11201,
  [SMALL_STATE(278)] = 11233,
  [SMALL_STATE(279)] = 11261,
  [SMALL_STATE(280)] = 11289,
  [SMALL_STATE(281)] = 11319,
  [SMALL_STATE(282)] = 11362,
  [SMALL_STATE(283)] = 11405,
  [SMALL_STATE(284)] = 11448,
  [SMALL_STATE(285)] = 11474,
  [SMALL_STATE(286)] = 11502,
  [SMALL_STATE(287)] = 11528,
  [SMALL_STATE(288)] = 11554,
  [SMALL_STATE(289)] = 11580,
  [SMALL_STATE(290)] = 11606,
  [SMALL_STATE(291)] = 11632,
  [SMALL_STATE(292)] = 11664,
  [SMALL_STATE(293)] = 11690,
  [SMALL_STATE(294)] = 11720,
  [SMALL_STATE(295)] = 11746,
  [SMALL_STATE(296)] = 11772,
  [SMALL_STATE(297)] = 11808,
  [SMALL_STATE(298)] = 11834,
  [SMALL_STATE(299)] = 11870,
  [SMALL_STATE(300)] = 11908,
  [SMALL_STATE(301)] = 11934,
  [SMALL_STATE(302)] = 11960,
  [SMALL_STATE(303)] = 11997,
  [SMALL_STATE(304)] = 12034,
  [SMALL_STATE(305)] = 12071,
  [SMALL_STATE(306)] = 12108,
  [SMALL_STATE(307)] = 12145,
  [SMALL_STATE(308)] = 12182,
  [SMALL_STATE(309)] = 12219,
  [SMALL_STATE(310)] = 12256,
  [SMALL_STATE(311)] = 12293,
  [SMALL_STATE(312)] = 12330,
  [SMALL_STATE(313)] = 12367,
  [SMALL_STATE(314)] = 12404,
  [SMALL_STATE(315)] = 12441,
  [SMALL_STATE(316)] = 12478,
  [SMALL_STATE(317)] = 12515,
  [SMALL_STATE(318)] = 12552,
  [SMALL_STATE(319)] = 12589,
  [SMALL_STATE(320)] = 12626,
  [SMALL_STATE(321)] = 12663,
  [SMALL_STATE(322)] = 12700,
  [SMALL_STATE(323)] = 12737,
  [SMALL_STATE(324)] = 12774,
  [SMALL_STATE(325)] = 12811,
  [SMALL_STATE(326)] = 12848,
  [SMALL_STATE(327)] = 12885,
  [SMALL_STATE(328)] = 12922,
  [SMALL_STATE(329)] = 12959,
  [SMALL_STATE(330)] = 12987,
  [SMALL_STATE(331)] = 13015,
  [SMALL_STATE(332)] = 13040,
  [SMALL_STATE(333)] = 13065,
  [SMALL_STATE(334)] = 13085,
  [SMALL_STATE(335)] = 13105,
  [SMALL_STATE(336)] = 13125,
  [SMALL_STATE(337)] = 13143,
  [SMALL_STATE(338)] = 13162,
  [SMALL_STATE(339)] = 13178,
  [SMALL_STATE(340)] = 13194,
  [SMALL_STATE(341)] = 13210,
  [SMALL_STATE(342)] = 13226,
  [SMALL_STATE(343)] = 13242,
  [SMALL_STATE(344)] = 13258,
  [SMALL_STATE(345)] = 13274,
  [SMALL_STATE(346)] = 13288,
  [SMALL_STATE(347)] = 13302,
  [SMALL_STATE(348)] = 13318,
  [SMALL_STATE(349)] = 13334,
  [SMALL_STATE(350)] = 13350,
  [SMALL_STATE(351)] = 13366,
  [SMALL_STATE(352)] = 13382,
  [SMALL_STATE(353)] = 13396,
  [SMALL_STATE(354)] = 13412,
  [SMALL_STATE(355)] = 13426,
  [SMALL_STATE(356)] = 13442,
  [SMALL_STATE(357)] = 13456,
  [SMALL_STATE(358)] = 13470,
  [SMALL_STATE(359)] = 13486,
  [SMALL_STATE(360)] = 13497,
  [SMALL_STATE(361)] = 13510,
  [SMALL_STATE(362)] = 13523,
  [SMALL_STATE(363)] = 13536,
  [SMALL_STATE(364)] = 13549,
  [SMALL_STATE(365)] = 13562,
  [SMALL_STATE(366)] = 13575,
  [SMALL_STATE(367)] = 13588,
  [SMALL_STATE(368)] = 13601,
  [SMALL_STATE(369)] = 13614,
  [SMALL_STATE(370)] = 13627,
  [SMALL_STATE(371)] = 13640,
  [SMALL_STATE(372)] = 13653,
  [SMALL_STATE(373)] = 13666,
  [SMALL_STATE(374)] = 13679,
  [SMALL_STATE(375)] = 13690,
  [SMALL_STATE(376)] = 13701,
  [SMALL_STATE(377)] = 13714,
  [SMALL_STATE(378)] = 13727,
  [SMALL_STATE(379)] = 13740,
  [SMALL_STATE(380)] = 13751,
  [SMALL_STATE(381)] = 13764,
  [SMALL_STATE(382)] = 13774,
  [SMALL_STATE(383)] = 13784,
  [SMALL_STATE(384)] = 13794,
  [SMALL_STATE(385)] = 13804,
  [SMALL_STATE(386)] = 13814,
  [SMALL_STATE(387)] = 13824,
  [SMALL_STATE(388)] = 13834,
  [SMALL_STATE(389)] = 13844,
  [SMALL_STATE(390)] = 13854,
  [SMALL_STATE(391)] = 13864,
  [SMALL_STATE(392)] = 13874,
  [SMALL_STATE(393)] = 13884,
  [SMALL_STATE(394)] = 13894,
  [SMALL_STATE(395)] = 13904,
  [SMALL_STATE(396)] = 13914,
  [SMALL_STATE(397)] = 13924,
  [SMALL_STATE(398)] = 13934,
  [SMALL_STATE(399)] = 13944,
  [SMALL_STATE(400)] = 13954,
  [SMALL_STATE(401)] = 13964,
  [SMALL_STATE(402)] = 13974,
  [SMALL_STATE(403)] = 13984,
  [SMALL_STATE(404)] = 13994,
  [SMALL_STATE(405)] = 14004,
  [SMALL_STATE(406)] = 14014,
  [SMALL_STATE(407)] = 14024,
  [SMALL_STATE(408)] = 14034,
  [SMALL_STATE(409)] = 14044,
  [SMALL_STATE(410)] = 14054,
  [SMALL_STATE(411)] = 14064,
  [SMALL_STATE(412)] = 14074,
  [SMALL_STATE(413)] = 14084,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(128),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [61] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [83] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [86] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(208),
  [89] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(399),
  [92] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [95] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [98] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(218),
  [101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(385),
  [104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(118),
  [110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(128),
  [113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(412),
  [116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(19),
  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(207),
  [128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(361),
  [131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(235),
  [134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(236),
  [137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(250),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(165),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(165),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(390),
  [155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(205),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(258),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(208),
  [187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(399),
  [190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0),
  [195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(370),
  [198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(218),
  [201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(385),
  [204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [207] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(118),
  [210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(128),
  [213] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(410),
  [216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(19),
  [219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(207),
  [222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(235),
  [225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(236),
  [228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(250),
  [234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(165),
  [237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(165),
  [240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(390),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(333),
  [269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(209),
  [272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8),
  [275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(205),
  [278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(254),
  [281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(258),
  [284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 0),
  [289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 0),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access, 1, 0, 0),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__access_property, 3, 0, 10),
  [313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__access_property, 3, 0, 10),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_access, 1, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_access, 1, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 1, 0, 0),
  [375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 1, 0, 0),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__access_index, 4, 0, 18),
  [383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__access_index, 4, 0, 18),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__access_call, 3, 0, 0),
  [395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__access_call, 3, 0, 0),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 6),
  [399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 6),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_call, 2, 0, 4),
  [403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_call, 2, 0, 4),
  [405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_value, 1, 0, 0),
  [415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__const_value, 1, 0, 0),
  [417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 1),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 1),
  [421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression_method, 3, 0, 11),
  [423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression_method, 3, 0, 11),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 12),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 12),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 13),
  [433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 13),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression_method, 6, 0, 27),
  [443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression_method, 6, 0, 27),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 7, 0, 29),
  [453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 7, 0, 29),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_expression, 2, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multiline_string, 4, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_multiline_string, 4, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 5),
  [465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 5),
  [467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_execute_statement, 2, 0, 0),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_execute_statement, 2, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_handler_statement, 4, 0, 0),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_handler_statement, 4, 0, 0),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 2),
  [483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 2),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_handler_statement, 4, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_remove_handler_statement, 4, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 3, 0, 9),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_statement, 3, 0, 9),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rise_error_statement, 2, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rise_error_statement, 2, 0, 0),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_definition_repeat1, 2, 0, 17),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_var_definition_repeat1, 2, 0, 17),
  [527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_definition_repeat1, 2, 0, 17), SHIFT_REPEAT(404),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_statement, 1, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_statement, 1, 0, 0),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_definition_repeat1, 2, 0, 3),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_var_definition_repeat1, 2, 0, 3),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 0),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_statement, 1, 0, 0),
  [554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_statement, 1, 0, 0),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 0),
  [560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 0),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 0),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 0),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, 0, 0),
  [578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_execute_statement, 4, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_execute_statement, 4, 0, 0),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 0),
  [596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 0),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_each_statement, 8, 0, 0),
  [608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_each_statement, 8, 0, 0),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 3, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 3, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 0),
  [626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_each_statement, 7, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_each_statement, 7, 0, 0),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_statement, 3, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label_statement, 3, 0, 0),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preprocessor, 2, 0, 0),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preprocessor, 2, 0, 0),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, 0, 0),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, 0, 0),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preprocessor, 4, 0, 0),
  [652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preprocessor, 4, 0, 0),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_statement, 2, 0, 0),
  [656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_statement, 2, 0, 0),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_statement, 2, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_statement, 2, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 0),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 0),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 8, 0, 0),
  [670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 4, 0, 9),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_statement, 4, 0, 9),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_execute_statement, 5, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_execute_statement, 5, 0, 0),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_each_statement, 9, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_each_statement, 9, 0, 0),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, 0, 0),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_statement, 4, 0, 0),
  [692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label_statement, 4, 0, 0),
  [694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 0),
  [696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 0),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_execute_statement, 3, 0, 0),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_execute_statement, 3, 0, 0),
  [702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, 0, 0),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 0),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 4, 0, 0),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 4, 0, 0),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rise_error_statement, 3, 0, 0),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rise_error_statement, 3, 0, 0),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preprocessor, 3, 0, 0),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preprocessor, 3, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 2),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 2),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add_handler_statement, 5, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add_handler_statement, 5, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_handler_statement, 5, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_remove_handler_statement, 5, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preprocessor, 1, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preprocessor, 1, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_statement, 3, 0, 8),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_statement, 3, 0, 8),
  [750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_statement, 2, 0, 3),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_statement, 2, 0, 3),
  [756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 2, 0, 3),
  [758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 2, 0, 3),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_statement, 4, 0, 8),
  [766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_statement, 4, 0, 8),
  [768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_statement, 3, 0, 3),
  [770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_statement, 3, 0, 3),
  [772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_procedure_definition_repeat1, 1, 0, 0),
  [774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_procedure_definition_repeat1, 1, 0, 0),
  [776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 3, 0, 8),
  [778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 3, 0, 8),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 3, 0, 7),
  [786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 3, 0, 7),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 4, 0, 16),
  [792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 4, 0, 16),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 3, 0, 3),
  [798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 3, 0, 3),
  [800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 6, 0, 21),
  [802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 6, 0, 21),
  [804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 5, 0, 16),
  [806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 5, 0, 16),
  [808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 1, 0, 0),
  [810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 1, 0, 0),
  [812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 7, 0, 26),
  [814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 7, 0, 26),
  [816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 26),
  [818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 26),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 22),
  [822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 22),
  [824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 4, 0, 15),
  [826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 4, 0, 15),
  [828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition, 1, 0, 0),
  [830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__definition, 1, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 5, 0, 22),
  [834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 5, 0, 22),
  [836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 21),
  [838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 21),
  [840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 6, 0, 26),
  [842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 6, 0, 26),
  [844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 22),
  [846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 22),
  [848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 15),
  [850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 15),
  [852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 26),
  [854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 26),
  [856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 5, 0, 21),
  [858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 5, 0, 21),
  [860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 6, 0, 22),
  [862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 6, 0, 22),
  [864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 21),
  [866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 21),
  [868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_definition, 5, 0, 15),
  [870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure_definition, 5, 0, 15),
  [872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 15),
  [874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 15),
  [876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 4, 0, 7),
  [878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 4, 0, 7),
  [880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 4, 0, 8),
  [882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_definition, 4, 0, 8),
  [884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 2, 0, 0),
  [886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [888] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 3, 0, 20),
  [890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 20),
  [892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 4, 0, 24),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 24),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 1, 0, 0),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_member, 1, 0, 0),
  [1020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(217),
  [1023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multiline_string_repeat1, 2, 0, 0),
  [1045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multiline_string_repeat1, 2, 0, 0), SHIFT_REPEAT(393),
  [1048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 14),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(206),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 25), SHIFT_REPEAT(340),
  [1070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 25),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 19),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 1, 0, 0),
  [1080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 1, 0, 0),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 23),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 20),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 28),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1142] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_comment, 2, 0, 0),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_bsl(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
    .name = "bsl",
    .reserved_words = &ts_reserved_words[0][0],
    .max_reserved_word_set_size = 45,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 6,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
